(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   3818051,      65276]
NotebookOptionsPosition[   3815908,      65201]
NotebookOutlinePosition[   3816577,      65227]
CellTagsIndexPosition[   3816443,      65221]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
Logistic Map Bifurcations  (by Iain Stewart)\
\>", "Subtitle",
 CellChangeTimes->{{3.563242902193676*^9, 3.5632429040467167`*^9}, {
  3.563243213616746*^9, 3.563243215837675*^9}, {3.563342200940592*^9, 
  3.563342208604192*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "NestList"}]], "Input",
 CellChangeTimes->{{3.563243257213798*^9, 3.563243258689966*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"NestList\\\", \\\"[\\\", \
RowBox[{StyleBox[\\\"f\\\", \\\"TI\\\"], \\\",\\\", StyleBox[\\\"expr\\\", \\\
\"TI\\\"], \\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) gives \
a list of the results of applying \\!\\(\\*StyleBox[\\\"f\\\", \\\"TI\\\"]\\) \
to \\!\\(\\*StyleBox[\\\"expr\\\", \\\"TI\\\"]\\) 0 through \
\\!\\(\\*StyleBox[\\\"n\\\", \\\"TI\\\"]\\) times. \"\>", "MSG"], 
  "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NestList"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.5632432624695253`*^9},
 CellTags->"Info3563225260-1052472"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Define", " ", "a", " ", "function", " ", "to", " ", "carryout", " ", "the",
    " ", "iterations", " ", "of", " ", "the", " ", "map", " ", "function", 
   " ", "f", "  ", "on", " ", "initial", " ", "value", " ", "x0", " ", "for", 
   " ", "parameter", " ", 
   RowBox[{"r", ".", "  ", "Iterate"}], " ", "nmax", " ", "time", " ", "and", 
   " ", "then", " ", "drop", " ", "nmin", " ", 
   RowBox[{"terms", "."}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.5633419204577913`*^9, 3.563341992783866*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fMaplist", "[", 
   RowBox[{"r_", ",", "x0_", ",", "nmin_", ",", "nmax_"}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"ylst", ",", "ylstd"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ylst", "=", 
      RowBox[{"NestList", "[", 
       RowBox[{
        RowBox[{"f", "[", "r", "]"}], ",", "x0", ",", "nmax"}], "]"}]}], ";", 
     " ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "make", " ", "a", " ", "list", " ", "by", " ", "iterating", " ", 
        RowBox[{
         RowBox[{"f", "[", "r", "]"}], "[", "x", "]"}]}], ",", " ", 
       RowBox[{
        RowBox[{"starting", " ", "on", " ", "x"}], "=", "x0"}], ",", " ", 
       RowBox[{"with", " ", "nmax", " ", "iterations"}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"ylstd", "=", 
      RowBox[{"Drop", "[", 
       RowBox[{"ylst", ",", "nmin"}], "]"}]}], ";", "   ", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{
       "get", " ", "rid", " ", "of", " ", "first", " ", "nmin", " ", 
        "points"}], ",", " ", 
       RowBox[{"x_", "0", " ", "to", " ", "x_", 
        RowBox[{"{", 
         RowBox[{"nmin", "-", "1"}], "}"}]}]}], " ", "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"r", ",", 
         RowBox[{"ylstd", "[", 
          RowBox[{"[", "i", "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", "ylstd", "]"}]}], "}"}]}], "]"}]}]}], "    ", 
   
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"output", " ", "a", " ", "list", " ", "of", " ", 
      RowBox[{"{", 
       RowBox[{"r", ",", "x_n"}], "}"}], " ", "pairs", " ", "for", " ", "n"}],
      "\[GreaterEqual]", "nmin"}], " ", "*)"}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.563243300049548*^9, 3.563243393699922*^9}, {
  3.563243624119957*^9, 3.5632436534998617`*^9}, {3.563244207318355*^9, 
  3.5632442276826143`*^9}, {3.56324425914048*^9, 3.563244319792617*^9}, {
  3.563245011362192*^9, 3.5632450198069677`*^9}, {3.563245222004655*^9, 
  3.563245336265456*^9}, {3.563245523469866*^9, 3.563245524279398*^9}, {
  3.5632455735392103`*^9, 3.5632455867236423`*^9}, {3.56324580145012*^9, 
  3.563245801702107*^9}, {3.563309961902673*^9, 3.563310008954763*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "same", " ", "thing", " ", "but", " ", "do", " ", "not", " ", "output", 
    " ", "list", " ", "with", " ", "the", " ", "r", " ", "value"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"fMaplistnor", "[", 
    RowBox[{"r_", ",", "x0_", ",", "nmin_", ",", "nmax_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ylst", ",", "ylstd"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ylst", "=", 
       RowBox[{"NestList", "[", 
        RowBox[{
         RowBox[{"f", "[", "r", "]"}], ",", "x0", ",", "nmax"}], "]"}]}], ";",
       " ", 
      RowBox[{"(*", " ", 
       RowBox[{
        RowBox[{
        "make", " ", "a", " ", "list", " ", "by", " ", "iterating", " ", 
         RowBox[{
          RowBox[{"f", "[", "r", "]"}], "[", "x", "]"}]}], ",", " ", 
        RowBox[{
         RowBox[{"starting", " ", "on", " ", "x"}], "=", "x0"}], ",", " ", 
        RowBox[{"with", " ", "nmax", " ", "iterations"}]}], " ", "*)"}], 
      "\[IndentingNewLine]", 
      RowBox[{"ylstd", "=", 
       RowBox[{"Drop", "[", 
        RowBox[{"ylst", ",", "nmin"}], "]"}]}]}]}], "   ", 
    RowBox[{"(*", " ", 
     RowBox[{
      RowBox[{
      "get", " ", "rid", " ", "of", " ", "first", " ", "nmin", " ", 
       "points"}], ",", " ", 
      RowBox[{"x_", "0", " ", "to", " ", "x_", 
       RowBox[{"{", 
        RowBox[{"nmin", "-", "1"}], "}"}]}]}], " ", "*)"}], 
    "\[IndentingNewLine]", "]"}]}]}]], "Input",
 CellChangeTimes->{{3.563313454947378*^9, 3.563313508296904*^9}, {
  3.5633419035965767`*^9, 3.563341909497678*^9}}],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Note", " ", "we", " ", "can", " ", "define", " ", "a", " ", "mapping", " ",
    "function", " ", 
   RowBox[{
    RowBox[{"f", "[", "r", "]"}], "[", "x", "]"}], " ", "without", " ", 
   "having", " ", "to", " ", "reinitialize", " ", "the", " ", "above", " ", 
   "fMaplist", " ", "and", " ", "fMaplistnor", " ", "commands"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.5633100939175577`*^9, 3.563310101818371*^9}, {
  3.563342016724229*^9, 3.5633420322324944`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Logistic", " ", "Map"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", "f", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "r_", "]"}], "[", "x_", "]"}], ":=", 
     RowBox[{"r", "*", "x", "*", 
      RowBox[{"(", 
       RowBox[{"1", "-", "x"}], ")"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.563245514977767*^9, 3.563245539591527*^9}, {
  3.563310022212122*^9, 3.563310082236281*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"f", "[", "3", "]"}], "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.563246010765545*^9, 3.563246022817032*^9}, {
  3.5633103254558363`*^9, 3.563310345941758*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxFxW0w03EcAPCNdZRrjMr9adxE5SlOUlKpuMhDneHk8nRCWk/InXR1WrdJ
nua6nZTnh5R2jGyuMnHsdDnPo1GzMUtj83RndnRZ9cL39+JzH0r8XWqiHg6H
C/7n/wGJypGu+fAz2xN8LFJkmLv39kcrS8paMV84cED8vhwLgyMStB3PsQR4
yuWpTwGWDlftvZydizFgumHroWcYG74SWc1dWa2DjXT0KD8rLmwXsqTsyePB
GYOe3iVrH2FzHkmKx3fCbXKf/qFT3XA3rdwyUi2ENQdPGzfe/gLrbXBMLO36
YA9dXFtoUz/cz3Af7HUYgq2LVBsNS8OwSiuTjruOwnUL7X3EQhFMJL9ZVijG
4Pwb/KQq22/w+lmOIjlLDKe7CXn7eiZgWZMwb4TyHf5NGyu1f/ADdjxnsJXU
LoH9aijXW8ylcAY51mYmSgY7qcONxMHTsJnxiqFwE03oLOUeKJuBb7q3T+4M
lMOci/FVn9fRGpWFyVzxLMwP9dNn+yrgLH9mJW8OTZkKmKhl/oRPHmewMbc5
OMpqaAMvQmv6CuQp9F9wCSEmnWqrhM2k/Bo9IXrHI3qYZ+o8jGuI4cpNF+C0
V9wC0250h2OOIemOCiYFpDk9IaphifOwKFOAbq7wtlXELMLRXA8SeQv9mFlN
l7xbghuV5FJi0DKcU86Mk15CJ1AX7ZpC0PsFgubgCHQu62pvfjw62ePl6q5M
tA1jj79BPXrrxMPd4rfoycXZ0XoOuiiiNfpCC1rnQL3HFKAlI6wKfRH6Q7b2
mmgczfaKta+dQAe+PsI7L0V/uj/wlT6PLnY+xgpRo1PlZWGUZfThoFuyrjU0
AT9WV6RFT/O9aHGbaAGt1sX1D/qFtZFGp0P/BaO4ekM=
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJwd2Hk4VO0bB3CKt0UJkVeblC1LC0qLfCuVkkIJpeilJJWytBBJWVJokwjZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 1}, {0., 0.9999999795918367}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.563246023355463*^9, {3.563310342404492*^9, 3.563310346345243*^9}, 
   3.563312801910316*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "output", " ", "a", " ", "few", " ", "values", " ", "to", " ", "make", 
     " ", "sure", " ", "everyting", " ", "is", " ", "working"}], ",", " ", 
    RowBox[{
    "here", " ", "we", " ", "use", " ", "whatever", " ", "the", " ", 
     "currently", " ", "defined", " ", "f", " ", "is"}]}], "  ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"fMaplist", "[", 
   RowBox[{"3.5", ",", ".1", ",", "2", ",", "5"}], "]"}], "   "}]], "Input",
 CellChangeTimes->{{3.563245340683481*^9, 3.563245365749074*^9}, {
  3.563245491669703*^9, 3.563245494094944*^9}, {3.563245805853332*^9, 
  3.563245806074345*^9}, {3.5633101153448963`*^9, 3.563310198241805*^9}, {
  3.563310363866222*^9, 3.5633103680225353`*^9}, {3.563342045435905*^9, 
  3.563342054425446*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3.5`", ",", "0.7552125000000001`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.5`", ",", "0.6470330294531249`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.5`", ",", "0.7993345088744278`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.5`", ",", "0.5613959812891678`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.563245360822414*^9, 3.563245370958303*^9}, 
   3.563245402717023*^9, {3.563245471425725*^9, 3.56324549962638*^9}, 
   3.5632455929603767`*^9, 3.563245806465139*^9, 3.563270357368527*^9, {
   3.563310138647696*^9, 3.563310148880229*^9}, 3.5633101995350523`*^9, 
   3.563312803431161*^9, 3.563312869698361*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"fMaplistnor", "[", 
   RowBox[{"3.5", ",", ".1", ",", "2", ",", "5"}], "]"}], "   "}]], "Input",
 CellChangeTimes->{{3.563313523135294*^9, 3.563313523348913*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.7552125000000001`", ",", "0.6470330294531249`", ",", 
   "0.7993345088744278`", ",", "0.5613959812891678`"}], "}"}]], "Output",
 CellChangeTimes->{3.563313523943256*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "ListPlot"}]], "Input",
 CellChangeTimes->{{3.563313324681239*^9, 3.563313328205221*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox["\<\"\\!\\(\\*RowBox[{\\\"ListPlot\\\", \\\"[\\\", RowBox[{\\\"{\\\
\", RowBox[{SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}], \\\"]\\\"}]\\) plots points corresponding to a list \
of values, assumed to correspond to \\!\\(\\*StyleBox[\\\"x\\\", \
\\\"TI\\\"]\\) coordinates 1, 2, \[Ellipsis]. \
\\n\\!\\(\\*RowBox[{\\\"ListPlot\\\", \\\"[\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], StyleBox[\\\"1\\\", \\\"TR\\\"]], \\\",\\\", \
SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"2\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"y\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]]}], \\\"}\\\"}], \\\",\\\", StyleBox[\\\"\
\[Ellipsis]\\\", \\\"TR\\\"]}], \\\"}\\\"}], \\\"]\\\"}]\\) plots a list of \
points with specified \\!\\(\\*StyleBox[\\\"x\\\", \\\"TI\\\"]\\) and \
\\!\\(\\*StyleBox[\\\"y\\\", \\\"TI\\\"]\\) coordinates. \\n\\!\\(\\*RowBox[{\
\\\"ListPlot\\\", \\\"[\\\", RowBox[{\\\"{\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"list\\\", \\\"TI\\\"], StyleBox[\\\"1\\\", \
\\\"TR\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"list\\\", \\\"TI\\\"], \
StyleBox[\\\"2\\\", \\\"TR\\\"]], \\\",\\\", StyleBox[\\\"\[Ellipsis]\\\", \\\
\"TR\\\"]}], \\\"}\\\"}], \\\"]\\\"}]\\) plots several lists of points. \"\>",
    "MSG"], "\[NonBreakingSpace]", 
  ButtonBox[
   StyleBox["\[RightSkeleton]", "SR"],
   Active->True,
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]}]], "Print", "PrintUsage",
 CellChangeTimes->{3.563313328870975*^9},
 CellTags->"Info3563295328-3925509"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Low", " ", "precision", " ", "plot"}], ",", " ", 
    RowBox[{
    "ie", " ", "use", " ", "a", " ", "lower", " ", "density", " ", "for", " ",
      "r", " ", "values", " ", "which", " ", "is", " ", "quicker"}]}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"fMaplist", "[", 
       RowBox[{"r", ",", ".1", ",", "300", ",", "600"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "3.4", ",", "4.0", ",", ".005"}], "}"}]}], "]"}], 
    ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", ".0005", "]"}]}], "}"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.563245056328314*^9, 3.563245135600391*^9}, 
   3.563245188769562*^9, {3.5632458102551613`*^9, 3.563245810486636*^9}, {
   3.5633102037167788`*^9, 3.563310262469665*^9}, {3.563310372833702*^9, 
   3.563310376564568*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHGYMDt8PZu+Ym3n17Zw/i/xR47fn9zB85/hyb/
HU1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH566AcA
VmthVQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG2XNcXF9hyO/AuLBBf/fOVPYyvULNVI/PGHTif
D01eCk1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcAfMfQTw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHuD6tE1rlzO/haZeWHMby2h/EN55X5shy5A+cH
osnLo8mP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1U8P
/QA83jIX
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzty7+LwXEcx/EPg4WBxU33LSmJUG4xCMO3zCirUgwGMju/ru6f0OUWu++g
fHfFYtfVZXTDdzm7kIH6PP8Cw3t69erZI1TvlBtupVTCpdRty7bx6ZS8hZrf
jPx7nPz9Tz7a58389/F3Ab1bPb1P4btjvc/gv9/1voG3Rnofw5t9vR/gDfgm
/Ar+BL8c6r0C/zrQuw+9BV9Er8IH0bPwOfQRvIH+Ap9B/4IPo1/Q39AX6BH0
I3oa3UaPov+hp9DX6DH0PXoSfYseR/8RL168ePHixYsXL168ePHixT+tvwIK
C4RB
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0M8rw3Ecx/Gv1S6+SY5zIFaimMMSw2y0lCwkmRhJJk2L5se2LCK7+LEZ
x8VpKVfi4CLkRiEHiTRC2kXW2hY1OVCv11/g8Dm9e/foeXi/CwZG220KSZLK
MiTpZ1oDx/Fiq2z0mbsC7qyo4Xd/Vqb8u6G7v70qhC6vJcAvLei+iyT4UhD9
5BD73H70vm3snYvozRHsNUPoW8vY633orynsw3b0dRf2I3PoMRn9zYGeP4y+
OYOuUaG3jaGfWtGDXvSHQvQcJ7q3Az17Gj1dgt4zjm5rQY970LXl6OYJ9I8m
9CLqlVr0NPXhRvQVN/pNBfr8JLrOhJ5H/UsleoR6TwP6uQt9UEf3TdF/6tFX
qV+oRu+mXm9Et1HfWoM+S73fgG6iPkp9iPpM6kup761F36F+ow5dRf0+9UfU
d1IvU5+k/ox6NfUK6tV69Gvqv8g/yU3kt+QR8gS5hfye/Io8Rm4nfyQ/IH8n
d5M/ke+JXvSiF73oRS960Yte9KIX/T/vvwH/uxun
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt09tPz3Ecx/FfByErpaYbh7LWLGRFdKIyp/T7dZTOIZWilm78LmyltRU1
tJTjz2QtmwtryzKGmS1arkrjgjLDz6QWkUZHY2N7vv4AV7/PzXefPffYPvt8
3l+f3NKkfHuDwbDGzmD4/S34sxZEpY/VT372GIr8u19qOJT6pKb/3/51kgU9
zXM9+tP4BnRj/QH0D96X0c0PQ9HDs8+iFzXkoDevu4Te7bsZfW1AI3rhrQz0
K8cuoh8/FY0e1kP/tj0V/dPwBfSYoK3oVlMT+pucFPSocnqfyO3o6W30bfXJ
6MUr6QNf7EAfmaDf6J+EPmA9j97vHoNeF3wOPdwzkedvp2912oU+m0t/IyKB
91tLb+6kj6imP9kUjx50mL4lNRb9zDX6rx70Psn0Xd30j27TF7fFoZuj6I0r
jOiBXfTm/fTTgfRjBfSjffQzvvSdfvQBFvq+Afrl4yZ012X05Y/pK6z093vp
TV70NVb6siH62g5690X0GTP0Ll/ob16ld3Clb3Rnb/5Gf/c0+4AzfZU3e944
vaWSvWQevcdq9rof9AVm9hNO9G7B7Bsm6MtL2d3m0M+NYK+cpM8qYh92oD8S
zV41Rd+Yxz5ffMs29php+sF97Jn29AM72d+Ld85hf2ZHfzCWPWuGvieTvVB8
ton9nviFGeye4ofjZD5n6e+ksT830C9OYA8T35HKfl38d/H54j/uYa8Q35bI
Xi3eKD5XfEiS/H/ie1LYY8W3iu8QXyI+VPyk+E7xfuJXid+UzN6r97eb3Vt8
mfhX+v7ivcRbxL8T3yDeTfwD8YPij4p3Fv9S/Ij4veKdxA+LHxWfIN5R51f8
mPgt4u3EO0ofFx8ifVa6i/Sf0v2lT0lfIn1C58/mbd7mbd7mbd7m/5v/Bbja
Z8c=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1GtMU2cYwPHWgDoMCUFHphKMxohRS9AYdSADxYlzy7gMFUSUFbkMjYAI
uop0ihCEUoGB3KtY8DI6RASEeYuGFEO9oUvmBg4kI1RGcES3KM5h/KDx/3zf
Nz+dvPnlf3Le95znzFTHB0WNUygUKqVC8fqa4GX3izFhko96WWjr+ml/er9Z
R+pLmsaSut+u/Xy74LX7Vefe9ZAjUfBPz4Sjj3W8A9e2q9G3NcfDozUq9BlW
M7wtWo8+T7kHPkM5Hn1ZzBX4xBkN6G9Z0uC76vob3/UfVrbCr2++jd417CD8
1hIL+h89GuGOQQPoT1qz4GXZTehtnevhhuFR9DZGHXyfxYg+7qIJfvalHVxb
fxi+ybcIvuL5afgHsz+Cx7gXwBeEH4Ivbj4Jz7DOgkcuL4R3GrRw++4a+KnW
+fDER0V8/urdcMuGarh1ZBHcvKYY/sf0RHjvVCM8oGsZPCW2hN/vtW1w3YfH
4QUNXvCJwaXwsYgYeIRPFTzk9Ar48JQy+IWOSPjd/GPwtdZV8L4G9p2/RcD7
x7GvzfODL11cDp+TtBn+IPcovP3SZ3AXA3ubvZvgE9zY/5fxOfz+U/bzft8I
z+0x8PxffAHv8qzg/0MXCl97lL1G9SVcmcI+cHcIvC6O/aCrP7yihn1D4QZ4
iTd727/Zl91gP6VrPdzfmf3LigD4oSH2Dr7s48Yq4dlzArm/8fRy8zr41QH6
gmL2Ts70xgj26p/p6ifsDSq6jz37zDZ63ydB8Gee9OHrwTyf8/TmVPYtfnRF
PvsBEz34DPuQQLpbJPtF1XTzffYfh9JNXuwdKuk/jbI3baE/d2HvWUxPc/oK
/mQr/Vdb9skF9KUq9qu/oa8aoefoxf296Z3b6dG99HU59Fn+9JZ4euFdelMW
vSqMPnUnfWU7XZ9J74mi2+2i21ym3zhI995Br0qmJzXTw9Lp05Ppj1Poy+vp
bgfEfGroyj302bX0JfvpAVr6Q9GPnqBv+47ulE4v/ZauN9LbtPSFmfSFGjEf
x+ieor+cRTeJPtEg3l8a/WY23WEvvaiCvlP0Gh39a9FPLqe7ir43l14j+tul
9Ef76BMO07tF31Ei5kv0f4neLpX+uFjMj+hb8ujuovcQ/XbRb8yn+4v+xBF6
gOh7RB8renfRe4h+TQE9VfR3iuhzRV8pep3oM0Q/TfS9oi8VvZ/o7UXv8j29
WvSOoreR+xe9SfRDhfR/hceLvlG4WfT/CM8RfavwOtGPCDeK/pLwctEPCb8g
+mvC00U/IPye6M3CE0TfL/yB6DuEh4u+T/ig6C3CQ0X/UM73+/59/z/0rwAL
5IlO
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1HlQE2cYx/GEcBjCFYiggoSIqFRQKqjlFlNLUh0FFA8KEkBFBTU1SjUY
BE9EKlBBtIpHRTwK0dYiVscKRCp3FEGkQwOoHGqhgpbIYex0Ou08v792dr7z
mX123/ddQfSWkLV6DAbDlclg/HNN5CkDO+SceaK2855FDq/8/7tP3ecbvlrS
+v99zPF9bwtJt1qWXBBJ+mnFXQ/qTy/Jk1F/e4XFEPUiw8pM6n3tDrhRf9Sy
9iD1LW7vR6l37TNMor47qt2FemG45wnqdU0SBu0DUU2bqE92uuVMOz95wSXq
jVmLWbR7t7VEUp+nY06F978iLKbeqLPRgHaZ3f2l1Id2XppMe31hYin1R2Ss
MbQXRISJqRe0nZtEe/Kh6dXUs37pZNOexAqbR71jSYcD7W9rUhuo95lxgAPz
Lcr+hHr30tV82luulrVQzyvvNaFdLtR8TP3aMxb2tKsddG3UW/pONqN9ntrS
hfrfJ762o52ZK+mkPnqpmzntkh7uVOq7GFpb2hubDF/C/qu3saC9vOvuJOrT
u/ngRZnGfdQPKdvAf+jR51OvcVk3gXa2NqWf+oxP07m0S4NqbakPqK8YT/sU
9+S31B8WCyxp91miP576z0K9wfepx2qpP/fXOfCV+/OsqU+9pxpHe4x18BD1
HAuuFe1dRWk82H8Hw8HPDvcbof6FTgp+WXCpJfWbolng3wf2jFKvaFSBT0vz
4FJftOGGDe29nJU66vPDODyYv05jTv3mNzLwD4/nfKD+Jzsx+L23SsyoD8n0
wudXXWTQbipNAh/cf9OU9mksNnhVWjaT9o2JheDtBlpNaOd4aaxpH9FK9Ghf
6tsIXjVqD36n6GfwxxO5LNrTsgbBB2rlHNr9ok+AF3VeBq+ezRtLu9mKXmPa
jZsV4LfudtWnfbDOFXyIqQx8ntk68PsFZ8AndgvBWyewwe/ZHwz+pD/TAPro
cvDlYiWb9rnV/uDZ70LBH06IBS/KjARfIncDP4l/Bvz5a9vBnzpmCz5mviN4
T7EGvHQoBfy75+1jaHd+YgM+7hHPkPbm7HTwg3OU4F+PmoL3eCUEv+tODviN
2/aA95UbgO/Ijgf//kIeePn34eANBDroc37IAG8hz4e+kOMD/nKlFrpYTwk+
IfIK9KQ2PvhxiwegF8ysBF+WcBW6LN0IPPtoL3RmtQa8bet16N8eHjCifbni
Bc6/eAB8zcUS6P3r28HHD3ZCXzmNBb2+7xZ0j9IH0KtfPoUuKeZCn6+6A/2B
lwr6KXE79KoF9tBrPEqhmx4pgb5KXwOdxXeG/jKoHPqanUXQt5m1Qh+jmAVd
7HgP+oSKfOg2Eb/h+TzqBX2kuALnD8iD3tX1BPqOjADo17j3od9WHcPvc74Z
ul9uIPQ/fCuheztn4fqmP8Zeuwj69IAq6N+EpEN/cbIJ+uyFwdD1BdXQTZxS
offUNEI3dg2Fvugp+sxD+6AvGYd+8sGV0GccqsH9G58C3UfxCLpV/BfQA8fX
Qr95OwnPn7YBetOrCOjFOejdN+yCfmMvehFPAt2JWQe9LVYOvZ2P/vP+KNz/
EejPFu6AXlT1ELrT1zHQDZTon7l+hd9vN/qG12ugz3yDftOz7dCH/dA/cVyH
52NGPfSJv26DvssI/bBLLPSEaPR31TLoWc0PoPdy10PXHUE/MrwVupsS/XfN
6KXF6BcK0SekoQ/dswF6/mP0Bflf4v8zDv2dsRvxfLxBr7RFPxSEXi8HvbmJ
GtfvghTXzxN9h14c9M0C9EH+6O2noL8Xhb7DHf1H3Vtwfh565XX0aiF6s5Po
pxuijxtGnxWMPmQV+pgh7Iq58dC3RmDPckC/qg+7dzz6H2Ox5/65GXrDc+xl
J9BnSLH7VaDPbcVuVYZ+1g7spWfRK5qw6z1DX5eEfVYK+jD1v/1vWejysA==

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1nlUjHscx/FRV5MUUdF2FZGrmUqXEGm5RZYmpA0tpppkLGOpSFHaS7cr
FC0IGUtKFFc1JaZVJo3MiEormlZqyoyl7vHHvffz/PWc33md9zm/83yf53d+
c71ZjgwZEolkOIlE+vmM7tvyaE70VCvOco7KhH6f5b/rUC328Rz7lv/Wd4bl
qD3gGoevOGnQ/nfGWL7sOPjN5eap+dCnBEcYi8ALu7YcVYU+U0JT/AGeHHB2
xQPodXqOaPWC+5MbFJWhr6K6Ur6DR6z3YRVBP3/1lGHsZxd3kBWht3Kt8PwG
LjzLtC2Ffq9Y/0EfeIPlyp3y0Hvt5GR/BbfTjikvhz4w6pxfP7gJx1dpMvQb
pid/k4JLZ1T2caHvO9xPHgB/fjGfLAN90cISOvaLc0J4VdBTlbPTsa9u0Fk3
Ac7vEAok4HlqTntrwc/zpukOgpcmudR8B68ryHLBvvqdR30duMc2ehr279mJ
EV/BVfyGO7+ArxrTkvLAdX0LyUPgaVrhByXgRnvKg7Ef3pP8+QV4BoW8F3uH
L/6nx8CXBc7WxN5Tjsbhg7Nqrauxz101+FYM7majyR0DN3h+2KMR3NF+ueYn
8Dd8LdoI+NqrE4exT0t71vQKPD7rBgN7bd9tXZ/B5TOUqdizXpeZCNHtrW9j
v13RO/0T+EAdu3cUXLBr/57X4J4y13qwN+aas4bAaz8a3MX+VHNeXBP4exWP
uZ/BLcNMvQbB9d1UgrGPmFBJfANeVjLshH3uiHDXAPiUiU477Mdejh55Cx60
qTkSe+327ph+8Ctqv2lhLxoOdGjG82NrZB72l7pdivvw/1oQMiwG746NmtEC
fjyAJsCey9tKwv7u7BM87EOedD/F3oB1VoL9ZZqhay/4Ds/mHOwbRYt9W8Hp
LWz1Yfy+1d1LReD3KGv+xD5c890Y9vlDfFPsu7eHmmCf+DjgIPYJGZah78Bz
5rltxj4tcsP9HvBo7iI37GXE8aPYy/GD/LEXOGdZYK/7cJE19kUFAp828IQq
xgns9a0PCT7ifHwsqdhrfZ9bgz2l3PUM9g5jzwOxd2Cu1MDevN5Frx3cv+NY
NvbMpY1zsO+pGyRjn6VnF4S9go60EPtptSUvPoDHxiyVjICrCe8/wX55loSL
fU3Zi1jsy1d8FGGftGOdXAd47qxMPvYyD/3XYs/gvW/BPmwb2xZ7pemy77Af
9xlSwH7EaCYfe7Kqx3HsBWYbRNi3Ln376j24rMyWKuwTSobysS/LPTWCvZ/S
nWvYTzDiOdgbZgrasJ81v+079qmLRoKwzyzJLsC+0CREoRPPF+Ptk9GPqq1z
wD76QFIO+rF5NibYh+1XVkLvKLVfhH3liyXZ6Jf0Yp2wT/lbRRX9RmoOGfuj
wsiL6A9rLgRgX28ToIne8GqWqBs8SpF1Hp1i9TQZ+4xGK130x8V2POyf7vyY
jK40sfYO9rr8mAXom8U/CrAPkW9PRJ/i4VuBvRHL0QB9o8xEJvb1dFocuvM8
x7fYx1bmGaG33leLw76uaX4Ueo68zSD2J3uv/45+lT0jEPsv9e7h6PmLGaQu
vD8pWC9DL2uv8sFeKbo/FJ2d2KmMfVhonBn6bLqSE/ZVcs+D0b2tO3SwLxZG
mhPmX12+BvsD6uIgwvkxHmmI/ZtxM0t040nlK7A31vcMQB936DXDPn3lPWt0
krSfSpjf0l8OoR/vWLwGe4rFkA26qjN1HvYdje0sdFrdwU3Yu5tJ16BPWsZQ
x37FjKF96C4VFW7YX+5qtEP/60f4dOz99hnsRTfytKRj/zUmcj26teYeMvZ0
fhITvdF01B/7timKG9F1m5RJ2MtGq+9GXzVXwsJ+g+SAPbqMKV2KflS/Yhc6
080tCL3r1AMaemyR/Qj67qtJfoT5ZswPRQ8uaHEg7M+5cgC9hRrIQPd3ZJ5E
r9cQbUKfbFHWg/5kZaAvOjffNAadQ2ndjH7tJaUbnRya6IP+By85gfD+fy3Z
gp4YJtuObi985I1+rzQuCf3i5yhH9GfsVS3oUi8JHV2Qq3cG/WWw+Vb00/F1
TeitO9YT+nNiZgr6VK8uQv91SY4AXdv09k70XQv9LqBv1wtxQr/JbHyJnhyi
QegLKdoZ6PwFk53RZ6avbkAPaE/xQu9de/Yiet71CELvWN3FQ3dZMofQ91D5
l9EtKsWEfmNEeR26t9c9T3QzpeYr6BGJ7i7o0qb6WvRmfwdCr3j5wTX0qL5i
Qm9rr1CD/oop9iDcX6iM6+jnOcquhP1V7q9C1025SuhF6QNsdPMqT0I/dEpS
gX7IwI3Qyx5xvIk+xrlO6LkW2Vz0WydUCX2fNPUWer/tB0If/2z/U8L+RoXu
P/0fkTj7XA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1Xk81Psex3Eiu5DiIBRH9uWgshtbUdYJZau4xppS1rGFbnFwDcKktOBi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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1Xk0FdoeB3BFuR0KnQxHw02nQkUZSrmhZHgZQp0kSSg3SkgIyVSRIspw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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Hk4FHgYB/CRWsqQzRVFxjHkTI4HOcIaahrkGErEqJXWEbHS6ciw0rXK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt00lIFAAUxvGpg0TqJGkulLSQmto0iiZTJjNuaUmYS2laUmmMK9oqGpSE
hhYulePSYhFoajbkboVIWRmTCgm2iCWJB0kNOoQFhdEh4f9u3ef0+A6/y/ve
W380O/rYUoVCoVqiUPydxrDP+XZGS91Q6fA954oZ7b9s0Fo3Zp4YW8ztNUX1
re+/LObGum6XiJmPi7lOPQjv6OAEb3ItgY/71gAfG2mCX5q3AX5i/jJ8y+Na
eNPIK3jbaXd4L58y+Mqgcvjw+gH46ddq+PH5cnir+YvwKV0v4WvO+MIXJl2B
L08pgF/z8wW82l0D35p/FT5XfRZ+YzK9ysEffizxGrxmRS581Oxz+LS0AHit
shI+wXQS3rOMXqvTwlffoI/wOQ5fGUwf2qmDN1ga4L+6ZMPnL6MfHQ+Ej0qh
by7Kgq//0A+/fCAI/k4z/Tv/TPhLHfTXC4Lh903SF/plwLtW01fZhsCfVlbB
F+nT4cfP0yuL6TO96Qv60+BTs+jjpujX7qGvCKQ3JdHnqELhVybT14ylwvvG
0B/R0+edov9eTG+xm36XgV53gT4mnL4viN74iH5zKb3DKvpfO+jPvaUfMYj+
ZvXwWRr6iDn65pv0GYP0w770+gX61Xfpp9rov3nT91jvhNc30D+po7+vprd3
on/TRN9dRv9JRe+wgb6whV55gf7EZvqt7vRNRvqFXPpIT/qpLfQHH9Jb5NBn
eNDH+9C3t9L3ptF3u9OP+9E/baM3pdC7Cd+yjb62nX70MH3XJvpJf/rgDtHf
IfoE4R8E0A8Jr06kXym8vZZ+eye99wH6MTd6lY6+TPiGOPoHwisDxf0Kn7mf
vkT4Z8JbdNGf3Cf+X/jIIHov4Y2x9PHC9wi/V3hH4cOEtwqmTxf+dgy9Rvg4
4QuE1wivEr5c+Arh56LpXYTvFv6W8A+FdxZ+QvhG4c8K7yj8D+FbhY8S3k7u
P4S+S/jtwtsIv074XuGdhFcK7yF8n/A2wlsJ7yt8v/C/o+gthdeYvdmbvdmb
vdn/h/8DbwLNoQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE75FpfB+7gdhA04X0SvuS1PYz/rGU7X7/YLTj/
VlW4o+yxV3D+PXve81G+9+B8TjT9fK2o+p+h6V+Gpp8ZTb8umv6PaPqL0fT/
M0bV74am/wea/iA0/X/Q9Aeg6f+Npt8ZTf8vNP1RaPr/oek3Q9P/E01/PJr+
/2j6DUftH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0eo/QDU
zZmz
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGHvmrE9B/idlhuGLqsbutrexi/SO1RRNjJm3D+
BuXtjPO3vYLzlVYYRuxfcA/OX4GmPxdN/3o0/epo+kftH7V/1P5R+0ftH7V/
1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7WfGPsBuHY/Wg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFnz4AAt8OEftWzi4+8tofx17b8lljQehPO91au
+aey8hWcf1hzq/HsV/fsR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+qnp34AZJEdhA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHXFxfYcl3ndnj2e/uzsEuv7WH8/2nnpu/xuAnn
b+i4NF9+7is4X3vBM9l5uvfh/Kdo+lnSUfVvRtMvi6Z/1P5R+0ftH7V/1P5R
+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+4mxHwBoNFp0
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEPq0TWuT/kdrBM0yt8d++1PYx/oMLIlk/wJpzf
/FYozmLSKzjfs5d7S2r2fTjfCk3/bjT9jWj6g9D0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj8x9gMA1BNvwA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGvA3fItb7mdqg6YRS3+NVrexj/sVOWdevdG3B+
0lwlO7OOV3D+N0amk4xL79uP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1U9P/QCoVhB9
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHfNGL6D33ldvAvvxDyse6VPYzP2JWcbnD7Ppxf
bTqrf+7X13C+tCJDb/LaG3C+D5p+ATT9VWj6FdH0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj8x9gMA7ypWPQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEQwONwJSgw2qfslT2M/971dJAd+wM4/1XSC6df
/1/D+U1HtijINdywH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP
6h/VP6qfnvoBuSZPHg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFc1xcX2HLxOMh5GAsb5r2yh/HzC0//Xi7/AM7/
6x+z9jznGzj/VNW2du/QG3C+NJr+MjT9f9D0n0fTP2r/qP2j9o/aP2r/qP2j
9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP3E2A8A14eNfg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEi69wfVonwOLy6XCXVl/bKHsY/lSTs88/sAZzf
y39ZXV/4DZxfpVXQM1PnBpz/Bk3/UTT9fWj6S9H0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj8x9gMAIFubnw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHyra8Dd8jxODDe+9cVGv/KHsa33iMrmOT7AM4P
W5/drybzBs6/1ygz8xjrDftR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+umpHwAmf9a2
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGaMf2HvmrwOFgsfC5QE/HKHsa/vjz1+9ukB3D+
NxsO/YMqb+B80RvfI+c+uG4/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VD899QMAXCXtvg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHGYMDj0GNW7/Uj8JU9jB+t3sK5o/wBnF+vXhvP
ofsGzu/OZ93/cc91+1H9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/
qP5R/aP66akfAJhtGLg=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG2XNcXF9jyOMxp/Bt2yPuVPYz/lXvXvkvdD+B8
bvujP5hN38D5mZm/782bdR3O34mmfwuafmE0/XZo+peg6X+Cpp8XTX8cmv4t
aPr3o+kXQtPvgqZ/BZr+W2j6+dD0R6Lp34Sm/8io/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/TSxHwDYCHSR
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1dtL02Ecx/F56KiZlZAiEpKiZevCTCU8tJzbKmUllrqa80AinRQ8bZ5K
dBKBZWikZJk2MFO3PFDomqEQZUcxSyIxZyYlq1wniLCii4TP5w/oalc/vhcv
3g/P73l4vNOy4g7ZCwQCoZ1A8PcrMxe66aXO25NFJyueRc9G/psN2tH+2MbJ
hbk/bpWuL8yyMJd3x2dpNWMLs68uD/yjBgv4V/Yu4OUNGeDd1pSCf6x+Cf6U
zhV8ZWoieKOqALyj/h14SRX2XxjSwTd3FYPvrRsHfyYY+0E9CvCDBWrweYEz
4Fumsa8YS8X9Gy0C33luAry3dSX4SwEHwZ/214Df1jQNfsQT/fKOFPDtUuyX
D78GH3MXfZO7Etdfh33L1TfgdRHoB+ZU4B0+FYI31U+Cb25FH6LH/vkJ7Ls4
Yv9KPHqzBvvLbmF/yN0MfmMd+g7nZPCuTug9GqfAl6Whf74Z+1016H9lYn99
FfpYGfZ9/dArVdgXH0Gf+xt9Wgn65ovYF1aitx5DPxGK3icE+w+z0Veb0cuz
0NcasT9Uht6gRe8kRn/PC/uyXPQ9T9Afz0BvfIp9hxPo9bXoPXejv7MC+8X5
6B8Moh9JQZ8/jv2oEvQ+l9GflaPXOWB/sgC9xIheqkRfNo19/2L063ToVXHo
RfPoB9TotTfp/x1AX/MefX4R3d8W9H7x6IN/oJdrqN+NvikJ/X0L+kXUF19H
L9mHvu07+lbqN3aiv52IfvgjelMhnZ829PPUd/6Gfor6h2+gD6C+xxz6auqb
2tFn70e/5Cv6xeSvGdA/TUA/S/0c8ooO9H3UV31B70U+gPq11M+2ok8lb6T+
DPV/fqb3g/xbPfpc6vdSP4G8lfp25E3U30K+h/pK8h+ov4f8WvKryV+gfij5
evJ7yS8lH0NeSN6LfCn5MPIV5CXkvcnvJB9O3pf8UfIR5NXkReQ3kZeSl5Hf
QD6dfCT5HPLh5LeSl5CPJS8kryAvIp9JPpS8iLyYfBL5QPJy8jvIp5MPJh9N
Pop8Mvkg8rts3uZt3uZt/r/6P3HlV60=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xk0lXkcx3FLEteS7YrIrmsLuZbcK9zKUpN9nERSncwoQhqFdG+2spdr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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk4FegeB/Bj6yASqmOpXLtuNFpkK2sS15J9pyMcOiHZokaGO7LNFYbG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFpYMDjIKH/Qj2x9pU9jO/qbvo0zfABnP9Ocf+y
8NQ3cL4dh+EHnq3X4HztirllbowI/ZurOR9O9H4I5+/1DxE/ZIbQX7g283fm
5uv2o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2k+K
/QBJuI0J
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEFtlzXFxfwOHzel704ZdorexjfvP0lU/jP+3B+
ne3K2YsK3sD59sURf1/XXYPzt79/sj3l3Us4n2nHJpYF1Q/h/M+tT7okjRD6
Gy7mlFtevQ7nv0ez3xPN/gY0+03Q7N+EZj8vmv0f0OyfgGb/NzT7NdHsr0ez
3wrN/i1o9nOi2f8Rzf5uNPtHw380/EfDfzT8R8N/NPxHw380/EfDfzT8R8N/
NPxHw380/EfDfzT8R8OfuPAHAPxduR4=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztz80rwwEcx/EfLspOWslhNClFWpJ5KiwHUxNtN6VFcZPMlIfDys1ByMnD
QZrD1p61tVFLKQ77RcSEA3Obdt5BTXLw0+dT/oPv6dvn8O3V2zg1Z58uVxSl
tUxRfu6qPjSUW9ENXDnirjX/R//vfthIdqSOX7W9XpU++FouaLsvbrY0OLLa
9vaqY863vLZtcWvd7WFO28bFa8Ok6e8/7Zto2So8ats9jH42jb5Hh34+jP5l
F/q7Z+g/udA3JNCvGEXf7UX/k/ozMfTtPei3J9HXu9GfD5NvQz8aQ3+Q+s1R
9Je60a8+RX9mAX3jCfqBEfRv/OjXkl9P/UXyS9SfIb8UQT9B/c4w+m3k71F/
iPz9FPrb5HfG0LdQvxpAv5H8d/LvybeSHyF/M4p+kfpNIfSbyT8n/4L8WfKP
yH8hv4b6d4LoN5F/R75K/jj5PvIT5FeS/xyUfumXfumXfumXfumXfumXfumX
fun/v/8bFGScnQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1ns0FHgbB3CzEpZZZlmkza2Ru0q2XKLVRfu+tss0LVuvtVvTrElLLtm2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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81Psax4csKVqEOjd70dRoU2Rf0mKrJp0YTRLZTnKNtBhrF2UtZWuQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN12k4lesaB3BjiJ2iwsK2iEqGnChkLAehDBm2sZUMbUPIMsVOhYwZknnM
PJXIsBFCSaRiR2ibhQwNyJQjZ7iu4//64no+/K7/up/7ftf9LsFLruft6Gho
aCRoaWj++z/5f39sqkn8djey+WdV/n9+TDN5mUZsbPtcQz9RG+8+v32mqL25
7xv3fvtsSGdnKSQAX3ufJTTtEHykt9YXLyr87hszT+Oj4UeY/3KJ4oNX+5Kt
4iYBf03g9OnFq/CxcU3vmJLgdzR3O9MIwpscmF+/dAC+4OupzQgPeO8HunPR
YfCr9rt8LvLA/+R14s2Qgb/UGrXK7Ab/tUVatDAbPs9bJjH2IPyOPsO+Z/vh
dY+ULDzyhvdlLVrk8IEfduS5ybMbniXVqDhQC35EP/GErCO8UFXa07UWePOg
oR5LWfjm9cst0d9Gt88ulX5U05vwgbzaXK2a8F4yUT3klZnts8LFKIv0QOR/
/EeWPbMp/I8ARsvoQ33b59SOwsEjjshvZ6ZN9PJDfpXcWP5iLPy5lK3wiJFe
9Edli2xRj/wVdreORrrx7bPtms3ZNRH4hIFHR0Lk+7fPmh9FW01nkK/aEyLx
KWl4+yyaXEIOjYDnoJPcL8aC+u90rhtUv0O+FheJVPEW9R/7+y/B5wrwY3d4
DNtbUP+vG98DFCuRz3/V1sYxeWT7/LuQQCk1Cb4rjeFKYhPq19FZmGgoRr7V
+W6Fz4dR/09y7y7JvfCLCzHOPcmof8vh2XFRjjnMZ4V5qFvX0PZZWtk6yY0w
f9ZSSaPUa6ifUnDStJcwf0YL2qpDmqjfyd3Irowwf0YGDjamTfBmudXFtCfg
e5mpOwqX0H8PoSnm8hvwOa5sGs468EKFXNJ8a6ifKYsnR/oG8luP8DkHmcEP
TJSkXBDA/efS0f/gs0d+aUT30kQQ8hn4zYs+3oX3cCii+Ezi/h+eKJCsfIr8
kuBdop4byKcZWgqTE4WX3CfcPHwI9y+lO9KYO4b8eLPJEsdGzB9jzpWTBlHw
q0dLiyLWke/aEkjd7EC+v9yMRfc48h+ca7k5LA3vdO6A9vRn1P9gt1PaaBvy
revq58kKmL8GNncuSjx8xPXna3PdyK8TK+DLqkS+qHnoWjAn5k/9he0j3V/h
o/rFZTltUH8P6TKzzAbyJehf7Ys+hfq9c+oWPgTCh5k1Dx+UITx/axZmrnPI
H+q1i7JKRf3fWvKsm/TgR8ZeOUsao37LJ6WX/G4if/ZvxQoDTfR/I2/TzDoR
3jDtw+nMF6hffCoqTaoU+bfu0KtdE0T9JOOarCYu+P487u+hwahfhD3ojMhO
PH+ZKbN1LGt4/iR15IJIf8C3XzpRRqWg/r1x003zdPj8VZxzeeyXCc9fcbm6
iTW84xWT46Lf4edGDqb46cOT/PlaF6pRf87Yyu2f4fCTdd/cJNnglT/X2Nn0
ov7UtcQChk7kiz+WYFVVgtdJGJ8rqcP9x/zxLt6/DPk0lDsXz5Vg/tx1EpS6
Cd9/pP1FbaGNuH8K/fK5mCLkU8w5/H3EcP/UxlM7lzjg7Zm1vX3u4/4F5Ngz
p/bi/rllghtHW3D/VaS6mGee8OZ6AZT2ANR/WPWEacc+fP4ZkyS3SkXUH/go
bfPdFfiXdv+581L4zilHjzVxwvffe4NgRWb46hjps4J+hPePsvWpMVvC+0+U
RHgfI7yMRrtU6EV41Yw/Da1s4NnmZIu/fYL3zZ4M69SGH39VFcL0HP23oJMJ
7gmFD3odmaXLDd8Ubs7IP4j7f+HNOybXgHzernI7bjX4Sr9rpAcp6L/DULxp
chbyvQL7mNUW0X8tOiGjuGR4Ccpnd+U69H+wICqOVID82vPGZm1S6P9ve2q4
rXbDc6krhTuWov+NxhnRmST0v9aycjwgH/3vofX+Tia8v/IfLxJgSET90Ztm
C95kfP6Peew9icKon6dLS1OJ8P54/WDQlnoEvOxnkUVNErw925PSe8fghU0O
yscT3h+3ijTC0zLh9RdKA34Iw2uuxPJYk+CpxWOWr70I+8dP4xDtdfh/Hqt/
W8MBf5Vp4Ga6Gnz0Pb38SSf4oaV93Lm18B+mMp6EHYOPFKIExmxgfu5ckAzc
uA6fTE6xWDWCvy7BKqyxif791hLKVkZFvqBKn6eeFXyZhIqX807MT1nExfKH
FoT3t5y+wP3pyHduO9zSQ9ifVJHBpKIVzE9TWvwUpR35Sreml82mkD93JGma
cgz+wOt7/L+sIH86ppY74hXyt6w7MjxEMb887Yv0cXHwLKFCbdbvkb9QkNAn
+ifyGVlknZl2YX7ZhJN1+smE9//pxRFDY8zv49wgQZNl5AcdXkoxuID9+diy
/Je7wfCs+vK6G8K4/wn5vDbeCeR/6I/X6HiI+j3c9qz86wzh+yd9Y8PMF/Ub
yw0/MYwl/H5ZS7+iy4/7bxQi58sTnt+Ko1o0SvWof8bVy0WlEPm7ewfi9SRR
/wb7eNbdPfAiZ3eOzRagfqex2yorXHh+f7ekslZX4PltbzBI6CP8fmQUS5j1
iyR8f5W8q3PnxefvohvZu3AU9Td4KS2fIfx+3OlYqVmVCp8g01L5RQj+UUnP
DL0A/HKwkmc+YX9ELotedQqEr2SRUiLvhy8UjxpZVIAvF252YXGB99cPcWh5
CM8UbfLVirA/OJ3HXqeywDurlnN0+cIrpZdP59vDr3s4BnfsgC9SOPXl8gX4
9gRJLQZbwv4Kl9MxmoSXPO/8duUMvIpP0gWVl+i//BPGlzyE/RHZYRJsywfv
JFitSBlG//NXP3or1yC/8LbvBwZ1+Hj2sNfkGMyf6kNzvdw05Hu6l6pNMiA/
Q/DwfAJh/oJMOfuPEvbHiiVZmoOwPybbwpwHCPujwOOVihFhf0xyBSumEPbH
LWUR9grC/gg5NS8oRNgfn5IKVfcS9kcIj1irNmF/rA7qcqYT9odhvfQbNcL+
qLLSqz1P2B9fzadz34TDU+luTzIT9sfzLfctQWn4o6opvK6E/RHS6enkdh9+
8Ke/t4MIfOiIS5wdD/zm7WplVsLvv1DaN16FfvA039kyaQn7o6H0bLO8Onws
p9CcG2F/dO4h0YrXw7PraZ8ckIZ3i26fureG/vEXs9tn+8OPzjtmGxrAX+vY
StDdQP82GvXDOX2Q/9JA5v2oBfy3Vc0GYw7MDy3bQGAWZVbl3ywEWpY=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81O0axiciRFEiJUskqWSrlC1ZjxRiWm0lu6LUEGUpS9mTpVdZylKW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41GsfxhGVLY10vIhS1jQdS8aSlEZZQkwppReJyDZn7GIOUoTKlrJG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k01V0fxc2pUNQtRYRCpihUGqg8hmvMkERXEo/MIUTIPEa8pkjkktlV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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k0lWsbxmVKZDp8kjlJW5kaJEXm6WCLBinkmKKEDJE+UkpoUkJIhBxJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk0lesbPaTBcE+XQoaUUhkyXTqGTF2J0A2ZpYyZ5yFDkSFCk1IZSkmm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41WkbxzFTJISxFI3sIktOojOyJFuyRXYdTSTZW6REOUh20WQZ2bMm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lWsXxnfIEGWWjCFKJyWzSqZTKJkipHYyZciYOVMoouIo21RRO7PM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlmk81H0Xxi1lKgopRNayjyKRLGmxL92S7VZZUsk0JMVtCWNJhBI9QiFZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41esaReYpM+2QOSrjwTFmpoOQCoWSpIwhSSHzkEKRTCVDCoeKyhRC
R2gfhzJHZBY2ypCDcu/94+61//K8z37Wetdav/d7v4+o80XrczRUVFSy1FRU
//u7Ju2Q1LTKqpvK2eRP92xO5//1UHGj3yrjILl2ZVmcPmQwT67ZVlQrnk72
kWufOXcFdwLwS23C8QSGYXJ9c9ZeIGMA+K+2Z8bykrrJ9Ym0sRU3/a/k2rh4
L7FTf5xcF40ndBIbwc9rwCJ2tuATuT4sMrelLgV+4enaCtmYfnI9dkPgqsgZ
4FmYE0huD4fg93THTrl84LfjZu/4tPWQ6zPvTFmSaWbJ9UrS0NbSw1H0N/MX
tiwCvtkxMdr+MfAhPE859i/AnyCXZONaO/AZ4deD/NOAD484+Lcjay+5FtJ4
Pl4rjf4Jeq6XBw8Bb3bc3WO9Gfjv4yqWntToz7ovYCEzHv2tZo3TjIvGyHXS
dVVCkTTwRtX2Te8Dkd+bQnYLP3vkZ3TDzTWvFvlF85VPFBcCX8kvZ81YjP66
GiP+R5bQX0hCuEC0DfoZ3rOR3DOAl5iSlZKjhv8+lUBPLzH4T/yVsNvOFnht
wQvE4kbgcwfnvU0I6D/F9yjyVwb6Rwcpai3Hwr9s97SGlhbwhJjYkEZW+Kc2
fue99wD8l/CFGb0o/Uyuw4rE+uv+Ab4oKSqi8B/M95HydMsGd/SXYuRNSSOh
/7PbWt8DfoJfY7JFst1lgFyr29QPtVXj98t+rlcXOjD/l+5Usn9VQv+yzZWj
FrrQvztb+QmzAfDt8wJKserQPxFhTb9dB7ydRh/TZXnkx621nLn9GPp9zUul
czyg3yrErWOXOfDKumlVZS+xHxJ3fEgv34H+pk0ZHq2B2A89b8/wf5oA3vIn
8SifBfJ7U94oH8uP/krq80X9WdgPPvZ7jbKCwa9MTyzQ4cR85tF7Sr6PBn/V
6l3Jeh/Ml8xBXk0RJ8zXq1BVCcXWL9gfto+GWSn0cb6euvXWGvr+kN2KySZA
33OHB01BqdDHI32luDUc+jKTjMKt1rBfoxzvjVaGgp+JQ5JeKAX67mWxh9/1
g75W5eb0qvvQd1bHlXlmFvgWDceemn3QN5Tfa0ZFBX2jpORz20ToKxhzOmt4
DPoCWg6wBo8ivyjtxJIjz8BPkopJnIikON+nkjWHBsDPcokj9sImzqciwYDp
ZyTwgy0/Dn2/Bn/ZS4avcs/BX5IlP4Pea/gbr6dZMpgCXlypvrTXCP62LnW5
cXChfwj7+4dcT+Dv+aTTFedL8HefztFktx78UQnG3Ze7Df7ag94aTSrQd0zM
k29AhyL/UN38MG74qxg5paDWDXz9Ua7YsafQZ/6lQi3GBvrsnFtehgtA3yCt
T5jaF+ibfyEZ9ooG5zuxOmqY6Tt+r6ky+bM0D/uh93NzfnAnfufvZ4pltgVe
zG3h3kc26JPb7xTYyQK866OGhKI04Is4hUnrkZhPuTROorQL8BvWqrSWcjjf
jE0Svxc2IZ8Tdtc8VKpHyLWHSW238irwBqa86t4LXZhH/9RM7b4ZnNeTLAQD
4Qly/cnOqySLGfroO8Oumttgf8xdlz1bNwp+fWeeKC0n5B/91cEyVBz588vU
echEIv8BrrKZkNvg17TUt4gvgn82/ysOcV7gzwiPKi75F/MReEjLT6AQ/kMV
t2VXBTG/xj7fys9S+NflS79gT4L/A83O/4b3wn+if7ttzR74b4gSbNdmgj6V
Sm6CiCP8WzC6+TmNgf/10Tffox3g3zpaYZFNFP49iy3aVOLgX9Dqb7rAW+Dv
4H+3mFIP/+ye5eoFfuAPe5CjOjUE/4qpz95YZcB/v+sxxVBd+GfZcXhjbhn4
wAFW9rVV+F+LmNo+PQT/78qDGTa54X/267SYBA/0fZzuenNPCv4dmM3UqD5T
7E+vDaq+IPjfsNUbS1KB//ZMrrxiR/j/IEqsKS4Fv8IiSUSYA/4PiRuKmRqB
nyunYjHhE+b/ngkP22FeivdRpeZmswj0jbipx58dAt79zvlJ11DoMz5pFD36
O8X+NPQW7bGDPsJAdZBNGcX5VB3deLmF8z2n91tvlw74I7XElQbXoW+z/6Cn
jDjFfuDMnuAbxP0flbBic5Vif8kMq1tcKIW++N9c2O8eh76SKwGa4QToa4jv
aP4wTPF+qRlu12KGvoawLYXUFfwuPKWdMXcX+2c4KMshkojfnWnOTWb5Aj82
cpNZlw/6DJfYa1o/432zS+TXW+to4GeJgeUj4/h+5isSPIFBwMdmVJiI/on5
rew0XDkSivmN8fRdjLuO+VUV9rZ4tgB8mjtHTS4Pxf1joCIm/Q3ze22qJ0Fk
FvlcGv3xblMd+mjN/XIenEf+QvPpjNt/gd9/WSKWjQH3q16boSkhEfmfyL91
sioX7y+zU0/05GWBN6uzExo7jXyGwgojmq3QX5WbtttlGfffkZKK677lwHt1
twUs+6I/u2iwqnwHxf58v/JDihv9JwjXvfmvAq9027UtoQr5BqSulznHIN+I
MyzBr72Q70BDgKvPEvCjEZybDszIV/BT6ojaLPIVfU73Qmwd+f7BXecTIgt/
Qo/Ze749Rr78MdcCBtrB7yi/d6qrC/w9NVtOdN7wl6/n/TV7Cv5yJ5kad9JQ
vK8c55P7zDC/jJsLpS7P0T/uLu3el9SYP9GbLV3aesB7HIsxo/2G81mza8Ml
fQ/wg9O7HdhI0O8tuzr7oJfi/jxKE7CWA/3dkqV2aYehn41aQdluP/KZqLDL
H/4I/uz5QDlzU5yvbq9vKdVMFN9/j+FFKTH4yxAovOqSQ3H/cJI0BW0o3gcm
PtpmdhTvp0DW/gof+EvxVI03G8f3n+OKqj2xC++DDSZrurFF4Es/lsdns8Gf
W3Cbr+c8vj/f6gGvsmX4o+HejAtUhL7x3LImYjLF/2fOppsiRIr/z814b6SO
g38iT/788hXk1yr52dnlA75/wsv5JOJO4CssFf6bMfJJWTiY4p6C/pMyr0s0
MpHP0rFypgY34IXEtaYW2JGPym3tV5PlyCdFn/GvIRqcj53yfHmNFO8HQ5Nr
ycpzuD+nCp+WMfUgn5vTEmHFYrg/STdIDKH00Mcpc2K2yx330+VMg9aH4xT7
zbWgS+c48km6QZumL4h81phj1AjJyL96LFc5Ogr8P2X49++cgX+O95FFPsHg
D10fpS4owH7IlL044xEM/7ciOx3co+HfssRmfYIEfOfcxzy9XdC3r73rldHK
jM5/AKt/kNo=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k01esaNiRSOzuZUhnKFJnnRDJEqEMSkgyXCNnNEU5UmiTrEIXKUGYZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1ms0FGgAxvEx0jKW1RLVYCZRiVlDqVXZZOkyaJtYrVsxjktEdqaW7MVl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN2Gk4FdwWB/BjekkUMqYMIQ00SCLkVXrMFJHhpRSFqGQqmVMpZZ5nyRyn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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41esWx7c5QxLa5jFTJzKeRMKRdoWMGcqUSsZskSFEl3BVKBIJRyLa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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81P0aHVrsS0qF7FJSCpVyi0k0pEgYIwlFlmyRrU2WVvdeXRSFJMko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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk0lQsbRXU1mSpCpkIZGpRMmSpDTmZJ3RxlzhxNwhEyHUqmyk0iyiyn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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81Psax0mHNiqZ7GVM6lbmythJRYRQk5RcOZU1UrZGja0a2Ys6lbXF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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHc81X0bPshKGZFSUVlHVlZGWRmRrKzScyiyShmpUxm9bTIiIyfzqaQQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4VQsXPpE5UalQZiFD5pQKGRJKySwUQi4y1UHDMQ8VEddcKaIuyY3v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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk41e0Wxg2hDk1kTL1JpBAikWG3qa280k7JtJOIDJ3KPFUUigYzvVKc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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k01O0fHSIkTEKRpagsoSIku1REEkqWorKXXSFjrSwp2xTCqOSVSBtv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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41esadY2ZSh5DlE6EDBshW4ZdSqaQeWwbkumYMxSOlOGaUjrJkFSi
HJzKUEiZokmktrGQa5szRqM2Off+cff6/bWf9XzPb73vWu/wfVvSI9jai5WF
hUXpXyws//sNofD0F4Xw6xV9j1D3ekHb/38ss2nu0K6CKSbuDTJkrWmeZGJ+
6Wx+JbVpJj4bFBHOWTvBxMfCb89uK//IxA87OGsa/hpl4s9NJbZCN+eY2Df8
p5ioWh8T83SJrcndnWFixdf8XydtR5g4UMJxxDtwnomVeUwDsn5H/iLBv8jh
1shfj+eGr6EhsE65zmqtMzC7jE+gzV7gl493O/84Afx807P2ZgFgUa8pCqMK
2HGa/XzyDfjDPWUcr+kFf+Rf084V2cGfaacHTkMK0HdF+SJJ9zydiS19v9o9
kYe+tMGbO8y4upk48kJD5f488EfR+qkr8+NMvN2SfETrNvh3bLcrpfrCv2Wr
ezZN/uBPOJBD7wiDf1Ny1hxsR6EvrSwvtkcTWLhxdWt7KLC5XB7NYRNwrXnp
dYNq4MB2x+zIq/CHJDtg6umP/IvNSluqTODPWV6jsFAt5L/nBTmGyx/+pC7U
fAvWQP6v7gR6hzR3MbG4mdjNXk/wX12jJrvbg7+gqdPvizz435rwRzhngF/+
a6nxuhz4GZcOrI7ywn8puT9d/74G/s6ZAX/1KfjPcBNl0O+A/4u3tmWWHfx/
VLP8bydC/8qmSU1OEfr3ZZW6Zx2hfw+9aZ6kGQDHl82ORxPqU+rY9zc3oT6d
xleebA0HtnjImBDhBxbIOtcz/5Aw3w+2GDEuE+qjJSuhGwF9FU9ruXLJ8C/p
wo7iREuCf9P3lVP3wD+d3QExIwbQJ9OZTLKgoj5e7IW5QaLgT/qyx3r7R/Bv
XqOpSAdgf9RfEB8a1x5Dva0OK8ZQsD863OmST/3fMXHyeW+94bZZJp4dJJPq
ZwaY2NiP1BBVhe+z/Dgqn3T0ol8X4q3oodBnJBB5P2YU9RPx/Ks51wn61vsN
KRljqF/9WAJ5Sy38nTjMy0LJhb9UNfNWsxDoH17NGlLWg34FLvv8n4cQn7Gp
ceC9BfzlubTB8gcF8Zvo1XHJ6fC3fNHn16ou+N2sC/bmFILfdiCLs60N/nIe
mznFFoD9XCgWMv25Ff7crU9X8PGGP07aYyJ3NJCfR7SL82QY8ps/L60Xr4b8
BqnK97W6kN8J52OSTqHIb8OKZNEeXeS3r2b95HMT8J9X+sCXcAj8u7Q5AuwO
gL89IymLKxL8e80FGcJK4Hd0+zx8tRn8p04nnIkqhP6MhagKWiv0m/4mvZiZ
Af1Gp/L3nc7B/bSPr9xAcQL5FZkZrc5k/oeJq3XC1myCkZ+0yKa391zQH/yq
GpXhxuiPGDUv580OBOzp1hO7D1i8XJxc7QNcvWZ93EgKOJv+coWaDRzLdrKx
j4Z+o4h1k08Q5i1MdilUjDBv+YuebxQI82bSFBfXR5i3cnHx3iTCvPmpFoim
EObNxvah8FPCvFn5NgkcnsW8NZ6pUS8izJttxa6EN+3opxX/S3o2hHmTSq0S
6hrDvG0UkBK2IcxbP7lRQGcCftofWNUPI+wztbP1Sz1Z0D/BLpG4HAb9rh8/
sYlpQf/v6jPOCeaI/62uTrFUB/024NrCTddH/OimcwtnfdFvhrJB+T93gP+l
1Rlvi37Cfb/9+BGNRPg7uWeHZDQn/PXND5BRPQ5/ROX0yMrZ/UzMunKNWuYD
f+OvN6zmfhvCPrq8sfgpCflx2TbV8n5FfuQFFdkr6cjvg+RR5ckNyI9mxt3t
mgT9+2RFSdH34b/v0MkwRQ/wX5P3e/DuHvwnrdE52NLhv4SxSu/AGPxfeH3n
PjcD5wEshV5XJHAuMqpJydgJf9LntehdvfBnOt7PI68J+i0ip3YdkRpkYlWq
4IhrC/y7sHmMURGM/nqsID9mrUO4rzT1ja55o75m5045DZOhT1GStbWhFv7V
af3QU3eFf8bGrA4Kx+Ffq8eBMmVx8K9nuo9sewD+LsvKGPWt4PejlSfruOE9
ofVKuOX7APhXVXQ9eQLwntAqHov/uhv6yws2zn8UHEZ/muTV29mB/6J2J6Nm
DfVhyzzkSemA/4+trk8mhMJ/9vb3z0dKEN908o/2hbeIH7H4ufTZM+h74m6S
pLoF/bHP+7dk9xDEz/0ktKrmgPisFSOdvw4ifpgHW6K6O/BBTutxbhXgdUbb
Zec4YKk22nPzb8jXolmbr/gDzrdJ9/HJ2eB8jI1186c+6FE6091BCYceFV/7
1Gw5+Bn4lNK2RIGflek6yeOEfdN3L4PeQIcetxzZlOuE961bZffSQB7i57bV
0WwCEN+F3NI9aoR+0ZWOtiwm9ONM3driOy/0y1JKXpqEJuLPmWjcpNSgH2+t
DL/ldwG/u8DnZVcv8KsKxZ4NFQW/wWja0MlH4F+YFXxSuQX8I1kBbA5B6MfU
3s1+HyfAf8vLw6fKDv4VKBXWRBjBP1sVGYmC6x+Y+NDJXeOLhuAvjbjb22uH
/JtPROc6CYI/Lrbp8sVl5P+acTvkoBv2QTIvS2K9PfaBEL29PUwO8366bvrX
Kzruox7NWJ0GBvLrLm3YKzDwnonbbV7tDHLG9yYSHx9zv8S+/WE2Hh13Bt9T
870L2aKwb1Xl4v7cLAx95CtSjxQT4d+zuVdPC79C39E0Rq+PBvwrGdRLUCHs
823H5IIlVsBv35H3a48S+DsXmjs9luGferHB4bw08FcuSeh28cE/9qhbLl1x
qH/y0bUb0Y2Y10a+zGMO7uCXz0jJEHtEeJ+s3WQczCL8f368u7qlm9DfrYmS
gUKIPzgvala9gPjuZbn6yZ6on6ZjFs3FFPUz9eOQ2qEK/yvX5Hj3VqJ+dY91
v+VMEfpr+UZSkzHeEwb6rLwqZ/E9T+QrktYnvM+S5N/eNBHC97KeB48+v435
jmwXSVI6Dv3iJaJ3ikqgP2Nn+ouJJML/3zoF74dz0N/WvI3/yxzOKVWC01RN
nMvM6lRzrMMf/7IbvzikUH9bmqTxiyjkt9OW66dhDup/+MXoOXHCfaHQ4jBO
I9wXBgUn5j0HCff5/goOkj/47xn0ZPerEv7/5DhOuWyE/pSWNK0eW/APmw3r
01jQXxITlrP1ndCnwmuluiEI+uYVvT0SyxF/SDDvUkUr4mcfTByj9qD/+Hb/
VjI+hffxy+YhyUzCfZGykCj90w7+XzD6JPD9AOKHzhWMzx4DNhO1/2M7CdhL
LDWR9N96/QNmHEG0
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41WsXNTTIUJLMmccMoUIJGbslwzV1kxuRKUPCyZRzEUp9mQ+RT1E3
U8lQN+pIhggRGY4o85iTIaQMuc/3x/db/jrPet5n7732Wnu/7/mJOV60cGZi
YGBQZGRg+N9vCHfhscFgjqPr6YuVZZZfdf6PuWdYmwc4PhA4sSEkPHpwnMA6
8iSDEcsxAu8QickO75sgsMd43ecpjxECq/AJNsccniKwlD///smpzwRe9rWK
ZT2D+iwmNumjA20ENmmh9ylWoL5B/Fy7AQX1J1w5vE1DUV9ATs9UQ2mUwFYF
VtnFTl8I/MjZXLuZfZDAFXZtVAdb1D/HXKq2PIL6K9O01+TXqL9JiB5tG4f6
pbOrVnrRG+o/S+5/LIT6DnqHZ0MCUV/E6rTip54BAtOmCyytnVH/SKCk/pUs
1G/o1lrYG4P6Z22706tmUf8qSaGpYxrnJJclpTzNjf5Ec8cyThK4zMw/qU4C
/rDNKgflh8MfJ0NhjqCATwROCL053ycMfqnWTbXNZu0EDjRaPnq2G/3/4OE6
cykQ+f8bPk16roj8510yDbmV+qBfSdeTAEfkdwu9qi9Xiv6n93SXV6WiPxEH
0vZTNPTXLzX2bS8v6jclxjlozkH/4w0GnRPu6H9e3YzsaTRM4Hu7uh4XaNMJ
vP7WUzDJq5vAe/cLUCw6wJ/Pf5BF82UPgatlzNtPFiI+2U6G/IreSeAt1LTj
r2Ph/6JUXdLsA/i/cinP54E3+g8afuW25Ir+tYTkuA+eRv9q1YH83/WAHyrk
33ByA05m95mVkwN+H/xrVDMJ+F5+k7tWP/TLSDhnUcy6YX+NjI65seDct4t2
bP449BN7FqCrexP6sW17/TGTBf0v7be733znI4FHAkdnWk1w7jkiHznHC30l
Z7IE9hZCXzceVV1aTC/qt2bLKE4gfndKC3tBageB/WOcPFtegt9bpcaK7oQh
AsfnVzCqlSH+3hrbcE0J/NkeESde4Ql/3vEl6YoswZ8oSneNmz38iXZN385U
B388zeyEj+RA3zBW6p97qdCv5NkN+kNd6KvQ496rm4X5/DatKHalA/xL/eep
OrbgL8VVm19OA3+uHAcBzZ/o/4zJH8Zty4iP6qNUNTMhfocXk1Y+M/gnn/xG
jZvH/uro82xeO4l4Zf67p15Hwt/EKN4vExyoL2SXkU4iw1/96eQnU3o413jA
ZZJiDX8b9CMr3zXA36c7038FLGB//DiHbxtXIj7LY4yiFgN/lJd5h0ct4c9S
lL/fFVXc3/VdBRr3zNGfXvg/Ff2ieL9m8q/TqbPw50dlNl1BA/7cZdgff2sL
+hdMGa935sf9VVIcJnP1Jvi/7L3zt6o+7sdG+82VX3eh/hhfbVV7AvR96v6g
QYgF+W1c9bJkeJD/sptCUUIs8udGkLfPqCK/ZkaRmAsn8p+ZY9PhzkH+ny/q
sg15kT+kWSIx8jv8K0yL2DNagPwrsyozbCnYL9F16TjjKehftvCJRzgK8xV3
n3KM8gT5b3bHn1V6jPnyaToeUZKD+GjB2CbDXV0Evm2eYT/zAP4lDDpO1nlj
vyKtksXtSOjvauvwhJ029ktu3LiaQw3+/bynkj0WCsz0QmPt6KYN9yN5woP8
HnjNWt01yB9+tzzh97lZiH0sys873/sOfryq5mNJawfftc706y3f+wlMFWju
7gsG38PP5MMUhMC3a/P1vH4+1JdrEmVfeQzspWUmr1sEPsNVtQ6cVuDTnM00
xEvG/cBd7s4ezQg+6zU5hWfnMf+D+WXUp6zgI75o0W3agPkYFmGLD9oH//QG
cp2TazAfEcpRNhofMR/Wv3Inou5hP2+LtqgIP4S/1hbMO4OF4G8V99cL+/LB
7x+fnHcj5+Bvj5fd84TL4MfQEuL0WQ169fRbHH68D/psU3I4HnR9g3+VlhOL
c9CrT1aidZy+YZ8PuJIUdXD+xk3bIGwVeg4F7zymowR/L5bx/8gKQL+rjoIX
4h5h3+wXTXNt5cA3n4ll82lO6FnB6kuKzUN+nxMrQ21dyC+S5DEW8xZ6PL6m
TqHzQI8D5r41DzbMj+ZbdknKHuixOOHexC2A/uxSBSiMj4Avy76veFWKfg9f
Fg0uNAWfSlpTjOt1zE96TVuW9wL8l263MLy8E/ubu1n6Wv0q/OWRHn7TJIT9
jyqOkXPd8P9JWEkrPeoY5qfyb4MwmhbiJSh2RTq+uP85mXLun+mC3u97/IbF
izBfarevlU7lI/6XmKlsEAPmi9yXzSKTDj2lauWjZWOgZ8qy/JcLvtCT7ORy
+rY59Ew5WN4bbgj91H106kTPA0vwrbV4KgMbjTJJHrkGXJ76Y0lwAXqnCrl7
BUzifMzZcbefIc4F5L6Ukubhx4Xt8kfoRzEfsRmFXmRn6GH1vd17Fzu+h2hD
ammZhzd8D2gYWLjl4D3bfEXhlowt8sc5OX857wu/M0OMp/U4oRf7QRFuszbc
F9XOU9FX+JHf9nlL5+8+mO/K9Rf8jLPIHzl3n8z6G/if7uhx+ess+JcxbJWq
Vgb/SIV5v6dHkX+qs/LjiQjw/66wNTFYC/kvZWxx3pcH/iJbo8wVGzFvh96k
PY+5hHm9leA69qkR8/LUUmNI3hD/FzQMePrO7UX/yylcHaRk9L9wTp/HWAX8
vpLtO2QHwO+byRVx1yjwc3jZK24nDH7thyK3hV9G/rTcctHsfswj1yS/gON5
5L84+enTHzmYx5el0qHMsZifNN7aLusJzM/DWwNxeqs4d/r62otNAue/szbW
Z0pCn5+/0t1Ce7CPqt3P40TewJ893hY5NA6899SDb76l1kG/3kmHKbOz0G+3
QuBn2iH0ZybLe1fGB/ol/MdGa1IL/Uk/KRQ8lQT9tmk/NCs6Af3saewu2+Kh
n30DVbbwC/hzpotvrZeBv4+EzNbpc+B3MfrZi8w/cR+tqte8PUlB/MiBhdSw
ccQvyUe4qEcg3kbgr0tkOu6TgNVTVtWC0Kd0vEdb9wa+R4srePvkPdBfaKv1
Be9Q+KcfevCAigf8UZUTzHKQBJ5dFN0pfAc4946zPqkN/jE/nQnzEIU+2nk9
PAv90KfRuHiPZzj6u8s84Ke6C/5uV0k6JXYe/c2diSjemkYj8A4/8YokX/TX
uaP1g1Y93resOKqKoxL6O961n9Q5B/+2GCWeLE/c8J5wGalKbAK/fio9SZCy
4XtJU2V3AAXz/0PF7FmHD/KXOLS+97CFfo8O9TO3mECfDzV6wfttNvw/Yn0Z
z/Yb8Ip4+EK/PbDx7n3KuerAr8qiio6EjOv8CywAke4=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0blS2Skq2ERqJURGVfEuqlJFmzh7IlFcqaFruKqVdeW4mI+LJV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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4FHoXHiIqblnS/bqXlJ1kz1IiRSK5rmUyGCKELFkTKkvWLCVRMtay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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k01WsXxw/3ZArpSCQhdcvsklmmFG4oQ+F2RCGpDKXMiTKPZQoRRYYy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4VWsbxqVQiiZNKEkq45YiURmOJIR2pIPyUZlS25w5ldmpzHNybFF8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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lVsbRm06yBQNiuSYUoaUuQxHGRJlKNIgbdpE4mRKlBKZM5eQCMcU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHpFOoSSpESKERIsyUVkrWVJUYmSnRSNEdFqsUZYQIluNpYww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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lWsbJSFRjqHRFA2GDCekDCFOOkSiiZIx0UdRpk/b1GTYpszaEZJM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHiSdUFqGrxIGx16IVJKlk0ylrJFdm0RFwpe1kxBGaiLapLJn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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lW0XPZLIkCFTpkSEKFMipSRTpOkoKbNCyJAxIvNUXkOESobqIL2G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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c41W8fllEyflmvkYPUSdlbsg6VkWxR6JR0UAhFFCIaskpWRTIzykik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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGvA3fItb7mdTix1Nn/k+xZexj/luTSiXwcT+H8
xPwHz4W+vYLzO4wMP0UdvA/nzz5aVSL0+i2c/wjNvOdo5gWhmXcVzby5aOaN
um/UfaPuG3XfqPtG3TfqvlH3jbpv1H2j7ht136j7Rt036r5R9426b9R9IPMA
97JuKg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k41V0Xh0mFkDFKRaYH5ejIlCS8KIpSKfOQWYZIRYTIkKHkSYaoTJll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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41esaxSadCuXKUGSKjDshug4yZDo4SlQ7c+FulCFTpgxlKPPcyViG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lO0bVZRIshSyryEqIZ8ogxIKbWiRGEv67BWjZM1SGQwhslRMCknl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41esa5ZCMSds8HHYokbIzpJFoMJN5uGVIqUwZmlA7RxxjMlyRkhPp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk8lV0X9WYeooSQ4RpKmePKS4UoKhIN4pplyFyRIlSSTKWBW6JC4c19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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bHWslIYmQeFXSQqKFMEKoiamIElkrIgYtUqnI9FqyhsaWikkN
yVLWFLIboWRPIUtFTCWh5b2+P77fmb9c53ou5zn3Ofd9P/P7x4lmfoyXRCKp
8JBI//u71jayckpZZAf/s0Nfi98M6v0f75ZnMd09xgi85+pHceEvHQRemZi3
ZEQX5+ddPT7v4O0isBvPoTKPIpwP7lRsjt/UTuB6O3O7QYvPBG6QnF7et7SP
wHca9pHNF33B/99mJpvGNxJYROPEvPRjHwhsKZHr3tUPvqpmB9eART0E/uXc
mu/mNU7g9DibxqsvWgksOCtq1ao2SmDyqhnxRP1hAufxa0f6Xf9IYM7Jdg1B
d/hla/8imlGHeq+OX+ahtbwh8PcAxeXZMtDXrpHxQXfnOwLrJ9Z7j6xCvWtz
aqI5tg0ENm/pS6krwX1nqUn+nnTcF3o47cmQA/Jhqko/CvyJ++J0a8mrIrrB
/1Kfj7Ybfkw388yRil8R2HC/VUb5NPxYVb7Z9swj+H0zVb67Nwb8MQ1+LsKV
vQTOrON996QL/AezDzC+6LwkcNbtbguzqiHka3l+65TuJwJbhfnTNzf1w995
g+2La8G3yvy49J2NzQT+IVZbY6yNvJ5uHx2ujUNeaVsqPy+0gn9rOMpdu7vg
H1NtgHTLHXnNd8hUEngLPRfne+/J139P4KLTFdtmlJDXaMPdrdb6yKvy0NIr
vpm47/Dv73l1Mbgv7lLVyq+LkZd6g7FPXjP8lGO/9O/0Qf+6LLxxr+o66g9d
lOqlKYr+nf0R/LI/boTAy6TaRqIdgf8W+Go1lwE/H90m5icNHOLMZLzURN5m
TZoH16jDT05Gi87KNPh5XueWE3sb6qvO8xJiTqK+nRK36Llv2wgctvDpLv1A
+GnafGGprhLyLZCImZPjgZ9RQhuM7m9jE9hZnERyL0X/CTCtf96kwy83D41O
faG3BKadp4cMD8Ovv95RVzyimgj8jWTg+tAD/ZeaLzWwJQf6Vp//e8UvH3nf
lg4fUJSBvl/2dAPjMeT98QZ/2d0F0JfAGxRpzLUfRfivtfcJYD9upJRmfirG
ebYKo5GljP1oHpB3v5iK+prIdw65bMJ+NErMHbcSgx79C1MdVE/sx9DJZCel
fdBzPVLlz/A0+AyGurxjorEPtnx7fSCYAr/ilpjryudhH4wPldkd+Yr+EJhj
n2grAb/FoNcbvWvgF06/YJoniDzeudpuN+HKQ0Hzd3YsA3mohRjYN3sjj0qO
5P1PLOQhKja0o7EceWzPXVHSLYX6K6Y5szeFUL9/tSnPOhnoMx/06D+pAr+P
hYUEiToiD74ENz2vPpxXNK7udTXFPvB5xR9/ph566iV4Z2+egp5R/o7IZkXo
0Qjv3NVxDv2R9KrJSKsB8yI7K9BR7ov7Ou9qX6flYh/0TOcksxRwPm6fM/8f
FvTmWlpams/ivGi8bppxF/OmZKe+fpkN9Pq4WMxdvoZ5m2abBtYNII/Hqkv4
D9UgD9/E0+ETwchjbNfDelI4+N5fFLSPWQg+N8cZPr75qH9viwUpuhd5WBTY
PlEJ48qj6hdlbwnX/Dp/7/P9iH2XtmJx9zcW9NW7t2ekm7UQeLdoVeDmEeyn
X8NbskvD0J9hPvvsrSKg3zRgYJxDh36z+2dcl8lBPyNuy4IIPuhfMaRCPyeF
/bNX6ccxDxb0K92Jr3ZhQH981ZxOQxrev11uOfGvX0N/rO641cMQvH/1Ou9N
KJ+gjzHAP5y1APr6+3hCV1AGCLxjk/DX3lDw3Wt1qnKUxf5fZ3HnbPRt7PPL
Us8n3KjAthyxNd/6gGXMth8I6oV/wf63qsRS4B87KtTV1B361itmrd+RD31n
1SStWzLR/7seUCbsZeHfiYzHEc096P8r4p+90kjwT5MutJdthP594VnSwWzr
JHBpb7mzKxPnN87q9BunYT/KHdUuEI+F/+75GYt8SuF/9RGlGu9O+KVUK5Ny
2gz+/1y9zy+QjfoKnSjaNeqoLzWt4pviKPoj4ORcoVkp+F4FvT+ztg6/P0SK
TonuD4KfmkylEAllvJdaNsl/DHeh/h75lOGBv9Av5VR288JR7GOqNsP9nTbu
O5z8oObZotcEthG/qrdZi+v36Ooa+saV4P8x5fKdtYprn/HW8ujdwP7g8RUs
LOLg/AxdY5NCB/aH3YFqCscffkSOxP47qgY/QjQEOjb8gT6S+zxePzvMS0fT
Bbm2ZuipUFvbn+6Jeul80pGO1/A+tKcVKlTPgs/ZrnLcJgx8GiZhLeYj4FMo
O3i6nOv7YaGD+UWGJN7HKWtdPReu7wdyVAptaxz2UezPld0iXN8Pqsv8J04N
gK+UxpZTEMI+SvKS1vCkcf2eMIwpqKzH/OmNhAov2or58fo7QPHfxvX9kNlQ
YJmEvIKOW6/23433oNXSZb/kIPLIF0hKVVfD+0PdHH8wrhB5PL5UltF/G/NH
ChyjCcuh3t6R2anr1Zi/5arJvT7fcd9mXoc6rf24L7iBeZcWg/lTl4romwzG
efGVDS0qpnifqNGpLpPj8Gsf2TE5qx79u0G2OGuFLfw6FZGklG2I3xMlHS6+
ronwS0RigJLjhXl8JtbeeDgL9S4L+sBSKUO984Ponv7LUO/TwKJkJV7ka8/5
IBO9FPkevz021bMJ9fAKZ0slmGAe5Pv6hz3bcD6TUu/3Jxj+35N8H7x9AnpM
hOziJ8Wh58+nnMuNylzfb2Ot64TXwv8+4RJVTgr8D5eg/j16C/etG5sZEWzC
fmNKyD4dYsHfn/2Tbz3I2G8Zrw/0xD6Dvw5zFzWKUrCPSpl+6Qpe6L+7svNe
fjBG/9UrfxS3FoA/M4ash4f0oSfBNWKLwxf0g2qxtbd6Ds775mrmv3OCXtH8
5alLvKB3YsNjkweXMN+S9ACdtBnofdRI7jVOxHyrP59Qk52AnqdnyWalFPBJ
VOsfzTTGfCcULpYOF4ffnjLsd3P7kH+rMMXIcgf4WMMbg3rnQf+YQV6exTb0
62RxOqdoA/TtuZmXxX8S+5a9ZLv3kivwj/zYMqHrGvJ8foHHrC2XK8/YE4Oy
1vBHhp4dFOKGeqi1qoX+yfAnd63s9MRv3H/rhn5LkiP82S3fTPFrRT1aM8IL
ak+CbzA5QpIWBb7+j+5HtH6Bryxhr6f6OfCRFXMqqG/BN+6xVdXEHnyXex7S
vnaCL8O5QkhQEH6bkKNFun/A7xCjkvrVCeCTP3LpuWEm+FQMpD676qB//z1C
tVHk6t+MZLbN1TT0rzSTUzjog/49rEyi5hvAf2XJk6EBIly/J20/MO5ojun9
B5C1rHg=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41AsXJnGnUpZkjbFLEYoyPpGUIqUFRUkmW2mxNCHXUiQhIaJ7s5Sr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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lXsXPRwiShEnoYwNxkzhyJDLNdxoMBTqIkqIpDIkhfhKphIqZMos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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3lYzGsbbiEt6iBEGhq0DFGpaD2ihZT2ObahFOo0lBqUc5ii5aiG6jvS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk0lQsbPaYyhYhjOoRQZMysojlTQvhcQyhTUUlSUVzDKSdDKJkyVFe6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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41HsbxkeTlC3bqTip5JTsRBKKHFISWbO1HFLEmAjZko4kqjOyTVJK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk0lH0bJkKE0l4kKspSYWSLUqQQZWypSMy89r3BV9lLeAtlyxKVUZIl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lG0bniZLCVGNrYVQlspbiRohyVD2bKVkmSipkKVQvGgXSr1ERRhM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lH0XJirUSJJoIUv1WYuUKEzZy5q9LKVQaZFSlpbXUmhQlkgoQ1OW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lWsb3YYMGU+SKVPIWNKpY6OiEo6SRBxE6pjiK4pMJyJkLlMlQ+hQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c41f0bPskoGYmQSF4jhFAqEhoyk51wrLKKkqKUzIooykhGRsdMixRO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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnk01G0bx60hyhqVeSp602IJYylli3KyZGmRNYpelFKRJbt3LFkKqaSn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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFLCmy5ri/mcyg/GxlqpfbAHsbv2n5fUWPxOzj/
+kbhtM1/DtuPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj6kfVj6of
VT+Q6gE1KInc
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHr3B9Wiazjc/g65cF0+WX37WH8KG7VMqW17+D8
WUl3M7TLD9uPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj6kfVj6of
VT+Q6gGeCpen
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1HlQlHUYwPFdtERL0VUQbBQZBgO8EmkVkVtuUEDXAxdC7jNFMU2pgBFB
cCCQTUorD0otUTzBFBZYCAUKEaSodQQV0yiVUDPNoWmmnN/3/eudZ+Yz33mf
54+fReTakBgDmUw2Uy6T/futmpLdH1w1xjXRJ9+i5dQ9l//neLV9h85c92Le
m2bz9TuO11/MmfsSzEWvuO47IPqkjiMdoh+3wBv90P6HXaJfcEBZIfrbc75A
v3yy/J7o8+87tYn+kMl49HVtnd2iD1plfFr0pZ1X0E+Xv9cv+r6LP7WIfoJV
/1TRd2gM9aJ3Wflqpei/a36EvvPOwruiN0pzvyT6Gfmt6K/8oOqa6DPbg8+J
/stdY+GnZRrfEX1ehmeT6PPMzsDXRA27LvptfkbnRX/B1Ar+bu/gbdHP2K1t
FH2Z5UH47JuyHtE7F0dfwL7t9vCmMhP0rXtKGkRvtUbD+5vq0M8dkVgt+mV6
V/hvhiX3iX7MiAqd6HO68uAre1f0ir5WZVcj+nATP/g1l+7eEn30aRn6pros
+AfXLqGf0tyC/h+vB8Nrhm9HPzJqS73olbvS4efNsbgh+quhblrR+xQvh8/R
OKB/Kn08+k1XN8H3TYxGf1LyHvTDq0Lh5SOGboo+4FBDneht7dPgv1q5G/2A
5B70R90Ogz9sewX9me656D9LSoX/aG8N+n/5GNeKPlYVAZ/cehz9oOer0A/z
Wwu/84Qe/T0XndB/ZBcJP3qzBv1f8pTsH06B968e5H3a1Oh37ouCHxeQib42
8jX0p8YnwytjXoJXl6ShP/VcNPytH1LhD5S8jH7L+iT4G/0KeJPm7ejrC2Pg
jeWx8EvLHsN3nU2E1/pMhi+qLoGPsI+FV9xXw7u9/St89zT2DR2s4EtTPoeP
O8m+/98q+O3je+F3VCXAGyyeDl/56SH4QUUc/N4jQfBP73TDG0azX/l4NnzK
zXL439Ts52kC4MOTOuF9LdkvyJ0Lf+bESfhSDftHNvrCZykvwx8biIc/tUgJ
HxhxFn54HfutY7257/NW9lvYHxU2n/vanYP3vMF+qqMnfH52M3zRMfYH/3SA
L1x9Hl77jH19hwd86v6L8F6l7H9s5whvO6wa3sOIPqHWHf6zWU3wb+TQ11ku
hO/wroGfN4Ve/bsb/FbFt/BmW+gz9ewXuGrhy20k+/qzf3p+I7xiHf3IRCf4
iUPsb7Cjb2xzhR8qaoCPiqdP72LfrKgWfrYDfdU69kcq2M+IpC+2cYZ/KKuD
VznTj7Zm375CB/88jN4lgf3y5ez7uNMHPXCBt45hPzeU/pVP2A8vZX+JJ72m
kf2D09nvWUG/Q8v+j83sH/Cmbypjf/NQPd9/Fb2Vnn31APtxvvTf57PffY39
wGX0zwbYrx9DX+9Hf3Qz+6YN9JOX0lcb0IdY0bf608sT6VdV0L8ZQp9rRJ+v
pN8dQH85nN5rP31WMH2cGf1VD8n/BNJPWk5foKF/EkRvYEGvWExfLumnL6Ev
20lfIOn/PI1+QEU/arHk/fSjr8mmd5L0Q6bTP15NHyzpr/ei35JBP7SE/sIs
yT0j6HMk/U0e9BvT6dslfa859E+i6I9L+h5u9O+/S39U0g+aS18ZS98m6We4
0Jtvov9Q0tfb07fG09+R9M2d6RdtpN8q6Q9X0ocm0j+V9C2c6O9toE+S9Psk
/R1J9CMlPnAhfft6+rckvnAefUoy/QSJP+lIL5f0Vf/5fwByPRP7
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGHvmrE9B/icyhp9umQ23bYHsZfeaC4fC77Azh/
9p6UlI5D7+B828M2Ibmhh+D8B/NEvm0zugfnC6Rrtk1fiVA/av6o+aPmj5o/
av6o+aPmj5o/av6o+aPmj5o/av6o+aPmj5o/av6o+dQwHwAMzjDW
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnk01nkbxhGTEhEp5LEkJhlRlhZLliyFbI0eWZMY8kQLylCRl5KlIkTZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xk01HsDx/GJp6GRSGR9wmCUlC0pNbfJcpVlqimVCNGUNUuo3Jps1USy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lV0bNUTGKCIiTmaVIxVljkqIqDdDg4gMkVTUe5B59oVEUslQGVNm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lQsXNdyuKRxcqhsuccucpEHRUXSVMVNE+GigEI2KkCjjkZOZjBlu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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lXsXPYZycVSijqmOuonohqhMUcbki1DGlESZmsziEiLiUrof5RqS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk01W0XlQZDQpSxECIl5ZrKlFL68hqKSJrwkgqVihRCSpmFG5fUVaje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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41F0fxu0aa2RJxSvEINEiEkVoYqLlQclWlpIl61O98aQpqawl4UEk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnc8lv0X5iEi2aMyUk9PGSUtJFnZFUIlq6woIYqsSER6e6xXpGUm+7Ui
K5WVFJK9Z3psCklv3s/vj999+ev+XJ/73Pf3nOu6zvmebVbOBrYkOjq6PfR0
dP978mZrDnrxciiXPjn2jCXjm9L/seQC26riwiiB/ziEnZWpHifwHhPq+J7V
AQI3fNMwil2YJnBwREfITZ0KAsuaNz+Ryeoi8LCoyRkdOcR3LckO1W79QGB5
q7Hchn0jBP53b9fY87lJAtMPfL5j5NVKYCcfbk25VxMEnqIT+GXU2EPgJkZN
evtqnHdBfN55g/k7AhtrOLjmUvsIzMWp0C3HOENg1qMMGm/iywm83B1ZJOTa
SWD+omejuTVTBD41t/KQn7eJwILS06nNVmMENti1dXTh+hq+x/Xlsmy/EnhL
h7FEhBD43li2eqckfYjAY4zT+x1lUc/Or+eyXkqCP6d0qclUOfB3V4QW8nwc
/C0unlY9ngL+eitZDLhbwJ+WIJc4nzT4c+i1fByWhPPYdbl9nZSrCCyhuvdo
fij8ULV5ILmZFfyRfvAmbhgoIzDHR17Kq8EOAtu/LVGouQf+Jk+R31MTPhM4
r2eVptAEvlInW9iOp8CfOb2F6Z4HkX9dmxMpM7OfwJvUyrel8iCfvEHKuvje
UgJfjvw0byqCfEabLL1a9yEf0mmxxR9DXwicu/spi3E89CkPP1D+3WKQwDaT
AjFcXeBL0GKd8acDbwn8W/3I09JJ8Dui//eJ1Q+It8j5rlbDBn/GU3ykREXg
z6YrGuLffyK+qJRJhYf2msAMidVu0bbot4XIKosQUcRbvWu8WXOxHvX3VHbF
jMMvv24x+ihT4BeltsCCwLP4X8cq6USJIP43GcJcUZiK/w2FU87xc0CfHspn
IfZl6KPp9MLV2KSbwOvUQ35nX8H/zINch5Y0agksUKojSfGD/xNmh+MrDBD/
oCo/iiX3PfxoEp/JaDpM4IGstoLgQuhpY/nwy4of+jP1aUj/qzr053aD09W2
RcDC5JzF4U7gwPeU2byHwHPFd3YtcsOfZefD9U0l1vR725sTRR14HyBdlCkc
BX6YarvpVE6CH5mG57tVKfDvvV0BcQ3s8K+pyURjuAP6aWQi1vdbCPxLapvI
G7dGve7uArS0uGbw/cSWQz6FhveROu5JNeArL2iZ3+Qcvi9rdllWGcH32QmG
r8178f2NfZ0J9Gr4PrRAXZG5Dt/XD2XReTKC75FHK4n5huBHX17K/2cY+GmV
Cpzr3YN5WMY0l1zrgn5j3m36hKsN/Zb409Q6JwN+KP30tab8YyWBt6ZKFPiq
YD4NFExucuVeM985nG/w04NPgb0hG7UPg8/HFBf9BEXUo/JNt7IhHPPA0/fn
PrI18vtnXXvj5hXk5zHnKhT8CPnZzHIyF77B/KTy1TNbDiM/AbIR8+IK4guZ
7UPcI9DfXs/4/0ztQD9a3/zqw8aKeM8S8XcWjz4S+FD/LeuESPgtijzeeUwP
fstZPHRTdgv8ZmqVpCu3xm/DYnv2l/uAH3/Wi9qD0eAn+pRPavWlNX7TNzMN
9YRfTgVoJwgFwy8yM3NlvByYN1eFqR0uvPjelq9gy/VnLfBDoOHihp3Id9yd
ev33L+Rb1/9d2IsX+eZnqD+KrcZ8D7Qyj9vEhnx3ul8JZRfHecIstpVbBXFe
oS6nhXod9BySWJcd+gP6PKX41wqvmb/fH1+J0qfHvpPlGFTsfAP6jOo6dETs
RLzZ/h3iUzyYl1F9l/rOl4GPZ8E6mZdMMX9nZJpUtPmwbygtx7wtj0f+LTrD
ComcuC+5GV82nNVDPxm68+xVzkM/cf+klrYnQg+pFa3usAb0b9kXmwp2A/x/
ozDVyJcHfue7FkrOIYGf532Rwt9pmM8msR88Y9hQr5c7/Z/sG/DjNdNa5UU/
+DE3w+6CmT30lRwWv1cXhvuO5UF/vd2afezgcu86u8fYxxak6u+LOIGfw1qT
JVuqkb9xj+N8sQjmDxPDcV0BR8yfkkitFl8r8KX9b8V9p7/A1y7bjCbFQfC1
i8Qj+lIefE07RhubNeG8GQd/r4yURvB1x43vNRnndeZs/3VgBOdZdhyZuuAN
Pj7Kexd7OIEPh5t28l8dwQerlNxNPXrw4eucxJ6yAD5WSFWqF3LBh5srbb1N
P/I73DKgGt3TgHzOpOsbVqDebZ73S29RUS9rx1ChBh38mXfr4u3p7fgfr704
u4Iq+mfCObnfcBT+WC/yaio/Hf2T09ookcaE/PUMqUkx55C/ngPP/IQC8o9S
pL+0Pxfn9dAOzHskQc982bPdi+PgN+4WMy+DB3D7SKpohS74ficoInM9H/Vy
thW/GopHvT28S0nkL9DXL203++eTON+heZ6bJoV++Et3Z6rgJtRbca62Mv0l
+iGjdouJtjT6odJD++qBUOzrPXX+SuNXwW+xz7vNPv+g/53S42a4+dtx3xb1
JApl4P2Zo2cT/kjjfbJLcG5MMd53XFW7/7K9DfPcV6Vp7C7ea1X/bWBIwnzU
KMsmG+1AvT6mjSIGh6FvF8vIxqU+1JsmJKUVWAp9+7V4pj8xQN8hBYbNM5nQ
12rZW+ygN/Ttp+nZnPyA8+YlupyGltA/rC9Gyy8fh56xZDv7rGfQc9t7GSVp
DuhJtt4/ZhaH/GbY6R95W+I+VnTkETvcCT0GO8IZV5WwnztyUg03/MF+vn4w
039fA+ILHJketPYhnitIm2m6txf5yFLUROfW3PfDbiSbj7gfjNwO6mqzYf8N
aIqdnz2NeKG2iHuPArHPPqaz4bquDD96OE7NttWDr5Nn+nfrDIMvMeaY5zYq
4MvP/KmhVQ74yqZVVv2iYd4EHin3uNYKvkKrLNWiW6CnGrmXzLaK/HYMXo2P
kcU+Qr0redJiCHpG8vqz984hv4vmrGWsw58IXLTAWrWiBL2W+lR1Xc7g/GJ1
tmVWQfQP5YD7wex7OF/aQvw4KaGawCl1nZ82uUHfZJa9y+7NiA/j5x+7kAC9
uq35DNKCoVet9+3X3KOIv/Y2PqQ16g30PxYffJUFfvjx4yujy5p9rjBI+PzM
W+xzmx1uZ0iNgL+Yvs+xdWv2OYE7S6kB0eDPjMFxLE0M+0J4ZVvX+Q2IX5Us
v6JzF/en/IvQzG93od+8HPXHeTPcF2VNtUc2NuO+CGivTc5gQT9WeUXsKKRH
P1YXMisyraD/Q8Q16RIfQD9rBlXL9SbYL7xJnd5KEfDTG1ah2UOS0NM/pWpj
pRv0dP8m7bBYD31WFu38KDmo73Jh5kNpKvZ1zW6XbRX84O/DiaOcCmv2u996
NPX8j9jvBoJMG3y5OpT+A4WpFR8=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41VsbNZQphHvkVCi5ZAjXlAxxqAxdkTI0fzmGTpGhFCoRqXiSZLxk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4VW0bDRkzRkRKhiMiw6dEgyknit4iY6WUfJQXJSVTScYMTeYpU6cS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41F0bHpG9bFFKZKkoUmRpkcoSklQIRdJIskypEQYRWUKokC2iCJF3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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbngghyyljqZMopVJOlgw5Y9/qpCwtasgSRVrsbSiGhIhE2Vos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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41WsXPSnDNU/pcypFGUJUKorMY2QKqVylMlxSNyljpJQp00UoogGH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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k8lGsbth1CyCkqhaKFIimOkDOGCjnKEh1GZEpI1hI+dSrLOTFkyaSk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHiInLUKoZFeRrRkiKansS8KJmphKVITCSUIRxamTtRSh5KSE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lfsa3caGY+iUDLWRJAodJMrJEMp0uSIhor0zNohwlPGUIXYTSjKT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHc81W0fPomMtJBxkKwoq6fSKatOZiijx2giq0EdGZmPESqVSGlQlIqM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk0lQsbPWUqyZQhItQJuUi6cpQp11RSUkQSSUrGhGQ8EimUIVGsBg10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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVmk4lWsblUpKiArh08CRWUQlTpsyhQzHR6WkSHYyh5BikwwVxREhMmSm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbxjitnHxOkmxZskdCQllStowkkrIvKWsl2yEpY8+aRJI1STKh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k41HsbRqqTLE1EkUFJhZSQNZGUFHptlWzZoiZElmh0OohJKPtWQqEp
SUPR0SAktCAhjETKKPsWJzrX+fD+7/HFdV/zzPO772cfGScvc1ceLi6ubdxc
XP/9T0v9709IL3b+ioHGcNee/+PXt2ZPhYuOEthHlvIq7/ffBD6aoSo7mtlB
4Ib94RZ934cJrJIZd8685C2BTdbFfMvi/0bgnvitbOMANr7vd6lyzdUvBNau
4Q32EYS/Q5sW9gRIfiBwwKGF66nj3wlMHoiyCP8H/HfKD4eIiYP/Nnv5ANVE
8L/YFqqUYwL+XaZb7dJr8R6zpP+ejWMTgS3dlZdrkwYJ7EZLqF12A3qkBn7s
94rE5+U0zfU1GV8JfDVv8sWYyhCBM0opaqsr+whs7K+QE08fIXBd+/rYfOUa
xH87NSOnsZfAOanvXqWFQ9+6BfOLTdUFBDYlBYrJFDYS+JVFfdlnygCBXav6
k4JnEb8pHl9KYwdH/iPqf1mR4L/wL627q9LKCTxpcDSYIfoR70Uy2nSlwV/R
akWgSi/ez2tydzaNxPsBXd4+zi1431Tni8Odx92I76X06+cN8L6iSIVGX/kT
Au+byIyP92slsL38sS8eVPgLSwz8XJDeQ2C+0tUxh67Cn0yeGe+qOw8Qn6yY
OGdGA4GlPTaps1moR7KmpxG54AeBy1S8mLUR7QSW/CdGccAJ9VNffPLg9pkW
Al97mDybYYP8T6R2x43ZIf/VLi++xw4iflrBDdah+ZXgq8bjevgW4uOQR3fY
uwd6kvxHq021nxJYxLs8lqsb8blY2NogXov40MZuR/BwsaDfjR3wpzmHvwmx
82dnigm8t7q2wp37PYGpK5Scspyh5+aaiqGP+6Hn5czT6cZp6PkRvKnwfkMF
3p/vUOoOQb1x10SxTedgLybBfNPjBHuj16sc85RhHzxZLy/dD3u7wJOGIT8R
r4cn2w1frIa+7a+rzEasoO9GhwPXzRjoU31aNB12H/lyftXs1SUJffJhj9/7
zULfW11JK2oo3m+OFnZ65/KSwKXMlzvKdGF/9O+3llbzsKfI0OWi90HfuIVQ
Gp8E9C2l2Zqe6Oaoh3ipu0MnqggsQC+in8+GvskdIrOuZ6HvQWp2UUltEeaF
4lDkiCXmWaa8mI3KMsyrdSEbvEZzMc+M25M3HXDA57pLDm/IncA809ClPN5+
B/NbyGnssIo0+iVxoqCScQn98MCItevXLsS3pXRz1rFyfF+2+Gyzx9d+xKNC
LWSyFN+nFCp26D8B/yuikUxFZ/Ar+jV1NGkI/HhJ+sn/FMH/qareLYa/4d+e
5uZdehv+nxjkXGQdbyawIT3ay3we/gPa4vJTczG/VvzvdPuNfPST07eZWIG7
yIeCncb7lxz5yLBYaan0DPm4embvLulD0ENxz20v/oX4S5/6tpZRBmxv7bzi
njb41OucSMnTxuesDzoMF1notaSFzF4yAt89d5Xfx23G/DrQUp9z+lkngfWu
U8VWMlFvgRufyi2KVhN4d2P3RUU+7J81K5tbrqVCX1tuzq+uuXzMxxDa1lG/
OgLL3bqwqek7+uG6GMt6Kgrv+d2w5rb5XkvgwewMa9Oxz+CvHxrWugHvPT1O
W9h//Rni10qyD/wL8ziOb6KK7Ij8Smgb94b9gfnFvzUzzsID/e36fuCbpgb4
he8un2MvgJ9Ri/l8QieTwJEMdZ2GRsQvq+Nhf3417I25B7kVal8QeDk7iTcq
+xP20W4X0rUU6GlOSxPJU79HYNtdA2JzDxA/r8myzXKCqN+4T26tmT54b6mV
j8m8FexthaZWNbZDD/cOh66dabBPXzKy9hgZ8c77uox/xAPx/lgXLOVtA37S
2yvsli3DvNR1Y83waqGfw85Fqg0zUX9zquUH1XrBV/p5svogE/kYXWls3xON
+r/tV0bt0UF9k34peu/URH2fY2/xqNsC/32LDfRkXdR3XFprnY8q6vtyqsTN
BQryozxsOSZ9B/qL/I2EZ2NwX+kUquaf44P+m/MCQfYB0C8sfpgUkfgI+yv6
XPizLNy3Zp+0bGN4wLf/YWV8XST4yp0TP736JOajbMMjUqo24rFWPlbN8yfq
00RQQ9B5A+ZLqwCPLv9h9F/JA+1n75LAj1e6WyEmG/WT+LxwXID/Feazet2a
FQeRj5NODG3aPo59tPEy+2x/PYF7Pvr6/HAB3wSuUc2z6hz5ixDspQvjvnju
GMUbvgt8XXI/kEJFwFdxfgvdlWNeLHhReo2WgG/CGjl9qxDUL0tt3eVV46hf
sbmf3psjwXdHbv2ZIRns2842wfE7wrA3iE64coTjfq3oW9zG4LhfySqG5B1i
uF/v719c9OW4X5tSjEdNWLhfpfQ/chVdQb1RP9iUJ7dCb0ZW56nau7jPZHiY
Q+/08L5OkYkcjR/3ma0SRVn+CeIXs1zXY4gOf/mHR9ZFJWOfhFep+TWcgb/H
/uU2BTPYJ13+mUG0EPTT0daBXE0l9JPXAdb8J2vUJ/sYm+w5ic8FWP0anSXQ
96jlkaRSPPgYqtOGy6VwT2+oW9nWSAUfnknmVdHsQuwrw8/0etM3qLe2Q+Sk
I9jPR5LOLPmzAPNXYCC4ueoK+o9f60zDnBn8R0wJJXbsLcF+qWT/puihX353
Vsw+SoS/6uBb9bq18BfoSS2I2gV/gm8uNLnrlxLYgvvEYtND/L78eoKiwjiC
eVK6T5L1swr1EjEnr1XjyvF7TS/6grgA+i2ZGnrzIUe/lekdG+bh6LdWRdqq
liH0m9C72uJ9Hug3kfTmg8U70W8CKbZB/jtRL7Q3kvIkE+Qnxek3g3Ef+2Wp
9YQpk2O/HJDg576ugH5zl7kWopaNfjPvFK/0WQ6+05sM5fMDwPfNZM2QtCDs
Q1suJMbQ0W+XWsv4Zkphv96XqTTiiPvhq6Z3iO5uzINxz99pDckc+2/p/VkV
N/DzPJ6Y7dqG93ZPpMz1bAa/++HWnt/sOe6VYuO4BE/EX5gcOx0UDvvJeBv+
ShLsc2/dm12895rAbgmOQTGzHL9PSWZTgaqIr0TwuME2cfC/8dOf15Bjnkm/
0gyQXQn+hW71VKtw8NcWox7wnka85rb0fZoNAx85fv/pDDPMs+BILbK4MuyF
l7mtbeTGe599f/7IP4V7RCKAPeTnh3033UFm/JEH/yZVmhHjLth3cmbb7DRH
oEd3jZSXTgj8K0y3b1OMQD8b9bU0XVRHP/eLpHOt24d+/jK5evJLJfrvjEIW
1dcC/WcaK7yXzwn+qzZq7jwoxSBw2EAkg/sC7u+gg6pHbEWxPzPZJXHC7shP
r7yS4+AC8hMnQP/S8Lhrz785nmW5
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41V0XvXorczJVRJFZKESXcoVbokuIyjxEJIRSlFBEkkqGCrmJkhIS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk81F8bHSl7CC2WSLafSouEyhYtdpIthUgqYw0tkyijlBo1pbKFhPpZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41VsbJSlEyaxBOpSZzIUGFTdFGTJeTeRSIUMiolJuqJshEY2Gg3RE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41PsXxyelUrIrESJCZUmWsRRKi60QhaKFSnRJ6ipUQhKRhBRZQpgp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk81NsbFlJakBGlLkUqW4NwtYjKkq2URpFCmRL3om0oJqKIsl+uRogJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41G0btbvKJGo+e5skkZIoSUiypUipJLJEsr+hIlt2vaGQDIlC8tqz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4FHobHTSkskQqWSOStEgy1B3ZInEp1E0NUpZU15KypEuMJHuRpURF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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41dsax3cIEQp1lJRkyEmpZCjVtokynIQGKkOSTF1SyXQyVsjZpjan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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81OsXx0mytNJNKTt1Q4pKITVIi5RsoVFxK8kWP8SgNFIkIiWhK2uZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41Gsbx60t3tIYS52UDtkiraQiZCktg0pRkqUhoiwnCXVCpJIxpIVs
JcsQKSUplESiMDNGRbYsDRnqZCnkXO/1Xu/z5R/X55rfcz/Pfd/f+/v8forO
XrtdRISEhLSEhYT++/9/fxSj2MyRwwFuHYb/Zytr1o6o54OEqa8KL/0VmEJY
Pkmvtzi0lHDfvrx93LaPhHeaXRBla2H9Yq1gmVXxTwi73JwU589uIhzmni3M
PDNA2K/s3CnfYDb2y5WNc7ToI1yv9yNX8kkn4buxkx1lVOxno5Y3trT2GWH9
HIHVB8YHwtt2j9CFHwoIm++9eDbty0vCDa5ayl/r2gnbB/nN6upD/C2pWiUS
kuGE19aqfk3l3SFcUzXuGDqJeO1Npte2tSJexeqtF9t6ES+2pbrbTPICYa+F
Q+pDrzIJ9ziGzrPLqSS83CblICMT+WePr/Q+p4B4HKP418NuTwlTRlm9GQHv
Uc/T636J6SH/GlOLnK+lb7CfJb3EUL0b53vfzum++5Vw/9qxFI9G9E92Tr3a
mT70T8f0Lz+j5XWEJTcqDL2I6yWsYfAkpLX+C2FNvZkPhs17CDt/GqGMzOsn
LCKYFTBegPpZtBbWrBhCvi5pnNRXsWcJq628k+pvDb3m8p8elXaAXj1X0BiZ
FdDrajdH2gwVxNPXXrHoS1ox4QdBkuLarch3lWeJ1YgA+W6saPAeGXhH2EMr
KCL/BPLdpGErpjKXj/gbjRbblKO+UV75crc/It/0nV0uvNYWwj5tco3p93G+
D0n+1+Jc0whbZg8IH84uJ7xZf81D9c9thBO4scI9U1ifE/5jru3v2dAv5/EN
0d/LCBfY2Nben9hGODFgprLHqDth4ZoU6f2dF/G8V5FzPINFmF/YkC9m/prw
4V967h/vfiYcKCZ/9JUl9Ke5ghVYea0a/Wqys10Z0AX9LrIT3DmLep9Kmcpz
9YU/tFrotgQbwx+yItVFrzZhPtY4aUiETWI/KwXNtODtZYj3cOZbB/9mwjfy
jycz7VAvyu/7O2nKDwnLmHVQExnYf+5euhjtAPa37dbXMk3A/jWdFqqGaogX
FRqic9UR+oqVp59kZ0Ff1UJ7nwZxkG9ndL5Pnk49YSlhRbq1DuZnZI5s4T9X
oLcZBqNbXdj4nSrzVuWGGeZLrcDXzkAWervlYSB/MB3ztarUXyzjO87bd7Lo
EzsrEHrmUvSOnE4Am8xon/EW/l5HMba2WYt8PpgsfM6IQz6Spr1V7K4Gwpk1
dgcUX2M+mIHB3qoS6P+OmNy82mGs15dd5ZnAwLz1rV2isdQE+VO35c6ydEO8
isJIpd+DiDdf3o7W+Q/8bI7f0n2JkjzCjsLzJOT5+P2ZXbM2zRq/T+7+qcGW
xnkEIUP5VQaNhD8yfyrkOWP9UYskrlsG7p/S8/NOe5ZAj+GFsRcm7KfdP6cU
ouq90I8zBv4ru3+iH8I6tsx4VzfUq2m20+89uD8cM7rHRCSyCNOdfM9S+bg/
1I+Yl+6ogz7lLtjkHRJF/PUhaetaEuCXJmKqX9d8h1+yA2aPsNbi+Q4tcZGs
3iLCW2kiHa5B0+o1cMLTVBP1oubv1xu8wyVcdcx1l9MY9JhrnXKFpQX/UxI9
qb8sEvtJLS7Vlai5S3iQL3E1bHkNYda5QI3cI/DXhGL9b2r70Y+poqsqtA70
w/0XL9CBi36kSRcq50vAT/cGNHrYTbUS1u45XjA8ivN4HhCuY1C84RdlRqnH
hJiEjX+6uHKD7xFeZ3XCJIH5lvCjfilhn2eYz6GrI0VTe+AnLjs9HjOy0a/6
2d1uYYuwP82tOMAiHff9zcW1WuIs3Pcmp1e/F9+F/Cr82ZzmMPjtA56OpOdx
zMdoe3R9SiT6NXXJ/NQRRfgdn3Mhe/4k5ovKXlplEgF/vyzoXpDsg/0G5JKX
KedXEQ5KXF7VRcPzsaJyk0m38bza3c+Tj3or0D9nVjbrDN5PDyuuud9WhPx5
dz9zolJvEQ7jiVPWiL8gLM9nyN869wn39RxBOfMd1mvtVfD1irlBmDHyhXnx
12PCHNWezOinmO8XQoPumQ+hp9pF1VHad+B3l86V/KA2oH7po4Ia6y3wb29J
6vpiM/gz71c6W9MX/hUoFDjQKIX6br6+tKfwMfTsr2If3M7HvETJ2t82DsO8
BIntEhEkI7/q3cXKnb/wPjnMXd11sBl+kOyVKn6mEvoq9x19HTYb6422TzXJ
dpYQvqB7eqOsC/wgwrItM0sMz4cNnUpRPQH/qDegthVx8bz7wsFNhhp43v7L
LEGSOO7DiUNKxQGOqOfeoIhExVzUM1Rdqs9hE+6PP9bf0ZZZjXpdTOL5uHij
XvIdG2T20dCvrmR7mrIGzjOzibH42iD0dyo6jpnr95ywQrjXWM491LfpeGy8
ahbO7/eUf1uyOJ2waiWfPfMd9Gtj31C23xP6/fKoQ2ZF2bTvo5JVYZnSqeiH
CvPqe2W8n+gPPuL0HMD7Scx3I77LHqz/diXG87PCI8KNOtnO7xw5hMfXZXJD
xaGXwHILD2497pfYl5oVD6d934yNc+mUTfi+CQ9kTeSKIb/5IRM5NWrIz6+w
JcNyHPHU9j/ft6wD8Vg0a6VvRQzUe4vzoWHjPMLXGxOapQNqcT+yx9KylsIP
n0lGLejaNu38MdZGSlTsl9S6o5s37f32M9Mr2zBKBvfHIn8q77I2YSvniy9X
RlpjHqPHr10POwG9mOg2bD0ah/jP1cZlRfD+V1wcHVHuAz90eKdYO7wZfr19
xwjr53vMkx79qfP5CehrND7ugLYb+itmSTF+G4X+Cu3Ormx2Qj7m9XXHec4F
hN+FnvYR64f+BVsVFa+9hf7jP+yaeDMBfxWXvly8VhT73zo8kKPKwf3TYhXE
XdSOet9Uo/tazEc+Mqnfx/3NEE/XzbzyEgvxHKwiuk1DoYf+wkfVEhug94Ks
6iuq9cinziK+Y/D1dcKKCRK5IXrw2weG/ZfKl8BvDT8NbyicNr/ST+a3cNUw
v14h6galApxn8g9LP7NQzO+Hgr/FHcoxv1JdSn+O5+A8ZZvNYqTe4Ps9M0nS
d+wb3sd8ospN9/Ogtw16m7hMPtY7qTjRfRzOwx8ezxVp/zMDfrnl73SJ5a8I
d2i1TkXkoD4tCjMUn2dM88/q8NpnUlhfK5c2rKOA9Yn3MpeY3cb6rW8MtlzJ
xvrtlga5mkqY17yTuvXNxuhP3NfJNdy5WP9SL/k/f7Vg/c9DqnXFD2IIU4JX
u3vS72PeG22TBdO+R56MjRVdmfY9on9MutRn2vdIaqRogB0Hv4eFF1ACTKA3
etv3PTELMN8tTi09yomo924dDccFP3A+x/77cvRKf8JzZgnLU9KuG/4Ll6wk
dw==
     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{3.4, 0},
  ImageSize->{728., Automatic},
  PlotRange->{{3.4, 4.}, {0., 0.9999876051648642}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{{3.563245064136278*^9, 3.563245137295293*^9}, 
   3.563245192252287*^9, 3.5632455983561497`*^9, 3.56324581214545*^9, 
   3.5632703593945303`*^9, {3.5633102550765944`*^9, 3.563310264249467*^9}, 
   3.563312873553212*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"High", " ", "precision"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"ListPlot", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"fMaplist", "[", 
       RowBox[{"r", ",", ".1", ",", "300", ",", "600"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "3.4", ",", "4.0", ",", ".001"}], "}"}]}], "]"}], 
    ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"Black", ",", 
        RowBox[{"PointSize", "[", ".0005", "]"}]}], "}"}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.563244872774383*^9, 3.563244872997861*^9}, {
   3.563245045360387*^9, 3.5632450494505453`*^9}, 3.563245196041011*^9, {
   3.5632458139565487`*^9, 3.563245814203014*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHGYMDt8F3sseP3N3fsYfy3d8tPvP30Cs7/jSb/
Dk1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP6B0A8A
PIZoAg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEZE9/W2JtyO6y2k2m8/uKOPYx/3SHFx+PLKzh/
L5r8bTT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/oH
Qj8AHr3ESQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFz3y8/5m3O7fDoTUXOzid37GH8jxFdoou+voLz
n6HJf0KTH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
IPQDAHx4aBw=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGXfZMEIiy5Hco1GpjmPrhjD+Mfr1yg8vvbKzi/
DU3+FJr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf0D
oR8AAEwcMA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEca2SiUqy5HaoNdzs23bljD+M73YmuCv7xCs7v
Q5N3Q5Mf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn8g
9AMAPa6E0w==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANG2XNcXF9hyO0jVbNXIvHHHHsbnXVggvvrnKzhf
AU2eD01+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP6B
0A8AxX3W2A==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFFGRPf1thzO9xe/Wdr4JU79jD+80sT/zD+fgXn
s61Blf+AJj+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U
/0DoBwDldCss
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANErjnmbdzpyO0T3K7ywvnDHHsZXzCzUivjzyn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wywMAd6Eg8Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANF3VdgapzpzO+yW2rxX/cwdexh/j+eBhWv/voLz
b6DJH0KTH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
IPQDAHeL0+Q=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFCzQdOLXTlduBP8TAVPXHHHsb/4K2XzPT/FZxv
gCb/HU1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP6B
0A8ALv8DXw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHuD6tE1rlzO0jNK/NlOXLHHsb3tcrKD2N4Decb
oskHosnLj+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
APoBtas4bA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANG19qZxuzy5He4LX2P5uv+OPYz//4ri8ZWMr+F8
ExFUef6rqPIv0PQzocmrounnRZP/PKp/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1T+qf1Q/GfoBpKO+gg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGb5r5ffsyb22GCCmPU89137GF8hSuM2X+YXsP5
Bqqo8tZo8hvR9KuhyQuj6TdFkz+Lpl8bTf4PmrwRmvxtNHkdNPnvaPIGaPJP
0eT10eRfocnrocm/GzV/1PxR80fNHzV/1PxR80fNHzV/1PxR80fNHzV/1PxR
80fNHzV/QMwHAPCSlSA=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHPf6/8eMmX26HKbor37e137GH8Iy+3RvuxvIbz
xR1Q5blfocqfQtN/CU3/NXtUeUY0/T/R9N9G078GTf8vNHkpNPkHaPJT0OS/
ocnrosk/RZOvQZP/iCbvjCb/DE2+YlT/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qn9UP030AwDLCNHs
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztyy0PQWEAhuGXTSGqiiCSjeA0xWbTiEaQdPMLiJITfEQTBJqgmJmksTk+
GpugySawvfc/ONuTnj27d8WrzVI9aIxJBYz5bqxSy16LESdxSh73cy/3+4X1
oz8MPf9/e7H7C30H30B34A/oGc/ubfT72e4b9A58F30Ev0RfwffQW/AL9Bu8
i16Gn6G/4Qfoefgpehh9jJ5Gn6BH5eXl5eXl5eXl5eXl5eXl5X3qP+GKkZM=

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztyzFLAnEch/F/Di056JKTBxGIKFyQi0OYw4Hg5gmtQZBDQ9GalndCbyLE
lnZvELxd8Jb2EMLRhlt0lwwHg9/zChx+05cvD5+Tmwf3NmGMsQ+M2a4bWq9x
46haf7r/jYbfl7t/nXJyy8P4/7/1ZP9Kyx60ZR/AP/qyf8C/d2SP4ANPdh/e
eZZ9AW/Bt+An8Gv4cVf2Jnz2RfYk+h18Df0K/hj9Ar6C7sFb6Bn4Mnof/hR9
g15CH6Hn0Ffo5+gheh79B/0MfYpeQJ+j2+if6EX0mXr16tWrV69evXr16tWr
V69+b/0fMleMNw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0zFIgmEURuHPBlGkBgehJWhqa6/B3NoV2iQQHKShaHGwxEnJ2SHQKKNS
+xEcpKnBpXAIHVJSsEgQHHKxoSQcwiHhnr3tTpeXhzPe1dC+P7xgjFm3GTO7
KU+38R1w+YJnk/ua1dv6267Ygc3n+Jjv5Yr03bj0vQvpGfSZsvTRsfSTS+lf
6B8s6Vn09ivpG0fS07fSQ+jd19Ij6Isl6Zvom+jT6BfRr6AP3EjPoz8vSnei
v0NfRb+N/gc+RV+DL6Efw9cK0h/hn/AR3At/grfhQ/gOvAmvwwfwMPwZXoX3
4YfwFrwCf4dH4W24BX+DJ+Av8Dz8FZ6Ed+A5eI//Be/CT7XXXnvttddee+21
11577bXX/h/7Xz3VoQ4=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzty78rxHEcx/HPyUAmSlEXMUvZZPDjP5Dh+wfQpVxhuNFsMUhnVsqPI0TO
ue99rysGpEgdDncoSuluYTAYJAP1eu629/Tq1aNn2/DEUKTKOdcZcu5ns7F4
U7VX1x8+nGwIVkt9v395t7Fjtrb899/L6i2BevpEPZ9UH3lRb82oj52pr++p
jz+pR3314EJ9IKW+8qheSavX59U30Sfu1efQ5y7VP9H3ltQH0b9dqXftq/cU
1dvRn16re+hn7tRD6CMF9Rj6r1v1V3gB/TR8DX0R3nyjPg8fRX8O99AvwLvR
H8Gn0C/Bw+gP4HH0CXgN+hx8Ef0G/AOegSfhW/AK3If78G34MzwFP4bvwB+s
t95666233nrrrbfeeuutt/4f+29tUK01
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztzs8rw3Ecx/HvHIg5yNGBHHBzcHAiisvKpJ2+SsrkYLVsbDZbW9ssv3+r
laTUShLXpd1clIMDufh9Q3PyB5AcqNfz6vo5vXv16FnvRu+EZ6zMsqxWh2X9
3I9rt7fGdna3DSU+C/mHrt+d9t8dPFa9/+3MqXptUn3Qp14dUJ89Vi/F1edC
6s9B9de8+nBM/Squ3jqlXtxT75lRr0yr14fU+3fUo1H186z6BfqWnPpLRD0y
j//C6m/b6in09qL6LnrXlno7+sKS+i36pk31MvRHy+rl0+oDG+r38NEV9WZ4
cV39DP6EvhPeh/4E3rGq7oY70O/DY+ht+OWaeg5+iH4Enke/Cr9BPw5PoF+A
l9D74T70WfgX+gB8CH0GXgEPwm14Gu6ET8I98BS8Bh6Cu+BJeB08DO+FJ+AN
pje96U1vetOb3vSmN73pTW/6f/XfpnssfA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzty88rw3EAxvEPi1ZWjoglUWImIjNkawcXB4wLIYTad+lrv/zIsESuDn4c
HHb9KqRMiYtk5Ffi4oCDXGRpKQeSyIF6nv9AfU5PT6/eOT2qsy9RCFGcIMTP
5pfqV7PaUuz+s8NgJHxr+/3G7l6vyRD7+88LR+CBGfSWJ+xD/egTQezvQuhJ
At2toH+50GfH0aOp6I4B9MV2dOMYuikTvUFFf3Sid46iK7no54PoN/XoaSPo
ngL0Bw/6bh164TD6pRl93Yv+6UCfHEJ/K0G3+dAb7eg66h1l6Br1XbXoKwH0
WDn6K/XvNegu6jMq0Iv86C/V6FbqP6hvpt5KfTr1SxZ0lfpIFbqgXl+JPk19
E/Vx8lbq58mTqb8nX6Y+TH5lRb8mP6FeI9eovyCPU79GPkf9KbmOfIN8ivyY
3EC+Se4jj5Jnk2+RK+QH5Hnk2+Qd5PvkZvIdcif5HrlF9rKXvexlL3vZy172
spe97P95/w3xn5/z
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0M8rw3Ecx/Gv1S6+SY5zIFaiNIclhtloKVkImRhJJk2i+bEti8gufmzG
cXFaysGFOLgIuVHIQSKNkHaRtbZFTQ7U6/UXOHxO7949eh7e77y+kRabQpIk
TZok/Uyr/zhWaJWN261x327wzvC7e80dfldG5G9/VibBy4Po8ir2lxZ070UC
fDGAfnKIfXYves8W9o4F9IYw9poB9M0l7PVe9Nck9iE7+poT+6FZ9KiM/jaM
njuIvjGNrlGhN4+in1rRAx70h3z0LAe6pw09cwo9VYTeNYZua0SPudG1Jejm
cfSPevQC6pVa9BT1oTr0ZRf6TSn63AS6zoSeQ/1LGXqYenct+rkTvV9H903S
f2rQV6ifr0DvpF5vRLdR31SJPkO9z4Buoj5CfZD6dOqLqe+uQt+hfr0aXUX9
PvVH1LdTL1OfoP6MejX1CurVevRr6r/IP8lN5LfkYfI4uYX8nvyKPEpuJ38k
PyB/J3eRP5HviV70ohe96EUvetGLXvSiF/0/778B+VYkBw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0s9L03Ecx/FvSw9SGOQhCAoUQ1IQmRS72DZzVv7adBg4KWVagViiGIlM
D0qQBIERWB6CDmJ48RIIbhaBDLJLkBXomJAa/sjaimKQpHQweL7+AS+f04c3
D57whvcnO9hRd81mWVbhAcv69w5vhZxnrh5yxben7S9GYs692faj4e9s5ub/
uXvkJfzwaAC+FArD6zLojtPsU3fp7xbZPz1Ov/VpBn70Dr00JwLvyqPPjrJP
b6cPXmb/u4gevcl+voXu7GOf5qC3VbF/fYWeesLeVUKfKGZ/roFePck+100v
y2a/Wk/PecU+vYz+PIt9m58em2OfV05/mMH+US39/nv2kQv0Yzb2Z3102wL7
jYv0gW16sZc+F6e/uURvTcn/qqE3fqZ3VND9v+jL1fSdFdlf+syf9F7pE1/o
nkp6c5JeIP31NfqQ9CcT9GQVvWedHpbe/p0elf78Bn1J+nvf6OPSf5T+j/QH
pX8gfeUm/Yj42Ba9X/yx9CfEg9J3in+QPl/8lPQ3xNO+0u3iO+JN4vniDvFl
8YB4qXiJ+FvxevGAuFt8SrxWvF3co/cT94l3ipeLPxP3it82velNb3rTm970
pje96U2/7/0uuLXGmg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0s1L1FEUh/GfokI1wYCR6CI0NII0FxEWBo4MaJptwly4CNESVwWJyqA2
jm84iqAMCkLSokBo08IsCNJpsglfUkspyHGhoKCClGRqYxIuEp7vv+BdXQ4f
Hg4cblLpg1v3Ii3LuhhhWQdv8EaGN7vkhMNWM1L+yhfK+j/7Y21+u339cD4X
8RFuVZ2Ee11+uN3J3pkUhEcXsK/KfAfvLGdf6PoAz0tjvzzJPtXDvjg8Cr92
mv2fqwH42R72K4/Zb0axn+hgn/CMvb2IfXibnjzGvuiF7E9k79igp2+zD7ym
23bfw7dW6IPx9Nhh+vl5ev0i3XeJPhOgvx2lly3Q93Lod4L0tUH6ze/03tv0
42P0nAH6/jd6Uwn92AR9rp/u/Cr3q6B7J+lveum/5+ih+/Tnn+hl3fTwLN1d
SW+cot/tpDuk/1VNT5mml7bTX36ht7voT6RPbKPnS++upe9KX91K3/tM/1lH
z5qhX2ihD0sf94heKf3lZrpP+iXp+6T3NNEfSu9204ek/9tIL5b+h/Tj0vdJ
nyt9fgN9Xvrr0l+Rvlv6VeljpE+Vflz6TelDHvmf0q9LvyP9iPRnpLeJ70v/
VDxe+mTxSPEu8TjxNPFocY/4KfFM8RjxetOb3vSmN73pTW9605v+CPT/AL/g
s0Q=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0t1L02EYh/GfrmCRLGcqZS86K2MHSvaiEYXKsKBcqRURHmSDnaxAAoUi
JYmIXjRd9AIRRISUIFGZzWaZFlEHkSKGFvMgK4rNcrNFRAbRQcH1PeoP+B09
PFx84OG5b4enptKbaBhGXoJh/Dmn22NDbs/s4svDnc5gS6jo732DL/lVlT3y
727seIL+1jUX/dZwF7rvOf2MC/3oY7EU9PTdAfTROXb0flcf+vVO+ttHutGt
G+mXuB6h1x6jL9hzHz27hr6xsRe9vZo+YA2ibztDH5p4iH60lL7sJH28jf5d
PX14Bf1QmP59gH5qOX2Zg/7Z6h70hqf0zR8foNel0b/eT/9ygP7OPfqDSfS+
i/RXR+jb/PQ3ZtJ3BOhbx+ib6ugbDPqcQXr7OH1BNX3LNPvjcfm/D+yWcvrz
P9jfROnTPrEHXfSV39n9P+ltYXbPOvpL39jvWtibI+zuVexb4+yjs9hvTrDH
c9krvrIft7Gf+iz772T3T7GnprDnf2F/kcOeIL43Vd4vvn4p+7mYzD+d3TbJ
3pXNXiJ+yzz2neK9DnaL+APzZX7iq7LYB6OyHxns3eJbM9k7xCctYB8R/2sx
+1nxJ8RPij8t/rD4uPhE6SvF75NevJA9WXp0EXu19FrxGdL7xO+SfkV8lvRr
4iuk94hfJr1JvFv6gHin9EPiN0sPic+V7hW/SXpEfJ70veJLdf7i86VvF18i
3Sp9je6H9CLpdumF0gulr5eeKX2t7q/pTW9605ve9KY3ven/y/8GJO+bMw==

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0tlL1FEYh/FRMDXL0iwIijAoYYLCykiGLIMoSsI9c0mnxsKbgpaLdIqS
5kaFCZeKSNzS0XLMpIZSyyUtLaTExou0ovBCqYQWSloguih4vn9AV7+rw+HD
w4H3PeH7jyTm+ppMptU+JtOfMzKgeUm6LWhLfPiO/K7i8c1/7y9L/WMaQt/9
u3uTDsE7U+fC83zi4FE7A+DT0wfgZs8cuPX7bvjIKHtHshXuZ2H/KzYB7t4a
CLelZMPPjwfB63yS4LYK6Yey4MvK2X9OS4Z7n7PvqM6EOzPZb8tJgZ/xmw1f
2J4B/xjJfpM5lfMzs18byD42hH1EP/uj29k7z6bD18zQv1n2wA9m0R2L2X+d
oIdcZB9zmH5zcC98w6i8P84+ooBeWMJ+8jG9KDQNHuygl2ext/TSGy3sXSX0
smj2ZR30dRns80vpM0vZn/TQrcfYf7lA7wlg72yjTzvYWy/L/mbozhv0FeV0
30r6/Pf0WLfsv4ruX0U//ZZuv04/7qKXVdPNY/Twa/Q3bnpfDf2cl76oiT7S
Rm+upW8cpu9qlP/loWfX0SeH6C0u+qm79Cnp05/Qo6Rv76AnXqXnDdLHGui2
e/Qa6T89oldI33qf/kr6Zw/p+6S/3UWfVy/z66evl97eLS59tPRh0of10OOl
v9VH/yFeJH2ueIL0U+KvpT8hPkv6F+Ire+mF4gMP6E/FM6QvFq+UfkDcLn2p
eIH03eK10l8Sz5G+U/cj/RXxOOnv6Hykr9b/I71HfFj6OvFV0reJT0hfL75c
+lbxD9I3ii+Q3i3+U/om8WCjN3qjN3qjN3qjN/r/1P8Gcc4CSA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt08lLVWEYx/HrkJWhaUpuGjQkxMTQspxKjSbT63DNNKfK1LQUc9NdBJoI
Wkolpo03MsSgRQiGUVREoImtNKlFeSMqI1Msy6Qco6Dg+/sDWt2zObx8+cDh
eZ/jk1tqyrc3GAyBdgbD73fBn2dRtF9XQNqTmoGov+e94/VTnz2G/52XGw6j
vzZZ0NM916M/TWxAj68/iP7B+wq6+VEYekT2OfSihhz05nWX0Xt8N6OvDWxE
L7ydgX71+CX0E6dj0MN76d+2p6F/GrmIHhu8FX3Q2IT+JicVPbqc3idqO+ff
Rt9Wn4Je7Ecf9GIH+ugk/UZ/E7p18AL6gHssel3IefQIz2R+fzt9q9Mu9Llc
+puRSZxvLb25kz6ymv5UUyJ68BH6lrQ49LPX6b960Puk0Hf30D++Q1/cloBu
jqaPXxWPHtRNbz5APxNEP15AP9ZPP+tL37maPtBC32+lXzlhRHddQV/eRV8x
SP+gj97oRV8zSF82TF/bQe++hD5jlt7lC/2ta/QOrvSN7uzN3+jvnWG3OtNX
ebPnTdBbKtlLFtB7BLDX/aAvMLOfdKJ3C2HfMElfXsruNo9+fiR75RR9VhH7
iAP90Rj2qmn6xjz2heJbtrHHztAP7WfPtKe37mR/L945h/2ZHf2hOPasWfre
TPZC8dlG9vviF2ewe4ofSZD9nKO/m87+3EC/NIk9XHxHGvsN8d/F54v/uIe9
QnxbMnu1+HjxueJDTfL/ie9NZY8T3yq+Q3yJ+DDxU+I7xa8Wv0b8phT2Pp3f
bnZv8WXiX+n9i/cSbxH/TnyDeDfxD8UPiT8m3ln8S/Gj4veJdxI/In5MfJJ4
R91f8ePit4i3E+8ofUJ8qPQ56S7Sf0r3lz4tfZn0Sd0/m7d5m7d5m7d5m/9v
/hfvXW5P
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0mtMzXEcx/HDXJbMyjS3dU9HrbmUSyaX1BrVKafO0YnEpKKYYemidKzE
iZRrI2nCA8yOkcvmks11Zs0WZsawmhk2KZMam3nA9v488/w8+u+3197//fb9
/vxXbUjJHmgwGCYNMBj+fBvu+l3YtMZ9fme7Z2tbxat5f8+3j8ePmOX16d85
J7wKXmdZCW80+sKjx5vgWdkl8G6/TLjzaAjcPCIZfjloI9w9NwPu8XgqvPHQ
Ynhlx1p47fBl8LrISHj+QzPcFrEa3vkzHf4jeg6871oK/NjNFfAOI/uv06Lh
hwtS4blzM+Bv7Db4SVMsvNDNAnfY0+FffqXBx12Pg+eVsZ++NA0eW88+q3kh
POUF+9azVvidOPalfvHwY75W+GqbBX5qKHvPxAS4PY29T3Iq3Ph8CfzbjETe
v4J9YHkK3OZkH/yFvfM0+2GvzPDPdeyry03wptvsp2Sw9yxmf6eL/a1n7L/2
LoZn5rCvXJQET3rP3nKG/aU09gG17BN62Dvz2Ucksr9yj33xL/aZs9lPjmFv
72JfMJhe7MXeN4o+ZGQy/Io7/VEv/eAMujWM3uRBL3tLjwqn98ynF46iz2uj
t0+S+ZvppaPpH1vpxjD6k+X0l2Pp51voHqH0G7n0lvH0znP0vIn02g30EG96
3ym6v5F+poBu8pH/N9G9g+klJfQIX3pCA908gR6zjf5e+v56mU8QPWw7fbMf
PeMQfab0ZRX0d9KnHqA/C6Qn7aBH+tMv76M7pL9aRd8qfVGd7Ef6pzvpF6Qv
raX7SH9xl7xfvf9eel8APctB75feW/rX0n+QfpR4cw39vri1Wt6/+FzpL4k7
pY8U/76Hflq8W/o48Rbpj4iH7qYnizuk3y+eIL1VfL30Nbo/6dPFl0rvEN8i
fab4AukrxWukz9L5SG8XPyF9jri39NvEz0qfKz5G+lLdr/R54m7Sl4jflD5f
fJD0ReIPpF8nbnD1rt7Vu3pX7+r/o/8NsoQUMg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0/tPzXEcx/FvpZQsqiMll4pikTsLLcftCBFNmzb5QWNh5s7I/ZYfGjaT
+yaXxkwuMyyWGRPjh440DtJKqM5J6146LvMD83z9C/rps8+ee3w+nx8+79DF
qxKXuBqGMdTFMH6v1rB3bduXe5sX1edcf7Pj/cQ/+3MW68ZdAfa/+wX3t9z4
t2e1taLvGpIPH51djD7bZyl8bFATuuNoIXyeyYb+6nISfLZHPXrk0FJ4P+s7
vv9KHHzAsVr0kgfV8DHOEvTVi2LhCy/VoB+0N8DH3ypFjxk9Ft4t1IG+f3g7
fKhvGfrCe8PgV1dXo19rMNAvhJejO09Eopsbq9Dd97mjFxsf0UsPRKAHjqBv
7e+FfjSX/kRCf/S0rEr0W65d0edEV6CvfRiC/jSYPmKGD3r6RfryvL58X94X
9JcB3dE9nPRF/fqgZ6ykL9zri37W/Am93RaMvm44vSPHD91lE/3N173QvQz6
skx/9N7n6Bu70F+2fUYfOMWEbnlMn5sWxPm9R59dRJ9SSu9WGYje7zz9aEsP
/r9Geq/d9G6H6VvO0r9xZ48ZQV+yk91eSZ/kzz64rie6bT37j9AAdM++7Mn5
9PNXsI9JoN8Twe6bRV+Qyu63jn5CFPugjfTPU9i3H6I/OJL9w0J6n2R2I4e+
YCx7YRz9rCQ5/w59yHj2qmj6eYnsLk/k/hj2uUPoGxLYzVb68ljxYfSmOexh
b+kzzezLetGfjJf5K6MvmSTdRL9iFvuTz/SOyewh3ei3zpT/Z6d/OIU9ypv+
wQz221/p06ay+3vSDxK/t46+VvwRd/rrcez5DfTJ09hPudEnit/WRJ8rvrMr
vYf4T830deKfGfQvprO3tdCHW9itP9nPiH/dyj5bvEn8ZvF72thXit/6gz1F
vOc39gzxhniL+A3iz4g//p19pPhX4q+Kjxc/QHzPdvY88T7ig8TPFP9IfIWT
3Vf8GvEvxN8V7yn+tPgi8cfEu4q/K94mPl28U3qx+A/SU8W3SHeIL5c+V3yT
9GbxFdKni6+X3kn6F+njpNdJ95JeKX2U9FrpftKrpA+TXiO9t3S79PAO3+E7
fIf/z/wvVxWxBQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1OtPFWQAx/GjeEQuIoqXwyYiLpmSMWN4MDJxMBtLExQsSjSjvKQyQGmF
qAxvKGkcEDZXXjbwbmwSeUGO3ERAmdMxNZmKR0UFqU6xLih2dL7Q8f39B268
evbss++zZ8/z7PFLSJqzqK/BYAjsYzC8GPtnFkR8t8Jt2tXRewJa02+GvZzv
aayadH5Ex6t5jN15Qk/3tPcz9/TxA2vRP7bXo89/ev/Nnh6X7YAbUu6iH3P4
ItzccAF9zbLH8IWNT9CHhTXBI7t/QX8y6h94dJQH3Pe3q3CnDUXwr42d8Cud
PnDvlutw3w0F8PUJdrhXegB8ZugN+FszsuH7p/8O79oUDE8bdQtu/TATbs7v
gIfkTWFf2AJf5b0afmfyI/jbxgj40ubb8DUxqfDsMe3w0ImR8NwmG9y/NAm+
LqINnhI7E/7eD3fg7o7l8GrLQ7jrgSj41NC78AzjV/CNfdg/mDUH/s1p9k77
FsPLv38AX58cC5/sdw++s/xLeFUQ+1NjP4LnrGIfHPwF3K39PnzIxo95P8fZ
Fzz5HN5dzP7Srjje/yP2HzxbCD+4jn392k/gdUNb4Q8nsS+LYz846FO41cw+
Lf8zeEwoe0sN+79ms/f3Yt/lx36ueR68cgn7zKML4Kke7E072Iekyf7j2F92
0FNusX8ni946jP37nXQ373h4Sh7dYpsPf7eN3hDJPulHetNx9oE2unsS+6JC
ev4O9uXN9NLt7Jceoo/7ln3uFXrYAfYuxdInsE+8TP+jjH3FMfrWaPYjL9JL
zrM/UUpfEc5+5QV6/DX2phN0Uwj76AZ6ho294RTdJZD97jp6Xhv7rDJ6nT/7
qefoI+zsq07T/xvN/o1aeuzf7M+U0yNGsg8/S9/cxX6LVc7HxH5bjfxP3ewD
ztDXDmP/fzU9x8H+iPQ+XuyzpS8x0L0q6AGD6ROkT+5LXyz93kF0WxW92Yl+
RPp5HvQi6bv7yfrSxw+kp0p/w0h3rZT/w50+S/qc/nI+0ne60SdK7+NMj5Q+
UXqT9Bbp50vvIr1R+g7pE6W3utL/FQ8aQE8XXy19u3iy9Fni4dK3iBdJbxEf
Lv2v4uek3yn+pwv9kniH9LvFr0vfKO6QvlC8Wvp6cU/x/eI/i9eK+4ofFD8s
XiM+XvyoeIF4pXiI+E/iueIV4lPEi8W3iVvFp4sfE88QLxOPES/R99/b9/a9
/WvXPwevyeFK
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0/tPFWQcx/Fzwgqx7EgBO5PpyjZWEq4xiaQUY7EJTRSpBoIyPF7C5DIU
o2kXCpxNaFBUZgVb7dCcMaJph1lkm6DkwBPDEyj3+/0ml8AjtH6o8f78C/XT
s+/ee+15tu+eRxOSI/feYzAY/IwGw99nUGtEzqdJy4JLHrOtHT/atOmfOenj
C+Em8+C/c8v+rqcW95761S8t7jE/j8JXmn+F94gtg/8t1hP+8FVv38U9v7Aa
/szvJ+Hdv18Of+rFzfCGE3b4DXMH4Le96Qp/on4XfMUqB/y3u7fCl6a6wEdU
pcPnWm/Cf1kXCG+PW0C/tfYDeK/IFvR9cT7wT5uc6K92nIZfF96OvhBohvfd
M4ve/IUV/uIPneh+lx+E3xw4g541VMr7i7vR444tgb+YPoXuCC2HrwzqRbfP
ONEL3CbR7192Cf399/rQr7RNo3/WOYH+fHYl+n05/eg14+PoX0+Oow9NV3N/
lgH0yxPD6CZ/+vIPa9C3uw9yf+cH0IM/GUMvzrCjpxXSWz370Dd40XfcqEO/
smII/fp0N/qO0lH0+F/q0fcm0W/a2IU+E0vfG+5AP1hOv7uxAz3FTL865w90
/2n6jbZ29J86RtBfzmtAT/UZRjfWtvF9F+jXWBrRIyPoI0z0Wfn0vctvohcl
03+T3sr9HqFfd5r+2kn6J+Za0Hvi6AOW3kKf/4p+RwG9PYzeaKH3LaX/PIR+
ZxB99nf0nhX0iUb6ej/6Vf30sdX01dea0Usfp99pbkI/VkefUET/hjd9WjB9
eyN9wHH6Og/6h+Ppm1vpK+Lpk0z0tgz6H7voz26hNz1A/1YuvbWPfjKAPtuV
PqqQ/sYg/XUf+uJ76Z3n6A+O0GeupI9yoXez0WeO0eetoE8z0t+5RO8/QZ+1
lH5kgX39Vfr82+wGF/qyefZHaulLJtltd9nL7rI76tgLptgPzbJ3OtlLHOxb
p9nnp9iDxNc0sveIf/K2vP8Oe3QTe8IMe9MYe4j4xBb2KvHGUfb+OXaPNnav
P9nfGWYvEp/azh4tPnSI3SI+p4M9V3zYIPt68Yc62W3iMwfYHxK/pou9UXx3
P/vELPs58ZPiLeIbxPt0s7tJd/axV0rPFO8t3Sr+vPRa8b7SY8RbpXv2sD8r
3Vv8Gelh4kOkD/eyfyQ9RfwW6Xbxp6Tnid8u/az4bOkl4l+Rni/+XelV4mOk
vy3+uPQG8bukvy4+Q/qQ+ATp0eKPSp8Sv0d6lPgj0hfEW6RvE39Y+hLp+6SH
Sk+T7ip9v/QXpKdKd5d+QPpz0lP0/0hPlO4vPVn6SumvSX/mf/+f9H8B82nP
HA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1FlMVGcYgOEZAy4YEkItcSEYjZFGHYLGqAUpKFqsbWQpKogoHcpSNLIJ
2hEZLUIQhhEQZB/FATdGxBEQarWpIYNh3NAmtQULkhJGS7BE21RaS9OLNrzf
fe+8Ovnz5D05/3/Od+apE0NiJikUCg+lQvHPNcnH4Ttj0nS/mpRh83hqr++/
a/Wq8PYts3/+bx2tL2+Z6AH+PfCGw6orEz3sRAx8/aVI9PHO9+HaTjX6jtZE
eKxGhT7bZoF3xOrRFyr3w+cqJ6OvjPsaPnWuGf1dayZ8b+Ng80S/sLYdfmvH
PfTuEUfgd1dY0V/0aoY7hwyhP2vLhVfmtaC3d22CG0bG0NsZdfCDViP6hK9M
8MuvHeDapmPw7f6l8DWvzsOnLZgJj/Mshi+JPApf3noWnm2bD49eXQLvNmjh
jr318HPti+HJT0v5/HX74NatdXDb6DK4ZUMZ/Kc5yfD+WUZ4UM8qeHp8Ob/f
m7vgurdPw4vNPvCpoRXw8ag4eJRfLTzs/Br4yIxK+LWuaPiDolPwjbZ18AEz
++4fouCDk9g3FAbAVy6vgi9M3QF/XHAS3nn9A7ibgb3dge3wKR7s/8r+EP7o
JftFP26DF/QZeP5/fATv8a7m/0MXDt94kr1GtQmuTGcfvC8M3pjA/pl7ILy6
nr25ZCu83Je9/a/sK2+zn9GzBR7oyv51dRD86DB7J3/2CeM18LyFwdzfZHqV
ZTP8myH6kjL2Lq705ij26m/p6hfsDSq6nyP7nA76wHsh8N+96SO3Qnk+V+mt
GezbAuiKIvZDJnroJfZhwXSPaPbL6uiWR+zfDaebfNg71dC/HGNv2kl/5cbe
u4ye6fIx/MWn9O/t2acV01eq2L//GX3dKD1fL+7vS+/eTY/tp2/Op88PpLcl
0kse0Fty6bUR9Fkp9LWddH0OvS+G7rCXbneDfvsI3XcPvTaNntpKj8iiz0mj
P0+nr26ie3wh5lNDV+6nL2igrzhMD9LSn4h+7Ax91yG6Sxa94nO63kjv0NKX
5tCXasR8nKJ7i/5GLt0k+mSDeH+Z9Dt5dKcD9NJqeoroNTr6J6J/q4ruLvr+
Anq96O9V0J8epE85Ru8VfVe5mC/R/yJ6hwz68zIxP6JvK6R7it5L9LtFv62I
Hij6MyfoQaLvE3286D1F7yX6DcX0DNHfL6W/I/oa0etEny362aLvF32F6ANE
7yh6t+P0OtE7i95O7l/0JtEPl9D/FJ4o+mbhFtH/Jjxf9O3CG0U/Ktwo+uvC
q0Q/LPya6G8KzxL9kPCHorcITxL9oPDHou8SHin6AeHPRG8VHi76J3K+3/Rv
+v+h/xvN45F1
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1OtPFWQAx3EOVhiyoMsxE1uSyGKdWkenrsuCLaEN6aIwWzk1NYSlU4Om
BCgKKpcIFCyh0wmxGWCGeBAYSgFmxc3LUVCPgCMpzvQEhQgRSLVe1Pz+/oTW
q2fPPvs+e7bn4rdy/aIodzc3tycNbm5/j59bTk4vj50UnNTiqPPe0Bn0z9zn
2XXJn/i6/p379k5uuN0bmw7Cx2KG0U+wxcEPdd2qv93vtx+AG6bcA/9hXjz8
2EIn/EhFEXyWzQ8+ezgRHp3UDncs+BSe7TLDl3snw9tqvoMHJ1jgga8HwTsK
t8HfTjkGd59ZAH9jYxj3X5cKH48qh9vm7oXPLo2AO7fugJd4lMDzrB/C54Qu
gU8b2glPmVoEHwrbA1+ctwL+eGA6fHCZhec3Kw++uXk1fOZjGfCQfR/Bj4fl
wnf6roGbxtgP23LhX2fuhs8oWwdvL82EO2Nz4Jdcu/g+PnsH/tYz78OfP5EF
j4xhX2R8F+5lYz83PRMeP5YDf3raRrjRmAVfW54Of7OI/ZqmTXDPaPbjgWlw
+2L2FtN78CsH2Xf17uD9eoj9nkUJ8Ak97Fd3bId79GbD+0IS4Un3fsD/5Y9U
eP1x9hHeSfCBeexPh7I/kc/eo4p942vsHzmcAm9OZD8xeDN8Riz7XDN7+yr2
z9nY30hjf6hpG3z0FfZ1Plvg4wXsq+PY5wSxH17Gvr+EfaaJ/YiZ/dFC9uGV
7PcNbIVXB7Bf2M4+o469o559zMPsSw3JcEMj+5R89hVG9ssD2LufYe+/iX2k
N/ua+ezPtrFPWsLey5N9z1L2Vgd763z2ZXeyPxLLfm8X+y/N7H3c2btS2Xd3
s7/rUfb3/Uk35bL/uId+t5F9/i36qJV9x0/0cE/2maP0b4rZ1zjp0Qb2F0bo
3YfZh1yjTxylr/+Nnl1Fz7pOHxyU9YfpU2vpFhfd2U9/eYheUU9P/Jlee52e
epOecJI+p48e6qRfHqQXfk8/JX3sj/RXpX+qmR7eTzdepXfdoEe20iul9+um
b5F+ymn6pF/oaVfoT0hvOUOPlN7URe8boLecpWdL/2AnvUr6c3Z6g/T+HfQM
6YvP0a9JH3WZHiV9xHm656/0Jgf9Rel7pA+Q/gXpTdKvbKMHSd96iT5Z+lbp
I6RfK/0d0vu101dJP136IfEY6TeIX70o5yO+X/pE8TLpu8VPSb9dPFX6i+Ij
0meJL5XeLv7ABfpu8VDpW8TN0ueL+0v/rfhL0lvFvaRvEF8hfZH47+JficeJ
7xe/KV4rHi9+QLxXvEY8TbxYvFO8WnyXeKn4efFK8QLxL8SbxY+KF/7f/yf7
vwC1zxN+
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1H1M1HUcwPFDIx9BCk88efLg0BNUUAGRg/DUHAqHB0coKsQhIBKKiAo5
wbSsEYJmmCYlPsDMww2Yj6ktc5IPVCr5hEiJkxJpI5moIV2trdq9P3/99t1r
79/3t+/DT52aE5feT6FQTLRTKP55tvxRlHVm9ZDpBWs7TersuxH/jUMdnSvb
3Dr/H3efrom29bsDaz+39YABBvSPv3iyx9ZzqsIMtn7lxmX0LYUX42y9QteC
fnDrMfTLXO6jP7QnEX3M0wb0T2a5xmD+kh70Hj/3xdq6m99R9GmqlehHNdnD
v4qsRf9BZDXnH3YC/cIcZ/g48wr0N67vgj/P7kbf3uQB360MQR+YVQZvVmrm
Yf8StfARlsHo849shtfsNaDXxAXA9TUPjLZuXlYEH2peib6jLxiecf88epOx
AB6SV4q+flsYfFeUBX1ucB687Xw1eqVOD1/rUI7+5e4V8Htup9DrvF6He67a
iH5CylvwUnUjeqeMSLi5LRf9sSWZ8OHJzehnqqPg/e+moZ/yIB3eOrsd/fgs
A/y9Z4noQ79fAo8O70JfYJoHv33HyO93SIV/t/0Z+ou/GeGFujno5+9MgZeV
WNH7z4zj+rfMQO+X/CZ8e8pL8Eqzie/fHA73X5BM1w+Ch8fGwwOHTYMPKEyC
L05wgNeq3oBXmILg9Q2L4elnneDJ37APCJzM+zOefVmFM/yAIQFesNMfPujw
IrjvX0p47zn2TpkT4Mens79mdYF7+8yHjyz3g3f9shD+o0UFj8hnXz3UF36z
gv1tJ1f476fZ+zZo4XZJ7NPC3OCZPewDjoyFr9KyfxrsDl/nswBu/8MY+Pq+
RPiHAz14fgzsExzZH73F/sEJ9qYc9j3Lfbg+J9lvnesJX1PC/tavGv5/KtnP
amBvd4D9jnz2h4vF9/uN5v04zv5LFXtLPvuvN7Ifd4F9UKM3fHcm+7JL7B9f
Z7+pmL11EfsaezW84B770jj2q2PZd0xl7/6I/cca9vsi2b8ws/fvZq+yesGn
69lrN7Pves6+s5X9qzr2lfvZ77Cyt55j3xHEPuQ0+5j+9HWH2X8yiX7zCvsZ
A+j7PmXfO4E+pI391sHifBazf+JLX9PFPt6BXr+efbaW/v4L9lXD6JZc9jFj
6Hvs6eWv0Fdk0os1dEdH+mRn+skUuqM33V1JLxtOD19Iv6qmD3Kl1ynpt+Lp
346m/+lJPzCCbjTSH3rSPTX05S70LdH0ANFvGUsfMZK+dI7YHw96ni+9SvTn
ZtOdRd8ynj5KRd82i37Qnf7TRHqR6I/MoEeJvjyAfk30Wj1dIfreSXSXUfQ7
EfSzbnS/KXSj6C+/Rt8ieu9A+juibw+np4i+R/SHRO8l+lDRW4LojaLfECb2
V/Qzg8X5Fn2Pjt5P9MdEr3Clvyv6R8LHThXnU7hW9M3C3xa9j/CmUPol4Q2i
DxReIvpTwoeG0PXCDaKvEx4m+rnCvUR/UPhS0ccKtxP9fuEbRJ8g/OE0eoXw
vaJPEn5B9DuEnxF9qvA60X8k/KroM4R/JvrSf/1vZiMmtw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1nlQVWUYgPF7ERARBYQQmEuCMJQTWHixYXFcUhN1LMBMSwTZlBEBSRBx
RUJjJ0QRF0wxEJPSCAGxsMBMhNEwVGRVlgQ3dkSuSDVTzfecv85888zvzLwz
7/nmWPiEuPuryWSy6XKZ7J+n3irHgmtbxs8Ns5kebh/QMOe/s6Jqian164//
P1/ZtNJV7Hed7AzE7tb+7mdiT91SbCL26HT95WJffq0Ivqu/IAS9dBb8mFqv
FWI/Gj/NUOwGjulBYi+yqjEWe/YD95ViX1EcBz/sURkodtcL2+HnVg2tErvG
uHp4nw2LNoj9SPc78B3Raz4V+/fXprwm9tbA0QCxt1/smSx2O5OE1WLf1/EJ
fIzZo/Vi13X5EV7LMN5D7NU6CfDjvhldJ/YTxinws097rxF7b0YB/GioI3x1
WwB8fedkT7F7XrwL312f6i923wwX+JvyfHjTjQPwA2+pw5cttoXfsdjeS+wd
X0w0EnuEd6Kf2MOVRvDqIVnwnmWW8Oamb8DHfqcG35k8Cj9SMBM+I7LaV+w1
tr3oR5Z8sFbsSQ8WoJ83jIPXcGpD963/Ev76BTf05ual8DOCa9ELplbA70j2
QN9jbgyvG34DfXfRELx+iT+6/9onPni/5lX0ph5zb7HXbwtCt/L9DX5neyl6
ef978I+0wtAXmOXCxzYVoxsUesFnp0Win8xLgh979Qf0nzW2wlvM34X+yi0C
XhFxDj0vLRF+jmM0+qVAP/hTt86iB/Znwn+9fy+6behH8ItKc9Ezs/Pg49bH
ol959j78Zcsc9DT9i/D+VfHcv2hneMfuU+jG+8vhk24lolfW2cFXGGShW26u
gj8Zm4xedn4avCrqBHpL/x/waqoU9MKKqfAbbb5Cz11WB29tn4p+uU/B/dU5
jr7mbDP8w1n7uX/qxvC6JpnopfZt8JcUafw+ag3gZy89hv6tdgf88D36Vjc9
eOfMo+j3XR7TRx5Aj/94AvwUbfpizWfcf/lB9OnV2vA/JR3h/bCqGz5zM33C
OS34NCv6pmW98B/W0Du0aMKfrTyMrjXYB69rnY6u9NCAj4qiP+0xAG8TSB8x
SR2+by79vYRBzp9Nn61Sg3cYT2+X+Bxe4y59ly59RWMGeq/fEPx12SHO5yKH
X1tEr1S8gDe1on/7hAy+M53eqIh+YB79ZX368O30ek7D8MrV9G6HR9Hn+dGX
59LHbqJPUNJnudJ7aarQ06LptzS+Qv/7jwJ97wr6O6n0OQfox8ygj8igLzlO
b72S/k1r+rHV9Fln6M0s6S0V9DWyl+i1+fQ2z0fQzxjQL5xGn11C319Nv1OH
fsdS+lm/0Mfk0wdr0vsF0N+4St9ziN5VTn8jij66kj5qD73qJXvkQfrdN9m3
BdO7v2DvyqFvuMUe5EnvNMief4G+4DZ7gyv90T52ZRm9opbdZyH9uh72kip6
qzr28870sV3sp25L5q9n36Wk73squZ8a6V0b2ZNt6DOfsKe00ic0sZ+zpt/2
mF3VQZ/ezF5oQb/3EXviU/qt9yX7Z0Zf2Mm+vod+5gP2YRN6LYnP6ae/I/VG
9GEd7AHP6T1b2EMN6Yceshe9oP9d4t0n0adIfJ6K3q6V/XM9enuJ9xyhj5H4
wYn0nX+y//qK/rrE506gz5X44VF6jTbJfurQh0q8XM7uIPHHxrPPl/gGifeR
+BptdrN//V9Z8YG2
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1HtMlWUAgPEjiiiGCGwgZJBymRtesgTRxAsTxu0gWKlbpiAHHCCQpIhC
iCRqgokztJ2UQERMRpaUgnIRtBAVj8hdLof77QgIotxEWmu19+Gvb+9+e/a9
t++bvzN4k4+aRCJZMkUi+edpf+PleHnYrHVGATOsnGR1a/8bTw93f+Vnovp/
bBEcnu0o+NweWb3o1cprlmLvaH/4pejyt8aFYj8wV0cp+jfyTFOxn4h41S96
bFJUsdjP6I9sFD2/s3Ge2Ed5pLwQ/egyhULsR4/dbBL98wPvGIh97Y7oPtFV
tz+sEHvXxMJm0QOddHTF/trXsb2i1+wrqRH7S2WXW0Rfka3QEvuzsVk9omfJ
c+rFvuyJX6vooXcXaYr9Nrdp6PebGTaJfUHAnDbRmzx0NMQ+R+r/XHR3/+EW
sV/4VyL6oKt+08R+/Ga7SvRPruxuF/viXXPbRbcZMFMT+1ynUPTDITGdYl/1
aRT6wMLlErG3WqmP3sTIvVvsDefXoJ9aEvdW9Gize92iXxqvUonuITHvEH3r
dwvGRY9Vi0S/v8KiR/RF5T7ob2j2jImuo2+HXta3oVd0W5sL6PUSWkdFT2me
jV7hvbJPdMu4R+ijEtXQW5m2dImeZKf5QvSgN4Pod8etH8H3WZiL/nl2DvqC
bw06RTdKOD8suqL0Avp068/6RY/UtkJvl6yN/t6xaPQTUVXo9Z3c0I8sOzck
epp1AHqdcocB0X+p9Eaf6vwB+iDnLeh/HUhFb7g+FL369urXol/c4IA+zWYI
/brxGPTdtifRL8legV5ydfVL0bWCz6CXaknR57hYoo+f2I++UpWIPn+5Pnqf
jPfR616/iv5kzhX041s6Xol+V26AXjq1Ev0hk9/Qx0vz0a94po1++/Qx9Cqn
LPTrDS6gP7VqJnrzy0aDom/0y0OvrD2E/tbpqegj0q3Qx126i76oyRf9w9tv
4Z0Frugr592H7zvhgV5HPgp/Ee6J/mTvQ3iw21r0G3WH4LWb96AfWKbg/LKX
on939iD8Wu4h9DljpfBRvwXo3Q/2w0tnxaFP+qIcbqhpwPNz6IP7nzqL/rZv
Jdxkkxb6BlkP3Dr2J/RvTKvhLtPU0bsUq+BrbNLQBybVwDtU4/Bkv264bVEG
PLLtGby9dgi+0LYL/tQrE756rBZelTEAD1jdCf/BMov3t7MOrljXC9f26oB3
2eXAPTLr4Zlh3Vx/ajv8fkE+/LRnA/y4bQc8Qp29V14hXD7I/s7BVnhaRBs8
3eVPuN5XSv5/jZvheRrsaw4UwS2U7HuMGuE1Ka3wB5uLub6PG+F6Oxt4P9zY
u/c+gHufYL+tqw5+Sp39MedH8Ecl7I+k1cLXFrXAZ+4tge/SaIKHf/8MPnGa
vUPIY3iiDfvon2vg0TL2e10U8PSd7PMaq+Eptuw11Z/w/hxlv9iKfeA89vIU
9q6p7JMvVsFnS9hrW5bCY/LZB5mzf9LRDC9JZN9Xwd7/ViXcoIx97pSncP0u
9iPb2csK2K/ZzD5khH39HPb219l/mch+twbd9HEFfGsq3aKO/Q49un4Ce6mc
rpxTBj/zHt1Txl4ZT2+zZe9qQb+1ir3iOF0mY39nMd3cgP3zw3T7GPbGy+l5
w+XwGRF0n2T28Svp+Q3sJ0LpwdnsrdfQ4+6z/z2E3lvCfqkdPeGPSfMPpocq
J52fPd03lX1bAH1PL/twR/qRc+yt/Cbt/xj71870jFj2Kl/6R9PpulL6j4fp
QzL6UW16kxt9JIwu9aaHGdB3u096/x56gxfd3Zie70F3DKBf9qQvMKMrN9G7
fOjnd/zrfwPTmWPD
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1HlQE2cYx/GEcBjCFYiggoSIqFRAKqjlFlMLqY4CigcFuVRUUFOjVINB
8ESkAhVEq3hUxKMQbS1idSxHpHJHEUQ6NAE1gFqooAU5jJ1Op53n99fOznc+
s8/u+74riNkask6HwWC4MBmMf65JPHlAp5Qzv0dzqSwyqt3vv/tA9QWPYrtX
/9+n7fcJX0N67In9b4tIt1ieUkj9GVmZO/VnluZLqL+z0myY+kD96izqfWwO
ulJ/zLz+EPVtru/HqHfu00+mvju6w4l6YbjHSeq1LVEM2geiWzZTn+Jw25F2
fsrCy9QbspawaPdSt0VSn69lTof3vyosod5A06xHu8Tm/jLqQzWXp9LeWJRU
Tv1RCWsc7YURYSLqBerzU2hPOTyzlnrWLxo27cmssPnU25d22tH+ti6tiXpv
l4McmG9xzifUu5Wv4dPedq2ijXpeZa8R7VKh6mPq1501s6VdaadVU2/uM9WE
9vlKcyfqf5/82oZ2Zl6UhvqYZa6mtEf1cKdT38UYsqa9uUX/Jey/Risz2iu7
yqZQn9HNBx+YZdhH/bBcDf5Djy6fepXT+km0s4dS+6nP/DSDS7s4qN6aev/G
qom0T3NLeUv9EZHAnHbvpboTqf8s1At8n3L8EPXn/zoPvvpAviX1afcUE2iP
tQwepp5jxrWgvas4nQf771A4+DnhvqPUv9CKwS8PLjenfnMMC/z7gJ4x6mXN
CvDp6e5c6os33rSivZezSkt9QRiHB/M3qEyp3/JGAv7hidwP1P9kIwK/73ap
CfUhWZ74/JpLDNqNxcngg/tvGdM+g8UGr0jPYdK+KakIvM1AuxHtHE+VJe2j
Q1E6tC/zaQavGLMFvyvwZ/Ankrgs2tOzB8EHDEk5tPvGnAQfqLkCXjmHN552
k5W9hrQbtsrAb9vjrEv7YIMz+BBjCfh8k/XgDwjOgk/qFoK3TGSD33sgGPwp
P6Ye9LEV4CtFcjbt82r9wLPfhYI/khgHPjArEnyp1BX8FP5Z8Beu7wB/+rg1
+NgF9uA9RCrw4uFU8O+ed4yj3fGJFfj4Rzx92ltzMsAPzpWDfz1mDN79lRD8
7ru54Ddt3wveR6oHvjMnAfz7i/ngpd+Hg9cTaKHP/SETvJm0APoijjf4K9VD
0EU6cvCJkVehJ6v54CcsGYBeOKsafEXiNeiSDAPw7GO90Jm1KvDW7Tegf3tk
wID2FbIXOP+SAfB1l0qh92/oAJ8wqIG+agYLemPfbeju5Q+g1758Cj2qhAt9
geIu9AeeCuinRR3QaxbaQq9zL4dufLQU+mpdFXQW3xH6y6BK6Gt3FUPfbtIO
fZxsNnSR/T3ok6oKoFtF/Ibn85gn9NGSKpzfPx96V9cT6Dsz/aFf596Hfkdx
HL/PhVbovnkB0P/wqYbu5ZiN65vxGHv9Yugz/WugfxOSAf3FqRbocxYFQ9cV
1EI3ckiD3lPXDN3QORT64qfosw7vh750Avqph1ZBdzlch/s3IRW6t+wRdIuE
L6AHTKyHfutOMp6/oSboLa8ioJfkonfbuBv6zX3oA3lR0B2YDdDVcVLoHXz0
n/dH4/6PQH+uaCf04pqH0B2+joWuJ0f/zPkr/H570De9Xgt91hv0m5/tgD7i
i/6J/Xo8Hy6N0Cf/uh36bgP0I05x0BNj0JcpJdCzWx9A7+VugK49in50ZBt0
Vzn671rRi0vQLxKiT0xHH7p3I/SCx+gLC77E/2c8+rvjN+H5eINebo1+OAi9
Ti56UyMlrt9FMa6fB/pOnXjoWwTog/zQ205Dfy8afacb+o+6t+L8PPTyG+iV
QvQmp9DP1EcfP4I+Oxh9yGr0scPYZfMSoG+LwJ5th351H3avBPQ/xmHP+3ML
9Kbn2CtOos8UY/etQp/Xjt2iAv3sndjLz6GXtWDXeYa+IRn77FT0Ycp/+99g
g/ro
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1H8w1Hkcx/GN1pZVV5Ffd/1Y5yrRj6NLIkxN3ZTLzysS5WpW5ujHGrfJ
jz11yI9NoV12bX7k1+ZsyfYDoePO2KaMJCHn2IQzciSR/Lq5ubmb9+uv73zm
Mc/vzOcn59hpd64Gg8HYOI/B+OdbEhyQPBTBdvxCN0gQ6vO7w39jTXn39DBn
8P9xH+fBsxDiSaPf7KbONRA40v4kv36E+qj5VZ0fiIvYUlfq7cMh2rR/pWPT
R/2QeJED7euP8r2pC7VcOs4SP2Kk2Um9asogkPaCkSXHqfdIzUtp366cfE5d
4RSTTHvbmpTvqdun7Emi/ZxwvIH6QaWOkvbrM1bxqBs3jZ2ivdC6rZ56vZbz
U9pX3n/Bp36MneNB++m487XUb1c8H6D9+QPN4dRLp1W2tI9Y3F5F3T3SmMEn
rrF9QxT1c1Mf19C+IFVVTn13WLwu7Q0/n/yJOqujWY/2sjK7e9RbvxWY0v6R
2d6L1LuXzcynfbXIVEl9v3qvFe0vGW5IoG5jYj5BXTOQV0I9ocDSkbr4XqmQ
OnPdZ4PU7xzSvwm+ke9E/ceFfUnU++Xibuo6axcUw/qZ7TtAXZrUdIX6xsiA
VuplWjuKYH95nb7Uh4MEKdSb1NxG6quCiuXUh/q9uNT/yB5LpV5TGKCinqF2
LqT+Ymt3IHVLE1sR9YFIl1rqb1+vKKDuH5nCo36I6SWm7uY+U0ndSaWbT31B
TwKfune6axp1eb1XGcw/zTyPuoWROoy6aYRZOtz/Sqc7sD+zfrnU2U9uCMAr
+qDP7K4toT65reQ6dR/mxHnqHe2JEuqehxUK6lenlkO/40JbNHWtoU+l1F+G
ThdRtzhxOYf6ltnDF6n3XJdA783NlVO3+2gEfX7IpXjqSndWBvX4YXEB9Xkx
ymy4P95nE6l7sE5A7+fRkEd92Spv6PMaTC5Rn46rgP4c2z6X+r6VOtAvr0tL
ov6QqymjLpCrc6g3LVZlUXey7LwM5/vDTuiVitvZ1G2KhdBHm05eoZ7DC4Oe
FSzPoh7U4QW9S+9IMvy/rQh6K2ZNJvXAfHPoi5Y+SqHO122BfsJg4hr1W5bz
oV9REpNKveDNJPSq/j3Qb65XZ1K/t2v9VeqndI2vUW+xUMiot1f/Cv38znLo
9ThbobfXXgt9VMIN6IXrrEXU3TOcoZcxSjOob1ekQC8Jz4O+bfw49HNqJ+hZ
FQLoPbs0xdRDJHzoc+tHpdSb3U5CzzX2hH6qIxZ61YJ86HM4R3D+5VnQv2GL
oO+x/A56ttoV+in9LuiHgnKgj9JYA32v627oK/3006jP2BRDH+c7KqH+yXZb
6P0z90CfUXAX+tr9ddDzgiyhH7p7Bvo7XVXQH52+Br1u9Xrop0+LoA/TqYN+
TBEO/WFtU+hF4XehX+3yGPrZal/oPb5cCX0Crwl6Qd1T6B9n74J+pYER9Pqt
A9BnxrdA3/rCAvoTuXrQX149B711aTv08WOG0E/+sgR6H+XSdOorPDqhX5bB
gn6f7yLoTf7kQC+L7Ia+8uwH8K8CtKHX1dkM/sSxB3rfnYPgOc0s6MXH7MBb
b/RCr1nZBe6QyoQ+ds3X4Dt+64e+VNECfkCmCb1Foiu4hnQA+pj+J+CxvfOg
d67yAu+zGoRe7lAHnu/PgJ75+ii4UPIGelFyNXiK4Ry4H8cfXNo0BP5TVRm4
7vsZcNPUQPAe9V/g0kIleNX4NLidxxlwfuMweKH1LfAmQ+wPhoaA12aOgId7
/Qy+yXMKfJN+KJ4vj7e4/hOF4HY3P4Iz7MPBg99iv4SZD/7MGPuXs5HgpuGj
4LeCr4NbSSfB27lR4E7vsN+0JRt8wgz7SMEFcI7PO/BB+0zwhaoP4A/co8El
97G/Ei9DD8beYTAGPIA1Bj7OzgBftA77EpeL4Nr7sWc+lOD97J/APjYOvCEe
e4EsHd+Pm9jri+PxfFZjz8hKAy+PwP7VhQRwvSHsG2rE4NFu2Ie5JYLzlr8H
b2Rg32iOfR1TCF60DXuulwh8QPvf/m/rYHaA
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1ntQzWkcx/GKtgipFC0rIkIXocueiVWaVUmKpCVU2Jp0Nt0oElF0OZ2S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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Hk01Wkcx3HZSwkZW5iSJVkqVKYrknVKKktKUVGSyha3KE3XOgmZqxJZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xk0lXkcx3E1pg0pXUZCCffK0k0ppFuWNoWubBkUsqTsNzK0WBNRie4V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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1nlUjHscx/FRV5MUpaLtEiVXM0qXECndJEsT0oYWU00yYiwVKUr7druS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1nk81Hkcx3FnNVM0RiaRXBnjyIZGkWs0lOvRoAO7iCKJxoNtWR3Yoqkd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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV13dUU1cAx/GEUaaAWJTKDCMShkwl7D0UEYKjQBpkB1mBABKijGDaQizU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV13k41fkCx/FjnaicW8icY4sxsu9c2cm+5diOrZJB91hCtoxL2Tu5JK6b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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV13k8VPsfx/EZ104mu3Btd6QoS1G2rFmyr0llScpyr6IpIxIlBiHRxBUt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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1Xk81Psex3Eiu5DiIIQjxn5KkX2Psk6WbIVrZEkpkrGFruXgGmRJiXAx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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1Xs0lPsCxvGZSGyRyrWcDEnbMK5h3CuiHCEby+iCdopqZ4qdS7ltU3IL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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk41NsDx3GSZIlGV7ZBttAgRSgaY2uskchUN1kiDGmxZMlNGi2/FFFJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV13k8VekDx/GLUFlyC9mluNcWZRKSrtDNUrKl7N1EWsY2tpnSLze/G6Yi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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1ns41NkDx/GJonJJli6K5JLbuE6paCZ0W6xLilZlGYxImClkihGFrJIf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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1Xk0FdoeB3Ch3A4VnQxHw02nQkWZGlxDyfAyhDpJUqHcJiEhJKKQzBkO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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk0FXgbB/BriCuEri0h9yWyN90soRBFtNiFZAldCdnXQc1YkwjZvZLI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk81VkfB3DiWrKHaDJ213bJlkSWmyWGLFmiJEvWRFEP4jZXtuKJi0K5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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xs0FHgfBvBxl8uI2Hddsst6pzEuCallyt2bocUsNhVvqDeLjFQaJtcp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1nk0FVgcB/BHkq2SF4+krD0h5FW2huRJJd6krNWb1DQlex5lTUmNMkrk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Gs0FGgYB/BBLWWSza1RyrgMIRI6yCWsoaZBLjOViFErLYnYUpJLjVZ0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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Gs0FGgYB/Bxv8xQJrO2RiG3ylZuZadFpdRmqVzaItNNJBROddhI62SI
ak2IXCaaUpHaTKTdHG2OpF2DruQ2x60YuVSmspI9e/Zs5/l/es//w+/D+z7/
9zHZFe4VqMxgMBYpMRj/ni8aPnj3FDJX8Gts+kNTOpb/nx0qRvw5sYNfcmi5
tZ53Q+uXvPKql0/IoPxLTgi9WE59lz7vR+qtEo/aUn9uZTGfev2StGTqR5q3
baTerfP4BurbzRsDqfe+YRlAfWXl6h+oL/7YEkz9YEl/GPWHhotWUp9n9HgN
9ab68jjq/Y1nHqA+7EqUGfXPBG9cqNettkijXnd3XDT1vp0qTOplS4TLqZ/q
HxRTn5Roe4R6ceGTsRDiR9tFjtRnCFJKqW91do+nntkc00W92QrWMurzbNZV
Ub/ZT5ZAvadWfhP1dR8aHKgfjw58SP1iw8kk6sekg/eoD7RrW0K9oQrnCfXd
wrIU6sssueXUCwWW9tQPnUlso77jOfsU9ZN2I0XU+9+6akv9ow/d3dTL+Kap
1HdM2RRQfyV3hw31+WUeA9TbzxkVQv+OlWVRf+L9cmvqLR/2DcP86uLTqJdX
eQipN920ejH1yrzad9QfeSNLp9517EUy9Rs/Bi+ivleo/pF6TTu9M9RrTvAS
qK+pLFpIffiWOxPUCzdwM6kXFnkdpZ6poQLe6dD7z9TPdVfJon7YkxVD/UxJ
5DfUR8c/UPIhXilZCj59g1cU9SaMd1bUqxs4qlL/8PmRs9SnXmAfpN77VAL4
zXo71Kl/dtwgm/rHIqdI6n1Xm4FPqHXSpH6zQATe8fT9/dTzfJoWUH+Y16lF
vY83O4f6/NPnwqjPt0wCv9R1HZP6Foto8I7LqkKot+WvBd9ULWBRnzXYBD4z
hruX+pd/TAN/vjhbh3qn9XNyqf85/Poe6q3XyObD/rRO0aU+qmYn+FV2EUHU
v1cuBx8k2zqNet2MPPCsWr9A+H9WQvC+xezp1H9uaQTv/Dp4N/VSVgR4oaoE
fFvKJ/CjnMwA6ltZPuBPjjjqUX843jSPesa6zl3Ucy5+B95Y+xZ4pZ9cwffp
OIMv8LcAzxEZseH9OQHgW7dJdlJf0TgD/NpLMeBb+mLBb8/+FnzdBRXws7r/
At8UlA7eL7JhB/V3UhTzYH8+1ZtBvaraZfBuLyPBx64YAF8tXQ/e3ug2eAee
CXhJcid4qeIY+DGNB+DP9rZup15s+wx8vbsEvIvGU/CPMkTgrXWl4E9IWsF3
b5WBl5oEg2cq7oOfJZ8Ef9JxAHxYMg+8vOYu+DMiQ33qFS1vwIvl08EPbf8d
vP1OB/DX/cbBb40f2ka9ekk5eMdb68FP9E2BF4gbwB9LKwXvqhMAPjJHTUS9
2W83wWdMXQOfV3cQfEG6NnjbVXngx7uKwTc7JYBPHtAFf7AxCfzlBVfAZ1ec
Bm9UygZvMHEIfGx9IXjNKBF48ScOeI2IIPA6lRewv2WXwX9q+xr8wp4t4ANG
zoP3Ed8Ar87ngufN8ABfzy8AXxtyG3z7idngWQ9cwN+cOgf+rt1d8FoHjMD3
1/PA/9wgAq+YfR98FdcE5zduAz68Jg+86po/wU+emgv+lYUVzq89F3xjTQP4
6iZT8J725uDd2Oj//vUxeGO5GXgtNWPwartywAtmPQcfKjMH//ooF7xvXTb4
t/ovwLuUW4BflGqA/XFBn3GtDXxJuCX4JiN98LnSs3j/0Q7wi9nzwNub6GH/
9qD/Si4D35aP/lWCLnjmNPT7xF3g+dz54L93ZoG/ei8LvOfcHuxvEnq+izZ4
Xhz60Yhe8D296AuTNMGHrUJ/LaMPfMXSBeAvqmmAnz8dPSP9JXhWHHrzcjXw
h3sywUsiXoHnVaJvSVUFn1iJXmHTDz78Lfo5QhXwqTnoo1vRS0yscP+VKoNX
xKLftG8AfK8b+uZhJfBmAehDh9A37ke/1xX9JXf0Knw5eMNf0N8rZYDX5qH3
qEK/pwi9sg36Ucv//D+vJk8O
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1HtUDnYcx/En6mg9KZ2FtKULi0VUzqRMRVlGPHNnTTKJR7eni6SUkkvF
dGMuS0m3p5Sii5IU5ZhZ2k65PYolsajj0ipmY2fnbM7v7a/f+fzx+uP7PZ/f
1/TbgEXrBkkkkklqEsm/r47l6aNP86RORbLw6gfZbY7/Z80Ft1oTY568y52x
XyUYlKve5brZj9OcHz5+l6dU2JaIfliE/I7o3bwUyaIfKO5NF/2D9oxc0esM
WKlEb+6w/aDo9X8vPib6i1nB6aLPO2N+W/Q10pNpou9ytzgues9xkQdF79Th
fEv0pq3DM0U//EffLNEXJu1LFv3drO03Rb+99Ea26CeHbcsWfXFj9F7RV0ru
3hC949wPlKL3jpTniN71gE2c6INrFsLfLL5YIHrdNqtc0d/fs3uH6B0dVNdF
n3xdv0j0CytV8Jlx62NEr6sIgS9R1y0WfYefT57oN/fXRIl+VZkR/Cjn8yWi
b694CD/PbctW0T9pam4RvV6+5WnRz6mVKUVffjghXPTarfvhPQq8S0Wvss+H
Tx3bGSZ6Y/vV8ClLAstE/2doH3yPftRm0XfFWcMPxC4pF/05+dR80atNcgsV
fdgPWvC/DRtRgf6f94N/meS6SfTegV3NojfrPwvfez8NXhYvDxG9q1UjfG2g
6xn0R/sSfJ1nYbDoNUaXw/ea1MLHOz+C97GTwuunHYPXNvikUvT9cvUC0Xf0
xASJfu2YRPhD/RHwqY5G8H/0acO3O0XDV768BP98vQ28nSw/UPQ7UoLh2zU0
qkTv5+8CL5MvgW9o2ADvVWMPX3NlMfzI4drwkUmr4V9Hb4DXuOcJbx16TYH7
X7Wc+49KhFeo+8L/1H8YvkVrIXxoeQn8xthN8Noz/OB/XjkPvlutET7iSCT8
ZjNX+PDoL+DbjDrhn0btgFcrNId/6jGL8ytfwY/3SIDvGSyF77/twP8zTnpW
9M0eifB6Ib0BovdUTYefMcwQvjMzFX7Kmnvwfm528FX15vAK54PwRq7X4N2M
beF/OWAN7+5+BH56eS18jstn8L822sNL36TBR88rhZ9dMgXeWzkLvuXzDPj5
lUr4huU28G4rv4TfaZ7J+1GeAe9sYw2foS2Dr7h8HP655iH4adOs4FWPFsOb
Tchmf6KS4a3XTobXkq6Af7YyB76mew98WdEkeHmyO3yXey58meVueP0P6e1S
POBLbfPgY81i4VckWsLbmq6B731Bv79kG/xoY/qpsrXwYSlKeKcLW+FjaifC
p1msg19jmA9vMjMcXupPn13rDT9hH32DcRh87nj6QoMN8E3P6CfKQuF39UyA
z3WQw6tcCuCX1YfAj6umH2W3ET5kL/2ooGD4GUn0YTo+8MFX6JsWBcEX+dA7
N9D7/E2v5REIH+dGb7TaF/7Upyfgd36ngJfY0A/poF8vo394JwDe6yP6oMV+
8AkB9PEu9GM06S1L6bsS6DPq/eGrBizgr6j7wzscp69eSn+ui37ZXHrjCnrD
l37wzW30+3bSD71Mv0pJf7KZ/u0Z+rDr9Ju86LWu0vfdp7/YTp9qQV9YT//9
kAB4+2762a984b1r6C+b04/to5/TRK9TSf/1TPrzf9FHnKDfVko/eAW97eBC
+Dd76dOL6ef70J/TpH8bRL+gkP5SBH3gUPqWb+ij8ukvxNMr9OgHzaU3yKM/
eYD+tj79Czv6oTn0NzLo60bSu06kl2XRRyvf648h/VET+pZM+tZi+qUf058a
QZ98jN6sgt5kNL2Tznv7z6DfUk2vNKbXGkKfkk6vW0ffZ0L/WEJ/9Sh9dz29
nhl9yWsfeNP//D/jeSw6
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1XtUz3ccx/F+GtZoZV0cSaq1qJOQanEoCeGMIxHiaH40JCq6bHRxy7Jf
xGrGaDQt2pCjo5p0XJJQLt1sslJLVGrRxdZFdnbO5nyf778+5/XH47zfn/f5
fM7bQh20wL+flpaWvUpL69/TQxP4rCd90FT7JYmjM/Kq3P7PBc0me8/tfv42
x2dGRsUnV77NelN68sNrm95ml6bJ1kq/v7YkXuntv2+IVvplI/yvK72mc46V
0tcM+wbeIWjoNqXvdM6DTz9y2lLpD+9Ww19aa7Bd6Z/GDihQ+tFl3hZKbxri
Am9sWA/fHusBX9/iaK70oYFG8HGaxB1Kbz4rHP7ehJkjlb5p1t8apZ+UY7VT
6dN2HYffvC/GTOmLdWrgP4xNhi9Kz4e39agcofQPfi+Cf6TTb5fSL22ogf88
Zz78YINceLuzi+A7pnSx/xnVpkpfYXIGPtLzCPyJKN0bSn9IJwZed2sK/KLx
FfCqxWbw/YrGwtfd/RZepe4fq/R2y+3gIypbhit9+LUEeP+tY+DzBrjAG/Rm
wXfp7YGf/nAefHWuO/yghXvgF0fthO87GgB/9d5s+E99VsFProyGX569HT4s
bj580i8e8MF9W+AvvkiCdzf3gT+w3gY++mYE/J3WVPhThb7wY+IM4ONNw+B9
3M7DDzy5gvW9VPBBdZvgryzIg29/vBL+jk2bidI/1gmBH/nVDXi/favhN+yt
hy+NCYL3dboLr7n1GbyJ3iP4lo83wncfLIcvS10Ln+9dCm84agP80qcP4b3G
BcBn6BXBvzc9ED7Gqxp+zRfr4Vu1C+BHfrkePqevFt5VEwiv3XsZvrkxAL5R
tx7eJGgD/JLiXHizNfTfHX4Gn2m3ET5lfg68Z/c6+KrsRviI28IHXIDPOkZv
uPU5/KW5QfCuqkx434X0e9qa4bsu0m95cw7+hBH9a9s/4WuNguFbvDPgw2rX
wnfat8LvXEnv/OIMvE4W/ZyBL+A3HaefePM0fOMB+hm59PfLRf8lP8M/3Ew/
2OslvForhPujP32FL/3ZO/Q/WtGH+/4E/85M+tVObfAl0+gTitPhzzvSZ2jo
m5fRR/rQz7Km31Ym6gfTO3ecgp9tQj9drx3eaQd94A/08/TpX0+lP7Of3m8F
/ZuB9OoA+uyj9Jc/ojdS0ZfH019Ko095dRLep2cNfFg6/ZAM+pB79Pte0Xte
pe+7QF91lj6pjX5oBf21XHH/RHqPVvrkevoDV+gto+h3NNP7tNMnXKdfFkDv
3ERf2EdfV0h/wZd+XoOY37sd8Gm36bPn0mc/pXfQp+8opq+ZRu9fL/o3pq++
K/xE+k+e0LuZ0ofdp/d3oFfX0Reb098uobewoz/2B/0hK/onpfTt1vQ9tfS3
RtGXltEnWdKHCr/Olv5gOX23Gb228Ml29JMq6P8aTp9aI/6vPX2+8JuG0S8W
vnMs/YQH9KuG0hsJ7zqe/mvhU43oax7Tz3QQ7094N0P6TOGtJ9Cb/0qvY0Cf
IHyl8IuE1/+APlj4UEf67cK7DxHzF/6l8GnCJ+rTuwvv50RfILxK+HHCZwpf
JXyCHr2F8H3CtwtvI7yx8I7O9Nq/if3xPr2u8Grhhwh/RHht4ROFNxPeT/je
avos4W2EtxX+1X/+H26oGHs=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1GlQFHQYx/FdjOQwWmFDdhPBBDQhLmFSidEwX1hgg2/MPDIcZhsbMF40
DSKRhmTQQKy5TAN5RMUsmSQxmkBIwQxxDSIghyQRC7uwSyZXJkdNL2L2+7zv
na/+83vxmXnmOf6rE47sSnRQKBTBSoXi3zd1NCDM6aLr1ivemQfUXb9s+S8X
R6wty8qxLuYzpWWpiR/0LebSlUn6qf6xxVyxVAX/aKEG3il3Er485Di8suby
fnsfmOcGv7x8/VF7X5eeD39pXSJ8nMERPjNtN/yy6rPwVVMB8JWxC5fsvVt/
Gnx1uhG+K3lqn71/+/X78BO6T+H3bC6HL0xshr+in4TP012Gn9t1DX5WVQrv
/vVd+JzhevgTntfhsxdy4f0ybPAnKzvh/6yvg39HmQpvtI7Cv2cYhD+kb4A/
4K+Dd+w0w8c52eAdjU3wN4pfgZ/2HYF3zpyCDw9shc+9HQtvuG6Cn9PNwjdG
tMGX7dgGn39+CP6aQplm71P6b8A3vx8Fn3L1N/gjHznC50TchNdviIT3ejAI
fzbaGd45tgO+3T0UPu4gfXz0MnjXkE7405ZA+IShX+EHL7rBJ5vps7LWwdvS
6V8tUcGHpnfBr2rwh88MpK+IcYe/OUPfnrOG87cMwLd+7AH/2Z5b8E1Vq+E3
ldMHnVfD3zbSj8T4wquy6IuOPQHvYqWvVvnAhyfQl4R4ws/6dMN7eK2Cf3w7
vdeP9PMv0rvv9IbXPUMf8uwKeHMSvbp0JXyoll5TQL89m77bj/60C73zMH38
BfqC75+EN83f4f75ebH/FfQlB+kLJunrd9NH19G/oKHfbKXPPE5vaBN+QAv/
lon+jWL6wl76yG/px+/Q22roawbp5z6kT+mj39lFv99CP3SYvuUWfYaZ/odx
+i/j6Xs66J+boddO0AdEi/rb6aMcNPBfTNNnBdG/20Y/40p/8j690od+rJW+
24O+94G4PzX9hRb6rVr62jn6p1zpzzTTH/Whf2lBzG8JfWUTfe0a+ry/6e/N
a+BdhA9eS69X9MCH/UV/rJF+8mn6Q0r6vdP0S4WPCqJXOdAHT9Abf6ZfHkxf
JHzRXfp9wueH0D+2hD57nN5b+JZQ+sPCd1nprQ3i/wqj/074jDH6n4TXh9P/
Ifxro/TnhH9+A73/I/Q6C/0J4duFf1n4z830ScJviqBPFl4l/F7hPxH+lPCG
Efo44fuELxJ+o/Axwqsi6b8R3jJMv1H4bcJXCV8ifKjwbwrfIHyy8OuFPyV8
u/BbhPcT/ivhe4XXCu8rfKXwA8LPm8T9Cd8ovEn4YeG1wvcIbxG+Q/gVwpuF
twlfK7yn8Dbhfxf+qvBq4WeEvye88aF/6P8H/w+kkVyB
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt01tIEwAUxvHVg0TaEi2nVFSS1tI1xRUri02naUmYqa2rVC6WqWhZiQYl
oqGFl8qldrEINK8js7YuRJTdWCokdBNLCh8kM/AhLCiKHhL+5633PR2+h9/L
+c5ZuCdn096pCoVi2RSF4u+0x30snGX3NE5v6wlKGH1v+Jd7K/quzasencw2
w4zmrIMDk7mrrrSx8+3nydzc4IRv0PbA+6sC4F3B5fDm8Sb4lEQX/NSCQPih
iVPw7Xfr4V39z+F9R9TwYRGV8DXRVfDxjc/gR15o4QcnquC9Jk7AWxxP4euO
6OBL0k7DV1mK4Of+eAKvVevhOwvPwOdrj8IvSqfXqCLhB7afhdfPzIdP+vIY
PiNjDbxBWQO/zZUHH1JJbzAa4Gsv0CdEHICvMdHH3jLC2zxt8F+DcuALp9G/
GoyCT7LQt5Zmwze+64af/iwa/kor/ZvILPiTN+nPF5ngUz/Rl6zIhA+upT/n
GwN/WHkOvtS6H37wOL2yjD4rnL6oOwN+Xza9eZh+/gb66ih6Vxp9riYW3ied
vm5gH7wumX63lb7gEP23MnqP9fTrbPTGYvrkePoH0fT2O/ShFfSq2fQ/V9Mf
e03fbxP9fbHCZ+vpE8boWy/SZ/bQ9+norb/p51ylH75BPx5Of3vGWnhrE/29
Bvo2Lb1fAP3LFnpnJf0HDb0qkL6knV5ZTH8wlH65mr7FTv87nz4xhH54Gf2O
6/QeufSZS+m3RNB3ddLfz6B3qukHV9A/vEHvstAvFr59JX19F/2rXfSOJfSf
IulNN0V/O+m3Cd+xhr5XeO12eh/h/Qz0q27Rh2+lH1hMrzHSVwrfZKbvEF4Z
Je5X+KzN9OXCPxLew0Gflyr+X/jEaPow4e0p9FuEvy38RuH9hY8T3stEv1/4
y8n0euHNwhcJrxdeI3yV8NXCj22iDxLeKfwl4a8LP0/4IeGbhT8qvL/w34Xv
FD5J+Fly/zH0DuFXCe8t/ALh7wsfILxS+KXCPxDeW3gv4XXCdwv/K4neU3i9
27u927u927v9f/g/09XU9w==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1E1I0wEYx/H/EgJRkwTLjKaTZDFQu5lhVGBCSYcipJIsx3zZxJUIi96W
Oc2czmUvIK6iLSyK0JIGJYFEg0gLFGxW2CwHRUovbhk7SXRo8H3OHf+nh+/h
c/hdHp3x6N7qZYqi5GsU5e8N93sC2Q+StmkN+b1nlNDWf92c4Su0X5mPtyPj
+/zxyvfxHg8mbemfnIt3WZ8BPub3wucs/wmva0iGj73Tw8+Y6Q87FuALP9En
DufCrymgn7gbgZ/dnAIfTl8PP6ShL3VF4XOb6SsmcuC9oZvw0eJf8Lf89P6g
Dt71nN4ToI+E6PXp9L4B+pq8RfjpJfrrZ7PhT96g32+nb1m9Aj4rmX6ph372
KX23gf7jUBZ8xQV6wzf67UX0ipX+azO9Le03/LUS+rFN9BtO0e8qoDftpr+d
Sv/YRt+2g96wj37uhxZ+ZxP9k3L62gP0lVP0vmP0CSb6xkP0jQH6Xit9kZXe
fYQ+6KdPaKDX2+hjRvrOe/Qv6+nLTtNPmehfeOnfWsT+c/SlNfSpHnqt8Hda
6Y219NNX6d1m+qZ2+uI6+lAPvU54Twd9WPjxbvpXdfQlnfQ1ZnpLF71TeHcX
/Zjwl5z05cJfdtFnWsT/6KDPE76qm/6g8NF2+hThNW56p/Bpwi/W0p8QflD4
6vP0YeEnhR8V/nMb/RvhMy/SzwjvEH5U+D3CLwi/UfhnwtuFXxI+0ko/LLxX
+MR6+hHhHwk/IvxK4fuEfyj8a+FXCd8i/IDwH4RfK7xF+PvCfxF+nfBVqle9
6lWvetWrXvWq/y/+D1R2evc=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0k9I02Ecx/Gfsy1xNgeJSAfRIIxSQy+CmI5F7GAnhQ6eQpoJNhfUoUMH
FUX8G4GHiUwiD0YdFCG8RKQUbeoyFK1mZZFYmmGlRDuMokOD9+fa9Tk9fA4v
3ofvU9gYrPPbLMsqTbOsv2/egfOukimnJ+y8El/IeVfzb+89nfFOhL6k9u00
e0FTbTy1n0ytX4u82E7twzeC8M5p+sA5+niU/qCbfuU+/WQnfcUa/eyjVvim
MXrbBL3vM/1oO70rTP/6Of2RH/Rj9fS+EP3SJn1bgt5WRj85RL/6i979mz6R
S5+8Rd/ocMBXp7+Hb06n379JH3LT+x30d/cD8IFBem8e/WwG/fAWvW+A3p5P
35tJ7/1A39xP7z9Kv+Gk343TP+6T/3eM/lMWffkqvVd80XH6e4fo7yzRb/TS
Wyfoq1z0Pxfpw+IvnpS++L0Y/SXxV4vpk+KDC/TV4j0l9Kez6c/M0xeIfym+
RfzlOfpM8WdL6QfFR6L0iR76EfHj4uvF74h/I/6h+O8Rub94+yn6qPgH4t+K
LxK/LL5L/CvxHvFr4i+IXxbfIP6j+Erxi+ID4rfE54uPib8u/qv4LPHz4jvE
74q3iZ8T3y3+m/jkM9M3fdM3fdM3fdM3fdM3fdP/3/4fyuvy6A==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzty00ogwEcx/FnbvKuVmQXDkzDQVo9JxRtUcpmWUq02mVEypE0W8tss3FQ
amZeJlIOo91cxEUUu6woNRRxkxtFDp76/e5u/9O37+FT65q0uQsURWnRKcpv
+1zlTvW4qGN1yByzG+/b/358x2/PxN+093gSSYN6q329d+1Uf/Wq/V43+sEt
9A/T6Mf86EfM6K+T6KMz6G8C6BtN6I820Bvn0a8soP+oQ59PoLcG0N8F0b8b
0FvZB9FfLqIPV6HPraP3htDPhdBb9Oh95Bsi6HVh9M+V6C3kB5bQj5I3VaCv
Id8aRZ8i/1KG/jOOPks+R/67FP0j+d4Y+i/yNvJZ8pvkqyPoL0rQn5PPk28i
P0X+hHzhMnqVfBv5DPlm8l3kdeTT5DvJ95B/KkZ/SN5Bvp/8GfkD8m7yDvJp
8vvkJ8g7yW+T3yU/S36YfJh8irxPvHjx4sWLFy9evHjx4sX/q/8Bsj5W4w==

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzty71KQnEYgPG/gRAI51gmtDQ4Oemim0MuNTUZgaWT0KiiVyB+QNDS1lQZ
rQUtlQihSA75gQgGYeRWQw2FVxANHXifG2h5p4dn+AUy+cT+gjEm7DLmt5V2
73zj1hPfWo1Ug7HZ+t/f+Y/mx/VP53eS1kUtOHU+kS2dHDx+OF/2S1+Ev96V
vg1f8kkfh7/ck97OSW8vS78Gn05JvwlvLUnvhn+Cz8Fve6Wfr0gfTUt/CD+w
pX+HL8CfwefhX+FP4a/gQ/DP8A34G/hF+Al8H74J/21JP4Z/gW/BT+FH8G/w
D/Ad+CH8F3wX/l69evXq1atXr169evXq1atX/2/+B82tbzM=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANE75FpfB+7gdjBz4D0f5XvPHsYXNOF9Er7kNZz/
rGU7X7/YLTj/VlW4o+yxV3D+PXtU/Zxo+vlaUfU/Q9O/DE0/M5p+XTT9H9H0
F6Pp/2eMqt8NTf8PNP1BaPr/oOkPQNP/G02/M5r+X2j6o9D0/0PTb4am/yea
/ng0/f/R9BuO2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP
UPsBFtKgZA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFva+xN43ZxO6xlernyT9w9exj/1a2o4J/LX8P5
PDwNqzTZbsH50Y9WN1049Mp+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qP6B1A8Ak/sMTQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHKt3/WZe3hdohndueQKrhnD+Mv5//3qW71azhf
eN3HJo9vN+H8lh1P1s3f/8p+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qP6B1A8A1qSsGQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANERlltOlO3jdti6/ALXvoZ79jD+i+9lIq/XvYbz
xfJyyx88uwnnf/6ZW9Kx55X9qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/q
H9U/qn9U/6j+Uf0DqR8A1cTeKA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANG90/OEmg9wOyxW7g37NOGePYzPpRezy37Tazi/
venbo+fXb8L5kuZzL3TsfGU/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VP9A6gcAAQ3z5w==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGHvmrE9B/idlBfYRixf8E9exh/uWHosrqtr+H8
IrVHEWEnb8L5G5S3M87f9grOV0LTvwJNfy6a/vVo+kftH7V/1P5R+0ftH7V/
1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7WfHPsBdSFHBg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANE/gh8vnX2E22HVqisVOhvu2cP453J5UlbueA3n
vwpUKVDZfRPO75jwt/rk5lf2o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+q
f1T/qP5R/aP6R/UPpH4AP16M5g==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANG6m+a+X36M2+F7w3Z3h/337GF8kZi7gQd3v4bz
VeXaZnqvvQnn13gwPmTb+Mp+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qP6B1A8AjGmNkg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFJAhGWW05wO1TXnZrNcO6ePYxvKXR6+fF9r+F8
2xWK/47Ovwnn729a/SN03Sv7Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/V
P6p/VP+o/lH9o/oHUj8ADtKvjQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHT84SaD5zidmjPubau6M49exg/XEy1du/B13D+
7RkWKX2TbsL52/hmrt66+pX9qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/q
H9U/qn9U/6j+Uf0DqR8Amqw0Cg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFnz4AAt8Nhza3Gs1/ds4fxJ/Srnl185DWcv7bl
t8SC1ptwvrdyzT+Vla/sR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+ofSP0AasgnDw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFM2u1iN89xOxScXZ5R9+OePYw/9cOBqurjr+H8
hpPG975V3ITzA7b48C1e9sp+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qP6B1A8Aj5zCpQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHmnY4JTy9wOzS/mKamwHbfHsbfOuVisOup13D+
dB/m2305N+H8/qsyvPpLXtmP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1T+Q+gFkt4vD
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANE5z3+v/HiJ2+F31823zcL37WF80Sv7hZnOvobz
L5TK9qck3ITzi5cV2J9Y+Mp+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qP6B1A8Aj4Pm6g==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGLXLd9/nuF2+GCzZ8PaxTu28P40Tv2p246/xrO
rzdjOFESchPOz5rL8Ct3/is4/wya/hg0/VVo+jPR9I/aP2r/qP2j9o/aP2r/
qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2o/OfYDAIm7okw=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHXFxfYcl3ndpBd8Ex2nu59exj/2e/tz8IuvYbz
/6edm77H4yacv6Hj0nz5ua/gfG00/U/R9LOko+rfjKZ/1P5R+0ftH7V/1P5R
+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+8mxHwBCKmFx
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANE8TNrtYje5HVIzVqlGWd23h/EfXnmo9uHKazif
7UKDr6XtTTjf5PDMBXdmvYLzs9D0P0DTz42m3xRN/6j9o/aP2j9q/6j9o/aP
2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aTYz8AuYtaSA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGOCU8vKN3mduBhNW9+7HbfHsa//0B3dd3113D+
5HqjvBeGN+H8bx5B5UtmvLIf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qn8g9QMA83shzQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHl++ZL6d/ldsierthoE3zfHsY3Fq54x3TrNZyv
fTli/XG1m3D+thM8K8umvYLzk9D0m6DpV0PTvwVN/6j9o/aP2j9q/6j9o/aP
2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aTYz8AK9Jp0g==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFrZKJSrO9zO+TNXW6XHn/fHsY/uGBSUu2d13A+
39kDH69I34TzZXc8Phw05ZX9qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/q
H9U/qn9U/6j+Uf0DqR8AOxCyHg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEPq0TWuT/kdgjq5d6Smn3fHsa3TNMrfHfvNZx/
oMLIlk/wJpzf/FYozmLSKzjfE02/FZr+3Wj6G9H0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj859gMACTh23Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFiN899D37M7XDmTco2y/L79jB+kviymrCHr+H8
6MsL9hSy3YTzlxboiKpPeGU/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VP9A6gcALRqrXw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANE+5p2OCU+5Hbje/fj1pOm+PYxvMm3Dg62PX8P5
nPoXd/39fQPOb1dO65XrewXni6PpN0bTz4emvwNNvzCafiM0/cJo+rvQ9I+6
f9T9o+4fdf+o+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3j7p/ZLofAM+K
86U=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGNU527c55zOzj+0JHK7LtvD+P38f/7xPPsNZyf
uSpj/oaPN+D8LUv/FMj1vILzvdH096DpL0bTvx1Nvy2a/l40/Xlo+reh6R91
/6j7R90/6v5R94+6f9T9o+4fdf+o+0fdP+r+UfePun/U/aPuH3X/yHQ/AKq1
XCk=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHbPv+9UvGS22H+TMVJx2fet4fxix8cYo558RrO
17ILfNPx/AacL5q/Il+t65X9qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/q
H9U/qn9U/6j+Uf0DqR8AYhb30A==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGvA3fItb7mdvjGyHSScel9exi/6oRR3OJXr+H8
x05Z1q13b8D5SXOV7Mw6XtmP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1T+Q+gHsLBfR
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGKG4oyJr7ldug1EuKX3HDfHsY3b3/n8fjNazj/
ukOVzZLLN+D822Hbp/q2vbIf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qn8g9QMAjmz0uQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFhfLqb5r7ndrhb37KAb/d9exi/c10qm8z713B+
c17k5icnb8D5N78/Ns5peQXnP0fT346mvxdN/z00/RfQ9Heg6e9A038bTf+o
+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3j7p/1P2j7h91/6j7R6b7AVqF
+jk=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHdOc9/r/zI7bBxim+Z64Eb9jD+vfb/Nyc2vYLz
M9bKLn989D6cP09X76rvx9dw/ho0/bfQ9Feh6Z+Lpn/U/lH7R+0ftX/U/lH7
R+0ftX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7ybEfAPRjDMg=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEHTi103faZ28FcaWLO0W037GF8O+03PvsaXsH5
z2+utZ554T6cb3A/6EPF59f2o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+q
f1T/qP5R/aP6R/UPpH4A7ox/0g==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHfNGL6D33ldlBUZOhNXnvDHsb3L78Q8rHuFZzP
2JWcbnD7PpxfbTqrf+7X13C+NJp+HzT9Amj6q9D0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj859gMAKO9dPw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHa7WI3z33ndphZ/+yO3JIb9jC+97bre7RqX8H5
G+L/qqx6eh/O1/t29Pnu76/tR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U
/6j+Uf2j+kf1j+ofSP0Aoi0mOA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEJTy8o3f7J7fDpwOu8b7Nu2MP4E71+BGVVv4Lz
GTLvJbJ/uA/nu1w/o3Xl52s4/wea/ilo+j9moOp3RdM/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/av+o/eTYDwAXnMXF
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFTnbtznv/mdjiwRSLp5cQb9jD+l5r9z9dXvoLz
T2Zw/Pf4dR/O37WBr+PZ79cIPpr+j2j6r6Hp34mmf9T+UftH7R+1f9T+UftH
7R+1f9T+UftH7R+1f9T+UftH7R+1f9T+UfvJsR8A25d5Kg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGnF7pu+/yX2yHB+cuDbx037GH8FEklv9/lr+D8
4Nb/L8yZHsD5u+4363z++9p+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qP6B1A8An+vL8g==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEQwOPQdGSLglzDDXsY/0pQYLRP2Ss4/73r6SA7
9gdw/qukF06//r+2H9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP
6h/VP6p/IPUDAD8zUzo=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGmcbs8eZh4HKKWNCfEld+wh/E5yic/W1TyCs53
446QteB5AOeXqD3+/Jvxjf2o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of
1T+qf1T/qP5R/QOpHwCghqbH
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFZe0omS7DwOIimX3yxLe+GPYyfzK1w8l/RKzj/
272iJaqCD+D8gOeaaT+Y39iP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1T+Q+gGBR+8l
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANELpPTvqrDxOOwI2cGlnnbDHsb3/v7vbnzhKzg/
4uVke3axB3D+aY5F+96zvrEf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qn8g9QMA+2ZpmQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFXK16qGXLwODT75civi71hD+NvzXnFeCz/FZy/
u03N6a7UAzifbU2dwiP2N/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9Q+kfgCHXNfV
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFc1xcX2HLxOJyv2tbuHXrDHsaX8zAWNsx7Befn
F57+vVz+AZz/1z9m7XnON3D+KTT90mj6y9D0/0HTP2r/qP2j9o/aP2r/qP2j
9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP3k2A8AjZOUQw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANH2pnG7PHl4HB7MqV79z+eGPYx/YeXyjwtyXsH5
P6dO3ZGu8gDO17OIat3B/cZ+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qP6B1A8AZ5nj8A==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGlkyVYwvh4HEIEfH4ec7lhD+NPmFhdJ5r9Cs43
E3U6KKP5AM5nvWh4fA7vG/tR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+gdSPwCUH0LH
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGrPl7yTRLgcdhV8+fpYpsb9jB+o7fxnL7MV3D+
rFfZ0cd1H8D5z5x8JtTwv7Ef1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qn8g9QMAcFkUEQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANH3/Xun5wnxOMwucHszxeSGPYx/s6lfjyfjFZx/
eN7uk+lGD+D8gvhrf8IF38D5C9D030HTvwdNfyGa/lH7R+0ftX/U/lH7R+0f
tX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7R+0nx34A706XUg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEi69wfVonwOJRqFfTM1LlhD+O/ulwl1Zf2Cs4/
lSTs88/sAZzfy39ZXV/4DZxfhab/DZr+o2j6+9D0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj859gMAwNyh2w==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFePEza7WI8DnovfnlvVLlhD+MH7vrhKpL6Cs7f
92K7fLf1AzhfOVVHm0n0jf2o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of
1T+qf1T/qP5R/QOpHwDKsQZB
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANH1WXtKJkvwODRohm+9LXPDHsZ/t0d0xrzkV3C+
vVNZPZ/DAzhfL/+w/EWxN/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9Q+kfgDq5PdS
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFbTpTtmy/F4/A3bl64hOgNexg/cveNHzpJr+B8
Kc7jiztcHsD5jm/qZOdIvLEf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qn8g9QMAGhrl5A==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEv1Qw51sjwOCztCzyWxnvDHsa3dzEN3J/wCs7/
xPP+0E+PB3C+9pcI62SpN/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9Q+kfgC652CN
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHyra8Dd8jxONxrlJl5jPWGPYzPeO9fV2j8Kzjf
eo+sYJLvAzg/bH12v5rMG/tR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+gdSPwCy2t2v
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEhj5fOPqLA4/BKem62+b/r9jB+ge7dCe9jX8H5
TJWdBw4GPoDzeQz+6j2TfWM/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VP9A6gcAIYYmqA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGdjglPLyjxOHA36t3d8e26PYzv+8LBrzfmFZyf
xNrFKBn2AM7/UN+lt0j+DZz/vwFVvwea/lw0/e/Q9I/aP2r/qP2j9o/aP2r/
qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2o/OfYDADacZx0=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANH75kvp31XhcbDcv32C1/vr9jC+cnPker3oV3C+
hv5GpoyoB3C+1KeLC6MU39iP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1T+Q+gGay+j9
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFf/l6peKnG4/BqQ63Om+fX7WH8id3cCy9HvoLz
E+89/LAu7gGc//LEndn8ym/sR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U
/6j+Uf2j+kf1j+ofSP0AL+kKvg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGaMf2HvmrwOIje+B4598F1exjfYuFzgZqIV3D+
9eWp398mPYDzv9lw6B9UeWM/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VP9A6gcAbon1zg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFxuzx5mLR5HFS+Lz8ae/O6PYxvxqj0Vj38FZy/
gYHRQTX9AZy/4CNvbr7aG/tR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+gdSPwAmhWy4
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGTJVjC+HR5HA4bfpHTvXTdHsZ/P6NL5XroKzj/
jS7b55DsB3C+6yPudCmNN/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9Q+kfgAsM3Bt
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEnyvbNl9LncehtYZbgPn3dHsZ/NLV1WWfIKzi/
nSPdvDb/AZyff6lb95DmG/tR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+gdSPwDGCTPC
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANH/rlS8VDPkcZBOn5P6/fB1exjfMJMl2T74FZw/
c81Ro3nFD+B8a6+uC2nab+xH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/
qP5R/aP6R/WP6h9I/QBwDPtK
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHGYMDj0J3Puv/jnuv2MH6PWb3Xj8BXcH60egvn
jvIHcH69em08h+4b+1H9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/
qP5R/aP6B1I/AMLeHrg=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEZE9/W2JvyOARden7359br9jB+6bJ3vlsCXsH5
OeaX752qfgDnl5yOfLlM7w2cH4GmvwJNfyqa/lI0/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/aP2j9pPjv0A4FtuVA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHz3i8/5m3O45A+x7iOf/11exifU/RYXLH/Kzh/
kf6BK9fqH8D531/PqnEyeAPnF6Lp50fTPwVN/080/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/aP2j9pPjv0Aatg57g==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGXfZMEIix5HCw6WOOMVly3h/Gnib3LM/V7Bee3
8Djx3Gl+AOd/5nNTv234Bs63Q9M/E01/LZr+L2j6R+0ftX/U/lH7R+0ftX/U
/lH7R+0ftX/U/lH7R+0ftX/U/lH7R+0ftZ8c+wGpaPIA
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEca2SiUqx5HG4H9NkmLbxuD+Mz+Owv+OXzCs6/
esp16a32B3D+860fvhUYv4HzH6DpZ0LTfwFN/ws0/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/aP2j9pPjv0A7RrdgQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANG2XNcXF9jyOGhm/r43b9Z1exh/TuPfsEPer+D8
r9y79l3qfgDnc9sf/cFs+gbOz0TTvxNN/xY0/cJo+u3Q9C9B0/8ETT8vmv44
NP1b0PTvR9MvhKbfBU3/CjT9t9D086Hpj0TTvwlN/5FR+0ftH7V/1P5R+0ft
H7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+2liPwBr+3wF
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztzTFLAnEcxvG/Di4KgnergzQGhpqiy51TUIODtDRVouIQGA1NLQ7Roogo
BLZFg4GDuetUhJsg4SqCIKIvoEXFwYP7vgKH3/TwDB++gUwxnXMqpYIOpXb7
UKitnkxPMr++cc3rY3P/Y9pIr1wsrD/Qm4/f1Yn1faWXRCO2tL5b3dr8P7xX
s/tz+Cn69/Bn6B/BdzZ2P4S/Q9+A98OX4V3oH8M/w/fgX9GPwxvwb/Az+BP4
IvwXfBc+Cp+Cf4f/gw/BZ+Hb8H34U/hL+A/4IXwY/hr+E/4HPgJ/Bd+C/xUv
Xrx48eLFixcvXrx48eLFH6zfAkeVm3I=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztzc8rw3Ecx/GP5WYlpcROO/gV340ZVpIfN+TihoNSXF0k2gEp5TCL7bLk
JDUntzkoK7V9qW9pKS47yMnWDpKD1pIcfOv9LP/B+/TqdXj09C+vza14jDGB
OmN+N52fGT6Y8I5XrfOt0djz2N+3487pwlTZ/cHwV+ky8eL+Wnsq549U3N8a
kX4nKf1Gt/TzndLf9EnfdCT9ZL/0ix3StwxJH09In+qRvhn9UEj6LPqZoPSH
6NcPSt+I/nWv9O/wn+i3HUv/FpA+Db8Zlv4BftaSvgi/NCD9NHwU/Sv4LvQv
4M/QL8CfoL8KP4J+Fr4Gn4R/RN+Bz8Cvw/vQv4WvwMfgX9G/h7fho/AN6Ofg
i/D78B/o38E78NvwHvTz8E/we/BV9G34Avwu/Lelfe1rX/va1772ta997Wtf
+9rX/v/9H3sTr4Y=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztzc8rg3EAx/GHA8qKGw6K2IHiNrWDLC6O4uImK1qaNj+2tPzYLyulpPa0
w9SDmZ5MZj3FRbmp2SwtawdWo3agHZy4UHLw1OfzJ+h7+vQ5vHp3Wh3jM7WS
JPXXSNLvlrrrfPKIweKfsktKqDj095uiD5Xe0Tf9h+V6kxwp6/8x/a2emqv6
bwygP0ugLzrQ3+bQ22zozQr6jm30LRn01lX0uyr6Vzf60h3159HvHKDPh9Cn
qb+/gj53TH0P+knqDzjRlw/RFwLo+7Log270+Th64xp6A/XvF9ArMfRdfvSz
1B9zoR+mvn0d/Qt5bRF9wxF6kw99kHxyGf0H+dYN9FnyPUvoLeQvvOhl8hPU
z5D3UP+avJP60+TnqK+Qb6e+Rj5F/UvyUeq7yA9SP07+i3yMfIH6Gvlz8l7y
Ruqr5Kvk98hXqJ8if0V+k3wb9U/IP5OPkH+nfpL8Dfkt8s3UT5B/Ih8m/yn6
oi/6oi/6oi/6oi/6oi/6ov/P+z9g5zAQ
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztzU1I03EAxvF/SdtlmmTskFqKJZJiq7wlTcK8LEHN5QgMHHqRXogyX3IQ
RbIgg4iRlAfFoyBFJ2Phuohv3YKonG6i5UsvIKPZIRUPDr7Pvdvv9PAcPnzz
/TfqWvZallW6x7J29sCDyNTgeUeFrdbe7Lj3yb37J+pd8X9Vq6nfHT166/bL
WOqHN678LjvzI/Vzgzb4wJ8T8ME3x+Bts/RnC9j3uNmvzKA/uU7fMcz+QTt9
rJc+K06fsLMfOEXvLab3/KIPRthPZtJfb6d3LtKPJOm/HKcfLqffWKN3fqCf
ddKnt9LHl+g3f9JXF9JvVdGHVulDH+mbDtHv99MnvtG7lulDBfTF1fTvV+gz
PtN35dBfaKTv+07/dpE+kU8/V0N/Tvrhr/ThXPqbl+n/Sn9kgX4zj95xkT65
TF8Xpb97mD7ioz8tvi1Of1X6vnr6afHuOfoV6Y830HvFv4vRO6Wf7aV/LX5G
+iVH6Eul3yreI/158X3SHxBfNE/fIH7mEn27+H3SHxMfk/5z8T7pXxP/QvoB
8UviX4lPE/9UfKf4gPg74u+LnxQ/JD5P/BPxj8T3iPeLfyh+VHy/eJf4x+Kf
iQ+KbzR90zd90zd90zd90zd90zf9/97fBm4sexg=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1dtL02Ecx/F56KiZlZAiEpKiZXphphIeWs65SlmJpa7mPJBIVgqeNk8l
OonAMjRSskwbmKlbHih0zVCIspNilkRizkxMVrlOEGFFFwmfzx/Q1a5+fC9e
vB+e3/PwuKdmxR61FggEflYCwd+vxFjopI2y3zUXmpmlVo2H/5uThKcrnkfO
L8069Vh/TOPU0twfu07TF2Jamsu748B7avLAP2kwgX9t7QBe2pAO3mlDKfin
ylfgz2gcwVemJIDXKwrA22rnwIursP9Slwa+uasYfG/dBPhzgdgP6JGBHyxQ
gs/znwXfMoN92XgK7t9YEfjOC5Pg3c1rwV/xOQL+rLcK/M6mGfCjruhXdySD
b4/CfvnIG/DR99E3Octx/XXYN11/C14Thn5gQQHe5lMheEP9FPjmVvRBWuxf
nMS+gy32r8WhN6qwv+oO9oecjeC31qHvsE8C72iH3qVxGnxZKvoXftjvqkH/
KwP7m6vQx0iw7+mFXq7AvigTfe5v9Kkl6JsvY9+3Er35BPrJYPQeQdh/nI2+
2ohemoW+Vo/9oTL0OjV6OxH6B27Yl+Si73mG/mQ6ev0w9m1OodfWonfdh/7e
GuwX56N/NIh+NBl9/gT2I0rQe1xFf16KXmOD/akC9GI9+ig5+rIZ7HsXo9+k
Qa+IRS9cRD+gRK++Tf/vMPqa9+jzi+j+tqD3ikMf+AO9VEX9bvRNiegfmtAv
o77oJnrxQfRt39G3Ur+xE/3dBPQjH9EbCun8tKFfpL79N/TT1D92C70P9V0W
0FdT39COPvsQ+hVf0S8nf0OHfjge/Tz1c8jLOtD3UV/xBb0beR/q11I/24w+
hbye+rPU//mZ3g/y77Toc6nfS/148mbqW5E3UH87+R7qy8l/oP5+8hvJryd/
ifrB5OvJHyC/knw0eV/ybuRLyYeQryAvJu9Ofg/5UPKe5I+TDyOvJC8kv418
FHkJ+S3k08iHk88hH0p+B3kx+RjyvuRl5IXkM8gHkxeSF5FPJO9PXkp+N/k0
8oHkI8lHkE8iH0B+r8VbvMVbvMX/V/8HY5heuQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1W9MFGQcwPHrCDjwPMSZdNBENgyjSYmCtcSz0UIrtoxiLJsjUJnTtDoS
Q0BAYMCBgPMyTvlzSEhC6ak5JjFF6e+I6Y2rINA7UQ5RzghYpZ21XsT4/l72
2lfPfi8++27P8+x5QlJ2vLZJqVAoIh5SKP5ds3VRG86uVa+2Fpfc8dH/pPtv
Lgl3dbW8MDo9LwlfvzTkiH16ftRjsTVm1e3p2a5Ndc30X/qnwldf+ihypk+t
uHd5pj/XlID+yBe98DrXAfRL7cHoG4Ir0P96MAO+rzYNfetyJXzu8afQX952
EX4iqx39zPcD4S/ntaKfca4QvnDBGvRzGr3g+z8LQH8guQ3+g2dt6Dda58N3
LTiP/oceFfBdAcvQLzb5wHce9UZ/vOcEfGjaMPqvp82DD4v+Af2OSCP8kGYR
+nkHZsGfmvoLfmtnC3z+lXH0J76bCx86YYMvS6iGt5wIQv+5YTV8kHUK3jOl
Gb6n8E/0VWf84WO//QV+bN5hePeOR9A/+s1s+FWacfj2kCb4KvN99Afdc+Ad
rVfhL9yqgS+J9Uc/eIMG3n11DH6OuRE+21cJ78pnP+TFa/A+j9fBr8/UwO+7
wH7O+Vvw8fVH4MPWPQxvf5r9cOV1+J7f2U+oVcNXe/rBW94Yhb852QA//0dP
+MC79FXhN+Bte+t5fsmz4JMi6ctTb8IX5LP/eZ8XvMFGn/Yr+y852M8q84WP
fpV+rHME/olo9ieLvOEXddC/mz4M3xJshnfd96HfSO+XyH6kB/uH7rI/0Epf
2c1+/Fr20+vZ179Hr9GwH+Gg745TwbvN9Bu9nfDaTfTJb7OfmEn/xyB9xvf0
SbvZbzfRt0TQN2XQx61gPzaX3tlBv66dvq2G/SEjvX0NvaqAfkkQ+88U0Gc3
00dZ6D89zX7zfvq33qR/uYx+u4r9gSL6ZSZ6/TH6vy+yv6eSfvZm+ktV9M57
9HXF9Mcq6X/7hH5FD71fBX3vO/Q5RvryCfruEvr4UvrxBnqVjV67j95bL/xB
sX9j9MZSsX9F9Hfq6Q/20aeX0xfspP+4ml43Sv+YQZz/XnpjHX3zAL2X6P+8
i95iou900u8U/Vfy6I/X0p+8Qt9RRp+SSb/tEL12mN4i+upc8X6Jvpedvlz0
N++md4q+8gZ9n+hH7aE/VSP+D9HfJvraLPqVh+mfv04/KfoNOfTbRd/goE8U
/UrR14t+15C4P8KvFn2d6E+JfpzwDtE3if5W0Z8rvEL0F4r+ymv0McIHZNOf
FP0o0Q8Uvld4tehvEf1o4WOE/0r0fUV/ofCnhXcLbxD9pcInCW8V/rbwocLX
Cj8hvFn4COG3CN8vfL/wYcJXCD8q/BnhnxR+l/B24buFXyx8sfAjwp990H/Q
/x/9fwCU0Mvp
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1WtQlFUYwPFlMUtCEFS09YqjZoZIo5aJspIVoFGoGKUOpLlTMBQpWLJc
lXugphIEDCjITUXARSklwUoMTZFaNZNRVlxdbnETL8lsNs2Uc/7n0zvPh9/8
33neM+d1XB+yQqNUKBTOFgrFv09dbk/JmWXWi4vDWquzgn9X/z9rjt7KSlzS
8WS2vH3tRnex4ckcWGCVUKvuejJv3O52SPSrNwSki36mX0Cn6C8eWxgnevPU
IcdE/4fSAn1/9XWD6IOjTsWLvsKhqUz0DboJX4t+XlpFu+gnD2jRf8O2qkr0
by1e943ok2s8WkX/08I09GfbdR4WfVbTfvQt1DFtoj/4azH6uth6nei1B3oz
RV/k4nFL9EcDP0J/SbSuXPSPfZUZou87V2oS/e6aevRdHSai3+qTj372/EH0
R33ujX7gMHWF6Gf2vY5+eakd+k3xzejPUpUeEX2jJhD9jLFao+htnFzR9x1d
gH5Mayj6U6aX3BH98pYO9J0HfNHXmN3RT9mmR3+jpzP6h1tN6Gc/SEff02Et
+t5H7qE/eo0K/cpXpqOvSLS/jf3PmYa+ceRzlaJXeZahP9XlefSDlpvRX2Tb
Bz+vyB79sG439L3PT0T/cq0r/HvV36Mf2maB/vQjSnj9gB5+wrUh6Hss8Ef/
Qy8VfMAsX/jSpQ3o5xWY4Cu0Q+Ff3VQHn+c4CB/nGQYfMW4M/AyNBv5YaBO8
buJl+P5pw+DvmSvhjR4D8Dn6OHjj9VHwkUkb4XvnXIH3tm+AD3/6Wfi5jcXw
A6E98Dd+3gFf4jUSvmyUFj7a/Rr8DEMtvH61NXzQvr18f+su+GmxGfD1Tvbw
EeNi4avGX4cfq/kO/pHXcN6fu7Lhx5W0wxt7c+AVG+zgT6+Ohx8yuQXeoK+C
T+xnP0KRCR973wS/6cxe+G1XRsA/834S/OxUA3xLTiX824E28C9HpcPvq78D
76ItgD+/if2hm1Pgx6fehH/JrxxeeZL99m93w5/tvg1ftK4QPsmJ/T19X8KH
q1vh758s4/d7yH7Ill3w/n7szz1eBG8xaAt/xpwKn1HLflruIfg9jvSemV/B
H+gywvscKoZXXaU/dyIN/sWxt+CX/nYQ3uBGn/1wJ/zmfPb7V5Xw/NXRD6q3
wy/zY99uCfsJK+kvJLMfHsz+zEb2Z5XTX81lvyGO/ck3DsDbr6dXLGB/kgf7
7VNK4e/n0z9uYd9xP/uKTPZXBNNHKdm/6MR+rj/7a7Los2x2wM8/zv7NDexv
D6Vf1UzvrmK/Opl9rz30W2bTn29gP8Wd/cIt9Kfr6F2Gs7+2mH3LnfS5b9LX
69kvmMG+ayS9bxn9I0v2X6thX5FG3/UufUwz+6ox7P8YTV+YRx9ppjefZd+Q
Qv/pevq7BvoaK/ZTY+n/Sqdvf0jvf4n9dcn0KUH0vxjpLZXsX9hK/8IO+vJ7
9Lpm9lcm0as/k/Zvks7/IH3FNvoPUug/vkvfbKBPT6T3CqMPaqdPekD/Thz9
3wn0F/votUZ6G6k/6Qv6HzroIwfoT0n9nDj6sl56W5O0vwR6x3D66k56n376
EfH0HVvpW3roDW30n0j9JC29fxf9pV56D6lfF0u/XOpP6aB3k/qJEfRXpX5t
D32I1DfF0Hd201t10o+X+osipfvzT/oH3fRpUt9L6udLfZ3Uf0rqn5D6QVI/
TOrnSf22aPpQqa/qkv6/kreOot/1X/8fedFJQA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1X8w1Hkcx/H184qU2xKplJN+IIakUjq5dEIideVKh4gov7KZPWePsBI3
l35bJ3Ek2sreyeZn8jvk0pz87jbU5kfsyq9LcXNzc+b9+us7rz8e85zPfGa+
H22PgH1esgwGw1CGwfj3K57Klj7fM8/yXpe0wPR4y5f/7zPzeUqeVv2zeyL9
gjA/RzS7QyzUnm7bMTi7HS2691Oftuyn9mPEF5+9uEpIvLudbAn1JbIMPvWq
RZNytP/JMLma9quCu+qo14kQu1H/wHyniPZFu5PVaV+jdKCUegeXX9Ooj+Eo
z1Af7lfbRPsJcZueUF+m/eIE9a/9o3qpr+ucVKH9tYEHy6h3N5ckUV+yx2OK
+g7u4nbaL1ecrqHeeSc7kHoThzti6lkrnynS/qNcr8fU3z6/6TL1muLsSeoX
uVuJaP+aqhr0Hdu8WdTrpMj1U69kzZGh/ZFIw3LqNxtM/Ez9glMZ49QbOLf2
0v78Me9q6rcqMdnUd95/PED94b3nP1FfXFgB/eMBjQnU64t1xqj/eMvyLfWu
zuIq6m2M6sOo71ut8o76OBfeB+rzfzGpoH4gjHWe+lQDxVHqR9tr+6k3Lo2F
fqdZUzj1/iFyQ9Rfuuo3SX2iTAz0J4fyz1Hv2WH8nnp2dM4g9Y1CS+hLdPf9
SH0juxD6JscaxqlfsrUc+trL/WKp/7D48gj0T6kOUT8uUYZ+tmFgBPX2bKth
6vs7r41Rf69gGPq6CSFc6k92aEE/0V1zmHrfgt5K6qcLdkZSXxabBX2H5N9G
qZfGfg4+c39JDPWZpTVS6hVkRNC3v1ID/np2N/S9Ukegn2o5B/qCW3rg3xpt
hH6sXCz0jduDJdS/eicAb6Vw6Cz1U356Eurv5MS9p97MyQJ8pcKzaPB930A/
a/Iv6D98kQb+5Zb70Gd1O0M/n6cP/RkjO/CX2qKhr2WwAfozKsZSOP+rK+Dz
FCXQbxAEQ5/74PUI9RzOAfDCT/bQ10jRgP5Wh1PQD5lJAO+zfmUU9TlX46B/
pUoAffU1ruC7wnSgPyiSh/7FhTzoe3hxwauNfQX94iQe9HPXx0N/rMUDfYY8
9OvMxsEbHiqCfnx4JPgj8Ueh32aRBX5HhD/0o5je4McevgO/wWkAfLrqn9A/
0hoOftg+GDw3PRe8vLEL9IfMfMHvEHSCP7C5B7x2wBvoS74IA8+cigDvliIE
/93h3dDnJ5wEz5/7DPxc0y7wQWqj0OevYIO/3RMPXudpMfhN1yyg32LjD943
vRr890Wt4D9umYZ+/c1Q8I+mL4EvzyoD/3erKfR7LgaAz858BH7Gpxm8e4UC
+N3RZ8AL5Hng30RXgK92MQS/6lwgeFZIIXg56XPwS1yVwYtyWeDZnBvg+ZlV
4MUx68C7bw8CX3s9H/yJpU3gA7gLwNcuxL6oKQ3vz7wG/IVhXfD1VdgXFf4O
PrT0D/DzbjDBq6SGgI+xzQD/tXcteH1rHfB+esHokwTgDYoawdv0LwK/1wb7
6StvgW/Y9QS8uq02eGMW9q3lc8FzPjwF75m6GHznZ9gfCs8CLxrE/v6mFeDL
+Nhf23IPvLMf9o161cFPtJwGHxl5G7ydTx34gwVa4Oe+wL7PxF3wUgb2uc0a
4N3ysO9plQ1ephL7tn3LwQtHsa/thP1uQQN40bkl+P9Owr6wCfu6c+rB5zlg
/6wyel4zH/zqUOxrzdcEb8NFb7otB3yNOfZbOpaBP70M/RM29jl22F8bhP27
oehd47Hv64Z9Fhf7SuvQJ2zE/jx97FcWYv/5SfQm1dg/9gP2Z3Zh38sEfZss
9keY2A+SYr/CE/1LKfbXJGK/Rx37h7agN+q6g++vDPaZmkvBVx5Ff5SJPvkm
9ptH0UdtR2/wGL3wPXrbzegdv0UfoYd+ER99Yzt6Fyv0Hnz0zX3o8x3Qyx5E
77sN/fW8//w/j0+9VA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1HlQz3kcx/EouzmGhGxF2tQvRcWUsxzJJkfXT0jSptpSIlToZ5TZ34pQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xk01Wkcx3FLCteS7YrIrmsLuSL3CreyZLKPk0jUyYwipFGU7pWl7OVa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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xs81OkCx3GM0AyTdUkdKbJuDY5NpTUyyCXTDCElS20jw246ch1RHbSN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN13k4lWkDx/FTmmhscXBsHY49WUbhQpGxxbH0WgtZxmB6k62ETJaG7Duh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1Xk41Wkfx/GDDoqnlJRlPDnFJCSyDBWOOgfHvmRppCxDI1mS7WhTjKU0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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN13k0Fegfx3EqYSZXkhtZJjEH90rXkqhpskb2LBFyk+6gCdlaqFHKlq0f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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk0FWgfB/Br6yISqmupvHa90WiRraxJjCX7Tle4dEOyRY0M78g2rzCU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1XlQDngcx/FHEonKQ7dydKDLNl2UFKlWPUrJWRKVVVtCWV1b6elk8UTq
oZJHqadGHhIPqSekwxFSucKWVejpoFPY7OzObD7fv37z/uM7r5nvzHd+c7YF
u/lJMBgMw3EMxr9vaneUtanXFJta/fjMhQlPrf/vJbG8mTbenWM9fmGiucKu
1rEWngidX72ha6y7jH0m7+5/Mtbz056Ni1D5Mf+5ZMnsIvm2sbZlut6RWvpj
3o016Zwh+Mx56ueswT89YGuhCP7M5Rvl0G/TuHsMfYFXuT36PtsnJxaCnzBe
2I3+h5CEDgPwTTRcXdDnCvlySuDLL8r7chv8F+rqE/aA/0l4KAZ98e5XUuj3
TymXmQj+Sd8cW/StNesk0I804Vei3ziR8wH9vjtp29BXDQg4j/4snZFsPvhZ
+6K10L+bs6JCH/yq9fyqpeA7NDxarQz+cFt4C/pBOucE6OsbTWtG3zF9rwP6
Jas7F6FvaxXqjL5yT8YR9DtCDtSh75bQ8hD99N5lveizdvYNoG9irspAP9Dq
1kr0V0rK9uuBv4qf74t+8nJHPRXw11na16DfIFOqGQL+7E4ruUjwNadbVxeA
X3ojfz36+waLCtCf4Wy5DP0mu4oo9B2veInQPzh/yBn9VXo9Wuiz/C+loa+x
eKYP+h01Uf7om2+X1EJfkCKuRD+h8LkQfd3NeXvQP/SgwQx9XhU/EH2FhiOB
6DspG5uhn5sjlkG/Qn7tMPr1X8JK0BcnMTnoH7Q4Zof+ims8J/RfcjxC0S/y
bJdB/+sumc9W4M+5KK2tCn7Xbunz6I8Ob+CjHzYickV/ROjzE/qp1+5EoP89
j/FBF/zUA/nv0OfdKHdE3+qRdxH6Ja+9ytFfOljngb4/S6yC/voUpVj0o7MX
3Ud/tG72C/Q3s5r90R+y8ixAf534zX30U+vkfdHPD9s2Ef0V7H3x6PfoR5ai
H+Q78gB9i7BINvpSo6/z0O/2jXuBvqlzewD6UeXKn/PBf716ejL6vdYdp9Fn
atdUo1+ckMtFf5lnwxn0RZKV7ej7cJJ2oZ/KjhKjr+ky9SD6cV6VHPT7di4U
oR8kVixCP/HeLB7Z/93xvej/bmKwF/0NZQpt6Pc37z+E/tbrgWz0Nb93CdGf
0Bx5Ff1wvbIc9EeG+EPoa0VIhKPPXLf/Gfrq9slH0E+PCA5D39WyqgT9qW4e
t9EXGx47hb7xuuFv6Ata9aLQ/+1sUAP6094bp6IvM+IVjD7jS+x59EuDdR6g
P+9VTjb65v26EqHgN8bVRqPPts+4h35ybtpR9Affvf0FfafzfxehzwmyeIL+
ngVPs9Cvdd8rhf4a055Y9JvyamrQl8gQHkP/pmLZVvTz2pX46D80ffsS/T+z
jIj/2P27NPpxIaVx6Ju/r7+FfllaQRr60+pzPdF3ly49i37uYp836JvJFWai
H3u2cwr6DnP14tE3tkmqRL84Jeg4+jmZuzegf3399Vz0I+rFHeivDVxE/KnM
NXLoSxl5J6D/MrKxHH3eY/l09NsPf3VHP0dG7Qz6dmqFneg/YbecRN8vyWUa
+tYaWxLRH2rllqFvFpdB/JaS2W7o7yqsOo1+TIWoG33ttsPEP9jTx0Rf2c8o
Cf17Zreuon/zpFQG+szn1S7ot/7Kz0Ffh+n4Ef3TRS7EP9rKmoE+9+lr4ht/
sxKiP27pNuLXHG9ahb7hXdEp9E+4+fShH5yoRnwDywAF9FU+BCWj//HG35fR
D2gqJv6FAAsW+tIzRrPJ/YVrDJD9x388gb5O5lpF9CvEfxF/btZgKfoFBl3E
z1R874g+T2ML8aeO/2MQfYfJ9cQPvamkhD7T1i4FfXGZGvHXZM7iou8n2bAS
fQ7jZRb60YnXhtBn1gqIz+kQEr/l0HHid0vsuIS+/ERH4qs0dv6M/v7nwcSv
sigZRr83N4P4qt8tldFn1z0l/tzqxhL0RZJBxNfs1yd+da4i8Yu3xHxGX/Y6
m/i1A3ziZ/rLHkBfO3oj8dltKcS/4s5xIP+fbH0m+jvS54+g3+YcQvyBJgkV
9G3DLYlfxRu4iL7uBR7xBVpyxOd6cIg/QbeU+FOq/Ii/aZhF/Og8b+JfDeYR
33PNZeKrHc+zR1/g6EV8b6d5X9Dnpm8ivkj9APEXrIoh/uBDT+LLJlYTP0LA
Ij5v1IT4ScsTia+9xZX4TofLia+TwSX+AlMt4oe9eUz8XkNJ4lv0MIkvyGgi
/qfbK4lvv6CD+DYhxcT3iB+8gP6jd6+Ib7S1zg59g+ahk+hzTRS+op8dY0v8
yohJquhP4ov+8/8BaDNCug==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1HtUD3YYx/FfifJTconRurDktkzS3CJ17IyjpYuKVinaTxcqI0rxM7ea
NdJdttnQWi5dyJHTTRddpFKmmyxdmFYto4SMdnbOlu+7v57z+eM5r3Oe8zzP
1E1+tjJFiUTykYJE8m8ttlh4xNxN1Sw3oNxVLbpu+f/ZadQlZR2vjsFsZxDe
X+vcPJgD5xhND3HuGszap9zdjzTXDma569+WdWPf9fd65Bx48UHLYM5aXWod
b/KuX6/N3En0g70jh4t+6f4dA6KfJK/QF31LvzCZ6Du5jbcS/YDoNV+Jvt1i
mY3oW2d1rxP9nGnDlUQ/zFVlWJ3gm5QeHOLreoi+Z8ID+D/FhchFf5FOPfy3
UfvsRd9wdaui6Ced+WW46KdWWcIvX7DSU/SrDHdai/7mvEV7RX/OUgNb0b/t
mLFW9DUd1eBHTohSFv1ey+nw1Qt1vUT/XnIr/CCHT/aIflG1F/wf7b1sRf/k
9i8VRF+vrV9F9FPcRsIPssyFn1ZrZCP6VrKIYNGf1x4LP7fM30b0la0GJKKv
YaUoFf3x83uniX6nq5G36B8L8YE/0300/IyODPg78/OtRT8m9wL8G7ML4Rdf
egj/589D4T/ZewL+y8CUINGPmlAFPynZFH7scV/4ei7Wo0Q/e10D/PaIIvht
zzLgzzbzhK9f0gI/9GqTlehLis3hP87OgK+vUg0/VacHfnJ/JfyGWmP4rlnd
8Jf5n4A/0D8FfsGWYaqiH/ysDH59gMYW0derewD//fnq8FcsfAlfqiSDf/ul
Cvzjd5fAHycvhq/XagDfYW4X/EMJPbtFv2zmAPwlTsvhK8heDGgLfrLMHf50
k0L6BabwJYufwz8f8AD+bFOltaLfXaoHPyakA37LpP3wm+vy4LvWW8Bvr30N
3/pyFfynfcrw7eLV4Z/WbIG/rS4W/vpJ1+Eb+NjDH5MqsRX91pYi+PvSpPDf
VEvglxjfg99QkAg/vSqH97fNmfM3UYI//kUOfMNUVfjTJH1rRL9vRg38b70v
w69uzub/idoI//qvI+Drf3gN/nv6o+HP1+iG77ezGv7Inkz48+bRN3aQwffJ
VIF/rSsdfs0Cdfj7VrbD98+rhL/BKB/+D2lZnP9ET/iZOlL4DtVp8E0H6Ieq
PISvXVQOf0VREfwgW/oNmt7wT+iNgj/wTQr8VxFj4F/paoZ/0eYW/IM6N+GH
q9GPiN4CP7KVfnLzRfiyN/Q1EpvgZ5uXwdeJvAVfszETvta5rfC/8FWFfzTp
AnzpZ2Phf/36PvzEoJvw41wq4M+6Sj96hw/8grv0R944D//UYfqmhY3w29pL
4b9NroSv/R39KmVf+Fd11eBnaNEvTqUf33QPvoGc/qqE2/CtQ+k7+NOPcaC/
5Mw5+Gcr6RsvpC81pH9yfRX/TyD9m4X08+T0j62iv/QR/YTsBvg1fSXwT9+n
b+xLv/cN/Vnf0388gn7Jc/qdm+j3lNO3WFYN33cz/fCZfvCvXKJfVZsE/6HC
OPiLptJfnUJ/9CH6uW70s1bS35VP/2w6/Xwpff2n9fAb4+jfzaAf7Uz/6Ab6
ChX0m+Lpm42l31FB3zOUftlv9EMc6Vv40Q+oof86hL7iRPpaV+i7BNOPfUXf
Yh39w8H0Exvpz9lNf+9k+ian6R/dTv9PtTvwk+zpyw/Rn9tMX82PvlSLviyK
/uSt9Ku16O+yoy8Noy9vo3/eg/7v2vStj9B396CfNoN+7Fr6teH0Ox/RN9tE
f4Uu/c799J+400+aS/+ZLX3HKPrpj+l/umGIP4X+vj1D9n8jffnH9HcP8f+K
GXJ/f9B3caI/MMQ/EEg/zJX+rcX0pw7x78TRf/6f/w+AKupe
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0OtPDQAYx/ETqQ1zN7mzWWScGmJibikhTOayWZOkiDjSXKc0hUwsLFlr
OSQMyaXRRZ1quWcYlRnqJFkKzUxoMS8c+/7+AK/Oq2ffF88+e56hwRsDVrcz
GAxGB4Phz2w93/x0XnDnaZXtf/4adLJy6t8e+arMlGFqsPWkmCXl6f7Vtvaf
X1xVsqLR1j6jo49veFxh60SPe1kHO/3bf9kzy2PymBpbR3xpaLk88d/+i6Rm
+Mk7iuH3ygyCX262wH//JhZ+Wo8H8Ltaz8P37tYIf2fCB/qXCuG3Dg2Dbx5L
f+/kOPixvg/hTxp3Fr7Hbfp9LtfDz6gtgO/muw6+d1MR/OzCePhuncrhG6PP
wF/l1QS/+8Q6+MOL8uHP/RABP8BCf1HOXviW/fQjQjPgn4ijfy2zFv5SR/p3
UjfCTztN/3XAPvg/qujnXjsN33CdfvYZK3ynxDz4hmwTfL8k+ttu0Pfs/Ah+
6nT6Pk/pJznQfz6NfkjQJvhH4+nf/Eb/4yj6N1pOwU+to5+fUgN/RDf6vZ/Q
d4mmXzZkP/yK6fRd79P/2ky/dDH97s258Lv0jYS/cDv9Vi/67gvoh1+k/+I7
/R8j6Xu+ou88i/7MLfTz5tLPWUp/wwn61jb6WV3p73tMPzhE7o+iH7GEvlsg
/dmJ9Pu3+wjfs60a/vq79F230u+5mf6UQPrmIPqH4ukPd6Tf/wt971L6Lnvo
+0XST1lJvyqYfvpu+ls60G/fSL+liP7NA/TLNtEPC6HvG0LftIv+Aif64fX0
K27RP3eYfqT47qH0javpr99Jv1L8hLf0dxfQtxyhP0V8/zD6FvFdd9A3OtO/
YqWfmS//P0Z/gPjOa+gPDqUfsJ1+qPixNfRdxHdIpu8kfoz4y8Uv30b/gPiF
1fRv5dF/Jn6Lif5D8feIHyW+WfwZ4seJv+w4/U/it4mfJr6X+Nnif35DP1D8
q+I3iN93Lf0L4vcTP1d8i/h+4teK/058d/FzxHcUv0j8dPEniN8xhf5b8b3E
zxf/21b6JeIfFt9d/IHi14o/VfwC8b+KXyp+gvhG8QeLbxXfR/wS8evFvyN+
lPjDxB8vfo34c8QvFb/O7tt9u2/37f5/9X8DDbJiow==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztzc8rgwEcx/FnVkjKiZTHag7KwbSD4mLOfvXMjLXd5sdF4TAcdiMpI7WU
64qsZoZSbpKDOSzFweZHoWW0KIdRSsjB8/T5HPwF39On9+HTy+of7x0uUhTF
ZlKU37WXxlXvUHn7mS94OxJLO/56Nzxbq03n9e6MBMbcbXd6p06Omzb9z3oX
0tWqenShd+yrMKEWG/89d2Z9xXFv/PvNFTUtxv+gD/3RZfQfougPkt98hf75
N/pWF/ozA+hnNfTXltAviaPfQH7gGv1J5Q38fSf6j+Qf9qC/sYi+K4F+GfmW
G/RT5L9r6Kse9CPd6NeRP7eN/kcS/SD5n+SHyG8l30x+JoS+fQf9V/K3yK8y
oe8kv4P8aBf6CfLD5OfJPyW/nnwb+S7yp8hfJT9J/hP5l+Q3km8h30O+j/wF
8nPk58jPkm8nv5J8L/ka+fPkv4gvvvjiiy+++OKLL7744osv/j/+D2Bjzqo=

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFpYMDjULg283fm5uv2ML6E/gv1xNpXcL6ru+nT
NMMHcP47xf3LwlPfwPl2HIYfeLZeg/O1K+aWuTEi9G+u5nw40fshnL/XP0T8
kBlC/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aT
Yz8AxA2Ubg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGzjyhsKMrgcWidnLGtbPd1exh/yvUI779Nr+D8
LJszz+tUH8D5yStr1lxLfwPnnz36YOunFdfg/AImc5anf17C+blBFvqdYQ/h
/Ji2/wunmSL0j9o/av+o/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/av+o/aP2
j9o/aj859gMAv0Id3w==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEXlW7/rMvicbio0vtk/6Hr9jD+3hrB7zYdr+D8
fZOuOaVJPYDzuy/dmmuY9QbOf7zm5txZc6/B+T3R6avu/3gJ50t/vH9oY8JD
OP8hh1xgvwlC/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q
/6j9o/aTYz8A32IMuQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFsjVOdu3N4HFzPX9mVcfK6PYy/cuYvQcPeV3B+
UOWSM9/4H8D5Krkbv+flvIHzLwXcL3846Rqc38mk2aT69SWcX2187Khh1kM4
v87j3LKlxgj9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9
o/aP2k+O/QB7YC/y
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHW9/17p+fxOBzdUnqx6/x1exg/tsf74dOJr+D8
77FTr4iwPYDzU+POF07OewPnKx8v27C24xqc339dw23Vx5dw/vJl81+oFD+E
86clWb66YoTQP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/a
P2r/qP3k2A8Ayq0oCQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANEFtlzXFxfwOHRfzCm3vHrdHsb/vC97ccq0V3C+
eftLpvCf9+H8OtuVsxcVvIHz7Ysj/r6uuwbnb3//ZHvKu5dwPtOOTSwLqh8i
zG990iVphNDfgGb/ezT7PdHsb0Cz3wTN/k1o9vOi2f8Bzf4JaPZ/Q7NfE83+
ejT7rdDs34JmPyea/R/R7B8N/9HwHw3/0fAfDf/R8B8N/9HwHw3/0fAfDf/R
8B8N/9HwHw3/0fAfDX/ywh8A/4vAbw==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHLZh9R2FDE43D74cI1zbeu28P4J4Q5W7bMegXn
n7m+Pij0+X04f5l5veX8ojdw/iZhn+Te0mtw/kPVaat9X7+E8xcI/HLe3PwQ
zrcR6D5cYIjQfxrN/oNo9r9Fs385mv1r0ey/h2b/MjT7LdHsH/X/qP9H/T/q
/1H/j/p/1P+j/h/1/6j/R/0/6v9R/4/6f9T/o/4f9f/Q9D8Ape0/Ug==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANG3f9Zl7SnhcbjF/Dy+9P51exhfqjfO9Pa8V3D+
J4tvb7mu3Yfzc/yf1XWXvIHznwpr/mjNuQbn6xW8zIt/8RLO/xJyvDq7+yGc
LxgwNf6GAUL/ETT7+dHsV7VEtT8Pzf6baPZrotnPEIpqPy+a/aP+H/X/qP9H
/T/q/1H/j/p/1P+j/h/1/6j/R/0/6v9R/4/6f9T/o/4fmv4HAFZi66o=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANECEZZbTpTxOJRU3reXeHLdHsafdeF6yN1Fr+D8
nS9zeJKP3ofzHXfbmWaWvYHzl+19L3gm+RqcHxQZkzL16Us43znET+DypIdw
/mP1RVP8DBD6R+0ftX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7
R+0ftZ8c+wEW/E8A
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGu2z7/vVLB43D4QZRnyYvr9jC+5No56/ctewXn
O4RITPLZeh/OP2/6+qplxRs4f+HX3B3h0dfgfIWKjfteP3oJ50+/OK3/08yH
cP7lff4vLuoj9I/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j
9o/aP2o/OfYDAHUqyDo=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztz80rwwEcx/EfLspOWslhNClFWZJ5KiwHUxNtN6VFcZPMlIfDys1ByMnD
QZrD1p61tU2tleKwRcSEA3Obdt5BTXLw0+dT/oPv6dvn8O3VWz+zYJ2tVBSl
vUJRfu66NjCSX9MMJdNTbTvFx8HffWWLOja8H+p+2Ip3JU5f1b1Zkzr6Wi2q
eyBqNDXZcup292cn7G8FdVui5obb47y69cvXumnD33/Kg75zFP1cCn2XBv1C
EP3LHvT3z9F/cqCvi6FfNY6+043+J/VnIuhb+9DvjKOvdaK/GCTfgn44gv4w
9RvD6K/0ol+bRH9uCX39Gfq+MfRvvOjXk99I/SXyy9SfIb8cQj9G/fYg+h3k
H1B/gPzDBPq75HdH0DdRf9aHfjP57+Tfk28mP0T+dhj9EvUbAui3kp8m/4L8
efJPyH8hv4769/zot5B/R36W/EnyPeTHyK8m/9kv/dIv/dIv/dIv/dIv/dIv
/dIv/dL/f/83RE2kXQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt1PtPzXEcx/GDzS0HJdJxbRS5NBormyVRKgrNpdy22iw5lJJWHdPI2dBW
Uqcyl+YyJVSMue3IZaeiq0WGsNAktULH0ulifnB4vv8DWz999/rhs8ee7x++
diERAVv7KxQKp34Kxe9vYdS21Ja9w9yVu9UpkW0vFv3Z+txKv5n5TeZdMSXv
w8mMd+Z9L8pDd0vTbN6a6wcHOSyvNe/B8f3ULW8+m7fWOLQ4OqfevK/0Hp9u
cvr7vmTdXPhns67Dz7Jw+Pivv8LHE75vazT8XGPH9n/9MxcnwG8fnwZ/Y/46
+I6BBvh+O2rRHxazBP4JywT4xeE98A3nLeEXHM6EH1TgBr8n/Q787Iwh6N95
din8Q8mx8COaOuF/2WwLv/JqOnyDyh9+RMID+KU3GtF/rp79j/V74ffM6oYf
GmoN/4g2A76j81L495V6+BG13fC1m9mvVsbDd7ltgv8s0wa+KVAH3/6oL/yq
xiL4TR5t8L8o6d8t0cC3ze2C75Y0Gr5Kxf7qWC/4VqPuwR/b1QHfcjF97SX2
nxhOf2XdGPgDTrO/xNYHfoM7+52Dv8OfN5m+XQj7F0bSvzWAflEL/U1hy+Ab
97F/jukH/ID59J80s79uLv2GZPqJd+i7JHjDTzPRL8prh180jb6rK/uzNtDf
NZ9+1Gv6J8vZH3eJfso09sfOoX9/EH21O/3mcPrexfRDFrH/21v6r52N8N/M
oN/gQN9tNf1OH/rva+hnG9lfp6dvX00/3on+Uyv6W73olwfTn1BG38me/c41
9G9upz91Fv3ySfRD/ehvC6BfWk0/ciD9MAN998v0L8wW/z8b+vXe9Ndvoj+5
gr6nir5/Jf0f++nni/6K8fTLltP/upa+pop+gpL+sVL6C07R9xf9a2zpf/ah
b72BvlH0PxxN37ucvi6J/ifRnzqO/iTRr15Pv7WSfsxI+p8e02/IoO8o+u1U
9IN86U8Mor9K+M9H0VeX0S9Mod8r+i1Ef63wLQLp3xB+oSX96Cf0vdLpq0T/
HtGvFb5e+LuFbyP6rUW/fyr9wcJ/Kfy7wvcSfrbwp1vRzxP9nmn0rYWfKfws
4acJ/4DwDcJvE/5P0T9M+I+EXyD8YOHrhL9F+A+F/+wY/ZHCvyz8c8LXCD9J
+OnCfyX8YOGPEP414ecIP0r4ycLXCr9G+InCHy78m8LPFf4u4R8Vfpzwq4Sv
67t/3/377t93///s/r8AFIN+Ww==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1n88FHYcx3FuzKOODrN6ZBKRH1lWR/NjlUskc0ddaNfwqKtw9UjWzgMZ
alLnUCecmXKSZH6UK9JNJImVcPpxWjwmFf0gWw9bP/3YY489Zp/3X9/H+4/P
4/l4/fe1FO7mb2doaWk5amtp/fMOqhf0vk3S50hXL98z788ej/+2i1ntsXrl
8+kdv00xOXKof3rHHJQVRyaOTO/8GTqeYas103uxMq4tu/fZ9DZ46VL8sGpg
eo+ulNkqHP+/r//ewIn6GftF+6jPrtmU+oL4956ZlFJ/Tb/Ykfpb3fsvUX+i
Z6+K+tGs38ypPyBxFVK/wywtl/rNF69ZUH9to/gk9dWPZq2gfsnwLy3Uf+c/
r4z6Ze+/Xkj9D+czPKivsWlJpf4D576d1K+V7jhFfedAOzb15RUPGqm/cZZJ
LfXruCkW1Dc75yeg/vqHaVnUdxjrcKJ+0egY9A9m+7lTv+e471XqxyeHV1Df
NMXSmvoNmgpv6tfpNUmof/9JaSj1N+cxod8mxNWZ+oruycvUv2VSdI76Y6wo
S+oX8/mB1O9RBByh/sUA0Urq/652L6G+pfCKK/VnTH3bTP1O3hdV1L/H2WNF
ffcYoS/1X1wWSalvd6M+iPqZlRrwS06GLaO+jV9hE/XNTD2V1Dcf+gP6N53O
WE/9hC6jw9Q3VvC9qD+fLwQ/WTnoQn3+y/Er1I/J5pyhvmeOIfT7cMR+1A9k
bEynfrs+fz31LziqwF96ivE59TsdXkN/tUFyNfUH1W4LqG+5UHsd9ZdUb86k
fj2j0If6wcFx4GtW7YT+6ryfof/CZ7egv9/6Pvh6KQVc6pcu74X+4Kg+f+rP
uVwGvrd+GPRb19iBXy8whn4LsRD8uSrrAOrffDuRQf3OmWJf6u8tOAC+XNcW
+kOO54LvG2x1lvqJnfXgyww5POoPvbAG3zItkUd9C7kC/KFxGfQbBXiBf6fl
Lvjjc+PBZwz85E9971et4HtMxX9JfaM96eALJrWgv0p7P/ifytaB7zxUDv6R
awXQr5zigS96p+JSn5PwI/i5m6ugP125AXypdg34TqpU8I/v2A79Ibwy8G+O
M/2of37VEfAbbg6DL06NAb+uRQT++/gT4JcPdEK/06Nt4JdOcKH/aXEe+BPs
BvAPeoWAn7TkBPiM5gzwH3h6QL+eSx74dYJQ6I/akgX+5Hg/+HfNd4Pfro4F
v9DtGPgFocPQ31byDfhsjiH0T+rLwQ/UaQW/m7kF/Ifn5eAXVcnAd5iyh34b
ZSb475RS6I+VHQW/NeJX8HMzd4I/UZIMfhg3H/tXvIf+1qY48A3DR8FvWZQL
fvjoDfBzareCX9MrA/+vvqPg+y80h/5EoQT8yNcnwRe4ZYOff+ku+MUyEfjD
2gfAV5fngR8zWwd8Vt134O+Q9IJfXZkDvqSiA/y0pdvB78vPBP+MSQ74idI5
4PvuSgV/RP8c+HF52O+ovA3+uDgS/Ijog+CbNsvBr9GZAX7QSBL4HTrd4O8K
x34vdhf4a3XDwXe4ng5+RDP2L+v7CHxeWwr4nCEV+CPt2J+QeQv8J5oI8De0
HwJfxMF++xYm+KG2+8BvtGsH38sD+5n6avD9ErDfsVUKvptVLvjMLiPwP+n7
HvxFaxrBt3uG/U+fd+P/Kwn7yzMk4Fu+Qd+VawD+Sw321zxuAz/aHvujUrH/
4wbs71iG/WwB+n7lhuBrCbA/+kIT+OK32O8jw/6zPOyPfYP9d7rQ77aZBb7G
dT/4Wcat4K+Zh/0m17G/YQD7QwbTwPeORd9BD/vHWNjvY9wMvoSBfnso9gex
sT/RGf1tKvRTi7D/q93Yr8u6Bv6+2eg3jmK/7SvsP3wRfV0J+usqWeB7PUF/
6jb2y/XQP7sK++daYf9IEPqDlehzH2O/MhP9A0kt4KuM0W/6AH2pNvpZCvRD
stA/HY/92Wr0mZyr4EfORH9qKfo/mKIvj0T/+Sn07WeiX1qIfuti7C80RD+G
hf6A3r/+31mSRvQ=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV13s0lHkcx3H37BlMl1mRSw0qS4YlFA1lY8i4i5LNbIxE6UJH49aNRqUG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN2Hk4lXkfx3GSrHNC0hyUx5aJKGuN0kGmGJ0LaTLJOBw7WapjzXJMlhZr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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1ns0FHgbB3CzEpZZZlmkza2Ru0q2XKLVRfu+tss0lq3X2q1p1qQll2xb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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztz88rw3Ecx/HvRkttUttpyUHspAgHsZWlNMuSaXORlBoW2XG1w5pk39VO
Dn6dRqm1WTH7gU1SJIqS5kcRmdpYS9zcJgffr/er/Aef06fn4f159agddQzY
pBzHNUo47udNGRXSBl6hX/P1utqa7zp/WxY5q7RlCkIHNipMycKj0N2rWx/n
7qLQpXjNcnnXjdAe406TIfsmtM0889q+/ix0i+9Ab+oo/vn/2OJK3wqtKmn7
wwFxX+7S2K9zT0KfTMqG1bx4L1fzoX2VuG9uteqKp+J+XltXdnEv7pvGOGWg
XryvmqN+Z5j6NTHqT4N/epv6q3uo32mhfiVP/YdR6s9LdMQfnKL+OPgd4PeB
3wF+N/hLs9QvAf9IgvofwJ+MUv+ugfrNVuo/8lK/I0b9ESn1S+zUHwW/B/zz
4B8Cvxf8GfC/h6g/Bf4s+BfAHwS/E/wJ8KfBfwn+wQnq3wS/H/xL4O8Dvx/8
e+B/Af8n+HPgd4N/BfyL4A+D/wv8RfBfjTM/8zM/8zM/8zM/8zM/8zM/8zM/
8//v/wbb/Tgm
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHvlx/zNu/kcej3Oqg+y/aGPYyvqB45e+PtV3D+
h1aPH4tP3oPzWXqSuXfXvYHz98bKRTG6XIPzn079zWT+9CWc78y7uJVl/kM4
39H79BdzO4T+yXUBV04tvw7nqy6WWVw2A2F/k+m9VTNYH8D5+9h5zxl3IvR/
WyR6YiInwn5Ol9fblI8i7J9rWBIb8hRh/9FdilnLlRD6K9H8L4nmf/E2VP+z
ofl/E5r/76H5PwjN/1Zo/t+J5n8LNP+Hovl/P5r/P6D5nxXN/0vR/H8Qzf+j
8T8a/6PxPxr/o/E/Gv+j8T8a/6PxPxr/o/E/Gv+j8T8a/6PxPxr/QzX+AeYb
/k0=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1H1UzXcAx/Hbw8SEWLO1PIVEM7nWtpbZolSrlJCWmUTldpDSA1JKD9eI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN12s0lHkcB/Ah98tY1zWTMLEbZTUNlUuiXJJctlpKLpVChUoprKXUJoly
zxZatxKq0YWytNIdlWrZsGFcGwaFpsaYZs++WP/vq+d8X/zO93zP58XzPIyA
fRsCJSkUiqkEhfLfc8tO626PFCU7upN4e6njW9v/c3+4gops3/BszjyTVPVL
Wddsnkyc033hKG82s54V76tZ0Tabl46tfino587m/aoP5qoXcmazrHP9XeNV
5P7aFTsa7cLfs9lkzSqmTzbpl7OQ5nQr9czmZHZRgE0Kub9cr5dgwG+dzYbJ
tHTKPdLvxOqy2fuZ9NOZL/QGdMn9BlmPn0M8YX9kiEoTl/Tb2F3zzz5F9nsP
qeorxpH762G/K8mtI/sP7i/IruOR/m2iXDNuKun/Sax3dO0acp+h8yovK5rs
L8hUf3w6gfQ/8fM7QWeR/Z0e8/uWJ5P7J9Z/ZnUKyf7qErqt2X3Sr7Q3Rvrn
D6S/TJxVxGOQ++HrYZ9kwV84xube7yX9kaeen2wuJ/vPcO1f3AJ/08Aan8Xg
76IYrHkN/L9r97WuAf+nqcxmnh34uTaaBuWS/dGi1Sqfwd9uE7VmnyLZ/2mw
03kV+FtKHGArg/+tzpHNU3Wkv1+C8zwR/HW186Pawb9xkVtsGfjv8HYUD4B/
UmmAhTr4n6/pCaGAf/5a+Vv24L8/sK3nHfg/klSrLkD/314cDgB/ocffXUrg
7+p16r4L+HNvpi+8Cf4VKULTJeB/Jz5aR2KG7M/mdZk7g/8dVv9uV/B/onLS
jzKf3PNLry7OcyD7D2st5WSAf4auq0ZFBdlv5Njr/Qj8NUs11d5Yk/0xW6ze
xIB/qHGOgXER+Fu0eTwE/672zCP2eWS/LX1Jhv850m/racCMUSD7x7cW5tuD
fz6XlkcB/71nhTKj4B+YqVqVA/71M22xr8G/VrrVqgX8mfFqDD74azTWVjxM
JPtXpQop07HkviN7JjIY/J/qH1rxEfxPMwI7D4P/h0iV0HDwr6jfNlYTRfaL
rys0GoB/xMjDYqoZ2a9r36z/A/ibOUi3fAv+JU+re38C/9vm46+Z4B80lrBO
CfwDqJJ5vuDvGKApHwX+FWePu5hdJfuf+cV4vQT/7qZEvwvg3yJl+4sf+Bd+
z9IKBf9fr2zqKAf/g5Vs1jPwrxEItPLAn/6FGTskT/ZbjYWPOYD/nbEyB8En
2C9cOfwe/GvjqkoKwF8snk57Af72IYN7B8A/V23BEjH473dxSM4Bf7NVewL5
4K8xVzkjBvwls4x1Z8C/1aTugT/4786ZeBMN/rvUnXqTwd96fWyfMvifaxIo
rwZ/DpPRthD8+cnUYkPwn3u3U8kX/OO2PLNmgL/I4qucOvivCHNnWID/6OPN
brvA31lcwD4C/szoNYK/wJ83nT8aA/5Z98p8XcHfoL2wKw3844PeKuSDf5Ch
PVsjn+yXSt+3vR78/zIqoWeCP/taYZEj+LvVU90/gf/FXy1vDIK/1KRC1CXw
z2e5RzSDPzu2tfsD+MtsltCUGib9vdzx2qPgb943eGAK/N/GOYQlgP+YRINI
YpT067y82rAe/LMpK/3iwN/8ZJ5cBPjf2n9RVRL8PyuONfuBf6MgJccY/OWW
PsxaBP42KTdGt4J/e+T6Jm3wf9jPu6YF/unvZAMMwf9yteGzreC/SW+Z4hXw
FzVWS78Ff/WBH3l7wL//SCDNHvytvj52vwT+Qeb/pGWDf0x2U6IN+C8YXRb9
BvyDb+4QBYH/H5MGc5zAf6nP6uWT4G+l/TphAPzviS5LXgF/ma9PvJrA/6ZR
1RAf/LUC/ymVAf8QV2VmBPinWGiGToJ/VN/Ud8ngf9r+oJY0+Au7zg25gP+d
H0PuHwX/u1eVxoPAf9vx6DbhCfj+S/MOCwV/g46uD0bg71EfYrcY/C9O8QTb
wZ/fl+qlAf5uc2RztcE/vpI7RQP/BLZorQ/4NygM9twD/z8XFRW0g7+RUt7E
dvAXnmteuhL8j0X4alfi+z9P6vd08Je8W6i9EfzvUOxS3oG/UeG4iQf4Sz9v
M0d/DRe+/gT4V+6UGukH/6oiC88y8DduYjU0gj89Wk9xGvzlr6+gyIF/d71e
aRj4H05365sAf6M6K/2z4N9QLrohA/5H+EyvNeB/4rlYHA/+Dsta520Df9FN
z5wv4O9UKpKPAH/5xYm/of8XuQ3GS8Cf+sMXhR3gz04PllIDfxu/jlwa+Ovs
qU3QAP9sxZCJzeCv8NrWrhH825wMozrAv3kRzckP/K/Wy5ZZg79m4IGqKvBv
0Zmbngr+DyKdN/qDf41lR3Mv+DuUUB+vBv/34Qnu6G95XT/tI/irfYw9j/7+
XuZS5eAfkRl8CP0Npn3KhOCfpHy7Ev0ZGyWc94D/C6MLuej/YcqiLBX81XnL
E2XBf5ijGecI/g67SouPgX+De8s5X/Cv3u04wgd/2sQCQST4R/P8Q9HfRFPv
exb4376xIAf9i56avPoG/E9duMSgg/86K261Kvh/67GzdhP4H0ovZrSAP/uR
4hD6v52K7NwC/oUCRW8r8F+kOp13F/zVdBcfOwv+nIO5jJ3gH85IPj4A/udH
jvmuAP+67nof9KdWKa9B/08Z0uHoT/u43h/9T+l1uqF//HHzozPgr5ROV5YH
/6SUmaRd4L/bmRWF/vNU5x9KA/8l/nJ89P9oNZHkgP9/jEMC9NfxcHyyBfwX
SrlR0Z/KaRdHg3981FxP9I9YvrkU/U2nOT3oL6YNs9DfoowahP4j7ALHb8C/
eJStg/7sbJrxG/CXkTHR7wR/GfqrXG/wnzcWWW4J/u/f8XX+AH//ynn8M+Cf
4GupFwz+7KAA7iD4t2pMUi3Bn1OSEoD+zUMCffTvWXfL5z//fwEnhW6Y
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41P0ah8eeomVCvSd70dRIpci+pMWgmvTGaJLI9ibHSItdB2UtZWuQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lHsfxifLiCNvslSUxp5slWml7HVkmUyTQt4sqWSLUieS5FgqFQ4V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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k41VsbhzciUsZDNnYKyZQIJ2nYtuFFqSRUZCZDW+GNcyKZ21G00SQq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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlmk81G0fxWVkmcRkT2RNhZBslWiZMFIhWymRR7JEUpYQEmUM4rbcJEuy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k41HsfxqdGlkoyRNkqWXJSPZY6UiiEmMMolaVQ1kqnTjRlmFNZoyYJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN12k4lesaB3BjiJ2iwsK2iEqGnChkLAehDBm2sZUMbUPIMsVOhYwZknnM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnk4lGsDxkfK3mJJpYjEnCwjdKpJljZLhkKWpCHM4WQZykkG8cUwylbW
khJpUUiylxaikDZropCTTAmhovJd3x+f+/nL9fzxu37v/dzvew8lV7Y1aw6F
QqEJUCj/+/vsm01/boaEEX18XY0ep8Pw/+db4mPcz0L82bO+2pMX88V6Zs/S
dBsxavin2bNZgUi2/8622fOWQbvdfj8+zp4F47VcjoX2zp67JVYtVnACT/Wz
s86Tap89h81n0QoPDM2eGY7NRfsS382e24KllsWdBl/nY2Ns3986e9Y9csvB
4T78Gdopknun4Y+oYNDN1MF//apazFRA/g13JcRZb+G/M1ZuH9eI/B63mR+3
nQIfQk8bSByCP/qSyhevWvj5RUINAWPw662ayFmrBX7CP6tPQRR+rl5N/89W
+H3kRhy1f8CvWH9l14pk8KuX0XSSXsOfxcswda2CP0gu1UZVqG/2LCfDdTis
Cr7PWkfwykb4b0ydLH4/BD/lZdLfcUnw78+eVKfGgff0uCt6RQD9N9+bmGa+
gP/AmU0O8m3IbxBgsENDD/y2PXJbq+rR/w5nHxXvcvjtdSmm2dFvZ89lvlpK
kmfBL/6zoGl+BfL/mBs4suUq/DT683/StJC/XnNCc1wK/IUYfu2f2civltjq
H78E73++q5BBZ1k37m9yrMjzCPhCixS95nDkX9HlzsuQxfOP7KW1Ld2M/DaH
wxRF/MCXuYnXm18Cv4EXFmixBvwW9c0PGiTB51klvvvEAS8bdagnywO8TItN
vqYoeAXrbSoMR/DNMQsyGR7g58ZV2da3gP9g/qqAtRX8ZmW3jKgOfH+Vt0zz
aNHgRTyP3VZQBt/N2fTkSz/un/NNsYmeD3+vlMEVujl4n/jmvdVs9N9yfSxV
LQH+7Zy1UZ9U4L+x77zavAzwWdJ9wwXF6D91kVqOei78jEYNmtF69G/loeta
sJDIr6Ij1l2M/l89bex8ooD+Tb/HiY4lof+e309f3vQH794gKyiVgfwJ+0dX
H12N5zenGmk+XIH8tw92MI2OgmcIL+iPOQI+dZXqexVJ8L4pki/dTcELLu8O
Oe0NvvOFOD+yDLx8FsNpty74VrVtUoLTuD+Gotfr1cR+u268+jqU2O8am4zR
I8R+L6OGpbOJ/S4I1BdQJvb7oKmXYgKx34pnijMvEvvtvHOfejCx3/W8VUox
xH6nUx8l+RD7rUo9PuZO7HdtwNIMfWK/v5qJu9kS+90XGR+zgthvwy13P5gQ
+3197M5XuSbs14l799kWxH7zImLc9hH7fX9s8rEFsd+RLZZnS4n9/jwg91ua
2O+egl+DlcR+3+W07NraBj/rE21x7zf4myScf4gQ+71RhcWfIfbbUzR46AKx
3+ms+G1Z8/D+nmz/NVFI7HemRkDD/g3wm+c6JdoS++1cXffWJBX+Qu0uLpPY
77ST+4L9KOi/wpDKK3oOf/v4+MCZduRnHpzXmrAJfNewQZBUI/o3NvI6P14B
/+gOiXlm4djvh5xMnZ4z4Pe6997UqET+AYni3H+J/R7i5A3q0pDfPlXp+kVp
8DXDkXviziO/sNFotoQsvt9SD9sLVvfw/dbG9E84BoJ/tPKULy8Y+UdUU8Kb
pfH8/S7DNzy3In9nbOiDHb7gh2tUp6QKwO907i/yoIHvqp+x1hYC/zyNnZ0T
Sux39B/ewQ7gdRKm/UUEwB9Mm/Mlxht8JpeSnnMA/PMcrvSqcWL/d9W7OlqD
V37usqilGN8f/22LLI/o38Fhxih6BvffdklwgxbRv8NkR3VZB/yFfZspckT/
v7j/4aY+Rf9V+ccfLa+CX1VwVfwDDvrXv7myv4ToP6Cy8u7CKvgHF6l/9bwG
v7tbd4KcJvp/Qxm9pCYDXtlTqfVaBvoviXX065JB/yYGaqX0R+g/pXzGcimx
v3s+s7X+DsT9pfCt35wj9nfHsgMKe02Q326kVf4tsb8n7sfadpWA942a4R3W
AW9lLOAz9RP3H/NMVL40jPj9mN58ZpABvla00L9uinj/9ycERXDgT33Jpy3f
D34gt/yh7nzc/53BA9XjTPjzOkLYhanwfx09GHKH2L+S1opw/gfc/w0OU3r4
Ify2rCal0gn4GeEmzbWa4OUGy+e9WYT77wkxb/fuhH/emoCTvEHsT5nTnU8r
k4jv3/m9hMI7+CeqW5u41fAHJ9LDrWbgP32o1oC7Brzj+o9J36nwL6lr7zjX
D3+yD/WQaBn8npZ7UtoSwC98ubQyeQz+o5rNOsOP4XeJOFZ3dhB+BX+T3Wxd
8B7GVh4/R3H/35QKXLIb4Tfc8jLaUB3vv03kv/YlqeCLlCoDJxvhlznse1G6
GP6kET+ztUvx/ouwaidUFMCzLv/sKWAhv8UTyhGD3/CXmhy/0rAO+dNCmJey
I4n9tww956KN98+7sDDiER9+v+IK494M5JdIzRNPtwLf/jOwpISB/PYxlC/b
j8E/1piumG+B94+lMXVRkPj+BSWeXpyuRv7vi6/HXr0O/wqxG+KGfyD/76mw
V5Gy4Fu6bppNxCO/Lds8Nm0hvn+mMp9m+hbff4iVtN32YPB2J2tGylnIT5U3
naaK4PnruAOCaU7I753JST/7F/g5k5b07A7wts4Cb5jbwWs/CH8x8wr51Vym
fYR54FMEiq64KIAXoQnLW/cify5j2l6gGP6V698Hi5uB5ya0XCgPxv1r8Hrv
9SbDH2/r3OK1FH7HqFx9N+L/Z48TAq/OFeH+v9TqhU7lwL91blDLi424//Sc
jdGeC8BbzJ8OqajE/Zf/NVKarIT7T2pofbcgCvefPCph0cAGf815+7GcXOTn
J7msFlDD83d/PJ6rswj5za1FVCyJ/pYE/rPhONGfadnO82JEf0rtkZ0dRH91
2uy4KKK/3sPKNpKd4P08yvPTiP4OMTR9Q4n+Nvqn8FYS/VG0/LI75cFP6vfG
CxP9mSf1fcsl+tsWf3moyRT8bYPHuotC0d+WwHIdbgr8JjE6eh9l4X+vG7HJ
i+iPTw96xib6e6Wz+NQ7oj8v39YCUTr6M3Za94RB9PfTU/e3ZRX6O538zO8F
0Z+Xv1DZu0j01/hLICCL6M9OO1cx9jLyM9PYRRyiP9Gy3WEKC5F/pC8zJ4Ho
z359zxMZd/BiDyODjIXBf25rPJHIBO8QztpFIfprpM91/tEF/tNar8/SxkOG
/wWv5yuJ
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk01esexncoaivKkLmoDLE1SBKSNEmkKMTJnGOWedgZLlI4EpnHwo5Q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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk8lesaxkWo2A1UNGxRIcNKSspMMoZQ0apjHyTRYBFKWkQsMiSOqTJb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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk81P0axkcKobK0WSJFtsj6oHWErKWypIfK0mbfokVjnbEUxi4lcyhC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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81O0axicixBslUgoZkiRLRdmS9UghplVSsitqaoiylKXsydIrW1nK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41Hsbxmdkm47KWvHaUqRjqahEskS2iYSIHGMXjSickA4lSZGyx6Qm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN13k01HsfB/CpRCKylWRk39ehmGtJx03WShhDcbuW0hCN0UwuxhZXTZYW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0t1Lk1EAx/EtkFatpBfEsQorDHJmc5BMZaRL3XKtRlGukAJzrXRss6yl
jd6MxLqI1qItiXIGufLCYVhW0gpS3NVEarXUbbEUNUvIF2xm0UXPc37+CXGu
Dl8OD8+PD2ddiWmPbgGHw0njcjh/z+3XDEMxNz8nvsB5P3L83bZ/3Xj6YXX4
yjDTtqhx57ELn5nOXiJJrJ8aZVrp1fckKz4yXbix9Pnmo+y9UHD1gDerj2m1
/VuFMO8r01HVoz6XK8C0fthiuv1khOlNgcA9vzvE9GKdNiZys99XhTK6rEZ2
v91X+fJOHbt/rHK0+1Y1u//uj2JlcIbd91je+qVjK7vf90asdRxm7+fiUtP2
FrP7bS1S0QoV+//e/pp9+63s/iTX2Ow5F7v/pFwuS+aEmV6U3zMYI/Z7Wp+C
v/Z8O/iLy5XgH3QowL8mb8JP+l9qkYJ/7U/9QdK/qmzNCdKfN9f0ifRfWP7b
SPqLbQIX6e9UHgH/tqSZTtI/V64Bf8/ZTB/pb21MB/8b9vpB0n/Vyjrw16SU
pZL+u3n9KaS/7LK1iPQXbBn4RfqLSuKySX9PEfqHd6B/Qw76z46j/5Aa/RPf
T4L/A0Um+I9PlYK/s2s1+PutzeDPX8aF97+2fTn4v1iP/uZp9Fe/Rn+tQQr+
wiwJ+DcbHOA/HaoF/7YCM/jzFQPgr3GfAv+bI0HwP5SyFPwr5vkXqtD/TC76
S77P89+F/h1+9G/IR/8Mrg7833ajf8SM/hYe+kd60V+2Af2vT6C/8xX6x0zo
nyBF/4sW9E+Iov+zdPTvlKP/By/6+ybRvyme+lN/6k/9qT/1p/7Un/pTf+pP
/f9v/z9ccL0j
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN2Hc412sfB3AzZCTbUSGUPNmrInRC4pBfRoXMsn72KhRlZc+S9LNXmdFQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41GsfxhGVLY04XhWlrGk6lowlKY2yRDE1RXqRiJA5Y03MQYpQ2ZI9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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4le0WxjcSxzxkPO3IlLlCIXOHDJUMSZ9UZKpUPiGFQqqdiMzJENrm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lXkbFklF0oYke0LokDRFxjqUspWljdaxU5SyDKdDWQ7OkCVbHHuL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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnc41e8fxkmkpMyco05GMjNLRjIiVD9RCBFCJyMNOiih0MmIbJFV9izj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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41HsbxqXGFiFk12bvpNIk4zjWiooSnSivEJNoJUshMpZBdkPpVQgV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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k01V0fxc2pUNQtRcZChhuFSgolwzVmaEBXxkemhIy5Mo8RrykSuZRM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3c41m0bx8VdNMgoGZGZ0mNkk5BRGRmFtKzykKesjOgWUTZlZBOS0JNR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lesXRWQeQnLUqUhknjrXnHIpIbdOcRIZyhClSyVKOpShooSKZCpT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHsspLWgxyhZK0VBTJKeUPUuFEyJCEZ1QlklKSNYalFK2k7Ik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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bRenLm51sLQqNSVGRJCJUZN8TNSRLGkulSfQqy8haY2myJ0lF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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41HsbxmVLSTi8kj1JI2uLpMi+HRlRWQo5tlRCqKSXlBJKiRASUY4m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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k01WsbPRcZckwhic+QjCkpV0jGCpFTlPA5kkTmITMRtwzpIiVkqESk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k0lXsXJoTInBTS5Bq6KISGa0odmTMkQzqK82W8Mk9NlAiHbioqypij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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lG0bxgeRGJo2SrYWlWStlLIlSyI1REhjKVv4puy7bGVJmynr5FMh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41WsXPaEyNhCRKSLFFSVHqovMcjNmSi5OolSmzONFGTqiIoomMoQc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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk0lesbPaTBcE/3KGRoUJIh06VjiOjKkOGGZEwZMs9jhiJDyVRIMpQG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3s0lPsXxidUKnJNYUlySWSoUJQTSmMUIeR+S+lIoYwiKqGS3EIuhdIY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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlXs81Pkax2dc1uRSW8cKkctkw3Fd15KIoiS1cinlkrJE0VRr0xQrUWh0
rBqXMNgo9xq33IbWPZEOGcTIiGpzK+M+cc7548zz/OX1vJ7X5/s8834+vw8V
7yBHHyECgaBDJBD+99ckeo/XWJek5R0Nmn8n6Y3F/+vICU7ro8BPgnpu88iI
cQdXUF+uD2VUTH0W1NP6GR7jCf2C2lI4LrDhEfRX/O6vFEq+FdRl3RJPjylP
COqbNjn3ZG/1CWq1wrTtubtBbxT0p2aU5pCgNpbsuy2eCPqHqgGx2V9h/+W8
3ULzi7C/lfGVqa2MEUF93/MXIeVI0N9Pelg84dorqMsZeskq+n/De+GdrAwl
0Dc0v5eLLAC9sJeO+bUrMH/GnmhuxIT5MR+1SxrMgB9rmiK1fQ/oHYckNEjd
bEE9MKcw5TEN86eeUTlB5Rzg+YWwxGsEfUmSiGrERI+gJulpC21xh/lRA9FO
x77CfM0EU+OnvcCXYRCvdkV6APZ5nCMV0AN99rLEZroy9Kn5upcu9EF/oNM2
arsE9IWjpn5weA39LsryG3V96C9T1SVHh6AvJqzC2TQF/vGIjUkIboE+P1pF
lOID+nc/v1UrRP6LzfyYvfUe6HdUNzSxkf+4ok27rJH/+uikrzuR/8LfEr9V
If9Z62ZQJpH/Ik8O+2ppgP8U6yVduumgn9e2CuLMwv0j5LpXcpaAf8syLy4+
DfzzvE++4wnyH8FIwrfGCfxnrKZX6KML93980G4hhQz60OCFpvB80N/Q7GNb
h8L8XFr81swymC8l5BBiZwj3p02H1XH3gr6/TGE0gAX+o6pJabHHYP6ie2uC
7Rj4L1o/cZNCK+hJJew7XgPgv6Il+/yGn2G+F+O27E/io4L6QovV6/Rm4Evz
rPjx01m477Rs0fkfZqDfw/S5H3cH7qsxxPpVPhv6o+ecCVnycF8zNwbFeBvs
5/6vDpslCtzXqbn9bpUR8veTAeVCV7jvtlv2f4mkg971fb68VDvwPaHzu8lp
Lvy+naV8h4TXcB9nTx8bOgX0QsNaplVNcN8t+Z5u1ADgK2PIC7FIegf+zoo0
L21G+XJGcyKYC3wp6jvKelxgfrhHzAptDe7b1nX44EAH4ru6+vSmNfBNoqgN
9I+ifPZ9TNbuBL53j4XYX66BvgLxTs4zBuiJf1wlFhNgv5b0cfHNBqA/qnSz
qDYC9GOfKQMJrXCfC/VOFq+PgD7KbtzB+xr4ryLKeaWgGfg4sV72ul4fFtT6
QnorIq9Av1OR+zqeCXyYzNTGNFPgYxLu1lm4G/wXvLRHPTQT9jOZq3SgacN+
pp6bZr014H3iOio9zxn8I97s0pSiAXpv9kpW7T3wz3QSb7Y2B/S5nXc9zyeD
f/xGfzFNbYL9btFf/GSxEe63zBt2r3EGfdc9R47MKeDTtkCriagEPjG9VB3J
WuCTRg4w8+1C3+eM/Gl6HvBxGxFSvG0A882HE0V2HAA+jt+OcGuT4fcZFk7y
ZVyAT9GB3UpGhvC+ZfWM62F54JNdq/Vj6gbQH1vsUW2XgfzQ2e9RSC8HvVWG
Yf7MbuCTdWhGgnUX9iOnaz0IiQI+Hu0MVVU50Ns6Lw8GFsH8cecNuaTDMH9w
Tcr3DHsQ+NDCK0WjQZ+cwiZ+2QPfJ/Oi/2UVNeBbmVQeKGcG33fSAvuIeTbo
OR+UBlcyYf/9jObTqS9gf/6/m1V3fQf7x5Djnne6gZ5lLCU7vhfuS3qR9L4u
H+YnOyj6HF+D+yoGGrqPofsWR/IfsB7BfWcumj6u0If5HXPttcv2cN9Tivp9
PDrwISgwaZln4L7myW/3Ekzh/ZkeQvclUeD725YTBXbfgV5ZdkOd0j64L389
Z8y5Gvk3xvJGHRn4HG9rnTUIg/1UOKVveLnAx9twH81PBPT7p882fN0K+TJ8
KqeRT4X5BQ0+wpUz6PudPdWgifgOhitaBO8HvuRzlfVhhcC33MZvamYe+L4S
+sfGUcSXGl091I74upfJKtUjvnet80w/Ib4iJt2DxETYb+c2EsMd8TXptHw0
ZQLvq5IP1vQgvs/TF3SDEd/1R/1ZtnuBb91+Vp8l4ssvm9Qx3QZ8ZaXfll5H
fMv9esmuiC+XHibdgvjy68KsZxWAL79AmGGM+MpXjfxayYP97Zc6TkmfAP1s
Q2ajtzXw1Y+r/J2I/DtbUk4MJsL/N0WdelXs3282dpN1iG/MOXrYM8R3REyU
sIT4RmsEkeeRf41t9TpSEN9Qh6Kbq4hvR+7Dy9cRX+kzsWsOiO+BaA1bceTf
jGulnUcR36I360PbkX/fvP/bxgzxfe5WoDWG+Far+3+hIL4rifKzdci/t1OI
sp8Q34thDNbWL7B/VziTYIX8u69IdI1ni/wb3u9sifx7uz2oU2UR/DvDPJiF
/UuPrUtsRXzthNeTWIjvqpjqnUnEV3eVl72K+JLVxXwCEd9Gdg9hFvGlWm3s
rEF8DXLPUQIQX5cPjtLXkX9Ti70lbRDfkMmr7vLIv0Ylz6gBiK+/Lkc+FPEV
U1OqLkZ8Y/2F0yiKwLfKKoLui/h+6dvgWDML+293V68dwHynaoL+RPn7jras
ykD+dY690jSP8reAbOGF/Wu4PigG52+tt3Aazt9XV1d7cP46evGacf6qcB9+
wPlbvU7nJM7fHaFMR5y/PX61F3H+hg1JDSkj/5Izy4kuiG+4UgaXhfwbKWby
B87fz3MOOXOI7/j5f36P8zfp8iG/OeTf6N8qXnxDfHW32D8rQfl74N1fNA3E
9+I1uaVrKH+b0qOkIpB/i1NGvx9B+dumO0fC/q06HS/5EvFdJ0Uwx/lLfdy4
/BHxPfuoS1wI5W/FUfHik4jvQpDwWZy/0VHMTb2Ir4Y4sw3n79Bpu4a9yL/K
FPs4nL/Zpfn9O5B/hx7kVIYivml9+vNOiK+adLp3K+Kb10oxmED5qydjwDVA
fN0/lKa2oPztILmlbEb5y6m60X8E5a+clfLTxTzgm0V6qRmL8veIfNIW7F+W
HF2mHvH9RuUl4/x1PUdpW0R8B+f4B3H+Hj8Rv5SM+BqceHUI528SMyIrFPEN
mJe9dRjzNbPPEUP+vRKnTcP5O5n4ZO4l8m/IrgitXYiv1vP2PaOIr9y2ps2X
/sv3P4mO4W4=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lG0bHryhvIgsqSQkTciW7MuhopgkkS1rKCKVLVoohJIsRdZk5DOR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41G0bHRUpekn2nUSZQhmEZMkSLZZqVJbUDNnqLUuJ+pRdibdPpJFk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41Gsbx4dzKgnhMMp0ZBdZMonmiCQi2SIUmjqRZBlapEQZSnbRyXLE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV0ns41PkCx3ERuWssuUzH/ciuynG/HnEsmw4nt0GDYeRuhhJTci0tIdLS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81d0Wxk/dwq0UKXPmIilviKTI2CukIlKnMjcYkrFBMuc1liEiGl4d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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k0lfsXxmWolDFChpRMK5kyTykplVs35BJR0snMVeahrk5xUklFhoiO
yBxCkRSZ4mSKHGOmJI6MJZd01++P33nev87a66xn789+9n6/3/fdftbLnMTK
wsKitIaF5X+//pUposr9XHs368sq1vf0Gv4/9m8uiFZyYDDjMDJfubFCFzM+
7CHn4pU9wYzvuLsXZnIOMuMfPpWx0v3Q60tJsVFdOphxt7zH4J+CX5lx4A0d
StOdEWas6Ljf29VjkhkrveHXY5j0MeOZJ5PkM4HIH3rgTlJ22kdmnF5T0zR2
DnzeMa5/1eSDL181xOJlC/T0j7Q2k+fgW2tdP2B/EHzrI/bmq+0EX8OV4/Ob
KsBXYCn9p1BeDzP2MsiffsKH/PeP/dST/UJnxoJxR/PLvAn6uMtaRaro72AM
IynLB3rVr989FCrRH2M15nzLBfQXfvjQZ8Eo9Je1SP19pAN6zu0RtuNJ6K+k
7AXpqgb6KxI4bmZxFP31a7NU+1HBR6X4LW5Ux34Un7u8QV4L+Yc82CgnBdEf
b8iZlVAR6HvXV7EaLvYzY80Xj4UsXkN/WUJ4tmtzJzN+m58aGRkGvuQBrrov
ucPMuOyjbGIMD/TDi2Jef8+hvhPP9ou6fqg/N+RM8xKFv1Gjrs1JXtA/pM1z
X+2Bv7WqOfXkMPh7PPSptJUb/I1pLGYRp0N/jW6/rTUc/t49E5xmIgf+t/dT
zN67wl/h9quz22+C71/e6YGGTPg7lsevqmOJ/NU+K9XjHnj+OAQnrkg2gS/l
anzJDt9PzLgy4Gcsby/0i/KyJiW+4ONbY7tFWRx8k+IW8Rlh4Eu77l9tGgQ+
/9lTBiQO+MfHe5J91hX5PS68+1S4AP+s35lunYki+Cen2+NrCv8Eai0E8nqg
Z6+0Pz/jD745lvqrVAnwFV7UsMq5BL7a2bXGGSHgo9SWymgswb+AINqCijPy
Hy7vVRFmh3+PAm8uVd8H3+NpJ8tmbfCxfnxn/Jbg3wUTAYc0b/Clq/o3UbYQ
9nPsp5FwBPiczE7oL/uCb5mVFFUqBv8ea1dGjhL2L3uptGiWTni+eU/sKf4H
fCs/E14ZeYBPZHCt2FQX9L0cHA2fIsAXvoXTbJGwf/HKWzPOuoDPQb9USecW
+LREbU+JpsE/JaGnNh0WhP2pcBfN8oV/7pbG8X3N4AvmIqdMncX+fT70Jtef
MF+v7TcXZQLBp9wpVea2FXwNlNhc7lDwVSlwLE2Ggk9KZ9I9eQ58bUUiqQXn
kX99srpuKBf4chwLGGsegI+zaGYoUwn+eXxnp+r0Qd9N2zC54Am+xGUth3fC
4PMsO8eaFwm+kObmF5IXwSczU0ML3In5ru0dvCV2EfkzbHx/jdVhvpKsdlO2
/uDrcmA02JDBRz3JWxrbCX26pl2QZyz45K2pmqUq4OvINbcztQJfG53L+Hci
+EYbXjkp2sI/eRmFl3f2If/caXWrkR74RzlqFBmwCr44eX/l/oAB7JdMY+1f
NOj5atYVfWoE33hLU1ejOfgGt5e7yPGBr6x/r5tdM/icvH3yf5ni/gyvUxkO
nCOcP19D5qIju5nxLn3ZzzsL8L/hVEn20iT0jfZBriI7wHflbW8L+QruBz+z
xgrrQ9BH9dHWVnPgftK910vTSIb+ESe5eJaO+4nxfOtP0nf0J3y5TOFx/hAz
llg5cT7sBvTqI7ezHQ0w/4hM5+U6Rfh75BTXNqoS9JyeX/LoxdCLS3WSV8xQ
PyNcyVw2A/VVL0nv7bLD/ehXem01XA/6YlH1F3tXMF/pb/PbcrgJ71f8fqeP
KWK+5WSeerVa6P+R90zkWMB8ZfmbChPdUd/j9e+quG7U91/D//gVYX75EZ1d
O65jfgvKxmPpT/H/1SqP3NJvmN+a62dGBwnzM+3bfVT3EuaX6WjwjnIQep7c
VsF/eTA/hSn3qNcPoVcwoouptsK/OmM1J4cZ8JOSTNePlcH/BjEuhmIE4f1G
I/WPbkvMLye50U9BD/PLvRHm0coL/Y1Uq/ePK6A/UHO73VAG9bMkrWNWI1G/
2pFbKDEe/s0kkibSRaEvN7IYLChA/+abipSSbNF/vfi+Cec0nD/TXylr0gj7
917qUXi6Pviz6lys7Qn759Sz4dBdZfD/G21xO56wfxKr8bNuFuAvid8azPYE
/DbBDgvfbcG/MlblHaEPPUfBREHZD+yfvhEnY+dG8Is3lnvX6GD/DO6N7vWv
I5xPHDyalQzsX82Hxdd8zqgvOWlTrTuC+jzeWcVhDOQf8NZjeZaN/Vu3c8PK
m5f4fzakVKAhH/vHXb1r405+wv1sfkvr7Cj8ryoPUHn4N/QNe2g7XLTg/69N
1neHfQnvR6NznEefw//Oxbuu2l7wf4HcX0C5j/N/yPmDlPoH6K04y+5rpKH/
ru7R4Sgd9N9O6tScMsb5+lz+Fu1pJvg0v0mpnxLA+c9BU1dQU0L+t95t+1MO
oL/ry9LtOkrQ/6aZGGyKxPOV/Mcy26VC6PfZ8aftJmE/gsqkl3ILwefWvCpY
bIz5vKG0zmYdgn5eUZie+gz74RJMUjrIIDxfYupCtHbsx+pKAl2V4M9kZUin
EcGf9pFe+ziCPz7v86J7Cf5cStjfUkHwh+oU1ihM8GeHfPGubQR/Zr5ve7Du
IPyJLdA86ETwx7P4OKfidfgTyXi6257gT61cYP04wZ/g6ffdW4rAN7t7mrtu
P/zZwmqYuOMw9GwWoc2rBYTv78HMzA2T8OfFKXahATr8Wd4qNBxH8Ef8xrcH
C6nwZ/MFKzkJbdRPdaSLfDOBP/Onjeb9M9BfWFDTLLsk/FFzuD3tpkr4vqXz
yk+oEb7/rilzB8lC32+3Wi5cCH/auK90VpRCP6IioCljAn8GfUMEk1LAl8Sq
bcntDn/slj+96FGD3rB4SoAii/p6I4Gs97ah/iF57ZjKZtQfE3Fsv1xOuB9O
7TkerYr6J/uOnSXfRX1u6bRMEgX120T0h9mloU94dkDfNxT1x699tNcg3E9y
rM6GVD7UL4lSaeNIgV5ArE7lUTPqH2G9nhM8jfqWF1U6xl/ifPadaRckhRPO
p/nnMyY2OF+ifTdJxBoQnh/ehPo9G6B3T/yV/uMV9LfP8JRnS6A+qaVF/mQ4
6lO12tXjqOi/hVyYWyVI+P6eqfJpb0X/gy+rqiuc0b/Dy45etjM4H4d03hjb
XSK8H79iV78fAf4EHQuV35bgd6akJSe24XzUUnkd3fkO+qgMKXOLbux36wGW
gDHbr4b/AZ/ZxOw=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4le0a3RKSKfE5ZagQSsaUKIeUKYkyRMgYncyiskNRhpCMIRGZ58wN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lWsXxneGEGWWjCFKJ5JZJdMplEwRUjtzKERkyBSKqDjKNlXUzixz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbJkVkm0hkT6LFliVEiWSaSMryhUoyRKKjLFmOckrZUpO1iEaS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lHsbxzUoyhIaKktRKh0Nipw4QpHKHhFhylKMPaasFS+jBQ3Smea0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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41O0XxpFESUiMpTBINRSVQkVMdkUINXrLkjKKJPuWFrS82bKlCJFs
JZKIaLRIKQpjnex6pchrD+/1++M39/cv17lcn3Pu+zznOfN8ZR3cLU5wcXBw
bObk4Pjf39A46vXTg/x7aaanZZskm7X/H68sGHL3lP+HHQ+t+RgrY9zNjpc0
JETTnv1gxwIf9m8gmzSxY70bhhVSud/ZcaREh2fE4R52XFj6j0WzAfhd03HG
qVUt7Hjds9z+vjnUlyWVunpHdbHjMGOBxHAmeO4UrR3Z17+y44l9D9Ktt6G+
lFRufpFtLztWkcy2LcsYZscvxEdHVu5sR/1Gw8ZZHeT/yeIhi3RDX97tvJre
5eDTTPvp3/Sg7wZ/MxerAfxuhqel9hPoUxp3bJIxhb4rNZaeI/LQ1+Z6+n5u
LfKHcTq9t3JrY8c650o3HVyG/CSNtbp15FZ2nEAJt5yKAb+/T2nT8E34+/FW
sL/DltB/E06VUXv429keINZYj/4Luum4Ut1Y7NhQj4dvTT/4tKXdrEJd+DsV
mbw9Zgn81bsIffpVBn972jZ37D4EfZ9zba+p13ewYy7h1txHdwnztbAyeq4T
8zX2WEI8mBP6dtlpCD1IwnyW+KxQdCHwa19+tfmbBV5dObndkQv8pO4MMzUB
vIWJ8wH5FPCrr/pOO7SDFywpfsHJAV5L56E6113weVLPz6jeAe/KWDYZOAD+
mFNT4mEe8Ilz+97n3AQ/O/Ok3DIN/NmuglmNWvA7l2k4xUygv8I5o0phxeAL
1jj22MeCd/uo2ZVIwv028qdk3iejflGTg+y+A+AX3CVICiXgW5h6LJIF6lfN
KbPMH6F+rWDkgq057ne0vVdAnin4w83r+99kYr6iR+Nemf9C/c1yAsml9bg/
5htfTyp0gu9s2dPTchbzpXFpOn5YFvVtLMXDqgMxX91ZHG+GwjFf3GHzesnv
MP/BJTIrJ52RP5fBUaCwGvr4mhgm9Q+g7+HG9Rn5a76x40XaYMDOQfCCU4Vh
ujugT0JgTs58bogdM0fD1J7VQZ9FGf/IrD70bTn6bXCJWCc7tiZ3v9DMQX76
sRcnjsej/2Ii76ynWuDfU2bD72eTOL8Af061SR/whdLP7HOLcP5nj/TFF3rD
34Y48eW11+AvPIb5eaQLfPUR7qZgZ/iz1wgeVpREfUfRL96PrsGfTuWpqrZA
+FvmI0QX4sL9tnCI1tc/j/wUx6IS13fQR8rg+nU1FPrWNrhVSXpAH1Xs7up3
3QR/uhUKQ4egT81UXJ8qCH1l1cNU3jTo+zGvx8+gQ5/fjCs98xj0ndHeVnEi
gtB/K7Wd3dbQ5/s48yWfHvS9DLT35VmEPpLmaruK9+AveHoOBLVD38CMd5Su
M/Q5GbZeYIzg/tilWNUF/4K+B/mGU0UZ2O9L4rqXiDLw/zfaSk9so/H7QF+l
+1RFGPVDBCI0UweZ7FjVqSczKwC8TbpBjBkv/C+QM6zyvcDbD8uVhlfBfwr5
gsSZIPj3c3OPaveH/31hgtY138BvPefA94kG/x57ArYpiMB/1NGsQyJJOJ8y
H4r5Xg/om5EuEFivBX2822Iv0UORnyx9RvZIMPR15viVOB2BvrKk0SnTj9B3
+bdAedNX8KKOjjdE0qAvx71PWF4H+uT8/CTHdkGf3/7qItJz6AvozSu2eIP+
q3kFXpQhE/bnx0Wfy1Ho/+i4wusfNuDrScu5vavgb+38FtEtyeDf/zbn2P2D
cP/VExxT+eAvQPUWv0447n+R7Z3uoQzC/MWW7ggqA89QbGbyj8Dfbek1Utlv
wdseaExuuw5e5rn0igNU9HfMnzJ7UBP144PHjn4VA7+jNs2ntwb8eEhRBXWe
8D67Shk6HoD6GhsoUpVVmP/rOUaGx/nBpzwa7DZahvm3GW/30IhA/+6xPshP
vcF+56JzzUQT9nufBd826zXY7z3yw7eGsqHf8sYTA57VmI/zNhP5VMJ+N8wR
85pTg36ZHFGmDGG/j85dkBX7gPkwtdtfmE3Y70W2vsVZJOz3i2Id3iGE/R5s
YmbQcgvns9FeRkWQsN9HvpdmP58mvA++fR0XIux3itDDiMelOB9xrQ8+ln7w
J1ruwxF1Gf5y1oV557HAu7+gXN7kAH+VhfR7B0mof4xzivNyFPwxi9Q0lH3h
z/uSHP2gBOaXWnr9cZ4f8pdbfY9amgN93k5Z4Ske0Pf2xK5bjHjou9bHUHMm
/P5TyrxTHdwJ7+d1PBNTMtCnWKnf+iwY+k6xTGrswqCvbtWhhezPmA/WdPpU
1ynkjyw//dc5XsL7nlbAdE6Hvool0utyydBX5najpW8A/B8VIzF5dei7U7X9
YtQfzMfuXXX7lGuhL29C11DRCPo0jH2oYyswH3JmSgknspFfrvS1cPs9zIeL
7DvltV3wLx4racX3HfMhLsKg/g4izO8Dh9Wj0ej/o613n3Y4wV8c6a3c22L4
4yvpLeRqBb8YnTDfGQF/NCO9mAhV1D/KI2niaQd/ngxKUu89+KNJiLpO66H/
6T0Mrj96yJ8f/2RT/3v0n9Qt7ZTDAf5s5Vj/a1+8DxNiTDRvNIMPfHexfn0C
9AW6NRdXa0Lfn9CRCaoR9LV2DOUZPUL+BNqrE5RZ7O8/VgyWtCryW7wKFZPT
wv6WFtzSkLgdPGXVER3b8zi/k6JHOG+Xgr9bLcc3T8X5JQSFvKzNIug7TFOe
csD+0/hlw1OnC36H10qn2A705zkjuKyRF/Xve4w1KJsTvo/FvRQ7G8E3Cc7n
h+ShP0tPun44b4j6n9uPh6QpoT9vz6XVKNUg/2x6akHkdfSHVMGMcxFE/lVb
rLLNxtCfAH718CshhP3Q9q+Pxr84f7mtIjvJHuBZgZU8Im2Yzym6hFrhNcyn
QwGDTKNhPt32Nu2u7AXfrhj4IcgY/lK+3NEu54U/liG9y/Ux/JXKrete8Rf0
qSo46wmlYX/1aXVFHoxD/gpRtYbEldAXUXyu2l8K+mL8TWVpdoTvT4dDGwYL
wScu6s670XH+bj6HKD8qoE+ZVqlppoLz/0kiL07YgZ9WdrEQNsH5X2CKXMtg
EH6/hu+nld/H9/nASe4zoYT99L4hzvqkJvpzK+VVotAC9pPtTGyk9BvC+2uX
QegrE/SnQNFgLGsB/fHVSjq8MQv5hT25t6flw9/fLrb6sf3w92Xy5oADE/1R
UV+eyXkFvFHxU3lBOvqb1OOV6WUGf+Nb9Uw+DeD8DWQu5o18Ap9+RexnUAX8
iW3yUTG2/K79HypU9K8=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41G0Xxy1JkiUe21MRac8IMchelqTSVEJIljSeZHtGlqcY2VKyJGRJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnc81f8Xx42iopBCZBYZ10okIw179JWsr8pM5XZJiq8RrpEIJfoJhSQy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lWsbpXRSkQiRZCykvQkZElKE2AhbIlJfMuxwSCFyYqOTMfOQIRk2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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3lYzG0Xx1uomaTSJpU2paS9VBLDI9UQpazRYrRo0SO0vqKMRNqXJ0pE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k41H0bHQoVHtlCmFCULTJlCY8l1ZQKJVuWJCRtkogkrxAmS4sWKfsW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4FOoXxxGX7IYsUyo7NyRLTZaiBaFEFKPEWJIiJUtEQspoUfaREMna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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbRrKTLWpC9qhsHZyIkK2DKJWmUELKGpJGyL6kUCRbKaRwqExl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lHsbnkTF0GIvS0d8KCVRlqIyKsvE2JdK2caxK9mFOGULFY5tQtla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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lO0blU+lLGPiY2zZSrZiLIUWSySRQlKhkGmRUaJFhhSViBaUkT6l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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGs4FOoaZRolkUopRREyY6KjEZFbFEkhlSTRFolCOMqISshmqD3kToUK
KWqXlG5CxWCq4zLuZExs45ZLLsmc5/w4s+aX533mWetba33v+34zlFx97dwJ
IiIimqIiIv/7m2hGP9v3S9JE/Yu0f6dpr/H/65IbPx5mDg0I6v5N4U9+DnYK
apZxn23M+KCgltHQIvjO1QvqUNudtku/9wtq6v63hz8SwR+r9Mq4Xo0nqE+/
chbvqe4Q1B88H68Jaga/pHm8PCOtQVDHHI7xb7L+R1AXbUgdqdrMEdQr0nKH
X7PBz4oo06re1iqos6USt/LFwS+ukHsugNIiqLsNIvlt+cBnuPN7fpHbBLXz
/hZLPzvgJ3dJVjgnsQX1wNixZtlfyG8yZY3VhgfIr/i9CvnXMPCF6ZeWklbD
n2Ji/LNN08gv4UetBKUb/qJvOJLoe6CP0FfYm6OM/NjFGpppZeA3+Omo26/S
KKi5TvPa0/eQX4Y8XaPKrwf5zk9kPrcGnl+sTKAUwJ/8n4QtY0ScvzuJxiHS
4I+7TSxVhAd8h1rrBX9N+OuP1yLXLML59/91wGZvGfydmdcfWO4G/hBHt8c2
Se2C+nKAbFxYLvhlDwWbWhbD36s7PlZuc+B3DbJWL3jyTVAzwtbEluYBr6A0
rGVRCHzuq+Lc/dPAG009GegrBX7y1Noa1XtC/rxrF9WWA0/NfmhqRMT9M081
7eHcBn6HLJF1ugj4qUeN1NEo4O+zz9LefsP5tP0tahlDwJPKbRJV/wJ+oK+t
tUC/SVB/UTRZrLwH538qrGe0LQDe5ORRHYlO4BfYxLxWCsb9kMUPc2r0cL5e
5Pe+EQfcz9FRpt7GEtxP19db5OcczFdXnVxKnhH4ec4qXWeJzYJ6A+fCv8ma
wJe0L/ZpzEf/yhvnDR5pAN6b7RQc9zf0HbMzizB2hr71Bh3KVEno81dxanky
DP6yVK791lLMd5hIXUNtJz4nDhy62yEN/Q4aWS9Pz+HzexNKJ3i+wAflZGV8
qcDnP81mX1neAf6E4Y9z99Wh/+BLu0MLA+B/8/bmmWpn4Fc19V+PeoL+Xjya
X1n4EPil1mlpKcnoD7dWKVn+APxPBpt7dzbjfq1W3di0IBX4JfZRR8ni6A9C
XvOzAQr645YhYVJ7N/CWX2UuKNUB3xxb3uvZjvyXUXyTm4Jw/s3S2/oX67E/
MhVVOj1XAu+6PIYkPwT/ZtFd2w8y4D9/F+vYkgLs17xt3M/DAcAzplUSQluh
/6zDTtPnmdAvfWbZBVe9bkE9eOFYiv8s8EpR6Xnd9XifdFLqivcysV/5wZ6s
EwZ4n3wV3XTbx4XmZy4iciEL+20sUioq7gf41Qr4B2XFkU9ne7H31BD4TYc2
PmBNoD/LidVSRjrwf1Jz4FX7FfQ/z6ZM4g0L/AuVlA1X14OfF2a2edwf+afe
jfBf0438x61WHN8tCbztZHteihz6t2Kp/n1eNs6PzdVvT7ZG/kPq56UOOAHP
XDnH0XTB/p+Y9rsY1I18fvswTTo1uvBefcq+JTYFfL5pVJBIP/JfcGOQqtCM
fF56HZGsUkT+vSW9WvNS0Ne43iW51gr5JxpVtXV8B/9gg/35O+bIR7u0Z6Zv
NfIJN3hzXP828k+Wq/MouAx+Bm2s2nQR5i/Nc51uejT4f4TMhDS7oP98avXL
6U7wH51SZk1qQP8Vfpk+xu8D/pK90j2iCfSp08o54TLQZ5xi8sE0D/p8WO53
9YKgL0nva+CsBvQVVX8wUo0H/w6aWYvVFuhzm4woatgJfaOO0YzIFZjvLZQK
QkIr8E89SaIHrkPfY/ru+QFz6IuqipUIMIS+gENuwdk10EfX9+5hnMf+O6MQ
Y1SpAP4Z3Yq7HS8x/zePbC0MDxGa//eP3hauhr/GJELlrjjgjcry10pYwZ9i
dQKZfAD+lHp7Jj4PI/+uvsunC3uE3p9WEc4yF/iL/M8Ob2kS/KkwaxJbQuFv
RHXLvrg06OtVCG3JCsZ8jNw5vLfOQ2j+Ey02fFyP+XDLf3Ekrgz6Fl8MddRi
Yj7uvGfREn8Bz6ogP91ah/mwbWGpF33AfEhQXlNjdmM+rBN+yy/mgf/ZvVMn
SmcwH95iE+f2TYA/QW1q19wU+C2yiqwWccB/JZI63ikB/raqo4OmG+Ff5o/n
9T+52E9nAkeLuW3g/2pTPJtxDfnqf3pdxtuJfM+URQSNWCDfWl/R671C76el
qERw1230j0I1Xf6a0PvpmDkU+ELo/XwyYrZW1gX4BxYt0fwi9E/VcJ2du9D7
ufzjFpJRKt5Ph2+Of0zxoI+98t3Tx02YD7vZyxye0Pu5mWx9dIaA/nufE8WY
IyF/s6DaknEr4M+vcUun1ABPUyOEfuxDPlIhJ4m/L+P8Ri4lbEMl9veUbNI2
5fVC3w87tl9rKIF/o++Vsw8vwr+j+4TvEnn498s6b7jjutD3W9v1jX/thn5a
+FPbTdbQ387e+549ifnxSerK2vwNeK+1OvFtHtA/9KaJ3aQB/TaUqLOtfrjf
qQxbtZkc6Ktg3Di+xBLz83GJSV2TI/gtfo9/CPDA/Ny45Hf1Sq/Qfn1L/zkv
h/k5dPOu1NKfwO/VbmU/GkJ/i/+zch+/Df19bVv+Vf4a9Lftt52thqugL++Z
PeO8GuaHNhFgqMsBvz31of3YMfh/9OASTXQT/O+snUpddxX+6UUUf41k8KfL
mLAdY+FfzcMrdv9ZoXzlCvkXxOCfmxVdW/4U/kUYM7nqRNxP1kKnQK7Q/qgp
1PFyqoH/uxS/A16V8N/xSdlSeg/831d08knpB39a4DyzWgz5yo1Iu/4S2h+3
XfWbZsbB/8+3j2VW3eB/++Bk3fFl4DeOtXihqwD/genSt1z42B9XHd4dbRH6
/RERq/SnVyDy1eltZpboIN9R5lad4y7IlxE0d87ob/A/75HRyf6N/UGPUDi1
yhz88gNvKqltyJeqoe7vsA540rtHpBpx3H/5NXft/i7gfesIdGNf6Ot5Ki5b
tBX6pE4Z/PjgAX0RlpwgZgH4MxP8N3/agPsXpYbJ5NiA/4rDXAvxPvTxdnx/
G04Afkou451qJPSpZiR3iQ8CX37GTu00CfrSXA7efLdA6Pe1TM+S61XQt1wy
Z6XYcfBzNZlj2aXYH2YqOZ9PFIJ/mwU3rj0O+zO0YGqjCRf858IZKuVc7L/y
I3u0YhOA1w5T77NRw/5ZlRSiddIQ/ccmjZk3ygO/8qYfX0zo/z/K2ZoNpEz4
i6f6+l21xfm+Mul0UzL8OSfPmu9q5Rn/F3g/qvE=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4VWsbxrekVEgSu0GmSoRkTqbyYYeNbajMGXMUco4jirQVZa5MiY6Q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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k01esa3kikdnYyl6lMEZklkcxTDpUkKVwyRjPCiUqDIesQZahQCIUi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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlmk41Vsbhw3JUGRol3GToaLYCHGOKSRRIkIpZaoMEXIOZUiDpE3l8OZw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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFZe0omS7DwOkRx5q+dsPCyPYzf1sa60X/dCzif
b09bdWPlEzg/KqL5mML+V3D+9QhnW7lb9+H8mRabX75nfgvnJ6CZ341mPgua
+Slo5i9DM38Wmvmj7h91/6j7R90/6v5R94+6f9T9o+4fdf+o+0fdP+r+UfeP
un/U/aPuH5nuBwDUfL2b
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANELpPTvqrDxOrh+CnRSan9iD+MXfWozld78Cs4/
+8/+USb3Azi/7rKZhBjbWzh/z8tXL5ymXYbzf4RPZZdd8cJ+1PxR80fNHzV/
1PxR80fNHzV/1PxR80fNHzV/1PxR80fNHzV/1PxR82lpPgAZwGxc
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFXK16qGXLwOtz3d9d41HvZHsZf9PzE1U+LX8D5
M7ZPaT0w4Qmcz36HLVRo9Ss4n9niCheLwgM4/6HFmRd72N/C+bvRzO9AM/8M
mvkXb6Oa34pm/j0088+imT8NzfwNaOa/RTPfCc38+2jmH0czfwKa+XvQzH+I
Zn78qPmj5o+aP2r+qPmj5o+aP2r+qPmj5o+aP2r+qPmj5o+aP2r+qPk0MR8A
L4SS4g==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1ms0FGgAxvEx0jKW1RLVYCZRCRlKrcomS5dB28Rq3YpxXCLSTC1rLy4r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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANH2pnG7PHl4HSbMbHKd3vXEHsZvVWWMM976Cs5/
ky7MsJPzAZw/L72UwZ7nLZzPr9eW8q30Mpx/U7e+r2LaCzhfcGeRPMM6hPkm
c3VPq01AmH/85OVzKskI80OexiS/Y0eYn6TEfbK+H2F+QofnyQkrEOaPun/U
/aPuH3X/qPtH3T/q/lH3j7p/1P2j7h91/6j7R90/6v5R94+6f2S6HwD7ZwGH

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1ns0lHkcx3GGJTO5VZNbSFZFIQxN9mjcRe63VJRqNcSWLcnlyC2Jcr/k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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN2Hs41GkbB3ASopw6OKvYTckiQw4l55ySKGzi2ik5DTMh5BTCS86nxJhG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV12k81Ykex3FbdkWDopDdsUeWkiwjxjJ2lThMxr5lLUWDxpKQiCRlmWsr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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN2Gk4FdwWB/BDvCQKyZwhpIEGSYS8So9ZRYReSlGIImMyp1IazPNUMscp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41F0bx4dGPUWWh5J6IpN9qSSyZguhyBYe2XcKSbIl6imlxlKSsi8l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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41PsXxwcp+2gIhSyV1FWpkEmWm0pRFEL2CmmxZUsJRZTqEukiiYS6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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41dsaxze5jkyhrUynzDJP1zzerZQGSYqGLVKpKMfUgETScWSqtoyR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41PsXx8dIGFlCDZE93emGhGutiaKsFalBLip3LEVlNCWubLdFDZ5K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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41esWx3emnSEJ7W1my9SJECeR6Ei7QpmiwZRKZluEQnQJV4UikXBK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41HsbxgfFEUrJPvbKVtGohE4Tx8mUIUaSFnqpDGWtkEInslOhMtmd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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk01e0aPY5wJaTMMpwiJMnQoL6IihzxKZkydKLiI6LMrU9KKkmGDJml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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k4lWsfxYVjjEIJyXwMW+bIWI43TSRjhuwMJxW2WUiZmiSRrpC5Y54q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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k81GsbRhNFI2MJNUWypQUhHRxNZEtJQjX27TjK0nKKlA7nLZFdNdmz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81P0aHVJkT6mQfYlIlkq5hSyNpYgYI8kSWQpFRJssbdx7dYsoW0Km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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41PsbRa7sWSNrlgjZUxlrci2RLFFIkqad4ZK9W5LKlDVSrkhlLIUW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2c8lQ8bx63S86QISYRCGcmRKGUrM/Kkf0cJOcXfpkJ2ZERGwxZCosw0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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81P0Wx0mULSpkm0QkxDxKJSOiIiXbo5nGzXojgx5bEU+WLEUl2RNG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k4lWsfxXdIhiRDIdJOpoxb2EQqRVKHDBGlkIiIbWgj01HhlKkMlVkU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk01A0bRQuVtSJkK0uWFiVLEcqSyS6pN6OyZk+rMGVnKAmtskTZZfpC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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHioiWwnHzlcolexLkrhSHJ8lUpR9KUfSSpKyZclWk63RKEu2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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lH0XxyVL1ieEiSZLlimyRSghLYp4smQrKUIPLShblkgq2jQMnmRL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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81HsXtsQoekVDSPZSQrYGjSVbZYkQchOZbMkSaU9l6711VUqiq7Ev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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k81XkbxpFOiCEiy4lKNSRKdsqafSmkMMPh2Ld0iBl7WSbZQkk5lhZJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81Psaxy0dtCjJZIkyJnUrczDWlIoIIZKSK6fskbI1aohqJKKoo+yK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k81G0Xx0W2sg4qiVFKpMja3S1jKKS0mKKm0MRMkZbbUlEYQ1GRNaRS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41dsXxo3JeFAkyhBNjszkInJIyVjKlSJKhgwZw1UyXrm3kiFC3FMJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41G0Xx4dENLIkkX2rxu4le0alelLSYmklSdZMo6eUkjWFbNnFY0np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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lG0bHqkXM1pRWQqTkaUsiZCMXSk72fcIlSWEVJZI0qZCRVleu0iM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk41H0bHWRLiUjRQ4WMPSRL1iyRLGWp9Awhy5Qiqaksve32yBJleyop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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41VsbNSU6onQNCRka0EXkSIYcU4X0SXxKkqFMKYqD4pbMJ92QIRmS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk41WsXxomOsaIQKjOlIvNQMsvJWBxFZUpExd5ql1ftQp0UQhRl2Oap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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81O0axkeLRgtjSUiyZK2XqFBU3ibx2pLScij7kqXFrrxOEpXIXnmP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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41PsbtS9lGRmyFIZSoSwJNSEaW9dSjCyVLJUkS66lomu5yBZFUWS7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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4VQsXPpGZqFTITMiQOaVCKEUpmXU0kOkiUx00nMhYkeKaK0XUJbnx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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lWsXxlGOWVRkCIXE2YY6pmMeMkUTyjykDJVkyBzlkymZIvNWUTiO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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41G0bLQrTTvFZumSIpLJGloqWt4UwYUi2IlmSGky0KFFRSDOyFJIW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lf0WNSXzVBFFCt1QoRTNSihjZYikJIpyQmYSlVCmkwzJcIQQCl2Z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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVmk4lWsb3UQRsoXCTqbIsAvHQSop4ZgVIkMZChehDCdTjoTMKsVBbFOi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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk41e0Wxg2ZTppIhtSbRAohEhl2qK280k4h7CQi06nMU6JQNJjpleJk
qAwZMmUMW2TavciwiyTKuIsyc/Re58P53/uTa137Wuv53fdaz3r+FwmbK8Z2
HGxsbPvY2dj+95caWTcrQ113+IfXJe4aky+k/8dN3wtCt1ROEjF3rv9fIaFd
RPyDg+6lrTpOxE8FGC7O9oNE/OeJ/TlJO5lEfPrkNS05qU4izrL+nqaTMkrE
HL95nod2DROxwVxO2KZc1L9rQWNS9D8TsbqkcOagOerf7J5jWnW1E7EO71C/
cNIIEfOZ3Bl/VfaNiFO9VJOl5HB+GHWlXLPwKxE/D+TyUkkdI+Jz9he8qKXw
52PU4pU7wfBHcEJTib2tm4gTNfWfcfwAv86nF4M5hgNEnNE78DPiLPj/NrcS
9O0Hv8gTxlTWE/BrKsrna+SCv/7Qg7fvtMDPFRszvBwN/ob7zUyFNvCTjztt
jTADf0G/Z9b2CvDXCPVbyd1Ff3U1FnzT1MHvusAd42WF/u5h+oXtlAK/Ztzg
9JQQ+hvbQn3GFge+etWX3a8m0N/yUxxOGvGoz2D40AaD0d/qQiU1qzOoL0s5
0yA+D38S4tPI1iXwx3jr+yfN4fAnfm5pYb0nzj/batwqLwN/OpeOG1iexPnd
Pk9CKbLQdyF2rTK3Cs6PzfqYPFPRQcT0enKvBwX1ZQXI4vGXUX+ir/z6x0X4
f8j4c5TGT9QPnUxw+jUJ/4V4NppM2L0nYgn6G2/ZIOQrUfa08nMMEXEryWHs
hjHycz2+kkyHe4jY7HhZUYrvBBE7SJzPUA7pI+LiaRfRLZzQp99MLlT/gv4N
qzfkPZLG+YHjOpSUWpzPOePuMlSF+iMLFcLZIh+J2Iq5tDcrm2V/6KxvUvuK
+foU/Ytadhn+JyYcrCz4jP57H1fNuXMUfP5Vo4Oxp+D/tvg9u4+sov8BMuld
hrzov9l0+2q1AvgvudEKHXPBb8Z+cy+ZDn7GTw+HvTUfiHg8tyjvWzT4A20k
Yi/44X4/KhcUzqwDP/OqTEDuZvBnLD0dmbcEf5De5rfxbzG//sOmyvlR4P/T
eDywswX8Er03PQU2Yr4e2v13Q/AI5oubLrkulQp90xaZCkwj6DN8E3qxXQz8
JyyZX6jiDCLu+sgV1PIb+pMX03vqC/B7zItQ91NqyH9asny43rsX/ZowDa2s
QH4N97i/zi70n8Pbxm00F/knL3mQqR3of9T0gnmtLfzj9j10cWgJ/mX/Ep+f
JcE/2mZZzdvu6L/FbOa7NyLw52qyzjbbHvhD6Qt9beEGf1yrRuQFdsCfmbXF
TFst8NWWtSuetIS+MkfKK4s86Iu9seZUvT30iXdra0/XIH+ozkla0hH64s4N
1IpKQZ9YKfOxawTuv1yWkRefEPQZ2txufOuF+3c23941+wP0jY8mXL9qhf2Z
ukH9Qa0s+EyLYjhyRT4R8ZGWvu+ROizvi75hSbMj/DvntCF6/ybUT5A7LHz5
K/zzFWukup+Hf7c4h80HjsE/BRWNo3Z/QP9UmW7sJAfmRzLnvWbOLPgKK6aO
243h92s++waFDJGvXzWg+5AX/ssK1EeZ3kH+2qfk1jlZ7K9nbSk+CVPI3xuf
FmRGwf48ILZ3F80V/K1PvTIsJMC/WGlM9tFEvsjyipKfNc53fvKs43EBzrcN
Yh9ItUD/U4XntpdXIb+z0SNzyh/9d5Ukhfkpov/TUb9po+7ov4fxuyal7ehP
LZeCUg0J/R9zrO6vf4n+/OeW9XxdLvp/r/rw8/O9qN9Ss3G8tgrfFw/VKVLZ
LPunN5tTwaUZ+4cyaZugEIP9o7VhbE69CftnfcJP2T8243zuLf5fOD9jPlb1
P9Dq7OGvZWviVwl1+MtwaX61Sxb+nBGPfeldC387OpTXzX2Av+Xx+QYn/bF/
DWhnX6RfQ36EI4Mzcgb7N3BqxaSQE/l0jpdRwcOY/yDlSzSZ09BvEptZHbQK
/S9ePTt/qhL6y+59L9YLhP6A2IT+lhDol39XRA/ng/6g8CnBfe7wvzzCpYGr
G/tLQKg4JU0f58tpRZW2HcH9owU3flOfwflGMUcLMsVwfo7+PF1hC/zlyzIy
WBpi8XfSSa0uBfr//ctGR7oc8zmzmdwm3c2y316KLaZP4n7U7t7RU9+D+hWK
szylJHwf/mJm8ec0It/uwAJ/mQ7mO9ynff8qP/RvzLwlcawB8302Uy236Dfy
X2/LYrebw3zLrMnzjFNheZ+jFK8fTIe+zZ2Jht3d0Kdh0KBRFo350CZHrL5g
+f6ei6/ceKAV89HYcGUm4Tv4khy1+ZqMcD9m2/JC0lm+v311Zjhn+zAfzTuc
hkks3995EpPr5lm+vzdR5pPyNTEf2boqyWJxmI+MM/dWfJuh74BBkn3GOfir
JXKr7n0p+GWeGAxZJcNfxmh93taj4O9pGh4L0oO/CWEjtmR58PO6ffZpGcZ8
3QhR3WV6BXxjw6QMPWXwVcoWWSvqon7RcoS5tQHqr+qGrujKsrxP7qKic1Oo
b/VrsMLLB/VD7A5YREugvqLam0MyZqj/aqeCYI8I6l8xYTh3qqH+bs7UOUYy
6seap9DUDqE+4+CzEtpfqE9qYHYH1cNf6v0vHmud4W9fjOh7v3z4uxol76fa
BH8XTNglHazAF/ajfEcKD/jay7ckcmuBr7vK+Sw1FHzhPr/9H0iDr9WZtCGt
CnwvejMlI+PAd1rgucnlLvAJLrI/tb8KPp4kkv/9Q/h+F5Hit/fYjfn38vNm
K96H/VZV8Xf0mB74xOTUaq5bgu+lUKkcHzf4wq+5SvEsge8AR5vSJT3w+WkJ
0tpDcP/8fU58TJ7C+Q0r1yOFuXD/nHidjmWbgN+s06fQowP8JTPK6mRXlu+n
Y51Nwvl4v3/s3uqcthb86jrFeuJ52A+RFvNCdA7w+cqwF6rw4/1zjBix3+mP
+uveGfuRrqE+9yZqeAA76ut6i0+/nkB9t+SEPWryqL9ry/2fFYXQ72Ygml7f
hPrml/m33++F/lM5Gm1yidDPpK1Js6Vg/wjStelh2Zivrnmli6En8D7kizpU
e7P8/yJ53ObRSA/2j3KxZ4b0Y+yfGMt2J4kS7J/lHPZHuUos7/MRxkrvc/R3
RJoruSoP+igpDz2tEjF/gfaeyx3x4F+flNRebQv+0ksextol4B92qLytqwz+
WhvJR8sWLO+b6zFaCh383mtt/ZLiwa/yzeiuPg38vCvc3dRtLPupT8/tAx38
KQHi92oDWN6/1IViIx70R6V1RPyTEfhjRshh3xYwf9tS/6UkGTxB+ge9ff6u

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4FHoXJp9KJRJRV0W2Zkhudi1ElhChrqXI2m2aQlfJUrJkl8wtJRPZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHipbWSOHFgkRGjuVylqyll2OkKXESFmS5UgoHOWQskvISUJR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xs0lPkDx3GX9HNPo7Wba34ikqHSulRUaFNUwpJrTbmty5DJvcsvco1F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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41HsbxscWYuwtlohCjrGUUmgsDaIi26EUKbI0nZCtRHayhJFJQqLk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k01V0bvURIuMkQGUqDIVSEZJaiyFwyFGVWZkKuuQwp0y2Eq5JXIg14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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4VesXPuYiSpyDIjOFSqkk3biIZAghJUKOdCNdhGtqcIkrRRkyJGRO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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHnxZ0liKJlvJIaJI0qnIRLRIkXScSJbIerLkUGeyfiIMIlsh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbpiwhWT4l5CCRspSUOUgYCmHsk+wUoyhSQoVQlkiRjlLJciTJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41WsXRXUlUSIJlfFTKAopQw7CQYaQk66EZB5KmWU6KXOmz1AZMsQ1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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c41X0f9hrJKrlElELIlnVknDKyiuyZnfXYGYWnZL2UlEpGUhnlSU9l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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4VWsbxtmGUknFIWROhpBZkSnD3rKrnWMe+xBlpkxXlEIIlShCbcp4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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41VsXx02Z6nSJeCuk0pUhGSJPycyRqEynK1MpM5kr5ORGiQpNlCFD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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lVsb3jplHkLEpsssoVDH1CAdGXeGokSSkzFTZqVTmTYlY4niM7Yb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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c41fsfP0ZZycpNsilbtg4KGTejQaWsjkQRoiKbSlzjSDLqZoUu0k5o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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbFi2ylCR7iLJkCRVKyNopWY6tE05klyVhsmUOMkp92YdMPkWd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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbRpFsxUG20yZZShqhKAfZKvsSRYutsiS7IuGQNku2sitLSMky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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lWsXxhFKGUo4EkLtJKTahJAQEZEoZIpwQtjGMs8hGToNSJSMdXBQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bNZUsY0myRAuyFsoaspRk30lIKlKyRqYX0aIFaSFlrcFIvTKh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lHsbnsKYyNh3aXGEmpDQQiTSJiVaTLToMJKxtNlLVE4iY4kWKpJk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c41X0flhVJySqhI1Eqq7JHQj2UlZkdykoUykzDpqEeeawIDfFWqI4Q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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHoysJVuIkexbySE19kORRFmyRNYoSdkqUadQigyyZUk4VCaj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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81GsbxkeWGDqIGrwlS6KZkoohyyGVLBUhlcrWTF6lLG2UIYOYsrch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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XHkuiSGihQaihUBSNrSxhsoSSUCRbyp61hLJMKmS7qKi3xZqU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lesaxkMhQ4SthCVDaZdIdiTTKUNESShWhgwrqUxJlJCZQllbUWSm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4FHoXHkpUVJZ0v+4lZSfZEyVSI5HkYiaDSYSQpWzZKkuWZCkpJWMt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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bHY1IYqgQIkv2fctaBiUhLZZSJFufLHmJVBQia/YGlbW3QqF4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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4ltsX9dFniJtHlAglURkTispUMiVJSiHTJ4pISOYrMkXmZKrMMlzp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XRmgqLdYJZR0VMqFs5bV+RG9GlkwoW4mRpRKREJWSLWtlK2uT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlmk41G0bxg2isvU8aDEi2ZWlFakGQ0ai7EKWMWZspZQ1aUIhVGSpVCJZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k01WsXxw9XppBIJEXqltkls0wp3AwZCrcjCkllKMUxJMo8linkRJGh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41GsfxifEsXTKqSSKCGlBtqLsWxJHqTdCG43KSVIpQkho7NtYEpU1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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt090vFQAYx/FD3tpxvGRmWoTYqpGXaksRukmzVUdm5rQlL2t104ui9ObG
tCVaLmqLFGI6rNAah8ZFY+eCaWtDOk4cTjislXdpWhed7fv8AV2dq2e/q8++
F09g5sXkHHuFQrHHTqH4ex1S3cJaKlXx+kdmTWvqQNy/rSxecH5VZLbu7JlM
lal5yrrVt7e5vx2dsO4wp666k8YZ63Yv9qnRjRmt+1Tf/cbHlXPW3Zs+Tc91
GZ7K7wy8vB3B8HrOvYM3aDoCL8G3BF7GrW/w6tMX4Xloz8Lr2PCHp47qhDfT
HQIvxsy+T++n4BluL8GrmGffx9wgeMHH2+ANpUTDK3Jh38Ak+0J17LNsZV9b
YAC8MosO3kRoKLybP9i3mse+plj23UjJgPfzTSC8tl3t8Pwc9sNbVrDvvDe9
pEn2DQ3Tq6llnzKNfZ5e4fAeLrFvIZWeNoB9cYX0xtPYN1/CPoPHXngPftOb
3U2vd4V9lzvp6Y3sy/FmX1ZmBLzhFXqlifSqvNj3vZze0Uj2lbezLz0iCt6m
dXrP9tErs6MX8Zpe7hr7NMv0ilbZN7FKbz2BXqOK3nQFvQPb2Wfpo7ehj4R3
4hc912h65Y70ghroVTvRq5qmV3WYnmaNnlscPQclPctzejt96NkN0jtWQc9O
9K0cpKd2pldYR29OSa/BRO/paXploq8nlt7IZnraavHvXvRWPtNLvUfPILyR
Q/T8XeglvaSncaM3+5Ve1gV69cILF33Joq+ghp79Fnr9X+j53qXXJ7z4GHoF
oq+7lt4Vd3otRnqll+i1Cs8kPJXoGxd9kZ70dAZ6+QX0PgjvuvCaRN9V0efq
Qc9R9C3m0tMJr014ZuH5CU8nvIRRev359LqE90R4euElCi9beC+EZ7lGr0N4
zcIbE16I8LTCUwvvjq3P1mfrs/XZ+mx9tj5b33/q+wOSPMrs
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lH0Xx4fwRkhMZAuZkQqpCG2ytCFFb0rWSGTPVg9KKK+tLNkVUZYQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lHsbHgZZsqXi2EpEIh1kKYUip2KaQpQlxTepQ7ay1mTNUsduyJIl
hSyRFFHZT5YYWdrIEjVEpTq+aNC5vj++956/XPf1ep77fu7n/v3e9xoFZ09L
GjeJRNLgIpH+99djVXhDR56w8a/SMqXS6VGj/+O5mPHesuhPBF5ZfdrJdaiH
wMdmnzt/+/WBwF/PHeKammMRWHU8aZFtjucD+q4bxgWnCByfVfxuaPMEgR8M
JEdtypkmMENU5LHir0EC22/zThJTg57oBfvkNev6CEyNk1OVH5jE/8tNS8hl
oP/fPfJ2Bhrobzl2MdXIapjAP6VkDcix6E8rIJsYNGLerwOFpiKTmEdZ4xnT
URZ8+YzGlT48eO5bE6k96IV552sNo6oOjRPYXH3LvIzDDIFjVX34FD+8JLAh
/YhuXh302nC5NWyjwQ9vibngGh7o3fdkT0X0in4C+7scW2V6EfxnOkwe3dcD
v4pxRia3J/gZLZXtBYHg32jMV+0ZBf6CWQsXs0tDBFY3pzy8awZ+3qnwW7O+
vQRebiLz9ljBnyvns92/ZbwncGm3rET7MvRd1aCpu4q/wzyhOm3iiujvbPW8
t5WKfU89uNakuID+2X6af4xQse/TN4z8B4Kg/9FinbprI/TXrbzMy7Ti0N/g
RlLfCP39lE6Ldgn0V6QsMS+vxn5vP7X9amsH/d53+NrLQuFvJDtkl5cO/J06
zju5uukVgVOFOjT2yeH5sYr38tIHXhM4sKFLTdsaz5cbzPNsJVDfmNw6mNaD
+exj9WM+fXtD4Ib6E9s7JlA/EtZxRuIp8vGxqTXk+SL0Kya+mv2+Bv4nN+a0
jK2HP2LMkrlVjvB/MchVbZwb9SUKJskpBvA/VKqawoqDvi2jOhGONvD/luyo
5J+G6E+xvfmytQj+n2gf1rW7AP+PKJHZ5IPIzzrrwLEvTh8JvGfbVgkb9TEC
P/yye5wrEP2XskaknA2fE/itTMmJ+9a4rxzEn+lTzwDrl4m/VjED3k52o06F
Ake8evXfEhlgajKl/kYb8PXyUIVL2cjL+XsNijHxmKfufoSVtjLmaQn2DpBL
wDybtZY3JFfjPm5MoJDjkjj28fuP2x7ZuJ9GM5359drBl5HJXDKkgG+0YEg6
tRB8F1hMFvUz9ve4K2aUpof9Z81Yb9whBj76+yoh0SbsP/yJZ3yqOer5FZ45
ROUh/49727jWyyB/R1a/VteyQb5bnjg5jB3F85LR5u8Z87h/KP/ZwWPcgvzc
iCh3p+ri/guTtg1Z+IH6x0tjM7rWyLd+w53yhxXQZ7rlk+/eZswne0q6J6se
9d9Mf3NqyR9Anl7nxBZEYh+GbFNGWTf2Uat0hBYUB39kV4T/4K/BPtROyqR9
HsE+Gg+k77FSxT74Cl3TBWawj7fJ7b6pSdCbky225M8HPzWWKJVpSdCbyC/9
qLjkBYGPn7x+jCwHvzY0pQfJleL9Nmhf/rIuBXpjN8YpPEqA3rpPmsqkx9Cr
5fB5xvEE9LIlm7xKw6D3a80DYx55+NNpQ9OrbMP509rteP2iCfgGbtBCb8Xg
fI9uGH2r44L+8crT0yp09NfP33ZDcCP67xdf9NSv4TjfASqSagfQX7eTSyj5
BPqvcU/7wGOC/rThNoZmHforeEcXB/TDb/GAIuFQH+QjSF6c13IWfg89OCm4
Lgz5ys2R7brERP0J/2LB53TU0+apwW+mUM/2dib1FaG+9a7qKvEp1NfdUxz1
NkF9jHLe3E8BzMd/87ZPNwvnT6iXOqZ2CvVO7CthXKeRl+cCPHLs/eA31gws
TKHg/eEWLUub/oi8lJE+ih9wxvsjxWwuTakG9frz59y7mTgf9Y2Ox1/kYj8h
5ylpcXE4HxXFZu4Z16Bf7abbe5cA5O1eJmNkayHyVhGe1L8lDPvKXb9fNM0Y
+5q/XPvQ1gt8DHrjNJMHeYgw4pIUCAffN+9ri49+ga9MX+3vZnncz0bKDZVX
moF3JijMFnHo8dTJtz0XCj3H7w5a8e2BHsaWwzPXPKDHaujawRUC0LN/J68v
fxj09DXOG3Lz4f3z+8QKi21K4N9PFfweXwvMnu3Taa6GHl59i+DI09BjTS+/
2+sDPe/tl0LXaUHPBS4a0y0dejzGeleTbKCHtZHVd1MS56WhX2rVND/6C/u5
ZHVsAr+Sv/Kb3F0c3ztVfqygeuRt2/hlsatcyIvp5fbRpQnc9w+v6qbejMXz
s2VV4r5tuL+GZoUn/dSRR8dDf5BoDri/Tm42bB7n+D5XCVvjWFuH/R7dlWmh
NQ69EyJVy+uUMM/Cpv6a13PwqyZM2EryMuaJKuOtMFfCPHbcDFEKHXr9F+py
tVTwfpo3XtWx6Ai9u/7yMF449hZ+vryR1XcWejelaV8nR2D/TxVOns+Nx75H
/8l9X08GVjS53/X4C/CYctWbI7aY74fRGsq+nxx5KG/1CKbg+0tf8kOKNh36
NKWemfVU4fuLNf6b8dnD0Ccj0m/1Vht5ELQli15dh/7vDimMBy7DPxlp+guV
QPiXcNBKKMYQ/p3pfHOHdWaGAxu586TBPw2h+sY+BvS99Dqut1cT+kja1eY0
XY7zY60X8O419Gm8yi37lQt9t3cWHz5Phj4trer5xRqcBxdDzfUjlrifLM++
6CnPRv/s8tCropbI05xXy9akCPh9szC47fsD8KUPsIdOvoTflC/1/Xumwaei
ajk8cnuEwK8iP0j/kws+Utta4WYT8F361B6f5A8+mXO+2+kd4CtQUIzvLAdf
Wp5t4fRa+DfCNbzHoxPnZf/ZOv8VaeB7F/1kxjwMfDk8p5xWV4BPe8bP2+c8
+NqZKgmx9vAzPF++eQcV801lMextrHG/+JbVXHTjyLvyC5HFK5HIu1RGxLcn
icizX8xItwAJOGN9w8pmjt8PJGptP++2gL4EVu1mOsfvB9oXfxyuVIMf/UIK
MXbZ8EOii80dQEaeqEfpTDF16MuJ3r6WLYX3qYHOjosJPZh/LWN405/56F+Y
ejR7nxLH/XQ9fkNRJPw+bDtxqjIR/d90lV7pzYffBneWorm7Mc+kXPXCvb3g
u3VQtEDkAfw2SJ/eZTaIeT+P+4WQXPB9IDRflLg8j/PldSFeRvIgvi/oId3p
jFLUOzhKpMQ+Q73TULFc/kPU19Ie6XE9xfv9dtRAdH4m9t0hJz15JBPnZ713
f9dYKuYldzWx9MMxr65rEXOSI18l/j2+qucw7xafxAPixzHvlE91towF+IxM
BUPa7JEv4YFEd2k3ju/XyvmG2RTkK0+C9lfbdeRnUs9OZezjB6N/AVOi8kE=

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4VWsbxjWgFE2aKJJUxi1FokxnJyG0kQ7KR0WkNhkyp8ycyjwnxzYU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41O0atoX68qGkBWfKliWpKD7KckIq+xLxiWQSMWay7ykMiSkhkiWy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbxpdQJNIRIhOVdmp0zFhGWkj2oZG2MdVJ5mAk1ZdKEaEipMiW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHc81fsfPjblZES4sqVhy4xLkYyGeWw5uRd1leyojIaIqIyMk1BmqKiM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41O0aHtkmZWTJHlKRzxLtn6yVbFm+spQlJaVFWRNNV2Wp8Y2lNIxs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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4ldsbRR26yBQpRXKRlCFlLsNVhooyRRqkQ4cMcTMlpETmzCWkhGsI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lG0bxoVCSJuS1zZSqEiD0CuTJQYVBhUhRAptJGFMWZoKRWlKRZZS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3s41OsWHrdIuZRNdBy3oRApokgRocKgSCkSaiqiXKbpIoUuDCoqiVRS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41PsXNoyUKJVwpQVZpkQiisYWE6nspE0MTTeiJC1StqvEJBrmqkRZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XRlIoJbtXWWroFbIWaQwf2UYoa6koImUJI7Ivb0U10jKUNW9E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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41F0bHpHesiRJjS1CSLQoE5W1kiWlRYzspDRCtlZrlCUJEVFDyghT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lWsXZhsSGYoTqoOSiBDbXJklEVEqYySU2UEoJ0ORIVM6qRB2dtEg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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4le0Wxg2ZI5JKImNRMmfKXJk+ISJTyjwkUVHZn7GjLWVIGbbPkNqI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lWsXxlG7NMlQIkOkk2NORIakjtlHRWRKpmTIEM6OiIw5FDJmKjkp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41esa3WjQoIHMlQwlpdthR8Y4XZQxU0qmDCFlSMSmjqmk2DknN1IZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lWsbJSFRjqERiQZDbCckU4iTjkqiASVjoo+iTJ9kqBS2KRnbkSnz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVmk4lVsbJnORTBkLGdKM9BlLVMaMyckQiSilwVw6TkLJXByiU5StTBuZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lOsbVsqa/USNbGUpipJBixBSdrIkkVI6pEREyXKU9qiU7MmYGJJS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41esa3VHmedq5QnLbOhWnEoVCiFLJkBBKlCFTKqVTRBSZXeLumyml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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41OsbxocUoWPXnIyIlJAWJEKEskWWE6oTWZLsoahwLFlKliJLiKIJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHiSdpLQMXyVmcOyFSCVZOskoZY3s2mSpSPiK6CT7SE2EFqns
WSrLaLGcM0NTqBjZFbJXI2Wnk+86f3y/e/zjuq/3ep/nfu7nfp73B/WIj9Vx
QRKJtEmARPr395v6f3/EDCklnvuWC/MM/o+Fue1Pr8u+J7CToVS/YMkIgacT
1wyTWz8R+Hxrsp5X11cCJ9Tb8/wkmwm8Nmiyx8z2M4Fz6q06Qp16CbzTrskp
4Qby56jek/JPbyCwXXqpN2d0kMDKS2mPorSHCSwXd3B12NQAgQuvUhu25oJv
WdA6Ta9v4HvXRVxoRT34CjU/O6l4Hnzto08nGiSA78dde9opr3oIPGRfez3p
Ofj2HbwQrun7jsCS/mruYhLgq/rI+fzsBfAp0T7O+M2qj8DLauz7doaDjz9j
Qes4pRX5PxQaa4V9IbCS9egzJruLwCauqr7vQsEnkH2FMre5kcDJVK041skh
AtNCsgTnDgPXnLKyueYP3K+x4VqADfCnnc6tTDqwad8lxhI14Hs+gdTJd8Ce
AiyGSBHqf7YjRH0oEf2Sfpqboa6LfvlUxu+Iugu9G3M3RpvlQ+9vF82X769C
fVP+ZfsGtaD3ZHU56/As4ilMVcVuz4TeqSfi7h+dQf+bbRrz+mqgd5L2pgO9
qej/+S2WrJRc8FE0zZjsuQY+xhbbzhqxwecJ132zvgD4vPq16rBsL/iUko8U
FL4EH1Ln30VV+eAzMxhDSZkGH+oXswOL/DF/c1SvdX9+wf3whEMZBw/h/p5R
+7dflMCnOyJ/ftakicBaFrbkNEncp9p9Dzfc2A/9LrLpvGr4a+1ocpikQyeB
R1slfNtUEf/IcEPpMh3ELzp5y91iKeJf3dOvYGeK+P60iTCjXMT/7Mz9fel3
xM+qJ52VtEJ8k1ftFOW9XALrVTYHnLCBf8p6GN5Kz6CvTgVvLP8n8ntQYj9F
a0CfW/RhsdGdiL+68GdZ60vE92ftjKMyEd81SFvGbBr8x9RiXQd48IOss1/+
qdpuAr8eHzU5X4/4LGmD199j3xI4o762aywbfAu+0GnBqxHPcbjjpvE89qFs
4FxSrR3iDRm623IUwDf8ocBKkW3gazB1XZf7DfGTRagrg4ugRz8luya2A3rc
cd5XJdMBvx3+2Nui/Dv8n6QTGfrTBfxE6dVF8Sbgp2TOlhG6A35alqQ1JUHY
167KbWOKtZh/170lTSI+4Juc8FZDKwJ8WSKRQwWGyFeZunzC4hryCcsstRu9
jHyznYV3Xq7Cfmv8oTs2aIH9E0dKO8RhAL++1sBzogLvVpqYf9oL/MYmQzGB
Ab7Bg+PxQhzwrSkhW/Peww9Ge6uv/4cMP4vYtVvTBeAHjzadWN8a8I3Y4HRE
fwB+iN+11TWvCfU3kE93iLTz9etWZUVzGN/7mvMhYEAc8byYnE0POzB/CyUJ
A+xLuD8Y9qr6jAnel7ZLTJXDcej3oJfk4eGxFgL/eiKz1tsT9QQkHtOeMPkA
vymy857xvc9p7Zn1lx6g31HyC5WjPOgXIjdgObAF+tn9Yk8OjKNek6KWyJZ8
8G0KDjHbPYR6g8bVHqc0gm9wYV4b5RD8qXFV+V1fKPyizQtQFZ/Dfo5vjHvh
/Bh8qXkbNj75gf08xXAUdLcGX+Ntt8Xt5MGHlizqZ7QK/d5SorGi/SP0uXhm
YZ1vXQf2E20hYkwQ+aS0B1e6q2N/fxAxDGsvR/yjU7RwMhv1/nOz2itgBPWS
H4hOb3qN+1nHBJ+NyKFe63ZW1K33mI+/0ou2j3sgf1OK0pbhF5gPuZuPgpJ6
4PdIf+NVOQmoP+v9WfJ7Nvp1NMcy/nQn6g8uLj3DEkP9KuOeJxwU4Xcq7X5/
IAf5tW9If9xdB7/bU2Y85Tjov3y2o9PkCPSY7FuyaMARemgWKrFmFBBPt1J9
6Rdr+N0jZgnJj4L7WzKl62LWgS/Pjmo23QK+Tc1C235MoV9pVM+hoRWIH9mq
G/+4B/EDs0TUhSP53usAm7JF+pinX4xzs9EJ6NdDV/kIMQ7miSyqe1vBGvk3
m87NcyswTxpMt/D6LORvNHdx0NfBPNF2xaZz6OjPJamDtl3v0B9O4nGVBhbq
TSmmFVgpI5/0+OPaupSPBO7TVBykViLffJhHWOcuzMM2U5foyyTka1cR1aPd
5vt+LnSuy1uO+ndouDsaMVG/Xib3U/oc5lP+Z519QQ/8Ws9bIlazGPPpnSnx
Xw7fe3nhk/Qq4Sj4xZercU8kC36RtKlds0BGvOuqQ6kuk/D/puaRpIsOfN+/
xwaVJsh4L5sKjSk+KtDP2SHfu+o31Ks/IKpgF496o2t/SMWqol75cfGVNvdR
74PEkuL1gej3tJLhzIQC9I+ZK3SRyIT+xeYXzkvzfb/Wja1L09WB/neepO8P
nUO94d5f0wvSwWfX4la3rnnMh1+/56NgNvhsrXwRop4P/W8qMgW2FUEvyRw9
mTPB0H/x2lNC3Xzv0znfwOjSbuj/7aF0DqkRfKqG7VQzu8Cnd0yQHRsEPh+l
EhhMMuKxL1Oe21Zgnk5nhGZ/O8l3/08ZA/sA6GvVMJDn5oF65v0OiJBZ+Psn
Y7se9wUX+pqrW6//Yzm+H3+97vQokED+GbbzrcAy5H9JkrSs8ED+cYup4rhQ
5FdW7N4/6ob8xSXLPojxkP9U940tckPIX14eER+fin2yEP2dVT+B+9Xv4qt6
w7G/za96ebyZQv4u+/JyNX3oV9CS7davA/5/Rd4f0vgB/wYG+GabtMK/5yZ/
6jOKMf/1dL9HG3TBr6VGYuluI/hPVvnYpBQT8R08NHtdcuG/ER8/zjJNzMN6
mvzjo7bgq9n7cDo5C3ppcLJ+phmgXpeoz6lC+W0ElpGNIL3Qw3lAslXe5XKc
j9HESsv/4Pt/gQqTQ0/EuWzovuiczTg3Xz4n3jCJc5d9jmeTHHF+0EvdqEkU
58c/zYaGTPJ9n62fzefuR7/aYmKeSnTivnBpRf5RGcyP5d/GGQcdMT8ZVxod
XCywb/Rmlyk63ISeRgMleVfo2N9qvLuuh9qhZ7GpsN9nW/TPcqtHDa2E7+/V
s0tuKwkh3w/mlXVnqPAH44K4YoQx3/eMeHfqP8nwh/fzrwlcBuKH5JtI2Roi
/t6M3PLFyYjfXzsiyK3EPijuElbVL0f87MasG0sc4Q8tH94toWWop7H2wJQC
Hf64rV9ddW8z/NEa/GRi1R3oe4NO58wnYl+u3Cd54p+t6M/jpou73czg15jE
Cwa6ZeCTPCgZIXcbfFzT1HiHVMDHZZHLexE38JkJEGAmM/oM/gchzPAu
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41usWNZaUecpUOBTJfKJCJeVkKkMpHVNmylD4dIVChkiGCEUoUzIT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHkuE8mFEKommqEPZshRhJOKk5DSWOGSrLrJUhLLTlMNBJg7K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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81F0bxsmkhUSrklCKkaVGjCTZGUIZVEqKJKGSSXmUFFHZ4tGiR4to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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41esaFXJkHqJoS9gUdiRDKZntDlEkRRrIlK0yJVOSa6yjbc4QpwhR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lW0XPVKRIUOmUIkIkTGRUpIp0nSUlFlJyJAxReapvIYIlQzVQXoN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lG0bHtub7EuRzJtdZSo0lKUsoUQpskbxFl6TNTSlkE+LqQZRKCQq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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81GsfnZCiZZJIotBNllCEUEhSUuna2iyDKHu221WIsoRoVKJUVCIX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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41ekfvdFmyb6PFkmprFnKUnZKKIauUqLoEspQMbZEKUtlzZKytcpy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3lYjH0bTcm0aNGKTKOiaZNkrxhatJlKYlJqppdWtCBpolURytqixbzp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c41W8flp3xM18jB6mTsmUl61AZKTuETkknCqUiChENmZkNkplRRiKN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41HsbxkdRtk6D9EoyZEm2SCplS5Q122QtSdmylaXEyWgRTnajKVRk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81Psexu37muwiikREhCj7IQcVSUpENEQoRJRQI+F0KikiW1xli6uV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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlmk01V0bxo8xQ8pQEY95nutQQiEedBJ1DKEiQ8pUIlGvZEiGZCqpRMlB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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHbPv+9UvGS1+FI5MLd5S/f2sP4FmJG2ZcMzsL5
20oc/C0FnsL530//Spnx6hVCfeH9rXd/3rcfNW/UvFHzRs0bNW/UvFHzRs0b
NW/UvFHzRs0bNW/UvFHzRs0bNW/UPHqaBwBd+k8w
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGvA3fItb7mdZh7tKpE6PVbexj/xFJn/0+yZ+H8
W5JLJ/JxPIXzE/MfPBf69grO7zAy/BR18D6cPxvNvEdo5j1HMy8IzbyraOaN
um/UfaPuG3XfqPtG3TfqvlH3jbpv1H2j7ht136j7Rt036r5R9426b9R92NwH
AEK2dnM=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN13k4lHsfx3Fb6ViS4lhK6KCFHLtIzFijmSFKtplKdRLVsSVEtqlDhBKp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFhfLqb5r7ndXiy9qjZrPdv7WH8NW71lS+enYHz
xbPKTU++ewLnb7bmu2Yq/hrO/7LaU+Kc1H0431rPgXHeS4R5CaZd9vdNzsL5
5lP3BM4Rewrnx3Kyn+l68QrOP/js4KcS1gf2o+4bdd+o+0bdN+q+UfeNum/U
faPuG3XfqPtG3TfqvlH3jbpv1H2j7ht1Hz73AQBp+HsR
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk01ekDx3FLP5E1S4VrXyJ7NCnXLn4xjGRiKnJRyVIUTahoUQpluZZK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k01Vsbxw/JNZOjQ4ZCmaeUQpEhcRWKqGQmJ6QkSco8y0mkUgplqsyZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k41V0Xh0mFkDFKIdND5ejInISXikqplHlIhowRIULkkKHkSYaoTJGQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k0lQsbPUpFZciNhKvBTBd1jRkTFSdjxsyVGzJc4604lSFzpwxp1Yfq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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k0lV0fNZUoEeVKGaNUKLMyl6EMkUrkNQ9vZJ4vqUTGEioKmSJSEV7x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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k0lesbNRyUeZ4zFMlMJMM1lNyIZB5y1M1YISopJCJDQiRDpJQlQyUk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHc81X0bx9UxulGkMsrsUURGdBs33SIjm1MhOzml0LRSUpF5VyqrIiOU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41esaNaZToVwZikyRcZMhXQcZMh0cJSqZC3cbMmSeMpShzHMnYxkS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81H0XNZJBlMlIHg2VKIkUZnqQyF6UpaxPSCSRyJKyFbKURBSiJ9my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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41VsbdciUKWQs9enKkDHhGCpliojMmYkUriEpuqHQoJKEiGO+iEuk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41O8eRRlC/JRKI80PaehaYiSVlBSRZJlCRpIilVEixpJdNzdLSpaS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk4lAsfFV2kTGmhLNeSG1K0UhkUlSxX1pKrRmGYIkuEVKqviKhRlhCy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lO0bVZSSRArZ16xJKp8ogxJK2tCCGEv6sochWbNUBkOIQouJECof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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81Gsbxi11HCFRVCTLkcpaSQtjGZHKVkpOyU4inKlkSlkqW5TSYqlk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41WsXdTIc0udEgyF1uXJRIUO6plDIHErmwg2lTB051C0d4xGZUhFJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4VXsbRSQZcpGpMk+VqRPKFNGgDCFDhiuijNHkUt1EphDJ0DVkyFSG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bHUQkS2SUeEOYUiJ7ylIiISRLoRBZs4RKJcu8oUIqe6gGIyVC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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbNodkDY0s4TBRKSmTJa1EiazZl69CorJlqYSaHHGsyfKJihxb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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41GsbFpWKlMbU2IoPKYVkjRYi+1opKpKabElCTI1yaKzZl+zKTqiQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0blagYVGiovEh2hklMlqSSpSJ8aJHs+1J4qaskS5aIVOSVpUgo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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lWsblcw0GcqQIdEpYxkjogxlSkkOGTJnlkOEcGQnlQy74shQMmzZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnc41m0bFm9SZnmQlSTSJ6Pw4qGsZGto4CMjJKRJpDIqZGXvtB4yUkbZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lV0b9WYeokRFhmOIMseRlwpRJEOaxDEmQxkTKWMlCSkNnDJUqHhz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnc41X8bx43Ug4zwCx0nMo7MSPWkYWZTwpFCIasyKuOUxEPZiZYdKTst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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk0lX0XvcSrRJSS6SIZQmYZQlckvYq8kimVDMlQcmXsinilqCR8El1T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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk81HsbHV1rsodkX4sY15KtBUXKnQilxVSMqBvhTpZCWeIlzI2QpchS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k8lWsXPeZChBAypJCISEUDqitSJGPGOCdRlzgkUyEdQyESOdySCt0y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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lW0XPcYkIYmQeFWikKiQmUwnVESJjBWRsUEqhZxeQ8aQMYqTQjKU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41PsbHWsM3YwuaZGKya6UVCiSkiVZspQlZU3J1UIiIVmzXMu9FDdE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41PsXHrIkEm5KyVaqyVpESClRsoWIyhYSEm1K9ixRYpKbkSwTuRQq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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lH0XHsoa+iSFlGiyhkIiy2jIUslSWUtlT6QilcRrC0PSKqFemrRI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XViKULUu0WNMiibITCqUQWVuoyJYlM6GypIgmHybZi7SY19or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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k0lQsXJnEPKWPGcsxSxqIcn0hKkZJCUZKTqTQYOqGuoUgyZSq6N1Su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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41fkbtQtli0K2KxGVZaiQa4nIMrKULWsyyHIzo1GNriKyy76kQkyy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lVsbNmSMbYpz5EhSkXnWiEwZMnYSH5mKpDqUlG0O5VOcpJzQtm12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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk4lfsWNodOiFJkE4kiQyUyq3ClzNfUYN6kaJs7SCh0dYpSyUxlyDEl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lF8bnhGiKFFESqWQJZUtS0bWJiNbiy0lS6hI2mT7LFG2X9skO5Ei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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81HsXnjFkohQxCdnSYptsYYTJ5VputKGiLqKESCpLojHxlgot2iSk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbnhBHiAhZkjTIFtmasoXKTssXIVFJItlKshyVkgZNfSpL0qGQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41WsXNcRNA0k6lExRpFKGDjJTKhkiQ6aMmaVL3EydQp8MhYRIclQn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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41VsbRYpOHNesEIUiMk+ZDqmUbkXH7BK5CWWIe6WSi3RQUoaUKULk
mlISIamcDGWIzDLVyZzMJN3n++P7LX+dZz372Xutd613v/t3tp30PH6KhYmJ
SZ6Ziel/v72SG4JuG5L1BStfVB2pqKX8H9vnOlPzvIcI/M5sD7m+e5zAy5Yj
Fkc8PxI4YYrrzMaFUQL/dShq6yhHP4E3ffWqDTKcJPDdxcI80c4aAgssydVJ
Tw0SOLCtYpWqN0Hgyl3P7ylxtRC4iN9KPNZkhMDVdjH65cyfCWymtD7rmR30
+uxourXnRAeBu1NeF1lex/ov16r5wOPtBFaTS6K3b8R6/RTbOSXDLgJXMQ+7
hBhDX976qP6SVx8IfD/IlO7CD31808H7PIKhj295ZeeOnjECvy4PiT+5v5vA
s9Hj/5xMwPne4ga3e+hNBFYNHNmh7PaVwO403qG818AuD4TKt0gAn++pu7us
Owx9ajst8rUZBN7zekmuOgd6v3hSVshqyJ+tUL17Pwf0jNld/Wh9oBV6uCIb
XFSQf2jSWIzr/ACB9x249421Efv5Swyk/x5qIPDGazTrdzLQY3nOQHq5Gnoq
NMykmxfRH+eeOvoaaeI8KuuLbJIa+sOR3YfHzh37pTl+6sxVoZ5DPhHae+8i
3weNqtFl65G/RH9Afs0A8hnIpbFUSSGf9uBVL/co8L/+ztFymqmZwOLderN3
kuE/s3IJj40LcGCvg/AIfU1+h3UYu0TX5JU8Kv7DCHmJ66kUSkrDH5XPgipO
NajPSFjhnt4M/OnszFGU14G+toepBeki8OeITMG/7TbYv6C6ZR3/GPwxKvYf
mfKGP2/raH5PBuHP6mb25dOmWB9i9g/izcL9og7El0nmYP1C5JjCZGwbgc31
dtD+yoC/T8rPLfZe7CHw0nZlxscv0P/V7lkGreQ9gfXS5vJmYr8QOM6mTSsz
Fv33LG67cwgb+o93naVuiATmz/li895qWh36SzFlxXUI9T+TMIpivQj9Zysy
K1dLUH/XQZk4FV2sx8w5X3YS6SSwacCD5sAerIfRTVlW3DAvuyNCblvMQu/j
VdL+YV7My7pxhyznNfPyh+xy4fUuzMv9YmnhK2vmZckET/NLXfg1IHOcUs+D
vJ8ccn1qRkXeSsekknN+oN5ospaKtxP0kkr2MD/WRZ4rFR4GQv5Y1+SQbS3P
hR+fP1h3K2is2c/dq7yLAj++qY/b0Eaxrnap8SGNH36845vzIr2AHyPsHI92
p8APTRWTLYMa8MPEi+Gd8zfeq0ENzu1sxqjnq7DvVtkV8H2lMP28kI15xSdr
3rLkC76JKuUFS1P0y8MNCuLsXODLFJNTHb1Tj/sgGcYc4od5zlG+uTeXgX7+
Zf97OYWEebHJttjTJxz5PNHnPkxTwbx4kSkUkFSH+y+0t17fVgBYKeHu325U
zIO+T6MxhdyYByWKEY8/DiNfqfoUsadZ6A/Jw4dkdTzAz+xIu0oeAP+Sf6rp
pD3OH+0VG5tfxv16I5arqr4RflWefeVkZ4vz01ou8fol4vyjHTNvByvxXrXs
Xl834oR6uJt/H8ltALb2uZTZQwaekolvnz4BPdw1qXIzi9CT+TNqicwBPVnz
3VKJZtDjXTbdq54CPfkV7Lz0LOiRLdU0EDkKPjHJ65E3ZoHJBZzRRjXwV+uK
s71nC/SMZV/eJ0qGHrNy0XpVPeR/9bjV7LaMTwQ+ueBHSlZDPwlOM9HkY9G/
OyZsOx1s0b9nlPkPhk+ifzNJAY9YfqJ/wwQ9NXbmo36JPPtdbm9xXwJps06a
SuBL0JUUUGgE3/mmq9/o/uBTeXRR4koL+KK9KPvv3Mf9HLGcCNghgPpeMZcN
JJ7vI/DstHGxpwH4PNzLjpDmMK8ikmK+GzOBT0SVysekgnz+PFnBymqBebXv
VD+vHA39bH7W45zDNew3SyqJVa+B3j9eXl/PzIBehgNZ4xoFele4V2xIyciD
5ihdunFNHqsPa7eMJsKfAwJLFm9OgO+syqzRpjHwvWRIldrwgI+XNcJgtQx5
KAdzRzlkII+Nwc8pwmvmF4eIlqRoIPjaAxS4lo6Br01Hyi50AXwLhqHc09XI
30QgQHU+HHy1+aevqGxfM78GjYMKRcC384Z/3vgA3rs4GVO/TH7Mr8W8R7P/
GoNvynBv/cEGzP8PfZF+q2VYb//lRipVwHve9ryIZdINfs90+I0HF/Xi/jDs
RsuFoSdf50B27iT0VOkGRaaLQI92wS+HL4Zr+GTNdRLmoGciaIIc/g7rFfG+
hT31yMOxt5WzSwF6QofjNu+dQv5UTxM+Lm3oMedJTZk2Rh62ko09GUrIQ0h+
yaKbjH693+Pd56yOPJq+bA2hSiMPm/tUJQFuzKM5m3VqJq+w/+azxhXB8Eb4
JWhgyXkR80ae/nCF8yj6X3n7/VBjNvijxt6R4GWF+g8J1TpyBcCfhoLF1u3x
WCd/8y8LYsJ77bv13jfmPvizjlSbYaWG98p3d41c323oVaRF+vQNYX5K6e3a
oxqCeWkWrGlffRs4/f1AiYsv8GX3CxPK+cCcjumiVGNgJvfTr/l/AJfrCWgt
lcGP+ZsOtpu/Yv7ynLasYHyGH2d5GNr5HqhHb3JCnZKK/jt2NIbnuxDydr3c
47nIi/e8NTpNgU0J55mqkp8OKMC/T4msTiau+J5x8K8XkPqBdZ2AwvxXBeiH
WGlLuvwl9EN6fJ3mxAHczx83vGS0eKCnMfZihYs79Cj8DAm+6wg9lDOf2LNX
UV9nu3tEeTD+j/7jfXci/gTyykyuNHini/+jY7zFdKsc+BdZ28jO5oj3S7/4
WeRkO/R6Fzc/F7bD/OILvvMglgK9oXcG7nGScV8K6049LSLjvtj9zKTmSUPP
uatv6NZxmO/5GW4nup6iv9OEqZ2zoti/3JEdcV0U+21v/akf1I39yvckFElr
vncavTZ8isrGfetvT73wmzv2h9Wk37g8jO8dTeuizdtOwY8rgb+68ibhR4TH
Y+crW+BH2kVdkpwyzv8+aD+XXojz34e11r1RxP2IVxqjhvejf80bCtsNc8F3
gGYuLHUCfK3rxjipXeDr42x6vmgB/2MtzI0F9eG/TP+FDbvZ4P9WcoJ4JQn+
abEkK4TJQp+5UxJ3bAj8y/HQHaI/hH8FlzSEGdrY3+z48sxvbNif9Eci3dcZ
/e06ms0ccQh6z9t5ydW/RH9buUk5RTOwX7B102RHPv6/Oe22Htp0a833k3tY
qUgizvNgsPuZLaD+SDe7JvOdqH8lfka8gIr3o+dmkBbHW+jfxh4XWhozTvkP
ukT3WQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHnFCSMUoxiHFsRRKsidZzhA1tNgKpYScNI49iSwxWY4W6VMp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3lYzGsbrtCqLEmkoUGrtKhoPUWLpbTPEYY21ClKDYpDRctRDdV3pEWL
dtq0aUGKRovqaNEiQ1plqilfZzScyrm+P77fPX/NdV/P9b73cz/L/XuH7OZr
f1qAj49PjZ+P73+/B4aurCveL2FS/2nVopL4R+P/Y4teCmNGhU1gm/b0yEWF
1wR+ZGn0+FXJCIGHPdQ/mBVMEThaRZTPMKGXwEvKMllXHk4S+G7nEZqgO5PA
08Ey1IHRaQK/qLIaDmhpJ7CuGfkm7f4Ygav9vO35IlkEbte/JcFSGCKwQved
zKAtyF+u2G/79nrkT2oLq2hdMUpgmSdO5uUnkP/VkBcZ6W79BA568veHZ7GI
ez41YaXo9BF4sS7gQ+US9On3ZiQsjxgg8IHDXNHsU9Bn+PyS7XG5LgInzHnI
ZdydILBw6f5JndvQq5xRnCSXAb2kvs1RYaxPBP7MGWwyU4PeOnG+e1Y/Wgj8
6WpUU0UC+nXSoIjBrIcen6VtFs5S6FfmijQ7M2fo6Y7IzvOc/0DgS8HBki5K
4Kt5cvql7UHUV15wRv2/DeCbL70oTU0GX9qlHwoOC+ALZO1yvfUJfNEUacZR
jfcE7ihx3HAxEfXLHde/cbOnA/NUPUinX/mM+tAEz6zPB75owvWedQSOfuP9
kzsJvMbHlHv5/TiBN2e9EO2uQj/IPj989h1CP/arzYhacdEPepq6eqcY+vEx
RSw2dT/qM0K+37iU3Uzg9QFdMpffDoPP6UGvKgX6nLoo1VtvYD6KhOgR9WPI
p6TpdUksC/Mb552k2eWN+hksZByuKke/2r2b/Sp49oEsErScUot+6VY3JRov
x31iQXrTO5zRLxknHZ9lx7AP7u+MhAfoiG+vfJVRboV9cNlAns8TRTxXTMeX
tA/7QKXZ3CVZQ+9NeWf59GLolTGjjSwX+ULgQTOHlJfpyK/DOZljUA+9Yjo/
dy6NYl6UkhuM1jfj/rmeo0nkfW/QH5ediiPH0G919/bqphDwHZ6iiCklYX5D
NXIX79dBj0RtlmWHLOZXdm8bK90d+QTKi9d/HUT9y+Sunrwmj/rb+c9IcXxR
f1qiqRztHfiUtZ37FiPAZ7L7KzXAF/WVk3hO95BFXFBq1OAx8x2BQ7r/3hWk
Av383pH+pbe6CdysITA/Xwa9Az8Nz6kogt+60Ws0TwbnT/gaCZNmcb4p4QjT
8gfOB/cznJWuY57rwt9nP4/E+UNrO/7kanUSWHEqulv3L+wfQ6SF3bkWmO97
SEEGFfPuvUcg7JoA+tX8m9zSKgHsX1WidXSbD/gdx1JtA+6A3/2isL7mDPxi
Tcf2sqtx4JtTzzI3vQ48uCj6q0YasJXmpgh/L+Cf7glOFxqBXynp/7GVDJxS
pkqNN0P+04kjY681kX/D6siqplrU712FtqK1BOrPf8fo1RdV5F9zyTwvJQj1
Pyhzy7EvD+dlNba9yTLBeVWWP/eYEM6zo0MlfTzeon6BPmcZh1G/v0RshljV
+H5GiUzov5/G+a9kF9E5e3yPk8tm2dKn4IcFu1bUPejDff3e4g0rXOCHrAzy
NW9TzL/XYkJM3gf4oXRtifNRDvrHZmon5v8C/nqFiF/zVkG/5B629XFH6J9K
0omWXYD+wtv51MEz2A8t+bHOIVX416UohRdagYg/UzMom2zEfpXtiP6tcz/i
4z37lrSHcX7Z2bBDts2I65TLm1EnegjMZGSFZ5rBD/7o3JghFoH3Vb9iDHfn
HtSDlMPfe+cGvteVrg+qFh2g5/0FLzFLLvjaW+J3rmGgn4dTWXbWdNQ/+KXW
0cLN6GdaqF30YzL41lokl0Vmwn8U2X6/B3DAp87Z9IB0Dny7K509dwtDf7nc
vglJD8R/3xQYVLQD8SpDeeGcAMQXqQuZOq9R3yq7zEivg4g39LVbTPbjfIhY
oshpBuJ0cvXylXzw25LP4hqP7VHf3UnzKr36qG8jxfceRx16b4lXU++NoL43
vCf2zERBb9QOR83sVvC1Coom6r1FP+OPx36K0wWfbN8Wf4NG8AkvM/9kbcjz
3rzfNR5tBD6FbSVqcarge6URvjZ1PebbzspjRkkE/fQTNz8kvRL9fJa3MUjg
CPZjYfVPs7EMHn/e0vewNhH+1pY7mZVoCj8qSaaNfxGBH7UejODMZcKPwlNT
dUTXYp/8DUdW+tHxvc2xsMzX7IF+im1Nm8R5fG8PKEtFk/KRzx5dwcCH7sjn
mv0sl8Xj76Ntk4wAHn+3C/E53cHj716lOQrJ/NBf5O4YOuIL/SF17PTeP8F3
cMNAnN4c+Dbl2AquiwefWxi7rZvnfXhVt4KS+BC4+CKL85YCLD7FDTvLAq53
EXvk8hH5cYvK9EjlyD9x1ibnmwP8MGbrhKTsFPKPub1ru8sO+CGfa3jUGwvM
ywO7DouPj+CHr5Tbh1sHoDdKVurUlC303mcd85pNwXtpQsLBVOIf5MO/Yd3X
0Fr0zzPtzGuLdPTv8R2tr7r38P9Lj9OoHDyL+1OXjHK3asDvk0ihxTr20PeE
VnLXjg199gJpp/LloW9/jYOFIM/791tEYP+PQuh74zIgtPkd9Cn3FRyRsAf/
KMX0RHs8z3swsGrvGQ70NbsLng9rgT5OrqdjfRz0ffnM7Ds7Bn0D8vYj9Us8
7wF2w/hjWhuBP254Vqs1i/tmYv9RMjmN+4wmU7XU+vCea2WRSK7boU9ZJz+2
Mwh+uk5ywa1sCPu+zISpRwuGv5xXvJgpmwI/9GQUVrTsQrxqU8jXheN4z51/
q1I08B3x57GD1lefwC/G85kz0+HoR6RkR0usGvxf3r3miysJ+ZqODmtSmcg3
5Fuqm60U9GsVZFG7rMGXNRk7G1ADf3aesud+r0RcT9qwh20Lf9a+r5vVch31
E7ohvOY/hqifak/cuUFx5JOgTEleXdCKehubeMaHI59SqpneLSbue2q0uLHT
Av5z8jgj9XUaz3shhtZQXwg/oFuuednEs99Wks3nQnn2m399fLMOz34raI9P
u/HsNy3BT92DZ7+37K1838Gz3zlBSz/oyph/hw1Gg0M8+z2bppQ1Xoz5vxx1
YtaAZ7+Nh6djDtsh/4fmRur0ZMx/kBvXVfk78lG+F5gd+QL10YxZtutlMurj
duwsW6wC888lB3l6cnD/HWMnts0M5n+TwGabGg3oO7vTsXROmmf+hfr3evkP
EtjypKj1CXPo6zx2fuxMA/TF25QWbBuHvoSYal3tg+DnBO6lh7VDX8vTWYdf
yPj+PCtONq30hr5lY2MM1jzyuWC/Z4peiP+TrfWnhObO434Ks4ap29Vp/C+l
1mTk
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bpYiKKJU1pVXJ0iTKHiHxIlRkL62WSvmksSUxyJJKUtm3ayxN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c41X0fTsg4TkZWFJEIWdHT4jVCceyiXnoasmWPpCSPThIVInuU2SAr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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41WsXPaRIkUiZ+kJChpS6iuSQIjJniCJjdI4kQ6hkTDIl4fIoxzkh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lOsbNrJGsrSoIR1lK3uE7MtRKmEiqquUtIiyRdYjp2hCUk0ipIUo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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lAsbHqFsIWLsQlJkza6iPVtC9DmWLNnKJCQVpROmTJZQshWqIx01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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41WsXlaLckCshMhYSUTJkapLZPYckmaqLUFQqXKGSMbdkOGS4QrcM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3lYjG0bxtsjhFbRphQlqbTrNdOCLGPaZBnRgiGlUlIxmRbKOm1SWd6X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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2s41GsXxkeN9ls5Rs47KpFC5Rg7HcZ5ipzPlaRIJCE5k4RNhRQJCYNG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lXsXJVQ3uaZOQsiQ6Qmh3IPEPRqEbpIhMiZDCp9KkyFTHydSpBNJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41HsbxkeTlC3baXEockrIUlqEshxSEsmSreWQ0jImQrbQkWTpjGyT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41Osbxm05tNiSLW2WMsg2KaGj7JQlZC2iaGTfZaQwtoTsMuVEIkVI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lG0bxgdJlpeyFCJbq2yhRSZShJCIoqyDypJkfCJk7S1LSSR7ITuR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lVsb3oWQOLsotvhsTjqGnTJUcqIyD5mTKWVIMitjRWWqRIY+Q5mj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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lOsbJkmLZIkitIesWbKUrGUkVIcoZBKiU2cKYyeGkxBKSNGMIiFb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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk0lH0bJjIilDbaREXZypgaSylFKqKMLRWJmde+N/FV9ghvoSxliWKU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81P0Wxw3DGFuhyd5YWuwxqZgkkqSEkqhEBk8iS9pInpSuh1QopRBz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk8lGsbHoOULcXJkZAK2UJUKpGydcauRrRIajraZD2GUDlI+iqEQSGN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbJmSNjI5ERSUhKcPwhY5tyJLCEaXL9DWozlhLnWRXqUQHZVDJ
FuqM5RySVLaUGkSoiLGPJUvSguzn+v74fvf85bqvGfdz389zP++87ya6r4PH
Cj4+Pk1+Pr7//V0ZwTSL9pI0TmhwVFpeOWT0fzwRIBa6V2GUwLrk4Kgpy34C
66yayyps+EzgzfJqfQ82viWww7IgtckdfHsbUwXq4kYIfInhkVoWwyXwIjex
bsfncQJHitbRqzd9IPAv7dLTKqPQY+c3JqVM7SXwE8tr/m6MCQLvcYqIefDp
FYHbpAabuX19BB6/Zptazofv67qa04eC3hA4ZvMJaUHJQQL/E31Vkew2Br35
fqL3VnYTuF20znF4P/gqbHNefz/KJrDzpoSygWr071lKmX78JfTvecmLfAqj
mcBD7t6+1+U/EZh1bflgUir6qd66OOCjh37GxRkLazkOELiZ9DXdi4x+UiUj
DH8GtxOYzW3oFFRHfeH7ShN/PHhH4BoNwx8/B8EvmERmFr6G/ouG1jMnIvD/
yv4BrIuh0P9qxZiKvAb0m5fcI2UHQ7+OvPbUfi/wL4pEj0r1IA8vE9b63MiC
fk71M1thTiv8zlt8uzyJeRiHybEFZzoI7Ooof/hxLvQ5L5xv1vVuIvDq6LUj
HL1hAtNVV3seM4Beu1mhYQ4Neg8OJDNabkFvUYHpcbUA6A3ZLHfbeQl6nxe2
PBUsfU9g6ZzkVfFZyG/GluUWxjTy6z5DG3SxQ36iJbs1dfYhPxkuXzgmj9H/
tsOXTJRj4K9mUPJV0G70n/LOniQxCX+rzvHXp32BH+0VzWxuMfxmjCyEmjCQ
91qbO7e9JqH35OL54XZt6H3QQK208YRe1q3s4//pxL6lTz6Zte7Avk1scBhb
L4jvDyzJ3Jvfj32jPlE0M51Gfh+GvxcNDMN890XNjr7x6iKw0m+519frg29d
el3v0vlaAmenrdqbchzzCR2yVcmTQL98PDrE7Y5iPlEjtCu7TsJvnYRm6Nnr
0E+2lpelbEG97yEBqe8L6nDefT6YzFwD/Qot3zcvnUIeMjOlXt4T+Ujghenc
ak4UPqcPi9eMBrYRuDxo8m8/Kj5f/elDFWUN9tfo+Xg4hQ9+ZvOXloPy4Kd7
bqi8OQV+Zg1MmhZE4YfpGa780IZnfsdmXS9FI29H8/RTgzqRN/pzZe45f9Qb
MdTf0dyGvN3VPjCtEoA8PX19JtFwCHnqWidZUGIFPSkdGpzfP0LPoyBF2iRP
PmSS1W7NmiEfw3wq2p6T6O/A1BHjw5eRD7O9FzaQ9yIfOgasK1o64Js5rDE2
V4t8UG1tuskJyEdZe6gvZwj9XvFQLi7eEr8/Qmu73MUEUE+g9g9NKwHswzfr
dfNRXqg3LxzJv6Me+9B00FOp+y38VpQ7md8XwfcdTCtu+ZHgN88y1XBVK/ye
o3pz57JQf09V9kBEaieBj9yNCLjzC/iC/nKYs/Kox3kQG2v4MgB8i5YyrO0S
8Bs8Eur8+2Gcn5K7ClPyz2PeWRZ/fST9g3n/ym4Rj3LCvEVYxsF0NZwvFMZt
mXMjOC/7Jt5EBlQiT2kTN8YaL4N/ae638YYj4A/3l9spLgn+doW9L1NKwO8R
+WKOJg3+XmF3xlAO/FVFjH3f2oF+dSWyNG+c5eD3yeN2Wulb1A9aYyooIYj7
i6Zjq3G9M+pZf3LeEpaFeo6tcjWVR5GfxvdsDzIJfMWJC5kCe7CPvgqf213s
kP+nNRmq29jIwwHnmtpv4pjfkvSNwjNDmF8BQ2FbZAX8Xd1lXlxTCX9zqXFe
V0WRBz57o9PyU9DzQtQ0IEG2Aft2TJE5QcN+qql9uDq5BH0qWlxpAUnkWyTN
dMKfJ99hfbluR94g34taTL2kJvhZmawZ6syT78u0Yr5bssh3X88hivlH+Mlt
W/byzoSf+BjNmxl58NPc1DHqKQc+cWPOQKIR+tMa68Da7Q4+8dTissZNyLdH
8ZZfpbpwftIzs1ds2o/+MJhWopY1LQQ23ajUT9uNeWfU5op9OwB+7iz1E1sX
/IUURXquG/hn2Tn3tymBPzy23FZ+CPerC8pFrmUk9HtQ6D77tCv2Q+Jq+xyt
mud+uJQlIfQQ+fS+eXJPVh7y+V0hTd1wE/SGzaa5Jl2C3q8OeglRy+ivu0GE
090M7HsVnapvH496WhIjp5TksI9c9co7GS24T7CNXJJLVYDldbY/yT6Efe0/
WMogb4W+6uBx2aQv0OeTEDMkVAi/Jy5Gd22NQ30FjvQ4SxH1zy5319u2o56l
euwWG3ngd7F5ax96o35cnZGl/jzy/bOXZSOjgX6fJT9YEaSE+n5ylOnRftQX
UsousBJuJHDSNsqgbAf4xFLT4vNdwKfpf26svgD53yc1Eecmi7yeaS80bXFB
Xn/2sUxJ/phPyHjVWQoJeSrN51bW62I+9BqzkFFv6Lt+iF1gPY/+bH0jsqed
Cf/Jd/qmxVnQWyosouHDcx+QrzeemhGD3qIfx/jP8twHdE3S+pv+xH2AMW5z
hdGNfundvNKpchp6xsIYjQa90NOXQz+xOwx6Hn+e2TjXBj1Ofxrr3XWFnoYb
1WLx96FnkbQ512Qdz++j+COx4zroX42PWeZ6Gvqnn+LVv10V/Svqed9tX4p9
DKZq2N80ht6dbRbCrfLYR0fWsZ5XQcinRS6Tur8M5/s98kbtpRfg3/DUpJa6
Ae8R85D+OMNI7FdvJyfMyhb3EWt/jywNCvwsiBgeeVaG+0jp2zRaHs97mM2v
HW7A8x5+NOWg7MPzHk4MvHx9cgT941eVpBTyvIeNhCyCXXjewwpW7j5bRnBe
98wZv9fsR7+lP2hJpPC8hwP9iw5kh+C8Tved/PiF5z08cLOkQpYOv75T8S/S
JfAe3k4W2XH7APjMqpjpp52QpyFJbq1NOfJ06itpcfdVzOfULvu2AgfkyelG
7NZ1K5EnpTyhC/U1OF96hNxSRGfxeeDw37YkDvLBjJstJadBb+rl3v8GVeD3
hStkHDmiAL3dF95U1q5G3nrKA5VTrMEXVT8dtccQ8/m2m6Y8Y4a8FV4IYjJl
4Kfubdx2dx3cBwYEZ9rsrTE/PQt3t4lWzEM1PCImUQh6pI6rejgYYB6CZTlF
LWPQsy/v1tizaPiLZFiLs9SQvxDbCx12O8FH+pan2iiO9wvNykLd7wnyp5D5
STjqFfytzzd7/GEV8n56YemKcjDqGUzPnxQIQz1mI3N9pyHq9crxlTU6Iu8l
tkmvrexRzz/q6/GiDeiXU32Jsu8U9jODlZ7xbAP6dY0/cFjKDPl5e+IKo68J
/880t93c8qPR6F8Ne/q6
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGs4lGsbHYaECZEih1KmUk2lMpRDTRmlSKQkUk4pJLuQEm2kFB0IkUZ0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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lG0bniZLyVqNrYVQlspbCY1syVD2bKVkmVJSIUuheNFuK3qJijCY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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k8VeseZrOjDEdlyFCohExFJJkqMtSNZEskjjJkiLq0HfNsGyoZQoXY
mUvXlKTITKNZUZK5wTYXdejc++GuZ3/av+e31l7P8H/e911L0t7DzIHEwsKi
yMrC8r/f3FuNEv+5xKs7F6FaVtPRq/N/fGNn8Dmx2a8Epoy5v5Va7idwhKOZ
pWXpFIFZ3tnE2em3E/iq1so2H6EJAlfuPpfmSJ0kMB+fgbr8tzECr9oXk+4f
/kLgi4OnfS+NfCKwZqfLF+E1DPDpp0kqaLwkcGgDywnP6VEC8/LNDPJegX7G
D1cvA5kPBD7E+IuqoIrnFaz0Nw/XtRFYIJN0/kriCIHjvs2f1576Br13fOh3
pHoInGT34ofAHPRncM9bvVQeIrDLo3a1gIvg++LAU/YitpnAc/nfxSPuwW8y
T2q57Wbc3zDwNPsO6QWBHa4mC00dht/UzQ7mpfrQJ35FpHZm/Ts8P5EcIknG
vKg84XW7E7oJLFm9/NopHvq9Xz9cKJGHnlLu+4LFhtDDTfc/TqtqJTDtRsdn
9V/DBD5JHuDiPQe+39cah3q0Ogn8iH9OoLkDfZj9ekXBVhl9OC17ddZBE/Pz
/LnUFvBhkMCjFX8/GHaGnsgds45jrC0EzgmKThhfgP6QstO0LavQQws/zHf9
LvoTdLnFskQa/DXGziOxRuBPknXi4E4BP2MkWvzqWfC/ZrfYM2UM/rLGLb90
JZEHmWz96tok+Gf+uxwe1b/CPNiM5J5Ug79ojurbFY15VMr1nFfVgh/Fknzf
mUPgp7HaLH5dxjxG9nUKl0mgv0aXlxidhuAPpNccvfMF8+DIq+sttv6M9R79
PESNE/0qcxy6di8M/brZOEYPu9tH4DTnYPY1trjeqnxo1SfgLYENzMTi7Ztw
XVLZ8riBMPabzob3FpdoyPu3rOGntANYr05xR3Xt98GvvOPEgxUa1utCTp+a
2L/h9+F4SKUVJ/zqZO8t3huIvvMmNwi2hiLfC42VBm+PId81IR6PU7XBtzBi
fP3sQfBNLu5VSzEGn5f0vG2fDFO/Kj/xvCnrwv+V1Wlh88h32JPHPrwI/Uim
Ubmy0vB/65urwh/GsJ9u61aUSC3EfvqzxyFY2hvYr8rG3rAH2J9VK8Z7B3D3
YqEn6QzWW5jcShhJfJzAhZdJNf0r0Fe82nFiJQH6zJW6qVP50PeUVChfEAp9
HH1GVtam4PvYbRbNEADfkVdhbrz3wFcUKbZDSxp8WcZBH+77oW/pCtyR1bzo
i1JKeP86U5w/yQdKu3z8oceV1nPwcVYHgRWKPprsNQF/VsiwqpUm+BdtZ7se
d4KfJeSkWeYS/Ib/UNUfc8Dz12mEcosqY73Yhg0KyLbi+XdlueWDDmP9Dnab
/zTfhj5LGo0ojNt/JPCxKrdDnR7olwel/FNFNs6D7Rap1+88Rh8ZqY4chUK4
fxO/ZpmOCc6DOs9G91FP5Nex8VuMogjyO9ZkoanNi/zshKSnHjL545u3unhQ
Bf7aSzNjRNvgr/fl88RwPfib87fRaJeCP7GggqQaCvylq4iomzH5S1bSyk8q
gD/v8N/t72rgz6WlSuWrAO4n5dhV5zjCX+GB3E56APxxNXk10rnh75lVkxjX
afhLUWmmhwXD38JCw2xzFPqR/zCr67s6/A1H9HOKOqMf1I2cWTPx6Ict6b3H
yXim/XSPDHVpGvw5lsen3vHjfUDQYbVq3wT2F67+BQ2yCd4HblQEebUx5XOd
lD6kSEc+lE/Dy1+Y5l/n4+sSyzT/mvgLiv2myEdmG6dZ40Xko+3VwDggDH1B
qn+fit+IfPSEyWkpTshnZenWZyNpzN98rttarxb53Fw827n2FOYv/1nk9gQX
5t/i0rU9ahDzrzd3b796CXonshe2iAbA3wDH7g/edPjb8SDCfVYC9/PraYsX
dT5H/6niiv7y8CefwD6ubwd/A5EzjM2Xcd7cz/daFqrH9Xq6jIyeAs6bgD8s
KHJJ0M9Zr6EvzYrzxur5bKW9IvQILjZbZ2yGns9eW0sut6APPu77jnXXgu/Q
s+9WrPvBV2v45Iz8bfCtz5QoYel5T+DGtmHKkR3gE0rds+9+DPjKTWVFY9nh
/8C1nUtKUeCjh5iPJ1/DeSxi4KKUYI7rt1Ms3488Rj6uxmwGdkO4HvVFuO+W
F/rrZ0HTs9gOvY4MneQEG8xXvI+Rl8nUXw6rxLXuOZjvefG/2Y4+wXzZjfJH
lwVx/0jcCf2/LNFfN3ro6ldv+KME1p0a4Ie+1Eo5wyF59JfCWr7XwxP9zTBb
vNXFwPp+M2Br5xSP/v7asLQ2qgr9lbionN0Th/XJX1FVWqAKvat3w/i3HYZe
ql6TksB7vF+1TpcXnf4D86856OKSTIGes7Qo8Z40rKfXD7rZ+MSwn1xwcMpf
SITfs5nSPdcXkPfx7GcR/mPwa+4lp+Z2D883sWm/Pe2K87e8bttOm/04fzN9
S4R0NeA/vIzcccMB+1vFYHReUxL0ZFukm6ZHwY93d4Yd5QfyzyA/9fGbwPvT
I1qOWFQb8vPU0QnNvoX97WRkkIqHE/JTHx1uaxPA+7GScbgMGyvOW9f5nMXz
S/D3dr9rAXUG7+fePL2ebiaY3xurp/VCm5BXq366jkUG+jmzfTI8iel7K2y3
lGtsDPq5TkO0qrYI845N8NMsZvre2rUSPBmyivUX2Zszna+HefmlfVz6bYB8
3Dc96vNnx/eW4NOGvvjfuG4nFShFL0d+NW+6HO7nIb+17w9EfZ9Ffrrrjr7y
Pwk9bs7B4x+nkV/eHl2qcTjy2/mYMdpVgvxy2BhXaw3Rj+wic+5MEfSjJI6k
zn8J/TCf50gf+o589Xsv3I3ZC30VldFdFE7wOUwOzI4tgI+tyi9YQRzfMzMq
ZOMKJzzPd3JL7vZlPC+MusveUQJ+C+1f6aswnRdCgaqXyaGY1yVWToPAXMxr
uDm5sk4c9wuU5Z5JH8a8qkRrM41VMS+ltd//DDyJefSySbU8KcB+mOdeKTr1
FteTRDZ83Z2N/TBrdNi5WBd9mx7P109qxveg9Ji8tgFT32sHKG5TQpiXYVOq
tikJ+V1pz/35/Afyu8ei2fxoCX1fuvDRseoE8nOKutOfuwH8aoGmLBzV6Hum
Vv29rUz5bfJ6dvMzU377+JNZufKQn3UNn0cMU35Hj0j/K3wM+ZHbnUNG1ZCf
VemfLSMU5LMjjWe9dBny27JGRXLNB1yv2lUvuzUa+UV5Hb0msxv65TIDmr2E
oZ+c4F4d5gY9+cIl0pvboT/x+qBmQC/0y+bHiL3lwv0Z1Scy/aZwnkz/Nnno
2zyq8w8pSxWN
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41O0aRsdSpESypKjscn2MbCnbCClfIdnKWkJkHYlkq1NEypKtmjKy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lWsbJSpxDJnHbTiUr1BmScdQbUkkQwiZxUGOIZSZjJkrNFCIMiRC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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4VXsXNtOEiNSRKVGmPqdkLpUrKhRSxuJoMH9lHkKuCqGZFJKiKN2S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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lH0XJipkJKloIUv1WYuUKEzZyxpCWUohtEip0PJaCg3KEgllaApF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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41WkbtmSJsi8fUSZMlC1bqWPJOo6lhBMRJvtyESWFxprIkkMilKUY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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk81HsXxgfXrhJFCUWSJSV0LTdNSWUskatkV5kaMmSJFq7clG1E5JYZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbVomTmVC2sg+ypFRElikqUsnJGo6tJEk+a8KJjOWgCEXJEtl9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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c81W8bRlYcsrOLjLdJ6ETq58hKISsrJYSSVOZpGIUooxQq6ygNEZKk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lWsb3YZIxpNkylRkjHTq2GaV6ShJxEEkxxRfUcp0ECGzTJUMlQ6F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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lP0atjRZUhRjr0xSnxE+EUr2wkgkysFJmc9oE0NlrU7JUpStQkpF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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XtpYlKomXLDVvkT1FEUITlT3KkqWNDLLGq1dosUcoy4cpQiEp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k8lGsbngyKEspaU5bIRFMRJYociRChk61QspSEZKlDtigUIopSlhCf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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41O0aln2dkkLFyBKhhEpJ2cbyCZ1C8RWy72VJRRQhy1EyOCmFCvEJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lH0bnWQpWRLZInktSQilIluLrJWdMLayFSVFKaFURKiQQpYmW1qQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41G0Xxy1FCC20kJhnirKWlJhCKpGllEoJydIIYZTQILKMLFkKjy1K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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41V0XvRWJQsZUhlIZMhRKZkI0GAuJXKGQOUUyvKZcUyVTxq/UG2XI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k8lVsbNWsQyli4SWgw3ciUkgxFJHNcw8lQEUIDko5ccyJCE4d8pHD6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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lF0fRh+JN0sYlC1Li70hM5ZIZX2LLElEaEVM3ikqU0iyZC0ZolAk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnk01G0bx61ZyxqVeSq8KZFoLKVsUU6WLCm7KHpoVZElW3rHkqWQSnpK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41G0bHVSELInqFZUskTISSooUScmShEjSFDEhZGSJ6ROiLMNkizYi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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lOsfxgddmqOinEqyby06Y0l0MllKnKxlydKiRSmHLIMOQ0WMpCJL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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN2Hk4VPsfB/AJWVPUyJJcXFNJUUpKZamsFSElpbKFrAmlLBXKGrIMwpTK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANF5Qs0HTi3kc3jk9/1ey/x39jD+y1y3Jn+9I3C+
yz5nqT2uD+xH1Y+qH1U/qn5U/aj6UfWj6kfVj6ofVT+qflT9qPpR9aPqR9WP
qh9M6gEzMAQn
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANFLCmy5ri/mc7i+UTht85/D9jB++dnIUCu1B3B+
1/b7ihqL39mPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj6kfVj6of
VT+Y1AMAA5mRsg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANE3z30PfryUz6Gu4uaS7JuH7WH8i6qmCzgEHsD5
V97+7zmy9J39qPpR9aPqR9WPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6
UfWDST0AKon+RA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANF8upvmvl/O53D8/v394XsO28P4q+bvl9z9+z6c
L/uFWej98ndw/g409dPR1MugqR81f9T8UfNHzR81f9T8UfNHzR81f9T8UfNH
zR81f9T8UfNHzR81f9R8WpgPAFdHnxw=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHO3TnPf6/kc3ivsPj290WH7WH8U4LnxY3u3Ifz
v7b8b7668h2cfwlN/RI09V/Q1D9EU78dTf1nNPWj7hl1z6h7Rt0z6p5R94y6
Z9Q9o+4Zdc+oe0bdM+qeUfeMumfUPaPuGXUPMe4BAAtVjXQ=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGVL9UMOdbwOYh+6NNX7DlsD+M3NPRf+bj/Ppz/
tW2NV+/qd3C+PZr6nWjqf6CpHzV/1PxR80fNHzV/1PxR80fNHzV/1PxR80fN
HzV/1PxR80fNHzV/1HxamA8AEbuaXQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANHr3B9Wiazjc5iVdDdDu/ywPYz/dcqD6fLL7sP5
UdyqZUpr39mPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj6kfVj6of
VT+Y1AMA2BKe7Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGPl84+orCBz2G/39KDhn337WH8k0F/5s1Z9w7O
dzwZNWlN8mH7UfWj6kfVj6ofVT+qflT9qPpR9aPqR9WPqh9VP6p+VP2o+lH1
o+oHk3oAcPcRAQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANESLGF8upv4HO7GiV+LCTxsD+O3TcjjPV1+H85n
9Pr7mmHDO/tR9aPqR9WPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj
6geTegCmIKR1
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANF+SQIRllv4HMLt95xfkXTfHsZX2tHPE7zxHZwf
KqdwlcPhMJxfh6ZeFU29Fpp6VzT1ymjq3dHU56CpV0FTb4GmftT9o+4fdf+o
+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3j7p/1P0j0/0A8wHrPg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJztzs8rwwEcxvHvnJTyB6wcdhAXFKeZojQHYobNotWQ8jMOFK12UaOV5MfM
pCQk2s8vJknfSZI57GbJYTngNiU3B3Kwep6Dv+Bz+vSpV09vQ/9Ex2CBoiiV
OkX5vXPJ1I45Udww0zswEmzL1v/9Jcs2za/m8n9q3tDuq7rO/4+f6D0B9OkK
9G9u9NMr6B+m0Duf0E+uo4/V0f4S+uZV9Pph9MF79Ld+9EoT+tEt9Gnav+lD
r12hd9J+pgW9eQ996Rr6Qid61wV6Pe0vWNCbDtE7aN/Yg37zDP0H+Usr+uoQ
+lnyQw705afoM+RrO9HXRNAvkm/tRh8+Rn9H/pv2TVH0AfJJO/qcij5J3tOF
/pX2t8lbaN9O++fkn2l/LIZ+n/yXDf1LHH2CfBH5Xdo/IJ8lr9G+Sr6R/Dvt
H5E/Ie+l/Th5K3kd+RD5DfIu8lHy4+TLyIfJ+8hbyEfIu8kbpUd6pEd6pEd6
pEd6pEd6pEd6pOffnh+MUT50
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1GtQlGUYgOFdtFBL0VUQbBQZB/OUJtIqImc5gy7oquBCyPmYopimVOCE
IDgQyCallQdKLVFUFExhgYU4FiJIUesIKqZRKqFmmkPTTDnv/f365pm55p7v
eX68VuHrA6OMZDLZXLlM9u+3YkpGf0DFGGeV5/rut+2vOf0/x3vlWLWcuft8
jtXYdugt9c/n/SkzvxZ9+oE4S9ErrnkPiD6h41iH6Mct9kQ/uP9Bl+gXH1KW
iv7W/C/QL5ksvyv6nHsObaI/YjYefX1bZ7foVUGmZaIv6ryMfqr83X7R9zX+
1CL6Cdb9U0XfoR1hEL3TmpfLRf9d80P0HXfn3RG9SYprk+jn5LSiv+b9iqui
T28POC/6L/eMhZ+ebnpb9Nlp7g2iz7Y4C18VMeya6D/wMbkg+ovm1vB3egdv
iX7OXl296IunHYbPuCHrEb1jQeRF7NtuC28uM0N/Rk9hneit12l5f3M9+lnG
8ZWiX2lwhv9mWGKf6McYl+pFn9mVDV/eu7pX9NVqmyrRh5r5wK9runNT9JFl
MvTN9Tvg719tQj+puQX9P14NgNcO34l+eMS2WtEr96TCL5xvdV30V4JddKL3
KlgFn6m1Q/9M6nj0G65sge+bGIn+pMR96IdWBMPLjYduiN7vSF2N6GfZpsB/
tWYv+n6JPeiPuhUCf3TWZfRfc81C/2lCMvxH+6vQ/8vLtFr00eow+MTWk+ir
ngWhH+KzHn73KQP6+xod0H9oEw4/eqsW/V+ylewfTYL3rRzkfdo06HceiIAf
55eOvi78FfSnxibCK6NegNcUpqA/9Xwk/M0fkuEPFb6IfsvGBPjr/Qp4s+ad
6BvyouBN5dHwK4ofwXedi4fXeU2Gz68shA+zjYZX3NPAu7z1K3z3dPZH2FnD
FyV9Dh9zmn3fv9XwO8f3wu+qiIM3WjYbvvzTI/CDihj4/cdU8E9ud8OPiGS/
/NE8+KQbJfC/adjP1vrBhyZ0wntPYz83awH82VOn4Yu07B/b7A2/Q3kJ/sRA
LPyZpUp4/7Bz8MNr2G8d68l9n7Wy38L+qJBF3NfmPLz7dfaT7d3hczKa4fNP
sD/4px183toL8Lqn7Bs63OCTDzbCexSx/7GNPfysYZXwbib0cdWu8J/NbYB/
PZO+ZtoS+A7PKviFU+g1v7vAb1d8C2+xjT7dwH6usw6+ZKZkX1/2yxbVwys2
0I+Md4CfOMT+Jhv6+jZn+KH8OviIWPrULvYt8qvh59nRV2xgf6SC/bRw+oKZ
jvAPZDXwakf60TPYty3Vwz8LoXeKY79kFftervSq+07wM6LYzwqmf+kT9kOL
2F/uTq+tZ//wbPZ7VtPv0rH/YzP7hzzpG4rZ3zpUy/dfTW9tYF8zwH6MN/33
Oex3X2XffyX90wH2a8fQ1/rQH9/Kvnkd/eQV9JVG9IHW9K2+9PJ4+qBS+jcC
6bNM6HOU9Hv96C+F0nscpN8RQB9jQX/FTfI//vSTVtHnaukfq+iNrOgVy+hL
JP3U5fTFu+lzJf2fp9MPqOlHLZO8nz70VRn0DpJ+4Gz6R2vpAyT9jR7029Lo
h5bTX5wruWcYfaakv8WNfnMqfbuk7zGf/nEE/UlJ382F/r136I9L+qoF9OXR
9G2SfpoTveUW+g8lfYMtfWss/W1J39KRfulm+u2S/nAlfXA8/RNJ38qB/u4m
+gRJv0/S35VAP1Li/ZfQt2+kf1Pi8xbSJyXST5D40/b0cklf/Z//BxywG0c=

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk01Psfx/EhKR3KdlOWMjdZJzGWhhZayA/JNJUoit+1VH6iS1dl37cw
liy/oZpJ1h9FChE/3bi6uBP6JWO9xnJnrNkJ99w/ftfrr+/5nPM8j/M93+/3
/fl+iE63zjkLEggETQEC4a/ruJ+RnkPVduP8e54TAy8njP6/3q54ITFf4t3f
a41rxiKx6n1/r+OimyeFyzf6PQ7yC9k7NnriayX7Dyob/btE/duD4Nsf0Sal
gG8l+EXbA3zbHErAZvA9/O/ZlYGfJxvLGQKf3jLwPy74hDdWgUHgn7/DKqCB
X/e9groQ+O4HcxQawNdLyVFdB3/H9Zk9w+A/b7By8QDfU+LrycPgxzgQpwXB
P+lY6/gZfC0JZa+dqhu9VkyF5Qj4CTUv6uzBjx+Z+6gE/rC7/EcB8MdFzU1G
wA/R0e7VAH8qxcppFPyj1zM9rcDXnXAniYMfYS3xCwF87xJb7hz4uv7PUo3A
z9qd6/gH+POeD+2MwW9QsdFcVdvovwZodKxDb+nXeGmT+EY/X+lURQXfwCPW
kge9adRNZx3wOzRLy/ng5xS+mVmDPjLPoWoH+DpEf3cn8DuWHinxoafyR++q
gC8UZ8jigG/eobsf/SkF4b1y4JtnBTZ5gc+luPLRj3pfHSIPfgyV3NUMPjtK
zXUVenb/cOZ+8HsZmWOB+H6DTjHHoPdSO+MuCX5PKMm4FvzkG/+o+Aa9780E
44PgazV1TMSBT40OMB+HXt0sRUkE/Mu/d1eXgq/Z6yCDvuExaSIFfJV5/ZF0
8OXfHh9CX+zJeiYBfHoJ3yAXfMKYZegK9BmcA5bG4AenzfJY4H9xZP44Af3y
CLVuEfqtxBYmA/xUC7GVZeiLXM6zT0OvLUQXKwbfPiR7Hn2Cc2TENPREJQY3
Cfw3D4v90ZeU+FJlBb3MewHH1+C7/7z31iT0WzKr+3nQz5EXx6PBn318bhv6
ZpGrMhegj9JsnasFv01ktQd97+Wd77jQK8wMFQeDHz5FerwEvXKIyIwd9Hxf
EqcR/NHZlZNT0K/HlHzfB72yS+mue+Dfvhh8DP1MlsPFa9B/jJXf+xv4aZZt
T9D3ORY49wX6B16dCj+Cv8xkchehb6iLsXCG/kN+UOsn8C1Oqiyi3zpmSf4E
fVjC6At38C94T9PRN6u8xLkOfY+K7hwH/PuslNPT0NNqGWw29H53bje5gJ+h
wDFB32apT8wD+qBLitkD4P9nMDcR/cH5x780Qy+cPGXrCP4kq3N9Afq6uiSe
F/RJLWfbh8GnKA22o58wpiHVBP0VtXLbK+CbsP9Vi36QmYWvD/QVUoRsPvh+
u95KfIWerMvKfw/989XOWhvwp2iqYehzu21qfKEnbC4VngJfr+eZOfrdTTPh
9dAr/qARRgO/dC37DPqighG193F+2ZTvZsFPrBEMRL+KHMmshb41fd+js+A3
CnnJoS/1ihQWAD2ptZG9AL7tqGYJ+iEBBsvV0CebtotYgl9FMxmfh97jdz3x
YOg1jNaNVsAP2xnMQf+ljHVUFX5vSl01ZuD3zjbVo58vquIWivu/4KLbGu6f
SmZCM9BfsPYyq4D+Bt2u3AR8Hb+yf6NfYqOWGA69iKMVVQB6h+xmNfQlsxj6
r6BPkJ3knYCeH1L9E/q8fvG4SOiH1zTWNkFfcIJqif57z31nX0J/reuxrTH+
f0k5F9GXjvzn1WjoI1esvYWh1/CVckffpIAZXwp9NqP321HoB8vJFPQrVa+K
xUKvdlW+Yiv0itUW0ehbR3+bfg69Z4U3+zD0haIH5dEXcVpPj4M+szO5ZRv0
rcKaT9FPUqTdKYHeNDmcbQC9mKebIPpOnwQ3x0Nv0HOjQhR6LVVeNfqVlE27
i6HfVh2ydAj6w7te8OZw/xeZoiVA324g4rcdelWFonb0HbMefS6CXjJV2Uwf
eseh3g70Fwd3RyVCPyZLlxOHftieMYr+UNNYSSH0tECPSl3o+6V/rUPfs4HF
okP/jMHNkMDzknL/CvrGk92PCqBn+qea60DP+kYtRl/2cnheEs77cMGSJPR1
rzLEZqEvt4jLyYfexHTHkjb0bb+ey0L/vER8ejL0A/3nj0pDr5wyqoD+kZaj
tXnQG1aG1mtBn2Vd8gB9Hs3NJwV6ejTR9Tvot9T8QUJ/edGGnwt9WdmHpwdx
3ustAtEv9mcYp0I/Okm8uxPnpfe1IfpWkk6q6O83GM3ShL6Zvv02+t705BX0
XfqO+MhAfyrs5mn0I/wEfJ5B/5C/tegAPh9KvzP6hm8ych9Cf9yYbL8L7/+E
HA39A9SF33KgL/0Q0EKC/r+ShXboZ2b1m6RBTyFnk3dDH9DPsUc/Um0PBf3Z
Q28J6IfqX7ZGf/hW8Gf0mSMr8+gT79e5or8o5Vb0FM8/+pdPaUDvRe01RX9u
OsA+HXqH03mFstD/nNfliX5sWbcG+n39wmnq0HdF7juG/qFDjZ3oc2y4VDno
mWmGd9EviUgrZ0HfJvtgQQ36voty+ujfOaNnngE9+e5nHvqf1CeD0Je1bjBD
n+Ha9gP6XN/XmugL1CeVoj/gRf9JHvomaeEo9E88yeUyoa+c/dijCv3xZp4K
+gpbMiQzoW+xFl1CP30yNh79KyHRUX/5fwKB56KQ
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1HkwFngcBnA0eVfvkqNSRCi7S+WIEhGVnJVyFUUi3ZcuXaS0le20yFZv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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANERlltOlO3jc3CUemwSWX3YHsafKsvUMGfPfThf
Lvpkwbu97+D8lsmuJkZTDsH5bpWlx1pb7sH5J8+tDJi8FqH+AJr5dnKo5suj
mV+GZr4JmvnH0cy/i2Z+Kpr5imjmR6KZz4tm/lE083+imd896v5R94+6f9T9
o+4fdf+o+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/kHhfgBmEfde
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANG90/OEmg/wOayWX1AUF37PHsaveeovHrP6HZw/
6dJHqSezD8P5NgaZm7Rf3Yfzz+z9cqjkAEJ9xednvcsLD9mPmj9q/qj5o+aP
mj9q/qj5o+aPmj9q/qj5o+aPmj9q/qj5o+aPmj9qPi3NBwCl1hRH
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANGHvmrE9B/icxBI12ybvvKdPYxf0uzTIbftMJy/
8kBx+Vz2B3D+7D0pKR2HEOptD9uE5IYegvMfzBP5ts3onv2o+aPmj5o/av6o
+aPmj5o/av6o+aPmj5o/av6o+aPmj5o/av6o+aPm09J8ADi+OEQ=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQY2RgANE/gh8vnX2Ez2FSz5SiiCPv7GF8z+d/2l/ZHILz
L81IO88nfA/OL9fYWS+2AqFenDepZuGZw3D+rSOV0UvFH8D5E9HMD0cz/yma
+VVo5r/lQTV/H5r5o+4fdf+o+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3
j7p/1P2j7h+Z7gcAJBNAPg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1Xs013ccx3FihEyS0K8IMddcyjQKuaROIkr8pAtKblF0c2ntUGini9Yy
1kSX0VRmqE5LTcwvZTqnCylz6SKp1s04RradnZ21z7O/vud1zvc8zvO8z/ec
r2F4QsCaUXJyctPk5eT+eVpXFLwskX3ollyhmTVU/8L1v11j37z6hWntu52a
muLdOND+bhsMW0fXFf///sksj6aCrrp3+4tY2+dDJl3vdr5j0k7Rd3RpSRV9
Sw/rtaLframxTvRte/NzRV9B8c0V0VexvZQp+vHnt0SLvlNS+0LRP6w5gH6p
jlut6BvKP3wk+tcfn0F/a73RVtEPrNQKF/2MBQlxoi/zWVMo+q+uyppEP/5V
NvrlF8TFif4v/S/9Rf9q8aYY0a8JcLog+uVyzl2i3xfbhf7qo7JNon/Q+dYK
0b8bo4L+lDa5b0X/adGnN0R/89tI9HdW+caLvmZl9hLRPy53Bf375WvOir77
a/d20T+dPYz+v2K8Nor+zriaUNHv39gQK/p+jl+eEP29e9pvib7VUn/0O/ul
J4j+zH22S/F9dg6xX6u7UvSzF65oE33fm2Pgb7zmlyT6uQPrlon+DJVC9Ld0
tZWKvtnuVc2i75ztAT8hce560d9+yyVI9K36JPCNFbQqRH/I2/we/FYd+HWW
lYmi72uaGyL6PYU74AerLjol+jd8g1pEv/NHJ/hX0uvQ7272DP32qnbw05p7
y0Vfbfbqu6J/sFMfvravH/pnfD4G/WUNSfCvBc0+Lfqbi39Hv7q+A/yMOVob
RP+4qjRY9JvSXOCfD7JCf0fe41bR7w0xhp9dpIH+nMYqqehXqEXDry65jX6T
oeA7ov9olx38/RPnoj9eUoj+Xg1v+PE7Kr8XfcW0XPSnfWwK30CpB/6x1jT0
37UPh69v7FAm+v1v8tB/do4N/MuZkfQbGtGfn+UDPyE5Ev2yyAj0D4w2g+9j
1AS/3VKKfpvm5fCnnEhEv+fFy+j/pMkavuX0VPjzvZ6gf7ziIvjbpA7oD7nt
jv619ub0i6rhb4tzR/+OMcvgBz7IR3/VT228f6cV/KawbPjShCH0m80OgH9I
aQL6t2pMQ7/GK/an6lXAD302Hf16c6Xwd3VXoD8g8Dn6Peex/8DVHPgrFZXg
jzqxGH6p+ij0h96Ygv6RKAv43hEn4f980gL+sqnB8Be01qJ/1ZMB9Ff1WMLP
McmF3x2pDj9s3xL4Mf798EtX6qJf7yz7yyUl8CWyqfDzYoPgyxSa4OcXj6B/
Sin7U3Py4adNGgf/qVEg/O32v8F3HRmHfs8e9uuGHaevYAi/sX8p/Krtt+A7
9MnDb09n/+JLh+BbTNaG//Yz9vcpPoEv3asBv1CJ/lfHjsLPL9CHf6qU/bOO
3oE/9gdF+Lej6SsbFcD3VdaB/0c1+0vOPYJ/f7k6/IKJ9HdlHYFvN2Ey/PoU
9jt53YNfsF6J95fS/1XxMPwOV134Mx+y/8I3D+DvHlSDH/oR/YSbRfy/T5oE
3ymU/Yf62uAP7lGGX+5Hf8NB9usq68H/epj9pl734VePZ3+aDf0/V7B//zYJ
/Lp57H/4QTv8Fo/R8KfPp3/kNfsNMtlvokbfKKYLfmaGKvzSGfQjtdlvrsv+
kFn0a6vY33CO/WO96EdZFcKffIf9Y7Xph3V0wm8zZf+gI/3Ex/S33JkIP34G
/YipHfAb5VXgx7nTf+5P/7oq/QgJfc+d7K9/Rn+8E/3kBvrmZfTDbOjvjWX/
sC39i270W6Pp11vSjzOgH+XD/nGy9+7jTD/sDP17B+ibWdEfzGO/nh/9Ulf6
kmT6jW70Rwzpu5ixX6eMvvcs+k7f0Zdk0JdY0G8/w/454fSHXejfTKdv40u/
yJj+NE32Nx2mf/O9/owj9FO20r9uRt+ugf1R8fR3v9c/nP2v/zcDvR4v
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0t1Lk2EYx/HHFWgUsuZBB1lQWcQCLbJIBpXQiQRCprVeiGmmUthG5rIX
EDqwoEjszUyzJVTInA1a83XWbJUHFmQZJEk2XBbV0M2KYlF00B6+11/QwXN0
84WLH5+De1GRNW+fTlGU9ARF+fsW6c1ZnoHkjUmec2OOgfCGf11Sk1Z3RNcf
78bylzUVj0fj3TXUbGlqUe8Pb7aZrKmBeC/NS9h0PXcs3mmuDxODj9T7u8aU
mNOo7ivKLMvUL3W/1BvWt7Wq91un892fOx/Gu/xM5rI7c9T9RDf95vv0b++l
P3uU/owOK/wFkwr8ezz0KwED/NWHkuDfcpP+glAB/C9WrIF/QTv9dSP0/3xH
f06Q/h02+q/66X/eQX/sPP3f0uk3XqM/37wN/t1V9Ge66D85Qf/bKP2ucfrd
ufQXO+mv7KLfeZz+4WT6cxron11L/5Mm+gNt9Pd8of9ojP5XIfp3rae/2UF/
djf9Zhv9pt+J8JfU03+7lf4T7fTXCr9rkv6zyjD8he/p966l/2Ij/Q7hNxyg
/8d3+k9fpj94j36Hl3678Osj9Nt19LcI/+LV9K9roP+p8F8oo//UNP3zhT/U
Q/+Nbvr3y/8j/Htn0O8X/oOr6J93hf6g8JeV0v8pQv/HS/Tf6qO/spf+YuGf
G6V/RPiHhL96Jf3H6ukPC7+vhH5F+J8J/5IH9Ff46C8UfpPwp8yk/7Xwpwp/
lvBHhd8u/E1T9PcL/6Dwjwu/RfhzhH+58L8R/kgG/QuF/6vw7xT+KuH3Cb/B
T7+hT/Nrfs2v+TW/5tf8ml/za/7/z/8HGMJXxg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxN1nk41fkCx/Ej+5FCGkODK0vIsTWyRLI0dtk6SYUoe2RvLHOujO1YrrFc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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnk01vsWhxEnJSKSIa8hcZIrytBgyJChkKkjMiZxyBsNKFGRS8lQEaLM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk01WsfhndCKSENkiKZyZBSyREiGU4U23gcOQ6SypSEJFOG5sEYkjkZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k0FHobxydCqEi2CVcSCslFJCS0mKhsMYps2S4T4bhF6CiubMlSoZs0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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk01WsbxkkvdiLJlEyxSRpIhlJIKLOoyFGSmYREtDNmelE5xshwlCmK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k01HsfxydxbdNeNKIsUTPJVVzJGiE8bhpZklK4nW5FlmQbdaXF0jLS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxV1Xk0lPsDx/GJX4NRkch6w2CUXGtSam6T5SrLVFMqESJl30Ll1mStQbJk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1HlM02ccx/FydVzOobUiIlVh3QARWVUq1Coe4BQ1c8IUWhgIAc20keEB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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lVsbxhVXSChKZMrOEB2SD5FkDHWSIQdFsRMJSWVKOmzzR5ISOnbm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmGk4le0WxzfpNccRGYpoJy+ZaUCxk5ChEN50sE2pCBUZXspQEaJSiEuk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHk6li1QkZCnqKESKLJ2RJSFKjCVaDjU1lk8IjUrZKiInQyql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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lV8XNUTGKCIibmaVKylljkrGqF8oJSJDpDLU7yLz7AuJpJKhwZQm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHktpQaexVNaolMKohI6tUtZDi1CWskvKFmkhW5a0iFHJWiMl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41fkbJbsWU5OdpMIdZJKiXaKQaxi6JFlCcUmSZGmSMJaphqhkjeyp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bHVubl7JEKUpIqZdQIaGGopSGSslWEjL2NUJDi2mUpSZDaSJF
USLbJDKIKDWThLKMIioRSV+h+q7vj+935i/XuX7H/dzLuc/zjKqbv90RURKJ
pC1CIv3vb+wl8wSfQelNa1oc9S+/HTH7Pz49mnhvnVwNgXVi1s8uZXYR+Id0
PlfpPPj2js68dNd6Ai9MfPKiXfcdgYOMJ05RHoLvIUY20G2pJbCIg6PpqIiA
wGaRUvF8AfhfrZb6HG7kErhY78Btby3kIxrVtrEtFHxf6bOrEm82EPjI1TXf
XEnvCaydYknLpIKfZpdXM6r/hMAUmweFmfvB72ye/9LGBPy2o7EzJ0qaCLy5
oFVPvb2PwDvObm3MWjJMYGvrukNNRq0ENpSxpe/jfCYwiRvQOjwT/bpUIh9y
sQHndXbGylfqol+mysXXsjV6CEx1T0n+0Az+opLo72HtmN+A+YzzLre6CTzV
47thdhX4bw29aoseIL6LY746rRfxVwwliRV0g8+Z2NksOYh5kPn5Pv/YYx57
X44KSk+An/13bmLUIszjks+n4dzbqFdWlek4nQI+W/5P24QS9HTd3C/ivAT4
oR+99LWegG97Z/aLPSuR/y916yxxJeT/3r6Jy3wG/o01i3dbfEZ/pMNkQxi1
6M9wv93TXC74lVvMFDXPIL5TwFn9oXTE5+SUt9l0gL8pferb4rWI79Q+lGRS
h/5Q2Nadwang26iRG2S6HhNYgS0RWdHVS2DN0N2kYD746/4kdd2+gfjdKnlf
gw4h/73MplTv++BfoPZ5ZVPqkG+g5XbPu9g3iX7pXPYA+KLqphUJHpjvjsGU
tb7sTgLrd/OKl+4Gf9Lur9nf+Ebos+pFd/Jy7IOG3VW13BLsQ0XvpvLoED6B
ZUxqdI5lDBL4vLagSe0T8OMsk54IB+DpM5Ljqm4fCezWMbP9OHWAwFe05E5W
DH8i8BuN41JTJOTj4RRaf5GPfKwUfRs+hPIIPIMS3mb7GfEoueka51QRb3KX
8ev6tn4C9yoGsp/KfSHwCRb9XSDrLfZn7KK1nwT6JSUlPSvyXjP8qNddhh3z
gcD95fwHR8lDBKb9jWhcoY95lYgnro98j3jcK2bFS65jXjaeQTnPxzEvwTJm
bIeXkJ9kc7NuHYDfPX6u6EANgN9pSug5J+uA/4yjwLsc+BT74SRxc6E56n88
8WVoVhnqt7pIPhHY3Ebg14qhi3Y44HuIwYYuxu8OArdX5KXxqEL6KJWJSrZt
IfDsVWM5FpvR/+cjnQouyThfqiI2vPQw4gfLOto5ViP+hzLKUUlbxD/t+Pru
gT+I3+k6Xz+gGfGVAvjhZAr0MuWcMkeFif+XjGtY/XL7SwJ30eKUNQ9Cjxas
aKNof+gnzElh48lBxI+hUD52zUX8Z80G03frEb/kwiNbuhj2o0e97ODkGug/
ud2IYXgb50nttx9a/wb6ebR8iZ5jA+6XM9MZ1OQ++ElN9jxZER7mWxMh6bn3
AfzEIKg9fl8M/GTV2Cre+zLwNxY+0l0pAz+hNJ1/krQP+kxM1Nsp3w++mmtQ
tGIC9LmVyxntaIE+C37ujM87CH5eocFqp2bok8oLZjeUQp9Rmh7pweLgjxn5
m1RWYp9IzHlRd0+jH9r+66YljLBPF5aLui31QL7MU3sns4TyrfKd8VH1JPLl
FPgUBz5BvmsSzMsanMH/aWvKPvYd+XrHXS2Z+wL5zvfrjrH6jvnmDvMtVFjP
CVw/WdoY8RP5DhYd4XHTMb8n4vmsW/a4/zTuBTtLF+J8n40+/KVBmMecS2lW
tLeoL2fAYBF5EPwZ+dYOjs6oT/xQWq5hCupLbX0VcXUX+K+5WpYpHPi753Bg
jI859KvsPThuw0Z9fvTRBQMzsR8hh1zeGKhDrwmSByP/DGA/pui7Ni/QxH4s
Dw09FP8U+32y7OOpGcuw38mVWw+YWsBflyjtWB3yCed/FTPZ1rbiBYHf7SjV
O2mO86qf1v07ooX+JlxjmMb6YF4RDyVzu3RRP48+s3qxHfxPbUuqmZEu8kt3
PHLFshH5rVUZUNZwgv/9Mnk7GrAQ3//qLTgWHob88yhbQs9OIv948+y9j8nQ
h/5Q3sPwZuhj+7MzDpYdyF/MR+R5Uwn223Rl8BdRoffINXq1ubMh9ptjU21r
2oT3SLtTmfQ1Fvie8ynj6c/wHtG9oSpKakH8eSqBHZkt4CeLjCRHnkZ8/6v5
znXr4B8j5bw3Vvngr9n9D+txKfQax6FtZykhvvhYro6ikF4VTnTI17tCr/uk
krIKmdDr9iqP+wwK+LQ0vkVtPvRafu5o1Stj6LVAKYRscQP9nlbTULvXC79N
0Qn7fpkEvX7pjZbxWA3/zT6X5r+yCN+DD6rvYTZiPq1HXJXLuzGfhxkXlBg5
qM+Me91pv9DvLeOdG5YMKKB/4fx8u5F0zEeuPPHTv4ngi8XNioqh4H1ck089
qbIC/lD7xUZV7hH44y3k6I95eL9ajd6otmrG+1U5q6WT3AX+scKaZK8p9LuC
YRz/nyCh33+tfq9EzoBv+kvS27QO+eQYB1TfCEQ+EvTwX79zwD/u/lUp4Rvm
P1E3I3OhOfozOHpQfOcH8L11+FmnI5APX+nY7rwHmL/TenUb0wPg66t4XwjT
wPwXz9V3ThvCfuf0VokKBJj/2LfxLUdvwy/EJwp8C07BL040TUe5NsCfdt5S
c2C5QE/BRsYqiXTEO+7i7EFLhf/td+JczrsOvfR1pYYMDEAvk14Mv7H70IvX
gqLYvvnon5t7hptoHeprCJsjd8Ud87ztk8niUTHPJnbVEq1W8OcxzDOO+0Nf
svXrj71TwH7e61Ip/nkT/GW2UXVTJOw/zdbevWgH5uMS/ulEjtB92Xuf3tMb
h/ks3VsULS90X7bqfp0oELovPaOtNWoncF/Scuxftgndl5qJ95k14+inbp7G
NkM2/JDNSHJbOY3+Fd3XHvNjon/bbvqVk93RP3kl6oMLQv6jXeQsWlAE/UnQ
w0o6FVHfL/VNrZpC/jOqmXvutQvqk/Kn79l/EfUtjWt8ri3kP50LjVI4hdDf
YN8f/3pT6EVsVKvhRxbqO28ZOtzxFf4j6fZiPVUaenkt+FHBloH/1Fj5CfQF
+K5juenKhAf68Xeo4w79EN47FH9epORZ6IPZZ89404Z8U2WUOWLboI9f1csF
D3ux7/G/v/9YnAG+8mGDFebnoA9Zln1E6i3079RUdoyEkL8pk2ZXMhYhfta4
XT0tE/FvFt/hnk4Sep/0d1tnmMBPVo/Yzfq2CPOcUyVgedaAP4cmuzzyOPaB
d5iaS07oMfsvuVADyQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk8lG0XNgkllCJbiVDWVGhR9hYVjWhDJV6EsjNEZUnJTt7epJQlChUh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k8lAsXttyuncGlupZL3FIkSYuiUaarrBHZwkeLKUSrIiTKOjKVbFmz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lWsXpkgoRByJTUpsmaeiTFuRj0JSsSNbpWSMk3KciDqGpE06ZeiT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk8lGsbHqZSkkKUoUw1R0rZ0qKyVLJzJNVRZC1LpIWIOC3ks9VRaiKy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lXsXPSRREqXRFJVCpGsoU8UxJWOupAjH2O1ESqZKkcosqU6okBTJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4VXsbJRXRQcI1RqaTWSQJichcQikpJcosqVC51DVFylAZOqpTSCgN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lfsW3oYGbJXINtVWJ5m6hlKZoozJjVDGlEQJTWZxCBHlpHQu5aAk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3lYzG0bnahE2qSU6iOKIYMo7YmM0uJDWpREUqKS9kjxKhXFDGGyhBe9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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lP0atkQ7pZAIQyI0hHSILEVRkaSJGkpaJimNJaHkpPqGT1mzRJGl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHgqHiRoSkZOlwpCSoqxlKUKRREQorbYSRaRQZEuRdZxK5SRO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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c8lv0eFlFZFcrqfUlFZJNZSAihEB2rkMdWVupkJJyUEkUK9fJYZa/M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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk01W0XlQZDQpSxzJGSMpcppfTlNRSRNOElCpVECiGlzDJkiq5C9eaS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lesXPSgZSuk6JfMUukSUkMghiRBFxrpRFDdkigyRhIMIUVxjqOiq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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk4lHsbtqVkiz4ZUcrWNjVSKJREfY1SlmRtoYhoOJVwYiLVSQ0lxpJD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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lese3WxJOSXz0E5EGihk6LgRKTkIDTiFosGU6cgQ23AMFYmOoXJT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lWsbNUaGCplDolIZUyFTnUa2BkOHzA1STpRoG0qErZJSHxlSJDKE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k0lWsbxs3zEBlS8QmxkSiKhAjtjA0HpUQZMmc85YujdkllLAkHkRQb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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk81Osan9ApS/Y5FaUQRV23cw1ChyRZm+ylZIs4KfsyiHRpoa7cJmGQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHqJStsiuY4/sEU6WQ6mUkCTJSXYRhZAyliRJhkK75bM7JIWx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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHpItW0iSUE4xRRIZGkSJVChZipyEokk4ZCghIVmSHHISZRkS
ST5LIUukbJkhW4XsIctJ1hTf9f3x/W5/zXVf7/s+z/vc9/08728227manmMn
kUg72Uik//1mfm82shMS1HG9o6QTpT6x7//4Of9P+7vidQQOFKraTtoxQOCr
AvoJpdNjBHZjO3FX0KGVwOtuJkYcTv9G4E3H5SkU5S4C9xuwUcgfkI+2Wl+N
J/Y1gYUjOSTOu2O/32/6TGUX9o96PYjR+1VB4JTrlrJD9zsJrDxKzcsqxP7k
5B5WgGIVgZm7zE/nPv6C/S6mpZ6CkwRuYeR/LzF7RWD/ytIgZ88OAps37Lv+
0mKcwDrBiUbMqWYCO7eqXwsYHMF9c/nW/FDsJ7C3nfJFqzacX16sCxI2ZRKY
Ya9YMT87BH7qZxfCFRFvy7PrgyXt0KMzoUalhwI9pv2D/cYHPxKYvsffX3MS
+b62FtMeszfiPtsy+22NkC/hlnXRXe1RAqteEms3MOuDfml0+idH8HtB8DHL
N+QdgQsvpZ51Y2D/Zj13UX8K9ofMm88ckYO/igQ/m9JVUE+DdHvz1jHUw6F2
ei1XPPw1KHlp+FkN/JXj+jon6RL0vznYv9kkG/mK8yKG+POgv5iqa4Lkzh7U
3/LgsO0K/W2cuEWULKF/RTI1VN8L+mdorj901xJ8brjmn3RiHPq71r4UIPdC
r/DU3lu26tB/0wEvO91GnD8XU9rzsgz6+5oI61xV+ErgZzVN5hVNwwS+Qzqd
p5I0SGAnOUtTDQ3wQTIkOadHwt/H87PDOgVQ39bhH4LU86hPXW5hbdoN1Bfr
yF5bfhr3O9wd+L6sHvUdV+ve5fAW9R37cu2Qujfq0+qT4naJx/mde1/rias3
Ib/EoFqhK+qZoj5Y9LkE/6U9cShY4IP/Zn9YSNAa4Sc7cpR72Ubou+5zTWkH
o57AH+L1eHfygp8Z7drOs4vg58vOmypqhp/hV0Wr8UZ7xJPYxibDVQE/v4wv
KeB7h/wfuY3GSmSwf2pWvPiyLfKnnNJgnRiAn+mLi8vL8vCzJ7vJxn+1PhG4
bzT53pAA4qVWau51MWuAf+iNQetpqOdQ6HhYYQDqoXX/pL9dwrzksVNr2fEd
8fJdRKv635YTeP/aqyoFHKi/q47SnmGC/ZNaCtovOmoIHHXPY5WoG/R1avrE
ppsMffldN+1f4oW+DFIcldMA+pLT9JikCuj7Zs8xH85Q+Cf/4YEedm7wtal+
3uf2esSPiJkfXAppIXCNzJqOIWHUv/DgVz+7Evr5gtwVGYsV/azEqNY/eRJ+
515SIct5w+9S6VGTcyv62XNkF7N4FH4foLaGb/iC+1r2rX9/TAt88I+IOdjV
4bx4V2B19BT6+UWcBMebg+hnL5mNgs5p4Gdp5D/0bUvQd1NCTVx1Pvzf5d3A
qJHrxfwe8FUcHYJepu6vvq/yxnvo7tnwl1Yn9J2KdjI4Go79md8qZtxiqwnc
EciWaH0R8eXpX2nvm1bMdzep8NgMvM/Ox7vXfL0Nv6WP/3w60Yv9wobc3msq
cB/rIMvKugOYz5ZOF7fwMLA/jhIny0F5Q2BKQXeA3k3oWfswoqyNC3rG2gbv
sFIpxTxYftoyK4n3jlr9tw5/EvQ4I/vH4Hdh+HNLpO99qjH4F+OiX/HPhT9T
nlmN5yRB70zfiau/WdBb29n5xtQRxI/u2qjsof6BwE9HVaJEJKHfUEzjhPcT
zA9jvX/ydVVRv8sN8VW/T+A9ZG1gzgoYoR/U/elZpU2YH4PC1yWXtdsILH32
6OQtRayH1e9kk5PFfHknP2/guRr5FkNdfki3Yr64XnFnp+bAf0Uhz7fd/wP9
1ZywO+LBEt4TocA32nZC0GO9I2/FCw30V7kOo/e3LforYKgnxtQIfLkLHQ6I
VgJfH4+KcyutA1//nDzjcroYfA0/PDC3h7ziPaeFBwuNga86E13Dg6nga3GL
Xvney+DDa4v3dMQ13KepQaJo4RTuE+rvrlrchX5PUWbpVLZAf/JFjWEeC+i/
cY/OyYxCnHc2Kx+eucYi8Gblv6hlVeh3zlrhg5HlwGdP+0i7vQMWTu7ffe8l
cLCcDXtwC3D04X9lmY+AmxyNZTPYV3wPSGrayRhg3WA6cpEjFeu7Jbrtd62C
v/0WPl11yQbfnNHiAS170f+dkknT51f0s7zAN8n8d+hnlmyQ8htj9PMLhrb8
jXTsr2s4aNopgn4uY+SJ9LmgnydCJ85E8sI/8mFJ27gG4J+qEWtB117oRX4j
tfj6JviO4npVnliEfqaIejr09KJeX2NmTpQv/DxHvT/93RF+1jYMfCIY2U3g
35y/c7aTcJ/ZMVleDpEyAmvNXBJiVWG+SExb//Lqw31ytSW1+HPwPd0XpNhu
mwa+ZbVal43y4SfBtsrE+RT4qSjWoS7KE/FyWqp99myHH2MbPub06+K8R8gT
1b2Z8Lu9r8k5W2f4nXs0xGg2C/wpGAg5m7oivndlCHPGFPE/NOdTh+wRP50r
8tBBG8Rf0JnPzK1AfL6tn2XrMjB/pjVs2lg0rCvnx/CeKUD+wOvFBX4eK97H
/lbLEgryR4s+51Y3Qv6UGbeowijkv5tN4Z2+hfh7q5dHu5fa0e9avY1MKcRP
OORr3nQK3wtiAw4WQVPwux97wp6IYPhxQYEpO7HifcnyIbvm7ML7Msdcozkn
Af13GzJtKI+QL4B9v4a3OPzIOip0hXoCfuzzoqU5PYYfwrLNJbhyUW/NMGlV
Tib8IKvnxV/igvhFmTsaWBbgS7qntFjcEefF9I+9+2kOvkZJP8kONeCLRhbJ
FbsCvS562zgEmmCd/DMqm3IK9a1W30dpeIn8brc/Cxa6YL518+jPGBdi3ihc
vKVb2wG8z267dW4cMP2yXC5jLfhoXave0EfGutiw29/727DObcZTFXYP/Stw
rNz0T330r8PRK5q9+niPWPaCBaZ80E8j2f0T7TnmSbjkF874YvhxWKuX2rii
39LnJ4QZ8uDXw50zK1oH/P5LyZNXyga/VpyX/+S8AP6kd5vTyRWIf86kRlvX
G/EdrZtVU8QRf6uBdcIGFcSnuCU+PlWP+Gd9fnlZ6yO+6KOIno470GfYyiHE
d8X/x57BI43RJfjerM+iMSe3g9+i61KVLi3g9/XI/TTPePD7IrXkHJ8u+DVP
b4yaswe/nxQSXvnzg19hLrs0gUjwK1O/5JufhPrDv9roGdFwvwtHnDY99UD9
Ze/NjEf9UH/zj9pX1tKoP7JPdcSDtGK+Wk6eNZDA//+c0O4QOTrue4F/v5Hq
PsxzJs+YZND8xL7/ApNe5xU=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbRspIJWONiil7skSOrbQaSZnIbrI0lLRYOiVhQtk1lsqhENok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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk4VusX5SMimYfKkPr6FEpKIcmUuUKoZCpTlIxFpkhEun2mK6IylmS6
pkhIZUrGhMyz9MkQhaSb+/z++J3lr/Os5+xz3r3XWnu/e5u1i6EdiY6OToqe
ju5/T95crWEfXg4Vj27f7WLXPij/H5c9PJrIkvWFwJILbKtKC+ME/uMYcUa2
ZpLAe0ypk3tWhwjc/EXTOH5hhsChUV1h13UrCSxn0fZQNqeHwKOipqd15RHf
syQ3Urf1PYEVrCfym/eNEfjfvT0TT+amCEw/9OGWsU8HgZ39uLXkX3wl8DSd
wC/jlj4CtzJq0TvU4Lzz4vMuGyzeEthE09E9nzpAYC5OxV55xlkCsx5h0Hyd
XEHg5d7oEiH3bgLzlySO59dOE/jk3Mp9ft5WAgtKz2S0WU8Q2HDn1vGFq2v4
njSQz7H7TOAtXSYSUULge2P56q2XmSMEnmCc2e8kh3rEPp/NeS4J/pwzpaYy
5MHfbRFa2JNJ8Le4eErtWDr4669iMeRuB3/aglzifNLgz7Hf6kFEGs5j1+P2
d1apJrCE2t4jheHwQ/XmocdtrOCP9IM3dcNQOYE5GnkpL4a7COzw5qVi7R3w
N3WS/I6aAn8W9K3SFFvBV8ZUO9uxdPgzr7840/sA8q/vdCZlZw8SeJN6xbYM
HuRTMExZl9xfRuBL0U3zZiLIZ7zVyqdjH/Ihndq1+GPkI4Hzdz9iMUmGPhWR
MhXfLYcJbDslEMfVA74ELdeZNMm8IfBvjcOPyqbA75jB38dX3yPeMu+7ei0b
/JlM8ZMSFYE/Wy9rin//ifiSMiZVHtorAjOk1njE2qHfFqKrLcNEEW/9tuV6
7YUG1N9X1RM3Cb/8usHop0KBX5Q7g4uCz+B/Xauk4y8F8b+pMObK4gz8bySS
cpafA/r0UT4IsS9DHy3np+4mpr0EXqcR9jv3Mv5nEeI+sqRZR2CBMl1JSgD8
n/JtNLnSEPH3qgtjWPLfwY+mydmMZqMEHsrpLAothp62Vvc/rgSgPzMehQ2+
qEd/bjc8VWNXAixMzlsc7QYOfkf5VnAfeK701s5Fbviz/FykgZnEmn7vfH28
pAvvg6RLsoVjwA9TXS+d6gnwI9v8ZLcaBf69szMoqZkd/jUz/doS6Yh+Gvsa
7/8lDP4ldX4tmLRBvZ6eArRnSW3g+6Edh0I6De+jdT3TasFXQcgyv+lZfF/e
5rasOobvc1OMXln04/tr+7pT6NXxfXiRhhJzPb5vGMmh82YE32MJK6mFRuDH
QEEq8GcE+OmQCp7r34N5WM4097jODf3GvNvsIVcn+i31p5lNXhb8UNb0ubai
sYrAWzMkivxVMZ+GiqY2uXOvme8cLtf46cGnwN6wjTqHwOcDiptBihLqUf2i
V9UciXng7f9zH9kG+f2z7lPL5hXk5zXnLhSagPxsv3EyF7/G/KTyNTBbjSI/
AbIx8+IK4ouZHcI8o9DfPon8f6Z3oB9trn/2Y2NFvPdL8beWCY0EPjh4wyYl
Gn6LIU92H9WH3/IWD16X2wK/mVmn6cmv8dvorj37K/zATyDrBZ3hWPATe9Iv
o+biGr8ZmJuFe8MvJ4N0UoRC4RfZ2blyXg7MG1dhapcbL7634yvacjWxHX4I
NlrcIIZ8Jz2pV3//Qr71g9+FfXiRb2GWRkJ8DeZ7sLVF0iY25CvmeTmcXRzn
CbPYVW0VxHnFepyWGvXQc0RiXW74D+jziBJYJ7xm/n5/cDnGgB77To5TSKnL
NegzrufYFSWGePP9O8SneTAvYwYuDpwrBx+JobrZF80wf2dlW1V1+LBvKC/H
valIRv7tuqOKqZy4L7kZnzef0Uc/GXny7FUpQD9x/6SWfUqFHlIr2r0Rzejf
8o+2leyG+P9GYaqxPw/8znclnJxHAj9PBqKFv9Mwn03j33vHsaFeH0/6P7nX
4McrZnUqiwHwY36W/XlzB+grOSp+pz4C9x3LvcEG+zX72IHl/nX2D7CPLUg1
3BVxBj+HtKdebqlB/iZ9TvOlIpg/TAzH9AScMH9eRmu3+1uDL51/K+86/wW+
dtpltSoNg6+dJB7R5wrga8Yp1sS8FefNOgb6ZKW3gK9bHnyvyDivO2/7L5kx
nGfVdXj6vC/4aFTwLfVyBh+O1+0VPjuBD1Yp+ev69ODD3yWNPX0BfKyQqtXO
54MPD3faettB5HeofUgttq8Z+ZzONDCqRL3bvO+W3aCiXtaukWJNOviz4MaF
mzPb8T9eB3F2RTX0z1eXx4NG4/DHepEX04WZ6J+8jhaJZ0zIX9+ImhZ3Fvnr
O/LMf1VE/jFK9Bf35+O8PprMvFca9CyUO9O7OAl+k24w8zJ4AX8ayxCt1APf
bwVFZK8Wol7OztIXI8mot493KY38EfoGPNvN/uEEzndsm+emSaEf/tITyxDc
hHorz9ZVZT5HP2TVbTHVkUY/VHnpuMqEY1/vqw9UnnQFv6V+bzf7/YP+d85M
muXm/4T7tqQvVSgL708fOZPyRxrvH7uF5seV4n2Xq/rd5586Mc/9VVsnbuO9
ds3fhkYkzEfN8lyy8Q7U62fWImJ4CPr2sIxtXBpAvc+EpLSDy6DvoDbPTBMD
9B1RZNg8mw19rZd9dx3whb6DNH3bE+9x3rxEj/PIEvqH9el4xaVj0DOebO+Q
kwg9t72TVZbmgJ5km/0T5knIb5adPsHXCvexkhPPrkPd0GO4K5JxVRn7uRMn
1WjDH+zn64ezA/c1I77IielexwDiuUJ0mGb6+5GPHEVddG7NfT/qQbJtxP1g
7HFAT4cN+29Qa/z8t1OIF+qMupMQjH32AZ0t11UV+NHLafpbZwP4OnF6cLfu
KPjaxRz3xFYVfAVYPDKyzgNfubSq6l80zJvgwxVeVzrAV3i1lXpsO/RUJ/eT
2VaR345h1+Q4Oewj1NuSJyxHoGc0byB7/xzyu2DBWs462kTgkgXW6hVl6LU0
oKbndhrnl2qwLbMKon8oMp4Hcu/gfGlL8WOklBoCp9d3N23ygL6PWfYue7Yh
PoKff+J8CvTqteEzfBYKvep8b77iHkf8lTfJYR0xr6H/0eRQVxb44cePz4xu
a/a54hDhc7NvsM9tdryZJTUG/uIGPsTXr9nnBG4tZQTFgj9zBqeJZ7uwL0RW
dfac24D4VcmKy7q3cX8qPA3P/nIb+s3LU3+cM8d9Ud5ad3hjG+6LoE91j7NY
0I/VPlE7iunRjzXFzEpMK+j/MHEtutR70M+GQc1qvSn2C19St69yFPz0mlXo
20FJ6BmYXr2xygN6en6RdlxsgD4ri/YBlDzUd6k4+740Ffu6Vq/btkp+8Pf+
+BFOxTX73W99mkZhI/a7oRCzZn+uLuX/AM21G38=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41GsfxhUtyLGTJllSlBnbKVG2IqKIZHuzFW1EyBKmLJV9y1LZSbZ2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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lHsbnlAc0eCoRrlyEiGpKWmxxVgSfSpLSVmTr2RX9g4pWw0jLURI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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHvElsoXKkiwtopAiyl402XJQiSxxSFIfkiVljywje0nRLvpO
pziWlCV7BnGGGbIkmRhk7RDZvuv74/vd89dc9zXPvM/z3M99P+87si5eVm5r
SCSSMgeJ9L/Pwg/+FQ8kBPXJ4xJ8C9Ojev/HRSJaP7wpXwhM3n3Z4siGSQJv
Mw5fNVIoI7DWRfnUJPsuAo8Z8vJMnBgncHZqdnYeVzuB+S4FDuxaGiFwSsDu
GMryVwIr1UXQArkmCOx9Ldhsw/dmArdxyH7Pqv5G4BNljvduC48ROPZFVthe
ddSfGU/hOCaO+udGeFsVdN8R2NPA+ldIXieBdXzllrhXvhO4Z/QsKWYvncBe
jhaKAwnIV7y2culabR+BKyxN7D7/QP1Se86eXYqoJHC9e1DTeE83gfO930xs
MUf8xll+VUuuRgLz0BaPnkkaJHAJ9WFbYiL4jTsi6BIR9Tfm1TVam1zGIrCG
3W39yA7wdeeANf/vC5h3pOx2pYJA8OXxfg+1SAR8Ob8MGkkeAF/azrVOMjsx
75HPPTsstVDPM0pO23Ie5p3K0rA2v4Z87t6ari5VAwQus1c0aniL/hP1/b/y
LVRDT0LM0vgL/QTWY54zWtiM+saj68ixrqjv9eX0ZHo95skZ3KhA5UN9u/mZ
eXLtHQT+OTu3M8IC80wzPcfDLY180gpPXbJFkS9HWKV1sh75fplkc3/eAD7e
tTzivaeKfIF9hSJ2LPCxzbZiMSUPfKj71vRHmICPlZPTDg1D4CObkTvpEfqe
wAk6GrslpnoILMiQyfwtE/HUwzqL9IZaAku+PWDhNob5mi2MGluT0M8OM74f
5mIV8OdEFqdO2ycCXwmgi6+ZRj+PrQTz4v5pIfD5/nw/b/MhAn8w/3JXhoz+
dGWMahYN4e/4+ZOeF4NQ7439NeeS4+oJ7Np3SvsQP+KtbLzIBXcQ7+wrtWv5
O/qzYG0ZKecEf1KLN55l/kJ8f2NpydpK9Le5ed3+BlP4j6FNKX4ohfhivxnH
rWlNBL7t2DvwmRv+YTpviv03N/bDyo/42qH1mAfzvVko7QzbeVp+b7w0PhA4
NGxnUOtG+Lnxw5eFxBnw27TX+tPVfvBrH7emOOYw+NVMZb2rswG/jySHusmS
4Mv7dcB/MpKQP4E/IfWuZR2BRVvqnh42Al8dj/eUe7AQLxKZwyhzh96CKqlq
rBb0p+6Z3lWWjPhAn6d3vQ1w/qf1tMX6Qzh/do4+kzHGdn6srULqQZz/iMQt
uz4e51ckqEsrhiF+qlQrsvgg9MHI8rss3Y3zAxopfpOvEO/a0xK5Ia2GwC1n
lwuTt0L/uX7pasoS0P/+AnON2m3w80aq6oRxOvZHed0Wk8ofmDdvNrXDwQf3
gaY9qWO2BPuj1OmCZzijl20fmqT2N6O+0RQJbfvZKgKvaU2bcuD8DD//bRM2
voj4OaVu5tUM6Hfvt1lNYxXo92r1uaRcEcRfic9pLd6C+9IounCl3wr69fFz
0BDOQ71xjcbpm3fj/tIq3DRt1IvzuprfpDhuRr36zEORS43oz374poIvFfFb
BP2SD4hhf7sc073Oo4b+yovGLkVxgP9vGT/LL86WE/il80S7cTH2j9tTuZE9
w/DHWm3d3zKvfiRw2JafH4qT4Y/U0kFBu168L+6TauZ1TeC3qP4J8kwjztN3
vF96naONwEP8Bz96nBwmsPnYc56GZNynTbU1d4KV2fyoEbNT2B9+vJKRs5r/
EfpkmgkocxWBnzSu6P5rptCnddtx4cFu3Dfj8qvDfmz6LDhZvileEvo0aZSx
Wb4Fff6L697NqCno84RKtW5eFPRZ0qznMl6LefuIhQ+HUDC/KRbjEUcF6gtm
dOa0UTG/pU6LT8q7UR8lQphbfyPqk+2Ke3CxEPXpnZMerOPEffhHwatKqiL4
jqQVha2K4P7VNJ7X82gEf8lHBF7F/YRfLS753Y1bZvNPu80+fw/4gazl6xvE
Bz8M+N6u1+BGvBg9hvWkHn6gyXd2Pf4TflBgOHU5KIMf/xDJfoUO9Cv5utPJ
jW0eW28VXvWWYtsXP7vVfJIwD/cKU0XDaczjyIuxo7/CMI+wG9ax01XIN28o
yUjIwjz4ts7bU6pQ/77e+iyeDMwjMtou0/wb/LSuqVtvO9v7nLnzAbV9D97n
sg4pxoedMI/qj+f7lE5hHj/KHJeTlmjY94doVrWz8E/5uLkXLz/8014qXSm+
gN8XhZm1VEXjvlqpmFO2FIU/TuuJtghmYb4RZm+Uei7AH7mTtBA5tn0zRd+b
5CiOfXPzuukcvRn8XLeSV+doQrydtARZWwj85MeXNrF2gR8DecZbE7b3jqez
FIUsDv24Oa9Nm2N777xlRrWT2d47PK/N6j5Nob+A+LGmm6boL63zCYXPBP1x
WN4u/lMH93G1f9+riyFs7wGxJLKWFe6z/Jn1Knkj4IO3PX+2PRfxlZzpO7wX
sC9qDAdtn7vAHypuAjocm9Bfi0pdr0k29LkqemOQNQN95lTrjKbKob+nTTNP
Qo/Bj4sRq5mSk+gntNL2pUAa8iXuCj2tKYR85/PdH7aRoTd1oTPvCn2ht6gu
z4ZMJ+Sbo63r+r0SehOUlw+ZrYXePgWsCPFGQG/71OpF+u6xvY8oKYdN1PB/
Z3xW0Mr2Cvbz+RJxV3tPzOcyV0H6FzH0M3NCNzioBPOZUNrpJKgOvl8dl5xP
saTifsyfCnK0YmI/GTk4vKTD3+mnpGKpSgwCJ/3MYd7Zg+/vcH4UslHFfqrx
uKHmIop88bztIVRh7KcjG1Vz/c2xn/6xpdEEXmNfVFFOl/ly4r6m5M7EGtJx
nsaJ0sMB1+Gf27LHfC7ZIn7r+DP95UHER8vRb7U8x3vsYkG63jFF+E0uLlzb
iE2PPMkrec4ceH+zMisS59yhD0OXTTEhbPdDg5FA35GX0OOQ8nKH5Qr0GC1G
u799F+ar9VXLbno79MjsUdbOobO9dy2fnXHtRL7Sx6KsTC7ke/hQ5eCle3hP
OGiJyCj6wt9KjmmcpBbkI4W3xXB3txJ4rXlWcaAB7n+xQIazTBH0lerl+syY
ifmEOIjEjX1FfRnUP2IdC1GfIHfcgvJ61Cewtp+h1gO/rFcMrl35Cr9oqR4P
UExGffNHxU5PBkHvatttbA3+Qj0fdcVpuizUY7zZWFSvD/UYdr2fta9BPd35
3dci1qGeOL6+eicF8BWse9mgSgp8hTJJMzteoB7h+vvR2XS8l6wP0EmqW1HP
WZH9XzrFwB/JeYL71yK+l5GJqV82Rb2yhsPK/+RD382ub4ZfzkN/lbaxuWbt
0J8P885+Rgb0XZn4V7F/OPQ94Si8rDs6ofdfZXFDzQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lOsbRtmjIVtZQkmIsmXLGifSiTBJZC+h1AglJfvJkkKRsiRtRKs6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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41VsbNRQSknuMoeSS2SWSIVNl6IqUofnjGDoiQylUIlLpSZLxkqGE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41F8fNZKpbGUY2YksJeJNRdlVllLWRAsKRUp2skVv9saStNGmTSJR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0X1mKJkKVSsoSEpEwxkSUplPWVZKnQQtZkq1AToxfNZI3sicqS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk41dsbPUjJzdBIRHEjITLmkkyXDJGM0VFKUmYKUUKSecoUCRnKEIVU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lHsbNgpHKUopSkSIclDJUhglyhIKJUvIWpZwsqXFMoiMYqQmX8J8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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c8lX8bNiojMytSMo4RGa8GDaOcKPrJphKRlwaVlJCSUoSmvVeniGSU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk4lHsbZiQ6lhpZxtIgsk0UkSVFJyRliUSkEiEkUipxLIVEIeGU5VgS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81HsXRmVrLImplySSJltclDIjy3CTlKWFLllShCIVkshaQlLcspWy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbnimyxESUXVERFbJ+yqSiLA0HOQ4io05Zsp9UQ8naeqS0UEKU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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbJkk4sqVmaEFla5mZEpKIIRWdSCn7lpJBSFFoc3KYUFTKFkXm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41F0bHpG9bFFK9kIpRaJFKkuopIVQJI0ky5QaYZAtSwhlyVJEWbO8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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lG0bxifxhorUW6PFEkUS2YeJJLSoSXaJ7KFSUlS0iaTIkrQYa7yv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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxVV3c81X0btioyKhRZkZXi6CiRPUK0UCSOVTJayFaHevBoIJX5GMkKkYqs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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbNqKULVTIlF0hS7JFtpIly5wsWUtMthEjbRIplVbZVUIqJbRz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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41O0aRlmyDrLFaJVBlha7UF/2pRhJ80VSBolCOESpCKcsbSgRl0+R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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbnihrllPGUidRWsnJkiFnkL1OylapIUuItNjbUAwVRSSytliy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxd1H8w1Hkcx/HdJpIrP8rSD12kGDu41a3fv38cUkNav+5MjX6Qc5VICClW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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4VWsbxndosjspU3KodgMZkzGkbUimUEpCZEiEqMxJnPahASkJSSKZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk8lGsbJvuYYydbtpQlVISKoYxDUkIqFVIoa1Mkp+0oWVJJFGH4ki1C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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbHk6ytFBZQpGKso0thKhshRaamKKylITCKBzEUUIRWUbLiDgk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbnpTlkF36TDWiLElUKkSW7JGtSOWISpwmdUjZSpTKEnIQiijR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k8lHsbxgcna6RGROVYWlCcg5xkckZEhEQKScqg3nQsJUdElLKVUhMl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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lH0X5lVCX5bQxNhTkWEqSVEJZZSd8iaV7FFJUYlC9WVrpIxKliTC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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk81HsXtrWgXrIkyrUlS65o0w03W7SosQtD1JVlyBLhipQIUYmkTBRK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41F0btkZoUiSVfd+iSL0jQ9OiJEtSdlmTLalQKUpjKRWSUBG9fUgN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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k8lGsbtnQUQk5RKUuUKJLiiNJYKuQoshSjZEpI1og+dSrLOTFkySAp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41WsXPSHJeI4TQmUoKjcUB3UpU4ZbXFNuSrcSURLOkehIypAy1GeM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XniypvIQY3gmZVAZZSoWyVfalkHjfEmWJNhJCVCRlS7KFbCkS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41PsXRghxbWVplEQSjSUiFGNslSyJkFZbXSqEdMnSpoVyyVINEpJC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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk41O8XNSSDKCSarFkn2QstIkqSKFKZFKlQ1rQoFG2WUUKWKFFptCBL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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41VsbPURuGoRQyawiRecQSWkyS8KNOnFKUREKN8kQUVzdzElCyU0J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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c81e0bPlbGi5S8ycopQgcZycgoKRQlrWNkZb0vMl+R1VKvBmmYHUpK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81OsXRlLWTJEisqYkykWTrCEV13YjirKvTWMi5VoShcgdW5YoSxRy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3lYjOsbLjKdpEVJtIooJUO7ok0LU9N+0qJoI1qECh0alaZdRXtKK4lo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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41OsbxictOJEJJ4RQpMiWLMU0wzlzapQUZa+ECp2aRCnp1GmViJJw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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4lfsa3YakjuiUDLWRJISOVJSTIUOmyxUJmdo7U5MIh4ynDLGbUJJ5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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk4ldsbdcgYdUuFKyGPKTMpSsYQFSFDQobM6hDJjURoUGToilREnFBS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XHvXOFFFEi9BClkSUnbFmKZP1paKSFopkLclUspRKSSqlVdZQ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41GsbHqLpJEeUo4WKlClftpQUmVKIIkKRLaRItomixVYoosiJrBWR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsbnqHIGpWKjl2Wk4SoFGYqHJqyFRXpyIiSBp02S1GSDFJSaRkd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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHc81W0fPpSMtGwHyUxZPa1TZiczlNFjlApZDdURynyMUKlESoOiVGSE
hOwVlU0is2EfjpP1cuLJ+3n/eH+Xv3yuz3277+u6vtf3e/+QOnnBwpmdRCKp
sJFI//tJ0+TpSKKt2/dw8CP/aeVv2v/HlM/ieyzOMgn8teluewIjm8DjKyoC
QhyaCfxCh+uh7PQwgQs0xFVTM4DXWBmrr9wxQuCO8pEfCypYz5R7O6FBHiXw
8xdaX1J1Bgn8+mXTgBX3OIG7bjQ/PmvcTWABAxWNx5UTBO79aHWHVFxJ4LTY
iP4GN+ibbUqJ4zkPfTltg+1KcdAXmcKyKxODvkD3kEMvM8F3qtjnnJ4q9Mh4
HZEN2411DceK3lFe6PlXTyfAzgF6OqJY5sE/x+CfaSfzgWoPgW2bY16Y/IEe
Q7IkXT25lMCKqqrhhSFdBDYf/J5ZdwX7B9d6yJ3VqSHwLtuJf/I2/CSwENVM
mZOO/ZddbnBeDCgnsJ3Z9bYANfDp8eFSbSfBrxVPI+c8j4GP5+ZBSrUR+Ehu
XKqOpOH8nPKBxLWWH7C/SfdwXSn47KIetshaxn9fBMNpUhf8udzrQrP4sP9o
1avFq6PYH2ln/6IgFPx9xdL8xPTAv++qzEbDFeBPNduZdkQA/E16EnteCoB/
pztHr8ZxnL8/7HPTeZePBC7yNyvb69pPYOlTLFbQymX83TLd49UbCHyqK5yP
tmUIepKn9UZq6AQu9N4/Laz8g8Aec3GLcnrgG15/ov2JWx7q/XhRXZzcRmCX
N2pms8LIU7x3tpfT4e8EvkD7XXXwHM5rYORPXs9G3vVv5qRnqSDvVQPuHsKV
yPMXk8G7RrzIu2sEyZjqj/V4CysNrttY/0d0t2ecO/TOOj2ZU7aG3j2pt8e7
D6Gev3Ty9yh8gn+c1hk83MfRv1yecXYGI30ETjeIC6a6Qk+6Dj+j6NQb5EPn
WZfxJ+jZ3HGmzckS/E47Xf6kMgp+xbO5Neti0K/Wj2oawlUGMD9sjjp0GjEI
fOvo3hFlv88Eju2W6m1KhL5xpRBDzWjU03A09YerDPiyBYmqFBwrJLBgFE2u
Rb2DwMJyMYw4AdwnFJKYdL0L9XauKXURS0S9i3sa8lZl9hI4ztGBz1sf9/0+
fSRhURf5ESWNzcyxwL+SGUE/QsJ57h3G7h4xyA/r3pmMXS44jyWq5OB8DX7X
cNgZ0PvhN/mLNEX5PPyOWi3yWSEPfjs5nghyG4HfX7nW6xmeRD/N15s0JXAh
D0b5Pklt7OgnX8bfUtyrl9UvovCQ7wz8V3J6WXc5B/w31wrs3OYA/vU1TZ5a
m3Lgx/ZHpQqOLQTOc+N9bfwT/AWVqpiaZZjf3/7cy957En6d6CoereDF+3LL
8o/ajdO4byp3zvKSDPz6bNSwciYSfnELzXP6bcR9e02SW2Vs0F96EhbvGpux
vjp7MoU6CD5hpg8r+hTB5zGjjTkpDv0dCgJTGjTw4VBpoETaoP91GPEjXjVN
8P+WiamEN+5XKbJnT4rF/YVnLtfcd1hWT7kxbVca/P/zYeus/1r0942bRT6v
xlBPRd3N5oHOmNdtcgc2hQtjXqeX0nzuz2P/JeHhfl3TMgInP8+f71nCvG6T
TxEUTcf+48IpbyLZ3hM4NdQ7y+Me/NgXszV/3Bl+XC/8LcwRjfpQKTYrt4yh
PkUkH/8BT+jX4BxWVE+B/tWKjuVGS8jzM9m/5+23Is9qG4qV7+8CP3LsPs/p
O7UE3sTvsEjNwrx5V/ikO6wE3ztJJfdIPeyYD+c4cpRuz2I9McCbLvX0C94b
8y/Wh2SwPiQ2Lq+RDb8yRXLO7Y4Bn5MO5ESyazWBZW33tIlcwfxin6JIVCjA
r4FR17aQkgK8v9UcVLWydrznLy+te92E+4OfjTgNR2HdiyNsDTkX662blIQC
KdBn2qI5Y8CH+feCGUIPGMX80+awaDFLRd4TlKQnEjwx/5qOJ7WUa4Kva0Hs
OlOjfAJnZ0xRVzXgPLcABbb2WJxHmRTlGejHeQ61tarJB3GeSX0uZfO5XNSn
MMhXzAjzVNegvaLeF/1AY2mbf5iGn6fkvww1Lct3+iXl7o+GyHdJT0oN7wLq
NaybxP4kFfs9jAe3DAkh3+sP2Qp2JSHfjSL+SZWOy753/PocA1qRb5u4m+zC
0ph3r+wKbrkkI9+07hJxES3km6FUYE9Lhp6os/brxwKhJ1Lru/jEFtxH+Svc
3u8R8jH00epjXhLqHzW74/1MGer/5mHXbMI01kP3mFtLMrD+XN3XuaYd+b6p
6i0kqbesP7KY+sFDnQRuecB+YZcJ/Drfzqa/0+oTgWtnuX115tCfjRSDeLkQ
5M25ZNRcYV0rgc1Leg8I+qC/3/YH8ZqcRb8GbaZbp/Dg998/GYxxJIMva1en
gUUd8hUqWr+Wlod5V3vWam2OGPzL/Ut5RTG1CPO/avXtbAb6Y0NXmkg0Dfcx
LcLqwq6Ab4m83ze+bvDNLzuYkBkCvWxMKkuVgd8fl3mgkuXXSGD7OyGOO1pQ
/wcV71/9U7Ts+6gsPjq5Eec9n1MeG03BeTsDNcK8eJEvfre+sQcxy76/pMp4
SKdwvoamlL61C/LFrfc0RlMB70edVmylZR/qWWH0YSxMoYLAI3nijQe2o18z
k2uP9GyHn4X+w5Z8Ue8IzKXeq7S/BfXJzxdfSqciT+QoSSOdBeSpdKv2vYnD
uJ9/PZ30cBR/D7D4mREX8+AH9e7YJr0y+NFfFdc464X3ZI5JJ+Wugh/BVH93
g6t4b514LMPe+mJ9aUuGrGw8/OJI2ZHxLx/8Ih9qXtPKgl+rJClClKPg23wt
MpgvGnxvf+1NEQ4G36nmxfO3J8D3V+2Gg0OnkIc3YrGtYR9wvzQ5uya5DnnI
M/dOGkzGeWlaIqwL9ThvMEF4sk8c+kX8z/eXZkHvSh7P6B3K0NtNt23NUMN6
ncS3S9c5cJ9Fb1Z5qTu+f8oM6edK6tFfvc5/Qiiv0V+dPzfKc5GRhxLB3dLq
HuivCrO3oRP8Xwl836t0hc0V8NdSm0rbzYn+0nzo4K5/EXw2SEXHS/hhHoRd
kuI4wUKedLlsDL5fQ94CKXp9n/ixbvJL7OfVNfh/hr6iRoleFuo30qc/Y1Nd
ReD/6HTWZ7hh3jMDhw+wzkCfR6nbTvl5fN/tqTsQ5HIG/tcZZki8WoC/nZoO
nkvxwPtms5TMLVCPE/M9Qz5M1P9ncCLfsWvQv1HkcnWSAfQv2Fp6l2+DfxcW
qhV/yeK9XTQJGO+SRL1osvRtXzWhp2RSQaJx2f9nIvRTH6wMhR5h5wtzElzQ
89Ul0uviMv57rTvqbQ6PaP8XySJLbQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4FOwaVkaSLyo+zZfxZTtpceaLjj1bEsmSLOlEZJmKtrFFVLIUJSnL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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41F0bNiikskXJkkqkrGloUfaQEMmSpNSEMSH7UpZWhFxFqdAiUn1k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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHc81e0bx5EGx6gkQg+FJhEpK0cZKSOjImXkQeNYdSREw4j0pCgNJJXK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lV0blUgJkSHUyXhKdDJLUahopkxJUjJExpK5OMlQGmWo0GTOkBwh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk0lQsb1TVVZMoQEepkukhKjjo6ck0lkRCVSFIylSQZj0QDypAIq0ED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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c8lX0fNiKjIvMcRCozoiL0IFJEQjyyMlLUY+cl4zFCQxraGQ0pZVTH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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XJkth3owWayhLZY1CfGVLoUZUCq2WbGXpxRejbENaUMqWXlu0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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWGk4lWsXNpUpyRDZFbsyV+axY0iJ7FAZk7Ec1a5UR2bKkIQGfNg0+DgR
DTJEW5Iktcs2lDK3lWkbEtKkk3Cu78f33u8v1329+7qfte51r/U8y5r9xx38
+Hh4eDR4eXj+95ei2au4OEZ8czrlzRnDwg/m/8eP45jXpaKnCCxtwo5ynC8m
sNi3hsZTt5sIvM3zQ0/NMJfAuVqsGx8Mxwl8+1BbpaVAH4E9zvYN88eAv6Zp
33vB5+AX+DURNBgK/jjL5+MVjeD3T6pQYHuB31i1W1hDC/FPp6YeaI8Af/rY
Fv4snlICOygvFM4mNhP4w3FGTKXXMIGtH3nVlsV+JHDdqp62mtF+Ajc9iTqs
sxT8Op9aRMf6HhE4y/nMZSvjbgIHaKqs8ZGdJPDn+I5zVduQn+gdmfO3S5Bf
mPm9NfR45Kd2IH752K73BPYKP15ZehjnNx1LjpAXuUfg80z3/aqxrwl8i1fW
8YP8KIFP21TcOes7QuAQldE/KA34TqdmrHfnhR4mEVVefcsQT7OOkJPBcdSz
5NIRGWmS3pFCxlLZsiS9t27fl1sGvafa3JxKToL/h/db7tV90LvxAqW52XSA
wNxbOeW1A9BPjfvWpPXzEwLnF3exhac5BGZUFY27GSIe+emfknSZBwQedy/3
zI5oJ/DygEEBjtwnAkc4ablEz/QQWEbIXT26CudzE96/EqbVI//O98wBKvTw
owYtjSH1T5gxS8JkCP6++zT6wWga6v+sbbLiZA/qb2TeV11gA71PyweVixfA
3wd5NLeLkfjLuxQcOxfA3xjgvq/5DviXmkeYBY6A/2H+qzsdBuCf3TyrTxVE
/I3nNnAXSPzx/OtP/yb1p+4iyz2VYeCnU9lM1SbwZ3pbflIk9ad4UVgqWxfx
pxXra/BHgt+a6p60/UcJgVM1rjYwouEXjwbLuWo3+KXiwrfg00nwy2znCqHE
NvRnp8aFV6dlwW9WWCEy1VRN4LKe8V3Vfl3wK2/JxsaqCfiFejQgNQ/9Q58J
5WaYoT9qlnwMLlyH/sliuCyh/TFGYNompvNGAehhbOoaYHUI/jLb2LP8lDzm
g8yavU3yS+Cv2WV26Tn90Pf86Nn2bAHkzygy2y+2BPrqJr2UdI1E/epSrJMy
w5C/7SPGtY+W6EfvH/8xu7gAfRXVmOtyr4Hfd3rxn2wF6NtpMFs3NIh+FPzY
EsUJQ7xBsimH2BwWgddrTmoPReL3eRRjY6HH+H3V+VTxnULon0zdS50rRuCP
lNnoZV9J/otQ9eWINsB/Z8TMujwjoY/CUpUTV5uht3jzSJGUB/TZtCAg4W4O
fnG2nk8KyX9rhWo0CtrgvxX58xJXfKHPTpFfyY406KMgmhIefB36+Ou/F5Vi
wH/Z7ZT0Om3wK6s4Wn6qwfzZOa+/Woq3A+fbK7KXH4M/7pa5vvn5C/78y1KM
Pvkb/rS/IjFqUo746t+l8yUGIj6ul9O6LT6IT944bLGFBerBv2HlXEcf6qEw
vCOxYUkd5knsy+hIuV74r1jS9JkZ8tmiRP0qaFSJ+esxf3FdQxuB+X4q3U24
Dv335hh+vVwKPtFpeuOcC/g0TQw8L3tVEHjSqs/eJugNgXuF5+7e56C/PmXX
6Q4kDBJ4RFmu5dAM9FH3rZwyIvlbvfixSCDJ38LxfMqSVOgTVzD+WZvk7/ho
qXz3cOjT90x3J7Md/jZ3+yhLD8Xv/+wPVX72BL/X0Ql/ca3vKYFVDk6dX14K
/0mWhd60IPnbwb/TYO9X+NsqtOz2fC78bRI5+SStH/6m1CkWeZhD3wBNSsia
D+CvZlaODJH4zZpWOR9tAr94csYFWhT4E97R/PRegf9vrqZ5oxv4o5tvsFfb
gn+D1+7ctafAH7RIg9ZShv6Jvblx4eI26O/2y9LCbhP0vyDwaKVyNfRPrfOp
V3dG/yQK2NMkbcD/JDh5nsbHJPCQiqaNVMtbxGu7Na9yAnyBVt8v+7RgHkqs
ZzEvHAXfl9dRQ7daywjc/Xu4w8MB857lYTQpPI35btIyFyL/GPjajv77B6i4
D+7vz6KG+OA7s8NO82YLvneyRXOdvkPfWppKW/pa6Gua4qPUaYZ4B3LVNKhR
iHdTUPE2LyPoO+QtXlPKQf3yDqgf+0p6rwWNrbVeEAf/5ij7HVf/An+Ax/XO
1nDw+1gvs4pWwP1g5DPL0a1F/ZgRw3xd4eCnWZa7GrpAb/Wpk8Pde9EPkS9q
s3a/QT+wxlw50v2YL1lUtrS/Dd6zDHHPkFE64uE+n8jirMF7Vm1Oq2ETA/Ux
bN8/9U0b+tZq/iOhZwr9x6Zne6WXYl7c7pBNHaND/1u9liFlXOhz6Znf55z1
eD9eH2zVixNDPPdYnlzp73jfX2lSen9jO+7vhaKUu3Wrka+zwf0TChON8N8b
I+tHp3G+0rUwrZoGnH845ERNRgvOD+x0vVSlhfOrBlerszi4PxrHeWeS5XB/
FO9VWyx1CveHEz+tSiQH94ev90pf/TbMxyHW1sLuvlcE/rGp6/nBVOgX62Ss
WRAIfSnStSfPV6D+mWcMdmb+hL4nT00YtltiHp94HNm4Xwt6tBqXrLo0xiaw
6vigbdGnIQLvYnS4CJ5F/EF5JSPSxxC/to7rfGkN4ufrC54xTIQfYhkJLVlK
iJfvF40u7oJ8XmY/VYnqx3fvruNbHUjvVeuAsb/HPFGPWP56Jxl9zDupuEK6
FOm9YPdEuPrwF/TjHqPwbxan0C8uMcFOM67Qq+jIqyyLi+iX+/VTMZ7NmHfB
V7x2l1PA3y+Y9k+BP96rN9Sylqivgh4GwXejHzKgx7IKv3q75FbEb6tw6YEM
6qM5v7AtxwX56nmLMA0XkC/v4RmnuIx3uF/rp8ePj5D2LaMeDYki7FuUEPFU
w4vw6y6F2V1e6xD/xe39GmlHHhJ4u0bu3DnHTtyfKUmNkVqI31io4YuyNt4P
dWmLB/tJ+0mGgYwFL2k/Mc3hXclD+v/B5M/gwinSfiKZGmpcRNpPHD9T8taS
6n3uhkTWRtJ+4vB9UPQKaT/pcjJt4iHVW72X09ZN2k/y8/87IxWDepfsuX94
nrSfJG2ezpUh7SfCfs4HGe2ot5i/qvMi0n6in1SXK/QO9f6HEuCVdQL1Vijt
juM8hl4Jy7l5djHwP9/0A/ZS0n6fmaa0T9kP/t+RbCunyML3gT2cE3WCiJdl
xerzE4Qe2mZyEr8ToHf0zZFhnlDE+/LY63D7INwX0sVPiwscWgi8t7/wc/8L
8OvJBrhFdcGPmfIfQ+XSMC8SA4uqQyeRX/kAK+5HGPhm0nKydTngo4+6u/ky
wSdP+WqrwwWfiN+iMp68CfN/AWAUTpY=
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4lG0fVVGSDIbPECoRKSRUthCVkJIWSWhSRI2yvkoiKSZJyV7I0ock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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVmk4lWsblQolRIXwaeDILKISp02ZQobjo1Iokp1kCkmKTTJUVE4RopB5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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41G0XVimUbaYYJEu0oBRZIluEIimUIbIrSwwxX2VJY1cZeUmLJXsK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41WsXRYiiVMeYTk6FcC7KLYVEKVEqY3Uy5Zbhml2VDJEUbuYhKiol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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c81fsf1smJS8ZJCIkOstIVUUQkyhWSsiKVkVSEpKSs7HGzZQuV1LEp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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41PsXlr1scVUkt7TcsqRF2aVEtpCUmLK0WJMRpSwp+xpKFG3SXLus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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c81W0bx/E09eT1JMke2ZFQoYxkO5JIwx4ps5L1GCnHzkwykpmEHNJj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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk81OsXHhJppaSyS67pJjcpbUpaGEnJkqSikqUhDFmyNJZbonKVvc0l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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41esWRhkKJQ0u50jahozlIlOFcDslFDuZh2Rs2BIqYyKJXcmUeVaS
QpRIjiGUIVNmom0ssWWK3VH3uX/c37v/8rzP99vfWu/7rrW+RfQMxdiRjYWF
RZ6VheV/fxkBbhWe0Zu1qGlnfIJM2jX/j6di28VL6VMELre9UtZZNo5zrbiT
+8OmCawoXnTPyewTgU/76ub0+NMJ7PE1ck44oYDA2alS8WTtFgIfcRwx5Nab
IPDniaLH6uVfCZz8a/vPN/afgXViDaRP4/7ft707tBxLCNzTZiuRdLODwIM7
bkq7r37Bed1MLbvhKIFT+erm4tVnce5fP7TLrZHAEnyx9fcKxgistRDuK/np
G4FlDvTTFA27CZxil36W+hTny3eu9AVd7yHwqWJ7W3vzGQLv9mokayl0go+1
tmdkCPhbbFB+YDML/tepynbFwuDv3+/zUkPsNYF32OSf1v2OeNLZpZPfoxAv
LHdJZPY5/NYnkUxXdaEPu3qfsy0DfHO3yJ34GQI+w1l/auf59eL3Sr8nhruY
+AyvdNcMthI4QppLWiZlksCHj+qszpxHfbVNmHBOtsP/9Ckfi9Zu5MOVGa/w
MBN+rVPKqZCcR7zb25YERM0/ELh2haMuqhf31bS71Ec24b5h9RTK5ze473Ds
WoBdH+4LFSPZfctH/rbRJRcdbyL/7k7aiGEC8v+kktvz0hPxik7zFDhT4J/g
W3orrziNwMd2VwQqs8G/agangPupSgKXnjXfmHimH/pF/5CLS0R9Zo04vsnZ
VkdgAUantagd6qO7vzPjJVN/9HOkknLJ6I/7m0mlXVfQH+0Htad+zECfciUR
S3k36MOVe8DqMAnxXw04ulUXNhGYu9H/TLor5sOWnRxRjsuYDzF6laGNfQME
zlzWnKFyIz/z2KvrXbXeEDiJLaH0U2QfgRNd5QsfH0f8dtOlF/3n3hOYrjE6
pCOEem2lqEWvBcLPglndLzcVwDedLLhY9Bx8x8M8Ep6ugi8rJemKVzp+Xxqu
Laplhn4R1afmsS7Cf9f9uvWWheC/ljcnGBEL/o60hyr2PJiP20hbvBy8wF8/
crf5mw+FBK7T7hVcXEM995dc/KYnh/pLS3FZ5FND/tsZnkFh2xHfqZuvTc8B
/er7+lf4O33oqTuTGpO/D3ram2wd1FnCvDO3EbqQ9Bt6JuWSbcIDcN/JvdWK
rtno/1vV3fmCU9DrcglVzWAU+Q9pjskWiiD/xyxTZM6TyH+CV5lW8QnxyLyW
FdSHTPlvK7h1IB/zzM8733WLO+I1ZMt/JCfB317jsTh3bvTfak/xrShR+Ou9
xCVCswb/ASuOiwZX36E/TipMJ9/C9wN5c+E8G/F9AXlaTW0z3q+BoVrnXdLo
f/opNqngUcQvE4jdkL8wQuA9kiT+Pm/4z+2jo6WcCf+zN8TNUIug39Mmo+/7
OaDflJS9ja8/9Is0v1abegX6uYzwBRkJQx+HRvqwU9lHzEeK9ND7R6hPntlx
0rusIQJbi9VJ+TojP1dPNoae93PcX2omYjzZRmBqkyGHMxX94OVjd5stEnpU
N1eqR+tAjx23xwYXYzAPU9hHLVaqoO94nfO/C6dq4Me0g+5AyzCBhRg/FSWj
kV+oHc00MiCPwBWVbJdtGuHnktIU5UIZ/AzeamrkMwR9YlMSXvZ5Yt7/zJ4m
WbpCb1cL7n2LzeAXqmHgOMIOfrSuMWtWIej59/qZ5SFb+J1MuirOeQ/5sixT
ozn8nuB9Xv+hUSgP86zzhMyArCb8LJu5F89g2hfeVn0RMJLDvnDgycZWjyDo
W2SmyvBYxnvwZFx3tV0Q8SvVBv3pD7AvWAbEJHLoo58zytRnoisRb/6+1Doa
FX4HGSXmqqhAj2gVyxoJLeilPlFffVUA9SlfVHXkvD3mU5jgiO1JVvR3orrc
MdUEvA8x8tudQhmoh6t0VtcPqn8TOKHxSw0bL74/GN7+z7868P2cr9Lj+tlq
Aj/77WCWfBHzd/ZU2iOe69Dj0K3fJbv4sZ8q+QWtozQ3E3h6qo9lHQfTPsE7
9b1FEH5P9ne9c7OD33GxmYKMu7i/vUekUjIQfpe5CF8ezIffeqbun1u04Peq
yFd7PTPob6eaeP6uKvwO9RKeMwmH35NNYXJOw/C7obLIvUwM8auGFsRCjMsJ
vDNTdSDCAPNUO9WLy+oQ4hlvcKm4QUM8jpj66EYe8B3y7k5aCQbfwHO9YXwR
iHf8+REBfUo+5u3YQvxsIN6XA9dS8uUrwDc9p3iPfyvqYc4qpVjwCfbpk547
6DxjOL/26JJpxR6cPwspDGHE4ZzvztO0fbyoZ4tVm/XlTO/5iorhocumeM9L
rdTY7OdRz2KMp4ULxajXvTEGIQGR4N9saOKzXwr1tPFBzsGaq+A/zBnWPuKM
ed5M/s6nb4B5znGxIeZCB+oppIlt4VsX+mVJe09aUzbmVU/H+0vqc8hfWcI3
NOsy7pss7L1kOIH7RrojZP4qwX1twQ+9Py/hvkOlN9jlsnFfDutOI01N6MEf
s23/qSHowSVvcXgfDXpMnnuV4WYIPWyaTfLWp2I+z+tnPj8eBT0eyXhocRZj
Pm+S/RVYs4L5rOMy85dLF/ITstWePlvLNJ/dj0ornsf8SfIwKp4XQH4SswdH
eAMxfzSsXRQ25eD8YHB4crkl9Fnv1nNkPI7pfXbevimnEv2TSR4tNlVE/v+Q
KAH05FcEfrWhxC9/oYvAklt14ijeqD8Vr2flht2oP6UmG+FLv8Cn6h41u6YA
+4PrzjWnrkDk52B9jD3LGvmNjSpJZxvjvYw6eiFxxxfMu5RruVVhKVUE1rS1
+7M4bJDA4ZckI9KUwMfihYWyozf46FJuaNI/go+s/KtV5v1xj44btYFpfwy6
by3DvD+2qA2nHGXaHx98aHmZyrQ/5rt6nQhl2h9z5KIUbjDtjwsU2jpxpv3x
tVxychEN9b2n5E65HdP++HbZiR7FtD9WNUiy+A0hHmnzB+5NuYhn9cdBvp5M
zLu3lpYWGucQj/ZNVdX2NfbH+RKTXw3i0D895vC1H8PQ/0hD+A/fu+BfdkCj
rbYG/48ZjbKmUjpQT5wOHtUZ0tBffFzgUFdGGYHXGiVE4mowz0T+I8Z//Tvy
l+Unk9k74c9KyOEs/jM4b+Y3jBM2gT/7v44znisiv2wVY+GxRvizN97ghMUk
9BKyTWWTTsZ9uzK8jRa/Mb0PYwIvmyOhly+fxs9j1ZgXfUsTgylMfnx8ofr5
DJMff2jWKsgy+bFi5tMixORHQputer8b7s+7w6tEewM/KL6es12S8ONdZZN9
Rz9TPywX1++MAt9kiT/PB9+t0/wvs1OTrg==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0XFtlKWYvIlKIsLUO8egmlYpQlS/ZWRkIiWiwtyDRNJITIFrLv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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVnk4ldsb/VARyb2VRISrUykaZKxkTIY6lAy5NBxThkLGUi4yhSRDxnKV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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k41HsbRtJJyISEbBUVUkLWaFOSpddWCckWmWxliUang5hkyb4mFJqS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k81OsXlltJ1hQpU2SLZB1hKoQsbbIkbUqUSIkoQsqkVC51SV3clDBX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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41G0bnRhLdpWkJiRLX5ElJVowRPTKUsgWIcJovIriVUSyldJir5C1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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41F0bnuyya0ESoRUlJUQoZauod3xly5ahadGiRZtEWRLZ5S1ZypZ9
GWUZWwZpkMkWIksMQi/JK8l3fX98v9tfrvs6Z85zP89z3885P+udLvxF4SCR
SNuWkUj/+6tVUHetLE5Ev0kspjChZ0Tv//i5+wkzvegBAq87LJf4m3eCwLET
y+/LazQQePjED4aO8RCBP9K/tGWWjxJ4p6StnqB1H4FpQbMFM5RJAtvM8XlX
p+cR+OfnsmxJ6WYC+w4yxtgMNoGLtyvK0mUQb/wUbbyaNEZgzlBNlY3pX5CP
PWv+aSji2VmeyRwefkXgoddOKwx2vCOwuLrgy5WLyN9cLU4wPXmcwAdGL9pu
Ugc/qQrJ58zP4EfVau7IGvlK4NIfH1RlzcBPJ/H29Gx6L4E9842cB5+DX8KN
zL3itBTUI1d6jYBlDYHnZmbJonv6CdxzM0VlggO/F+wUlmk/VEZgn9DE6ARK
J4EPrzSjB6agn/cDpTjvOlYTWEZ0rHzHJOrXqO1RKX8f5x/THJQrVMgisMLk
SPIOPiaB889uLq9IRP4iYfNvzPOR/4LSeZ2P5z4T+I/PsC/5LM4vMqHqWvBB
D2Wrn5BLQz4Q2P721s9HD6DejRvzIvy2DRN4r4bRnhR96PnUoW0bzgmCj8HR
CXLRjW8Ebtc3ZRe+7yAws7GWdIYb9XF6N8rLtIbec3xaEqxtoL+s013zLQnQ
+297Hau+VOj9nmLtzkRj5GcaUqM3r1hI4KjdOrcqFz4S+KtRQ16sEuqlKX/z
8Tt19EPphthKqyV6aR0RE8xog17ajNrctl6DXpZftfagHoFeWLOvh9f8i/xm
DgmTwx+VEzip4q0Mz/EuArt6x4dXT2N/VKhdFZWnAvWeNS0yomF/kYuUqoww
+GXF1qcGLJYSWOhRRt8h6icCO8iMNwcY4/z5eSPWYjb8OHdp+cRD00ECZzx1
u0i1gh+HKTs2+Giifo6HTSXiItCP7CSG3d336AffIie5Wwv8zlV6PXPtf438
hEnRTJdW+G+t5Wj2JujlhxD70EQZ/LSHy+n7bQb4K+u8dJHPqiJwc+059m1/
+F2n9Igt95L+3RwNi+weRf/ILjua9/mjf0mtHKHLrNC/PcNv/7n0D+LZLn7K
LdqMfthsp7UKsNEPqR9U+n5pxPt6VJmdfr2EwNsUJLvctaH/qd4XI7Qq1Nfi
ktexvdfhvz+XzrhMKMF/ps20cQEH+C9+ucKmZ8NYz067d3hDC/xnw6NiYnse
+o46o8J48LuHwK9G9ZTiosHXdjrJJ+ZqGoFTWdIXStm1BO7KiHKe2Y153aWv
Fj1pifq4N5K1uevqCCx6zMM1qxz7fShiyeQB5NtUs7OsT7UJ99lcL7fyUeSn
rBq+QOXCfGHpGqs6RCA/+4+pk3tqkd93x1VaxnPdmLc0qV/HTyC/Sw/+Uhxy
LSBwyFy7EOdjFu6rMsmkkwLQM8n6+7WdW8A/KXvqLOMU8pU70hy8ZRvyvR9R
z6x3xP7Rccsx3t3Yr7pO/UFEQT3uqypTj5R++E02pK3hVwb0//VKgZJGUDvm
eUJqv/tZ1K9A5LCPWiX4dxWILyveBf4cB0XWl1ZCz5zMKcPT2eDj1jhB9p18
S+Dd6Ytv+RMx/+zk4ubFw1E/7UZqQWkQ7vMIdrHy1T7kLyKv9Vu0Cfkz9RSi
fraA78EDH+qez6DfXutJ3Jl56Df1dDdv5RHoWaFSuUhdGut03aG3FU7Qg79s
iOIIHfVrWefhmNmB+pX5FcRm3mgjcPmLQEcfFtbfp05MVsdjnTMv6hZ5BOuX
g07cKhbBetWJ9F0tYVi37eLlt1KFn19fva5sR0e+uz/RFR4+hZ/3cVMXYsyQ
XzCj1t9DCvltYxlyNFKQ3xYJPeeWQuTn8Mu8b+oL4k9xBp2WPgh+8fZHI/Xz
sd6RWdQ+QIF+YslJzLLj4DfTG6IpaYp5Hn3LkHwtEfq5vy/ktlYK5rnQj9ev
zE2gh066erG3KO5XSs63Qa5xnBevHS2gJAt/biKr9otaQl8eq4+5kp7hvNDs
yq+erqkEvthkYtUwi/nMezdBVTgeenbbaufLXHIf+FeGhD5Jw31AveJ7W94b
90Fclb1GayzinY7jLPD4ifvgewPteGoY4ok6iMWk2SPe1qokiZBxxNMcEODm
dcJ9kBI76uWtg/mj5rEsoHI74nVMFq1bI16E+g81lPpboX8Fbp1uN8vRv/B2
Rji3FPq3z5G9docK+qe56pGOuXUL5hPjlaf2hSX19ucQn/4H8376JN1gKgp8
5t6VvNOKw7w/tjurpVoIfo43HCtpPwI/i85SBLwNkX9/oUhOMhPvh0gj7sHr
Nkvm2XC0iYUR+MqyLqvdyIY+LO5p/W76Dr3p+oxYu7ZBH8bNlO7HAeAbSWen
vWrLIPC1CIeKuUHMU4nV79Ze+YP4ow/5Y4UCUc+0qcSrMQ7w60zoE9bJJfNJ
wmK6vmYB8yljY98jWiH8+UfsjeEKQ/j3wJPtBpNbsV6a7hjNYwT/JmUqDrUu
gI+n/gTjwxI+I46upb024MOnRQtTYIGPZ2jv7zXCmB/jC9IGRQzE+/tO4C7r
LeCzMX/xXz0K1uVrzJJlerAeSTpsscDG/ekkk3JF3hx6GSpLdTFPhl92URr5
apa8n8xbgkucS+GXiw94R5/awS9c23cpmujCLwaNNOsYEn5fIZAZuRCC76WS
ldIdb2LwvnvBv2VEtwj6olVX3Al2wP0UXFbSqagPfdjeubWzaomfPavyHgrP
g1+JrHLV2yjwY/bnC5k6gd/P5Qf7uL4h3kKPkS7TA35W7HyY+vMk/Cx7nsGi
aCCedN2AkJfyG/RTvF3SKBHv2SaG3B41M/TbQZunT70N7/EET5qKmzvij2r1
7FtmjvfWtMuZkhXt4GvRacFIjsf+oIFdZvoMfE8een/s+Co1zGuv2kjVgMvg
m6uyX/20ci6Bc3zLW8JeQe97PVpdHIKgn7krbu7cEdCPpHZDa7o/vseGri8o
plvBvys0AwzGT4EvV8Xal0Jj4HsnXeMNvx/qK95XcrLzMuqb67fCgk8HfOeb
/77Ak4DvhYFLfvMqaqhvT/RZEzYX6nu+901QSjDe48uolZ25nDhPMjeHuVkd
+nMg3U3zsYD+RBfUtaISwJex8eW54teob/VFU36hLahv2HTh5q1Xcb6E/tcz
67pzCKwc1rP4Sw71FU43q5I2Rn0tv+zMnRbHvIi12F7f7w5/cvAwFLyn4U8N
LcHm3BnkJ9F5g5qzDvFz4mTr9ovhe6P6J21t4xjujw16Q84lTzFfMv1znBs9
8f+VP7pRyhflwIe+MfFkyH/Ax2/QvmREGvXWTeUP9OHu0vsvcvhpHA==
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV2k4lAsbtuRYJilKoQURkuXYVZaUUpaYkC0pyUSIEB0iohBpki1rdg41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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41F0bHr2VvZKliFL2bUTRUEaYEg1ZK9m3SAilKKGIJG2WCplESSlL
yFLIvq9FpGiTFCle68h7fX98v3v+muu+fs8557nv53nuc2aj0zEz1yUkEonM
RiL97zfdR4urJ23lznN/hQrc8n9q/x+313VbPXXsIfDjjEkD44OjBN7CqOug
63YRWNKtf2c9Y4TAxTkLvjE5Hwmc+pTpc97gF4H7m3V87XkLCTzckqLOMYr9
brY5t+ds+kHgDkFvxWCTQQKb9AXoFd7Ffmoyj0xz9DMIfN479N+CmRoCfxMd
P9H8F/kI9ApGD0hhPZX8fVm1VgmBR76lmloagP+Y5iNj2l7wf35RokP2FvIN
7PxyMfgT+Pv8EZZSW0S+6VdJNNdwFv5P6YOP1zwl8A1xWz4ztmYCf+B5sORF
6lcCi/2JNTItgh4N5MjIDPP34CNX7W5yFPtLzVA1OLnzCKzV1Ukhx7cT2C/+
KyVv7zCBj9ZyPvLc9A31bC6rOGD1ncDRHgmTTt1fCDykvyXsWDn65cegNm2P
KPQq9Cp2rVKFXgZs5U4MymsCx6/0mjl8CHxUEi30DY8OEPiOWGKpQir4GHPd
dzBXQH3DF5P+UR9AfXvKOJooY6ivHVtiyogS1vuYbTaJoxcTeHXfOo2BS90E
9s/mzLMYBJ+FQLWPP/fie9QGNeNVpfius5C+2L4NfAs4xmSadcA3KfdgsXE3
+uNff8/NWXzgy1s0TVUNQX8sNRX2Zk9GvoeuWBlNuT8ksPs9h3whZi2BpwsN
qcr3P0GfFEaMb+0Yge8qVWbfuldJYN03knT3IOiradc/X86iLyXAMT6CHfrS
ijtn2cqhr7X+OHl7L/QtkDcMKdqG9Yyw8ZbvUkUEnqw78a6J8YbAl0hv7u8y
gX7bSu7e+tncS+B8Td/KruPIv8zI/s4heh2B145rlvX2gK/qwS0U/nTE21MT
pNwSqgncdXO4dlIA+bbW8nW0BiPfPQFNdlbe2QQuFVgz4KXQAj6LPTKvaUME
bmP74+Jdj/l+GK7Ox7YL+785HSr21gf7m66V4qY75RL4SP22HK9lmL9qi1BP
agXmbeoAo/WvOuZxoCwu9REd38nJ4RQmL+YxZGLvZOM5+MPQaokLhl/QX7ST
p3xJ5v0EdntnJDdNQX7J8ctf+pFQL5LTO8uic6jXWa3hrsEdqNegYxwvQ7cP
9Zxu4NBmQP/57rQvuv3QX8yRJyxTD/r47yjM1/PF+R/1lZ6ctIQ+Ph0OaT8m
2+DvnXMihwvAvyC5IuI5i18ZHk9pcGTxq4+zMr88WPyKm5x1V53Fr+Ltb4Wl
s/jV+oIRzTkRzK8z21QPN4tfufNzjNG14FdGV2vnWmyhr5c1M498EPMkrzzV
58NyH52J3iftdxDztKbvOa2GHfPb8YqXeZ0D/Wwi5j/BthHrb1MmDnu24T4S
2P2q5lwp8l2zeF1OMRL5eu+3XTbP1UngWc5A8ekU6BFrRumV3gI9Ruu9siv9
sT7cSdJIIgTrj7Yyf11gQ7+PxRwZXE37DL2amhk2Zqh/s+czUXfZBtzfjsMj
1kzEX+fov6LyBOf9Pu4Za8TdQWDpZA2jmBLUd9bj9oSCBuZPuElm0KsP+cTe
CaMMssz3aKKUyWuW+X6hIxrJ4YX5zl/+Pt9AHvO9usxmTJ1lvvsZc3OODdh/
QoX32Sld7F8TIieSxtK/ub97HQUN0b9qXMJV/h/Rv/O71/6qeIz+TKL+nuCx
Az8hw8k+BhPnu0/SC02SUC8viWz3ru2ol2Vr1sYiT+j36UZWC6UU9cretbJU
Ywvy7270oEzUob/U88jPxbNRL48mHUf5qSoC88l+1S18iPtohQVTWDgBfKey
vsX0dGeifs7cPFa69QSO2PFQr8AH9Q5f/n7SVonFH8oLh1JVmgjsqpl0ZFwR
/qXd55RvZoH53Mcv7KOdj/uBlKBUS/fAfpI1oqFmr3E/fBr1DWpUxPmZqhzu
X10Q/52eamiwEfmKMi7aO9ggfsnKuyv8qYhfOHTvWqhOI/xMZiYz4x7qQRPb
dJ7ERL7nuvpWciXBP/2jnq+jGOG7x5Lo0ZAB8AkciBkZOo3z3hpV5cp+gz+o
tom/GL6J+iVwikxztiF+mabyiU+SuN+LHjO3Ups+EPhOwI+TlrdQv9PBe+bn
6KhfY/D12Qd10M+i9Rr9pyT0iJ/XCeM6ivOsXvoOvGpAfHFN/Prt0ojfEDO5
ejlLffoZ7TK6bxFvatNUtF0Z8fyXBedmnRD/+djthNs7UB9Xya54JS/Em1y4
/NVmM+IDt30uSGFHPxVc1RdeFEA/CYseoz3xg/7HFn6dPDD3lsCRdb/cmsWw
32ZrwSOHufH+5nE12LQ/A/tdDQ6aDc2B/w+YbD3zIRTv7+22h52j/KD3BmOz
2CQy/GG5poWNbx78oSg9Vck6Dv6wMojWKH0J/lAvW3014C78Qef1nyg7dcz3
q7MOrUsr0B+Skymll/PB55lGlq1zBubbRXz0/Kgf5nu/Wvq1k3eQb0p84LT7
Krw3LZnjwZ1Z6MdSQfaAaj+cx/43uIE8hPOonmEXZ9srcB9LNf6T+QnvjwNP
xizXHcB5XPxnuZN98zGv18clgm7Dz9y+l3V5rgFfeT/O9se86Ide6ihPXxDO
P1rFlbKjCfl+08zdLRuBfOV/N+nR+hBfLpmrTg19ReAfSfwJFoOop1CJirJ8
KPL1iipJUVqH+yShvoND6zP6ZSrxs3mXGOr1UedLwaal6BdBOe4EqXTo3x7r
OfyaxV8l0tbZ38nEfN4wr3soLoJ5KJpXlZ4+AP498z+qRHXBJ2/9hmeLvPCr
sOm43kvh8Cu7ljwtvvW4Pyg++kHa5Xjf6PP+JauVIN/AOIUlz/ZAD0MVAbez
R5CvaNu++/d18f+yuFrU3K4a79unelKJTgHo586XK4w6a6CPZzSnUdgM7rvy
9XUTpofA75EQ13u5nSz8fG7rnZIDv6m2KhFGHPg1vl8dzeQGvxq6QajyVvhx
K0101SAn/ECAbaPZ0xPvCLwx0rE7hAR+Q74Ra4dvlhF4d4YIxf4e3r+KWeOq
IhXIr2UqzVh2EX6cs6RD7t4C3ocPosbfd6dh//OGZ5xMIx4gf3bxyhRD/N/i
j6BEv72M90dlRl5WK8v8bJlx1ba2wfwEevAs64zE/Fh78blUcmB+FChZ96VV
oW/BjpLpLAfk75w3FWxqi35rdmkrpZ5DfNjvLl7FDYgfSbhuqjED/z25Vt0+
Kxl+mREk0mJVjn46faxT6J08+mmFZUqCvQv4kN7uO3HmA/qpMlHlkMgevA/L
HQK86X/QT9ERaVwu5TiPnF77LOkKzrOdVd+drvdB+z/EdX9W
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41F0btmTfUpEQjSUTSUXUK1lDRZZQtikUSs2IKclWqCwtXtRLI0lK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41PsbtUUoS7K1INGIhMqSuOSKdEVXSNn30iq3JMkS0YZIGUvcEKpJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41GsblkpRjoRsR8lSlqNQ0YaRVNaKKELKkpphskS2ibLMZyoNPllK
JQ5DyTr2slUM49AeUZIloaJSceVc3x/fe/vLdV9+7/Pcz3s/z/0+rD5Gt/EQ
FBAQWDdPQOB/P3eyaEPTHDFKVJm/eUxBh9H/cXpyCSXCa5hge/0JxvGPgwT/
saBx83DtB4K7kw9E/hjtJ9hCWKZ8fsMYwSILLcz3RiK+YEpNMtUA8c2ETA8q
7BwimCrm8N5YCfHtHV/8dDo0QLD/444t+1ePEiwns729e6yLYOtaJ2N67zjB
8gODNMdd9QQ/s9hyriihh2AXY/Fjh0M/EXz35mCfgEohwdMDrTZ5Y3yC4xJz
blwtxH3ERS+5+kZxhGDjhozK2p/vCHYaCzfPZIOPpvUL66GsBwT/VL0Seb21
j+DntNaIERPwmUpxYdZXcQlen3dsxJ/xlOAZyVTh3+yPBOsoa9qp6fUSHN7P
F8+7jHhbQmItX2jkE3yLGeSYG9BCcAFnULZb6z3BUmbft/2IgJ4qzPPU7/qP
Ca6oE30RzYNeWiaRHeHt6AduRqOMxhucf+cvz1UN+IfgXbOSF0qDof/DQP4a
Vh36YxtvdidTG/fty1PxHh7FfT+u1Qo4OfiW4JuMmLV2c+qd4BhSdxmh3l6H
Ye+qGNSbHW3geW0z6m0eNWLwToOvp8RAa8w51LvVPqPDUxj5n7iGcPdsRL1V
Obn8d+7QO1vTY1BhTTP0KwsZ/dMN31v2KiqXGeL757LqictNeARLXzQUTcoB
v/0yH+R+TqP/x+5mcajXn4F/Iosaa4ffSz1QKOsrekUwTcm6eg8d+U7YuZe0
sx8RnKk1OSG+CPzMBNRza2Lxvb8MM8xtw0OCgxgH3Perod+TyjM8U1bg/lvq
8oa+LqkhuFM8JGQT9yXBkpMdnmcXIn7fieYzKm6YNxmr2kqx49Df6squ/F9X
cP+M0kUGQc2Yn7CZVMo+U+SvKOHNxF7G/BQuO2uzzAnz47FbWvhoMOanozV0
OKgB89MuZazRfg3x/E7QP4zP5hBsSE+/75+J+1D80XShgo77iPojZLHQOOpr
WB76NMa1Dn5X0+fla/KaYO2Tux0CtyEf18TyR09lOcGn9+VWSlhBb4ZSm3XP
Kug98mTaOvE7/NDYyqhMrQ/5vfjmlsYr4YdCqr57OIfgh7UfWTQDP+Tv5jzp
n7+tiOAm0aR5XXzMb2h7aX/q35jfO4G1ghdomF8NxzMK0++g35hIWoJ5G/wi
lrb67UYe+q3vZWuTdj/mbw9zR1rXduQ7w/pLgeeMfL+WaqrzJpFPMjh36b46
vBft33rGsxOgr/ttccXjutDXwOLDfqM5fmEvY3oqdif8IrWyMOMIC37xzcf4
qus2zGPyU0GJIT/wPZZf0FH3X/jFwBKdKg/ZOe/D8cUSfktRr69eOq34PPRx
HnWj+HqjnwwWSL+otkI/1TS0KE3OA183uQHqI797OO/WNnSZBf0lnYzdfO8h
vmjOVKaYfCPer6TJ8H1S8M817224jRzEf/C7XzdTPptgiRhvo0ChJvi3+Pfe
xeU4f2W5vEZbKs6LNictZk7lQu/CwMkFEfAb5/EfM5+nUV9Yv82K+ZfBV7t9
jLW7Bu8l+8w5xZEuzHv8tP2koAHyfY+eVVdjYV4+zR82cV+LeZGoEVzSIIR5
odgf7mJf6AZ/K/Xf6qKIl/P5js1W1VqCU/bTKA6X4KcLrQbydx0F3/QrWR2R
DvD7uiSqXfE56B0ibirQqIzvNawqdEJrWwkWLFXtFYlA/0bazchKj6J/lxje
ybqkAb/onZkRurUJfMNl57UcPFFBcNoGpySxLtT/K9bC9H4I6mdXjJl78+HH
j0IC+QNi4Nfr2aKS9biN4CPF4yJyspjnFK/Bwqhl4Pdj0tkiPhr9oDjDiHO+
CX6uVM1XLcrwzzx2Kff2a+jrsIurJfoZ+uqmVYfKbMB5zb5gZnsZ6nP9M0d3
o/Rz9K/9Pxb5N1DfgeQtiwf7XuA9q9527fANzOsyxd921h6d8IsD9XLXxeFP
8rmfj3aGQw/zeAM7hU+oN/UPzfgyGejx2fL+G2cd8GWrle7gfwDfRE6OZAEF
fLd2XJDsqwRfaZ5lRbMJ+JamGYp/t5qzTxfqH9se9wT+EDl1ULAH/iKqKmRt
Io77UxbhPBuKBp9NGyW96uvuEKy/qeVVexX6T00nUJ3FQL3pZ1QHFMdR78vc
r/zYlajXc3V4UpMu4tcOPNqedx/1ZmaYTixfhXo9Ms2lwrJRb0LJDV9eI+pl
Xfi4UYmNeoss7WfLW6FPlF7B6i4a9FEKXq+7+g78eOai/JfL3xB/MEC75z/N
6P+DUdGxXDp+v9zuaz1dHPMcuMgh+aoW+p++X1c+dAPuZ/jskQNyurifvrAn
hhts57y/AmaeK+oQb5bVFt8WgHihTSVmv3bA/zLKKWbpz+B/MnsLn6Tm43vG
VqaPiRb8NvzrGNelE/NlarJ4ip+E+z/oJfswSzMP9WRk/eWXAD/SXjMpEpkN
P6J4nh2dWIB88xjPDtWfxP5V603bpETFvO/9JMKIZqPf2kP7vVxeod/WutoZ
V8zxYwO3MMW20/Dj65kjEsoroAdnTOSL6jT6yzY7uSiqE368vJHDZq9CPOFr
D+JKZ6sIbtIXXvdqAP3TGDB73z4T/ZPhGeU9cRD901oY3MxciP5RGRdc1ZMC
PU/Eme9eyAOfbu5XF48J9LvKmoIkHVfw+WahmeZxtIRg6hb7V1mVyLeyK/rQ
Jyfkq7ZVC1r5GP06pS5VpMBD/8TsXXbOsgfzUkLVmLWVQj3rT111/DiN/bXg
1L4Klw/gm2hFoadsBV8XVVum1xbwFTOzdWyagh4+juVnRhjQY3qmNSiOAj4F
S65JMHWwT7R26ZlJX0e/TORt/HXpHfqT5W7P0bNAPwjfq14xHYD8pToxbzcM
4e/reE9bZTlD7Hei3pRvVBfsd4NvyrVvTWC/C7K+u7KnAXoldj2bnR+P+r1j
WA7au7Hf3b6hY38+AflF9uopjVZgPiLyfxe2iWG/W9V5qtL3y5z/Z9jdlOPU
4v4V1Vx9xjLw/4wes1zlYgfwK9zRfU9aBPwXVecIjjKh/9UAH7oVFfpbRxYJ
XzdCfJ/fSx94D8Pf6U9jVaNVUN9F87d3Mqwx/3oWVUdn/0Z9UiFhrfKPsK9N
pM+7NnoT+qSOb04WUIQ+tur8tOFInA+OYThs4hYQPOkVsU+AjfdfUMAt1fTb
nPfh0/wrE6bgt5CWoN/X/4bgOp/X/v1z9kn6zjKfCQnwKw66nxA6i320u3NV
nVkx6lP7ss7iRhrOr31aucapCfvkR5OVNVY28NNJfm4e5c07o38BbT2eZw==

     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lekbx49tSjWRUxMpFZHJlpBwBtFChY4yLahUEsppkq1EZU2orKVw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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk81F8bHS0IIUtliew/lZQmVLZIWbIkWySRVMYaWiZRRikamlJZKhLq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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJzt0lswnGccx/FdlqnWKRoqaWVsShwmDslkSUTjNIQIGdoKSUMny1aibTqW
icMQLRWDkKAmQUlEVFoxkaZEKq3DxmSWWFXLOm0SGus4aELMJKLTi/L/Pbe9
dfXO7+I/n/nO8/KPnwqMUONwOLZcDuff7+i1YonpTT1XW+Ed48TXLS7/bYus
3yQ5vMeru98+dOeWm7OrW6XIe+L83dXVnX0kKiqxcu1eW/Jgwijn0eruaXq6
N7dm7f6XKXGZ3uLavf1KW8tz4j/dIEgaJb78mL/MhPhdIV4zHxG/u/Bh5AXi
HyvovC8g/vNPDxueJ37ou3eHBhbW7q/wSgslxP9Sd2C+mfiRg0dfUF8rVbTL
l/jLvF/TMogfs+eGrxXx8zvE92i/TuUb9nPEn5600VMQXxglS5ER/4eVgyrq
Z37gsvkQ8W1L3A2ziS/i7z9oS/zG3NrH1PeJWS5XEd/H5YxrF/E1DbQ3SIkv
lrXMUD9MKMvwo++fbl6ZSXy7LCOf7cSXe6R1U/+PoqK3p4gftCMj/E/iVy3O
uHYQv1doPUX9nNNG1v7ET0gt35NF/JEJfWMb4oeEOiiob/i+rHaC+MqxFH43
8ceVy2HtxDeNE0xTv93KfYL2H3EIeU37ubJhCe13dJuWU3/WTNN1kvji6ZCr
1O/6O/Iu9UVbpdBf8uyQOu2fb9huRPsH8/3GqG/e2ddLfY/bSk3qNyisT1G/
PsGgkPr7vBbA37W3b4n2jwsuaVP/nPOwgvpvbo0Hv/yTPhPqL5mYpVHfLvBG
BfWvz46CX31Ze5n6vKRoferfm/FQUr/atgz89/4q3kh9rk1dIvXLqjpLqV+g
mgRfo+ToS+qHJ4/pUj9cYDxE/Y7RXPCdOwKMqR+YsOkM9asvWl+hfvHmcfBv
VWi9on7rtW/1qF+X8wL83VqF4F/X6DGifs9YYxL1Q5WOl6nf6jQB/k+3WqH/
To0n+E3S78HvP58P/qvYL96hvt+KdzL13T+/BP6zNux3kz0Cf1kYBv5FZTP4
3NwC8OVSO/B5tfrgqzlGg5+8gP7G1B7wN+l9DP5I6M/gD1uiH57vDb4iwAJ8
6dLX4EtH0D+g0w/+nCAE/KidDeCrAtB3KN0HfrDTFvB1KxLB959E39OpD/yB
zMPgGwzWgX/SDX1RqTv4cU/44O+2SwbfR4X+2AL6XzkEgz/cXg++tjf6EWpu
4PueMAXfyyoJ/JRx9E/8iP5n89j/8iT6YZ7oF1Wh/xYX++fz0Fdn/OYH6Fvo
YP/MBfRjvJj/LwL9mlbsd4hEX8D4pY3o66ihH/wN+hqM/2EK+p5D6AfFo89n
/Lhm9JM00c/LQH8H41fGop/ejX52NPpWjH/2d/TreegbpqNvyvht8egf6EXf
JhZ9c8ZPaUK/WAP9oLPoWzK+/DT6aT3oz4nRt2T8+0z/LNMvZPr5jJ/B9Bsw
/RpM/zbGd2f6jzP9mkz/NsYPiEN/kel3iUHfgvHVGd+S8W8z/WaM/5DxRXL0
z6376/66v+6v+//L/wf4QM+g
     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4ldsb5RAqSRJOhiiRylQKDaa6V4ZCJQpFAxIHlVIUusmslLkic4aE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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41VsXx005piJD6CYHdUhFoULJcEgJlaFOZIgkQ6W65Wa6pHTrlekx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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41FEbHTKfNMlSSrJFiiRriLSRPQlFilJSYwuJspRCRagsWRPJTtRY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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lG0bxkkKUbJrkYayxMheaFHxRhRK4m0lrxSyJCIq5Q157RGtlkE1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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3c81W0fNjISOeitjCTKTigSJWmRVcYxnkN1ToVIHiMkW1biTSipbEpG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNVmk4le0apSTbkKQSX4aEUqG2IkX4EnHl29oUZSpDoihCSdGnSJIkxSlD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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81dkbx68kWSKGMJWGMMIY23UjsjRaqCypbnETk8pSM6XoIiQiN40a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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k41WsXJZUpYx1kaNRoCLlRxnMRqTQYSklCZQpFOfiKEKKcTA0HiVKG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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41PsXx6dFpWRNiVAiS4VkGVEoJVshshQtVKJLUlehEpKIJKTIEoWZ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3s41FsbVbmTolDI9SBFJFHMIEoXl3QxqUQUjUIlpYbSxVGjEioqIomk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNlnk41G0Xx4dI0fbQNqmmslSyhBYkJJJUj2yZGEKb3ugpUpZIIZE92Slr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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81OsXxydbRFS2W0r4hVSGkK7cFhWiYnIRU/ip/BqJUkkxljtXsuWm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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41ekbxg9tJ0N2DlkLLbYSozCEJJSRsaSsiSSRtBwch8QkpTBZki3K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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk81OsXFlLaCFHqUqSyNQhXi6gsZSmlUZZCmRbdi0pDNBFFlP3mihAT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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41G0Xx8eSlEyph6KotFGZHo2lVI+UXoZI2QpT2SKlVA+FLF2FshQS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl2k4lG0bxyllmRZJokSW6skyUaESniIjLaQQUQpZCtGTikeWLFlfWUIo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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk4FNobJromiRsZe8hSkiLCtUSWylaEqJChUdlSKiJKQkWJMkrIdist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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk8FFobx4du0SBUSpIsabOmLMnIfqUkpiwlucKtkLhFabMrl3qTpCjS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHk41G0btbtiEplPtjZJIiVRkpAkoSylkpQlS/Y3VJQoW3pD2TIkCuG1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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81VsXxtGgZIgkQkiZEklFF/FKdYpMmZJbdKWMmTIPhXMNkSGEU+ro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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k8lO0ankgpx1L6iogw6ROVSKQs7ZqalEGlIZI5yXayFtKgFS2URJZk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3c81X0bx4+VaKDuh6zKyooUDVTmCQelPKGU2TCKKLKSEqWorCh32e5k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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNWHs41GsXFeWWW3IaByXkkmvKJZWIo1KphKKUEknSSc7UHCGp6HNLU0IR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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNV3k4FHobHWkslSVSKVtEkpSEoe7IFolLUV1qkLKkupaUJV1iJNmLbImK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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lG8XxyeVIsKPUpFERZKUlMqWVpWlsb22EIYoISKDkJKELIkWaURk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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81OsXx5GRrUQJNzeJclMkRW6yhlKpLCXlSmS5yNAitwyKbCFlKFKy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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3c4lm0fx42iQXiQUqo7ykr2qvC0zGSVUEa3SkNIwya9KpUi0S0ke9wh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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk4lWsXxrVpEFtfKCRNx5Tj7NqH0MBOgyIaxEmkECrTNhxzpZIhSYVj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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81dkbx68lRKioUVKyFJNSyVKq6yoKTbJUKEuSbP1IJduMtULm2rpM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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81OsXx8dSyc6NUEnUve2EKKXshBCTcDXaLJEiRSqUNapBolSuGnuX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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lV0XxkkoUkl600ujeSoydSmFOoaDkLFIQrxKJektkVBkyIcixVER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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81OsXx5FbUpeyVEKSXFxF/RBKZSlDU1IZlQhJRglFSaiuJbIlrrV7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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41N0bxifqzZKIEipLVJRsEyplC22TsrWqiEhk0CZkCSkKWV+ltyzJ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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk81OsXx0mytNJNKTvdGyIqXaQGaZGubKFRcSvJFj/EoDRSJCIloStr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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41O0ax8d6NKrRlN6XIspRESoiqVTEpFS0EbKUmmqSvHinyJLwUspS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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNmHk41GsbxwenkkwkUoqOkaE6aLFXqJAtshxOyVIoMSpbogYtSkhZUpac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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k4lV0Xxk1RhreiJJSiopwMUWhwDClFSfIZvhCFjCGlgRAyZTg4KpQi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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k81d0Wxg+OECXJnISKaDJliA4ylAazpKjIkIxliluSJMNboRJdOWSq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     "]]}, 
   {GrayLevel[0], PointSize[0.0005], PointBox[CompressedData["
1:eJxNl3k41Nsfx60tfqUxlropXbJFtNFGyFJUg0pRkqUhosRNQt0QaTMNUZGt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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{3.4, 0},
  ImageSize->{684., Automatic},
  PlotRange->{{3.4, 4.}, {0., 0.9999876051648642}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.563244891964316*^9, 3.563245215633622*^9, 3.5632458326183987`*^9, {
   3.5632703487239656`*^9, 3.5632703782886143`*^9}},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Plot", " ", "to", " ", "print"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"tmp", "=", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"fMaplist", "[", 
        RowBox[{"r", ",", ".1", ",", "300", ",", "600"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", "2.9", ",", "4.0", ",", ".001"}], "}"}]}], "]"}], 
     ",", 
     RowBox[{"PlotStyle", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"Black", ",", 
         RowBox[{"PointSize", "[", ".001", "]"}]}], "}"}], "}"}]}], ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<r\>\"", ",", "\"\<x\>\""}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"LabelStyle", "\[Rule]", "18"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.563270504504134*^9, 3.563270519375622*^9}, {
  3.563306299076848*^9, 3.5633063087514687`*^9}, {3.563306420276258*^9, 
  3.563306452706141*^9}, {3.563310281680421*^9, 3.563310283356094*^9}, {
  3.5633151571515493`*^9, 3.563315158622602*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyUsKRgAYheGPiXXIlJEFsANlCeofK4uT5DJyS3ZhD6aiTM4S/t4zOb09
flHmP9fMIsfs+fidl9ZVFoTXmXx9SDfSu3QrvUl30qt0L71ID9Kz9Cg94TiO
4ziO4ziO4ziO43/pN0B0WfE=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztybsJwgAYAOHfIIpjJGBpaR1ncAQhENK4gF0myI4WggREfMS3WFh4A1hd
dRxfuljOiyQiJr2IT8umXeXT4WyT1tW4W+ffH2W/v4UP4C28D9/BE/ge/sIf
8E/8Ef/An/B3/Bl/w3f4K/6i67qu67qu67qu67qu/8XfEiGvdA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztySEKwgAYQOFfi7cQPIB50XWbRxDMnmLHWPYQdpPBMESGosE5UWQMDNrE
YHkXsLz0+HiD6Xwy60bEsBPxbd4sVuOkl66rZdZ/n0c/v+AN/IQLuIW3cAPv
4Adcwnd4D9/gA3yFj3ANn+CL3+/3+/1+v9/v9/v9fr//L/8D19ScGg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyS8KwgAYQPFPYSgizD/BsiGDIQtaTJr0AhaT0Q3MJk/qFbyBbUkMBt8B
ll56PH5Fcz/f+hGx6UV8+zw1k8t+cHxfk8eifR1+v6v/v4Vv4YFf4xN8hR/i
V/gRvsSP8QU+xS/xU3yOn+Ez/FzXdV3XdV3XdV3XdV3vxD9z2I8D
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyb0KggAYRuHPCDSiMvoFi0hoaDAoHIKIuobGxsipoRvrrnRsbAlBpMHB
cwnxTofDs7w9L0nDzCLH7FfvNbveD+453T72fp6dqj/u6v+Gx/APfAP/wtfw
Ar6CO/gQ38Qv8C5+jm/hA3wbP8V38BN8Fz/G9/AjvI8f4vv4gVwul8vlcrlc
LpfL5XL5n3oJbmsToQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztybEKQXEYQPGPFCmjyXQHgyKR9c9VShkMTDYpg4nySB7I6AU8AcsdDDIY
nDzCmU6/TrY7rvbliOiVIj5N9dvllKp58Siutdd98vX5+esKfIAb8BZuwhu4
Ba/hDF7CbXgBd+A53IVncB+ewgM4h4fwGB7Bye/3+/1+v9/v9/v9fr/f//e/
AWtxMQ4=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztySEKwgAcRvH/hLHoAUyLhl1gC/MMHkEY2ATzYEeQdbvVJhgMFkEQNrTK
RBQMM1hsg2Ew+K7glx6Pnz+aDJOOmQWO2afTcf5MY2+QhevIaW7x9/vR78/g
Pfgc3oUv4C58CW/wK/wbv8G/8Ft8jd/hH/g9/o4/4K/4An/Bl/gKf8Sf8Se5
XC6Xy+VyuVwul8vl8j/xFimI0pM=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyTEKQQEcx/E/vTJYLAal9CLegkieMjyyKGV4g9GgLG+xKhfgCjiAyQHM
L0dwAi5gU5QMBt8DmH7Tt28fd7YI50kzqybMPj2cR/6mn+odt6fV43UNvr/f
/X4MX8Mv8CX8Bo/gd/gU/oRP4A5+jE/jh/gMfoDP4gN8Dt/F5/EdfAHfxrv4
Fr6Ib+JL+Aa+jK/jK/ga3pPL5XK5XC6Xy+VyuVwu/5O/AefDiMY=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztybEKQQEcRvE/5XoBD0BZDAaTSYhSItwJV9StW8rAZDNYzHcxGhjlGcxe
wGhQHoDFKBkMTnmDbzr9Oil/6gZRM8tGzD69pJ3luhIv7bex8PG6Fb++7359
wj/jX/GP+E/8A74Db+AEHMJJeAVn4AWcg+dwHp7BBXgCl+ExXIUDuAb7cB0e
wQ14CDfhAdyCPbgN9+EO3INduKuvr6+vr6+vr6+vr6+vr6//578B5SSSHA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyaEOAQEcx/E/RbR5gZsHuK4hXJBsBEEw7Ihm7HabjXBB0URJQPcERKKG
ysw72Jgg3Dd5gF/67rNvttWr+EkzcxNm32ai3XHppQrj8zp8vm/5n71r3Bt8
B/+Ab/h3/Mcl7hf+CT8N72EH3sIuvIJz8AIuwnO4BM/gMjyFq3AE1+AJXIdH
cAMO4SYcwG14CPvwAO7Afbirr6+vr6+vr6+vr6+vr6+v/+f/AELcR9E=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztySsPgXEARvE/RVBVNp1o01yKTaMogrHXzNyL62xsNpsi0ASbZDNVUAV0
RXuD4APoJgjOF1CedPbb8efractpjAk6jPk0Yfc8+4QrGjhvQ7Z5RL5eX39t
4VfwF/gx/CO+D/+O78B/4T8vv3bDN9gLn+AAfIDD8A6Owxs4Ca/gFLyEM/Ac
zsIzOAdP4QI8gYvwGC7BI7gMD+EqPIBrcB+uwz24AXfhJtyBW3BbX19fX19f
X19fX19fX1//b/8NPxFTcQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyS8PAXEcgPEf5YKmafQTiU4RKDZjNpvjDsW/M5tNICiSKaqpXgBJEmyy
dm9AYjt/3oAJwj1Z/KZnnz0x2ym0gkqpeECpb6dGwjxktfTGi5zdwNX4WXv7
fcc/vvzWH37P8S38Ev4SX8ff4YfwL/je0+8bvouv4BMchvdwFN7COryGk/AK
TsELOAPP4Rw8g/PwBC7CY7gMj+AKPISr8AA2YQeuwX24DvdgC+7CNtyBG3Ab
bsqXL1++fPny5cuXL1++fPny//Y/hqAEig==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyT2rgWEcgPHbkzIwKBmUQjpYnsFLJ0khg+GYnpGNbGLlLGf2GTCb6ZTF
YpHBy8N2PgCTUuaTZDDc12z8T1dXv0ija7UMpZTpUOrZ2fg6WX25ivOtYdrG
qfD69lH/8E5/D7wHXxz0X8L78Du8BE/u9ffB6/CLrf8PfAMfwafwX/gQvoYP
4H/wb/gZ3oHf4E34P7wGd+ItvBtfxXvxFbwfX8YH8AV8EJ/Hh/A5fASfxUfx
n/gPfAYfw6fxcXwKnxAXFxcXFxcXFxcXFxcXF3+bPwCzariq
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzj0LQWEYh/HHMfgEJpNVWXwBR0lJFovdS0Y2GWVgMRgMSoksBm91ShkM
UiaLjN5Lp2wyKslgeK7RfE93V7//cHtT+UTWUEr5HUp9r/0aPLZxlxna53Nr
5y3469VV7y3chMcO2F/0HsOLcOOotw8ehd/PelfgFtyC1+B7eBr+hofhnhP+
hwfgbngEbsCT8Cc6g7bRBfQBXULv0GX0Bl1Fr9F19BLdQC/QTfQc3ULP0G20
he6gp+gueoLuoUfoPnooLi4uLi4uLi4uLi4uLi7+t38AF8zHMA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyTtLAmAYQOGvEAL7BYIOLoGDkzQJ6i4ROEaTKEgFCYKLq6OImbckEIJA
yEsgmkYkZIHg0uQWTTaIQ4NjiDQ4vOcXOLzT4eE4w5eh6K4xxr1jzH/tJxHv
9/FeYJW7SL5aZv6NTVX6/Uo6eCN9lpfuVKSX+If4sWvpSVl6jJ/AtxWkXfin
+IuSdAF/gD/Cz+LP8c/xrUXpI/wDfA++D9+BH8Lfxw/j/8Fx+BdOwT9wGv6C
M/AUzsOfcAWewLfwGK7BH/Ad/Abfw0O4Dr/AD/Az3IAHcBPuwy34CW7DPfgR
7urXr1+/fv369evXr1+/fv1b/Nf0TL1d
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyTFLgmEUQOFXSwUhMElSg+CzMESEBIcWMXCSaEiHIFDTUrMlmvwFDeHw
YXO2C61hgz/BMQS3hpzSMVwcxKHhntnxTofDY1Uf8jWnMSbhMGbV/Of+0++F
57Rb3Lz6cE0y/799L/+9JD/UlG+X5efu5J9fy39tyJ/CvfDHivxOXf43PA5P
V+WPavLbcBs+hBfgGzfyLXgSPr+Vfwn/grfgffgL/A3egz/DB/AWfAhvwsfw
IvwHXoDP4GfwP3gWvoCn4Q78Cd6NT+G9+GP8Fj6B9+HjeD8+ht/BH+ED+Ch+
F3+ID+IP8CF8BB/GW/g9dXV1dXV1dXV1dXV1dfU1+hJbOg2V
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzjFLAnEch/F/DrWGw43BzZmbcyI0tii9gUiCW8QXIAgNNykIR0MQBoIQ
FaaW5XWXhSAKIk6BEARBNLSIQy0N0dDwe+bG3/Tlw7N87d1cOhsxxmwsGfO7
rjWbfGVWkkEjFT1fftv88/xBOt6UPu5JZ1vSxXtppy1dCaW3rqSHgfQ3uo1+
eC3t3UlbHek19AN035d+Qd9HX7/BP3QH/b0rfYLeQR+jl9AX6A569FZ6Gz2G
nkBPodvoO+ir6HvoEfQ8+idcgD9gF36Fy/Az7MFP8BE8havwGK7BI7gOD+BT
uA+fwY/wBdyDG3AIX8IB3IJ9uK1du3bt2rVr165du3bt2rX/Y/8Bra2zaA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyT9LgmEcRuHHF80IAoeQpqShJRBBIYiorJaIkrKwoXAQoilqqKGhpYY+
gOAqvNCSbo65tze0NASR4BihaGZ/aGi4z1fwNx0O12ThOHvgOefiAef+Wj8t
jgdz4fTLW7LshxuL/38znJJ/eld/HFK/aqlnQ+rNtvpIUH2so97x1CNd9Qj8
FZ4JqJc+1G+derynHoNX4ZUf/ein/hr8BN791r+D1+A9+Dk80ddfhe/DY/BL
eP9L34c/w+vwe/gDvAZvwH14C16Ee/hr/Cj+Ah/Fn+En8Ef4KfwhfhpfwCfw
eXwSv4efwe/iZ/E7+Dn8Nn4ev4VfwG/i0/gMfgm/gV/Gr+NXzM3Nzc3Nzc3N
zc3NzQfKfwHjwoLR
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyb8rxHEcx/EPi2PyF4g/QBlksJxBMZzBj2K4SV02Z0BK6pROF677/fu+
567Lr1IWiwWjhbqMBosyXVkwXTIYXs/BX/Cenj16Di2H50LdzrnhLud++9Ga
We5f6pmIRF9d0ffm/3PgVD0SUz831esH6ruGOnikdnX1V1wdrannE+opT72V
VI9X1eGUerGi9qfVhbK6jf9dUu9m1Gv4HfxOUb2SVXv4t/gB/L6c2oc/jf9U
UO/ge/jn+Jv4j/gL+G38MfzevHoAfxDfhz+K/wlPwu/wLPwCB+EWHIIf4FX4
Ht6Ab+Bt+BqOwFfwHnwJ78MXcAw+gw/hEzgON+EE3ICTcB1OwcdwGq7BGdiD
s3AVzsEVOA+X4QJcsm/fvn379u3bt2/fvn37//4fVCUruw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0r8rhAEcx/GHBYPBYtAZbjLoFIZb1JHJ5Ff3DE4pkiTdxoKTUwbqBoNM
N0nqit0odUYDp6TTc47nzm9JIpHB8Hn/B+o7fXr1Xj/B0fjAeKXjOKEKx/nd
ptbqTGCoqtM7dsOpmmLkz8Fv9dqJ+uBTvXWmLr+ru8/VyTf17IV67lUdzasP
X9T+pXrwWd3hqRue1MMFdd2juvdK3fagDhTVM/fqI/TcnTp2re5HP0XP36oj
N+oE+gZ6C7qHXirjD756F91FT6An0aPoO+jt6Fn0evQC+ldJ/YHuo9fCObgR
zsLN8D4chvfgLngb7oHTcB+8CbvwOhyDU/AIvAqPwSvwBLwMT8JL8BS8CE/D
C3Acnrdu3bp169atW7du3bp16/+6/wC322q4
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0s8rw3EAxvHvXJSdJBdxcBAOSslB0bQQmy82v9tEK9ZayJGLIlmyRiml
pPl1MkQrWQkHB25yc+XkIGolSXJweN4Hf8Hn9PTqfX1KQ5P+0RzLsqoclvW7
wcR1tiKY21henXQv5D27/rwyoS6rVX9E1MN16sIx9Xu9+jak/nSpHSPqJbd6
b0idblLvB9TLLersoLqoVb04oI62qX396phH7e1TT3vV473q5nb1SY/6Db0A
fd5Wx7vV3+jF6OEOdcavvkSPoDs78Rd0D/qLTz2Lfo6eQk+gP6BH0bPoNnp+
l7oGvRK9BL0B3Yluo3/BAfgVDsNP8BT8CM/A9/AcfAfH4Bs4Dl/Bq/AFvAZn
4HX4DN6A0/AmfApvwcdwEj6Ct+FDeAdOwbvwgemmm2666aabbrrppptuuun/
9h9jUS2P
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0c8rw3Ecx/HvlLEWS6TFjG1+syXZSqlNoRS1xEWsplxcnGVOLhwcODi6
K2tnHJx2YCEHB3Jx4KBWS2uyFXJweD3/BH1O7549Dq/D27eyPrdaZVlW0GZZ
v3c/n4qGEzWxcPnKv+l8if71eDwnbbNpf01rZ+3amQntY6d2KKZ969JeGtOe
b9T2jmrHm7UTEe0Ht7ZjRPu7Rbt+WPvOo50c0l72ahdD2ul27Yug9mWH9umg
9rlP+3FAe8ev3QaPBLS3+rEPL/VpT3Vqb8MzcD/c0YV/92ovwHfhh/BZ+DW8
FV6BF3q0A93aOfgk/ASehB/AN+Ap+B58DX4EX4Sn4TPwM3gMnoVH4DfwEPwe
3gN/gvvgz3AP/BXuhr/Bm+B5eAO8AHfB3+F18CLcCS/BHfAPeC38E26Hl+HV
8Ipx48aNGzdu3Lhx48aN/zP/AWT+cPM=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0b8rxHEcx/Ev0lG225TBIKUzUDIY0JGcs1gQcZEMh7MoZZAfkfwYiFJK
3WA5KSXC+XXOr5OkSOeGsxg4DDZJyWB4Pf8Cw2d69+g5vIdXdpuvriPZsqz8
JMv6vac1xRPlHlvZ8mj8vjfjqfTPRV/q+LR67UMdnFf3JNTeJXXFkzrTr7Y9
qt9X1HMxdXpAHblXj6+pZ2/Vg+vquxt16oZ66Fqdt4l/V+rvLXX0Uj2xre6K
qB92sM+F+nNX7ThXvwXVNWfqvT315Km6e1/9fKJOOVC3og+jv4SxL/oYuutQ
XYC+iP58rI6hr6Lbj9T96E50N7oXPRd9Bt2GHkB/DanD6HfoUfQQegJ9Hf0L
3Y+eBi/AdngKzoJH4Bx4AHbAfXAh7IOLYS9cAnfCpXA77IQ9cCXcAlfBzXA1
3AS74EbYDTfAtXC96aabbrrppptuuummm276P+8/SZN1Mw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0c8rw3Ecx/Evhagd/AFLOwoHF7sZFz8OJCmKZfNjkR+bbcbQ/LYo0lJc
HJQLy0XKgZODUCScHfwodlmKpBzk4PB6/gn6nD49en76vN/1cXT4G7szLcsq
ybCs3/N75+2mriOnYrEg5fXZnl1/fjpR24vVNYfquzJ11576w6X+3FYfV6vP
N9XuenVyXZ3ZpI4k1Nct6uwV9WubunxJ7fOos+JqT6e6ag7vd6vT0+r8HvXb
pPqlV+2KqaN96ssJ9VW/OjGOeQPq+THsP6jeiuL//Or7UXUgoHai5w2pd0bU
y+il6N/oFxF1a1AdQk+iF6Kn0VPDuB9SH6C3oi+gL6C3o++il6OfoTvQH9Fz
0b/Q38NqG/wA2+FbuAg+hZ3wEVwJ78O1cBJugLfhZngTdsMbsBdeg33wKtwL
L8P98BLsh+NwEJ6HQ/AcHIZn4WF4Bo7A0/AIPAWPwpNwFI6Zbrrppptuuumm
m2666f++/wCkv6bz
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0s8rw3Ecx/EvF05rJ+XHgahxmJoaxcESB2pqaJn5kTVmQ9+WHzMt+THz
Y35Ow5pEWRG1kxQWK3HCFacdyMlNc7Lk4PB6/Qn6nN49evY+vOtdYJGbetIl
SVKnSdLv1GSe5LVZM3TurOS1WfFW/WfbFzqgQu+8o0vK0fkv6L0a2n9A1+rR
dzdokxFtuUTndqIrTtHnVnR2FN3tQCeO0FoZ7YigW4bovn300yjavIt+dqOD
YbTdQ/eF0KEJtGYLPTaJdgXRyml0agM9OIO+CKC3vejDdfTmLDq2hpZ96M9V
dPEcup76LfWzFbR+Hl1JPU79cRlduIAeoe6irqJ+Rf11Cf1N/Zh62SJ6nHoX
dQN1L/VS6hHqSupx6kk//S/1BPUP6vfUU9Rj1BXkKDmHfEAuIofJanKArCX7
yVVkH1lHniLXkT3kBrKL3EgeJhvITnIzWSYbyQPkVnI/2US2k83kPnI72Ubu
IPeKLrrooosuuuiiiy666P++/wAIKVkx
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0k8o33Ecx/Ev/epXDiQOkhT1kz9p/iU18dOPZvabGcbPNNraOFAkduEg
l18jh5U/y8mBm5AcTM2fy7hxoDBNW7R+6zdGlJ8/EbXD63nb/fO5fHr2uL3f
77g3LeXvgi3LSg2yrLu/4f7ZnTHToWdlYQf5/3rhIEy6ckXdta6e+U395xe4
Xz1xUn3xQn12VD3drp02qL0Vrl3Vp30are3r0V6K157p1G5O0vZ2aMc90M5v
1bZlac83aWfkaO82an99qN3/VnszT/vza+22Au3Seu0pl3buK+2RIu33tdp5
j7SPa7THi9Ee7O+x9odq7b0S7aEq7O8J5vVCu9utHQl3PNXuqsQ9wAMV2sml
2r3wj/AUuA++U66d9Ux7AN4B98An4A74LjzwHPdbpr0BT4DPwgvhn+B18G54
O7wZ7oW/hA/D3fAxuBM+Bc+Gz8FT4ctwB3wVHgtfg0fBN+AR8G14KPw7PAT+
A26H78Nt8F/wYLgPbsF/w2/QfvQ1+g/6Cn2IvkQfoS/Qf9EB9DH6HH1i3Lhx
48aNGzdu3Ljx//ZbNXlwZQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0U0oA3AYx/G/MeZ9YwmtvBvzkpQwL1si8jZvpeQgpZYSdlA4yEXJS/J2
QAkrHJSXIkpKTmtJKa3c1MpFzWpFGDk4/H53t//p6dunp+fwpPQOtvUphBB5
AUL8zvWb5EObNcTszzP5a9Ru01+rXGboqSb0hwv0eSv67Rb65QR65yz6xhK6
ZxR9146e1Y9efYK+2Y3uvEJXtqLPONA1tejX9+jTlej7j+glxeiDT+jeAnTT
M/pCDnrZC+1nok++ovtT0Q0+9LUk9OY39CMduvhAL0xEt3yhR8ej13+jG+PQ
PwX2nhZ7SEH3YrEPA7H1MfS/IOxsDfaBErtFjT0SjL0ajZ0Wgu2Lwj4jHyAv
UmG/RWJvky+Si1DscvIWcm8E9gr5Mfkd+Ti5Igy7kTyfPJ28nVxBbiN3h2PP
kTvJ7eSn5OfkO+QO8mVyF/kUuZt8jNxDPkz+Tm4lD6DuoVZRd1FHUXdQa6kt
1AnUDdQ66jrqJOoa6lTqKuoMahO1nrqCOpu6nNpAbaTOpS6VLl26dOnSpUuX
Ll36v/sP3OCRWw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0cFL03EYx/HfdGyoMTC2RMzUeWnQXBshsUDFBDtIgobUQBhhIYMhSNei
HbpNHCtvHkzwUAcFKcEggpAmJcGQEHMhHgazMElK3bKMDh0+7/8g+J4e3rzg
gYen6eZI360yy7L8Nsv6O7PejeK9mLPDvZLOhavz7f/aeWpC+uO+evTrI+nJ
uofSV1fUQ5fUHXPqAwPqnybUn8TV2+6rP0uoP42r76TV5wfVXzxWL/Wqj86q
n+9Sjy6qu8LqS6/VbwTV197ifp96Jqs+0qz+ck29UK+ey6n7atUvb6m7Peon
8urpavWegvq4S73mi/phlfrdHfVXFepju+ofnOr93/Afh/r6nnrGrn72u3qq
XP3KD/UHZeod++pTNnX3gfqGpf4OHoQPH2L/sfYu3AsfKmov/NZehkfg9SXt
KvhteOaX9gw8Cc/BI/DKn9oBeAheCb8G/3ykPQp/D0/CF+DT8Gn4c3gK/gae
gK/C78A34TH4NjwK34NfhxfhffBjeA/cju5GV6A70S50G/okOoz2oC+ia9Ct
6Fr0BXQdOoQ+jQ6iz6AD6AZ0C7oR7Uc3oc+hvcaNGzdu3Lhx48aN/4f+B0O8
aEc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0D1I1HEcx/G/cikNB3mUcqDDgbpYpw6iEuSBOgRCcFmXmc/PeJUPiA6n
nENCSKKDRNTUIEjBVSDeEOjgAy4JiSiIUhyXZpOJJoqeNDh83qPzb/rx5jX8
+Hxd9c+9TfGWZd2Ks6z/b8LgePGwP9HjnL0+mu2IFl30h2iKtPNYfS2kbr95
QzowqJ7kUx+rUE8NqOfkq9veqY871fun1ZMt9cxldddusvRQRL1wTd1xoL63
oO62af8Ja+cmaa9/1G5O1e58r23P1A680a5ya8+PYV+etmtYO3Rbu+2F9pkH
/we1R0u17wS0g3e1X/dpR8q0u3q0l+9pf+3Svu/FPTu0+8u1G59pVz7UnvRr
H/q0s9q1H1VgT5v2y8fai624X6X2Sot29xPtOHhelXZZs/Ym/HOT9tNq7IP/
hocbtctrtB/AP8FjDdpWrfYUvBTeAw/Ci+Bf4NfgW/Dtem1bnfYcPB0+AffA
X8F98F64H94AH4B74SPwEvhbeAF8Au6Gh+AZ8DA8DT4DT4HPwR3wJbgd/g1+
Ff4dfgW+Co+Hr8Nj6A30KXoTfYLeQh+jf6CP0D/R/9AR9AE6it5H/0L/RW+j
99A7xo0bN27cuHHjxo1fws8BTJjRag==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0stL1FEYh/GfpuSiXRJSiijSQjAQBX8p6CBSRGE4s3HRQkYU0dLUsbyM
XaawBku6LAZEI5LKG6JBZWoRpIaKMJM1CxUNQRcKIhlE5CJauPg+/0Jndfjw
wMs5hzfJXeMsi7QsKy3Csv6dOavn7weqDzpm7GBcyuH1vH0vtn8Vu+9o/5av
3Z7THjygfTI6JL44vyA+a2v3PtG+Uar9d4N2v197pEt7VL/2cKb2Q9Pa545q
z13RXhSlPXFX+9bOF3FKtPrEd/VIrHoipI5PVhdMqV+lqW+OYX6W2h5ROx3q
zD715Gn1mWfq9EJ1UZf6vUudGlC3FatHH6lfXlCvdeA9JeqH7epzperXd9U/
y9S5bXCFOuG2+mSl+pRPvV2lHr6hrriE/7uuHqpWJ19Tf67B/VrVY5fVOV71
vVp1Y4vaUacONauX0R3o7nrsU5M6jF6Mnu1R/2lUP0AfQF9CL0c/1oD9RHei
/7qq9qHPog+i96AH0X3o2+jl6DFX1IXoieg2egb6cfQC9CPoLvQY9BL0PbgK
/gF74E3YC6/Bt+Bl2A+H4Q44BD+G5+EAPAN3wtNwN/wJfgp/hHvgD/BzeAJ+
AY/DvfA7uA8ehfvht/AA/AYeNN1000033XTTTTf9v+x/AT2yxjA=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt08tL1FEYh/FfRZhSEBgUYlB5gWxcBSMhVhBlKJV0Q7wUY6nkpZm8TDkh
NSEkERk0C8lAUUk0klw5higyiqMUzGgmSWIECZkFGhgGkbRo8Xz/A+GsDh8e
DuddvGdvgfNs4UbLspI3WNa/05UWNd3mijg6lBdy79rx5ch/e0+9h+2j7HcX
puCTcWH4k499oYJ9IoN9rJd9JIo95yf75cl3fC9xAq5qY3eeY9/kYf9dw267
yH6mif1ACnu8nz0vlj06LPc3s7fPs+9emoQzV9mH59jLI+lAiHbspMcCdGUc
/dhPf06mP3bTX+20+zntP0wfbKZrjtPfGumsTLr2CZ2fRY8/ovvP030P6Lps
2n6fDubStjq66RL90Etvc9An7tBJV+jTtfTfq/TT27SviN7noZeK6dlb9J5r
sj836cQSOuSmt5TSf6rpN9LTpVeX0Z1VdGS5zCu9XnpXJb0i/Zj0C9fpxQq6
Q3qz9B/S86XbnHS8dIf05Rt0g/RR6b3SW6XPSL8n/Zf0YunbXfIfpSdIT5V+
SPp+6RnSY6RnS98qvVC6Jd0lfUXsEX8Xe8Xz4nrxnLhB/EHsE0+JG8Vh8TPx
W3GLeFzcKg6K28Uj4g5xQNwpHhK/EA+KX4oHxN3ifvEr8Wtxj+mmm2666aab
brrp67KvAT6uvjc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt00tI1GEUhvF/JgU1CNG00hgdL1k0ZUEpk2WS5iBSljilYYIoBcLEKDlJ
3tIyLRGVoaKiMCojEOymUYtAp2hVboQcRXIh3SAEBSMYjBYtnnfd8lt9/Hg2
B875EirOHK2KsizLtcKy/r4Pb4Xih2pW7//iiX9s2zCX9c9x/lQ48ol96fsm
+HNxAvysjt0xyv5jHfuCwwn3vEqBD/rZwz72sRH2PS72qUX2ksVkeHxzImwb
Yx8+xl54g72lmT23lj3Sz76liH32Dbs3nf39JHuGgz1znv3IGvanK5Pgnb/o
Xjvd9JVOS6Rnw/T0dtr+kZ500+EQfTKHjrym7xbQh57T74roB4P07xJ6ZoAu
LZd+j46qpDvu0LbT9NubdFc13XadDvrooSC920/v7aMba2lHD113lvZ001sD
9JMueuAcXXiVnq+nN16hY87T6zvpVQ0yT4fcl/Sqy/S1RvplO53eRDulj0rv
v0S7m+U/SL8v/cNFell6vfTDLfQ26UHpP9vocenD0qMv0O3S06SXSfdKd0sP
SI+VHpRuSR+U/q1V9iN9QvqE9JD0OekvpC9IfyR9Wfpt6WvFvWK7uFMcJ24V
O8UN4lRxQOwS14h3iH3iXeJqcYb4lDhTXCneJ64QZ4vLxQfEZeJc8QlxnrhU
7BEfF+eLveICcbHppptuuummm2666f+l/wGFFbDF
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0U9I03EYx/GfRhqFlkRSSJQkVriyP0RmVB6CDh6kRdAh0GReChm1ukgU
I6KIoojAWDGDkLBDRILaH6Mg0tA5f9t+a7a0aZmEaQhKWpbRocP7c+74PX15
83rg4eGbX+1116RblrUhzbL+vsmZM0efncws82R3PbJyh/f86/qyOLrcpk9c
cjhf141ePxZDN2aF0HkeetUV+uKxKPrgLL3xPL3lcA86UkSvfUgP9UfQBTP0
zAC9oiSMXldJd3npGS66E6QH5mz0zk76/D765q90fyu9dlEvuiZAv1pIz/PT
V++mFxyj33TTcw7Rqzz0s/votk/276CX+um3XPTBy/Tn+fS0enrFcnp3A33l
Err3Hn1uAT3nAd1Op8ea6Sd+sZ02duc0e2M7++kke+oFe9sEe9cr9tpxdm6H
/M8o+9ob9qYv7NYudvEI+0ZI7h9mbw2zv31k3+5lB4fYcZtdN8geibBPp9jR
KPvOB+kYOzXAPuCwS8XHxZv62afi7CLxUfH29+z9b9mV4k3iWeJT4q+T7O0J
9kXx4+Ju8bvia8TD4j/fsSfFE+LL+tiPxbeIB8XLxS+IHxH3ifvEq8XPibvF
r4vvFW8QLxG/L14s3ixeKP5EfJX4S/EV4h3iS8VD4tnitvhCcUc8QzwhPk88
KW6JD4j/lk5Jz0oPSf+Q/iQ9Lf1Z+rtx48aNGzdu3Ljx/+J/AADh62Q=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0stL1FEYh/HRolLMvDQ2pcVUFuKFogtpiKm0qLAIKdEmWlgSRNS0kSJr
ESokmCFmUpNmjqWJzWRXaBGIMLko3CTl6NQ4jXaRyiwTC4kWLZ4v9B/8VoeH
z+ac97zLi4/nl4SaTKa0EJPp7xlVmHH/Wenc7C6X9+L3uOCWf50S8Qmd+mgQ
XRj3EV3pGELbsj+g0w750ObK9+ip6DfoL4FRdE47vbeAPp76Fj3mHUHXNdF/
2ukHZvnRg7H0zH30vu4g+nUrfWsZvWOU7s2iT1mH0SVh9Ff59KGBd+jcs3Rb
Fz3SSbfU0Cd66Ift9Ho/3bWXXj5NP5pFT48KcB+S6Qkr6dUW+oX19I1hdF8O
feAXe88u9uavcp8idvwIu7GYnTfE7j/Cbn7JnjnBnnjBzjjJTuxlO8+w43rY
tnNs91N2aSXb+4QdXsUuf8xOqmY7HrB9NeyF92TetWy/m72tjj15hx1Tz97R
KfO+LP/Rwf7dwK69zU6+wj7Vzl57VebTxjY72K5b7EHxHzfZ56/JvopbG9me
VnaLeJ64uYk97JT3ileI94lvEI+/zv7cwt4vflf8kniZuEd8p/g38VXii5rZ
oeLp4oEb7AJxj7hd3C1eIe4QbxCvEm8TPy3+UPyYeLf4QfHn4kXi/eK7xX3i
28WD4rniY+KZ4uPim8QnxdeJT4uvEZ8RTxEPkU6Sni29WnqOdKL0POkV0uHS
VukI6WXS86WXSkdKJ0gvkI6XjpJeIh0tvVg6RtoiHWu44YYbbrjhhhv+H/8D
j/iuxQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0stLlGEYhvFPK8eyrIZAGsLo4CFQQTLCCUlqBqwES6TSUsdT5eiojaQV
CiouTIqCDpSBkGQIbirIpKRgjNpIqQkJQZllVFiidrLJihYtrvtf6Fu9XPwW
z8PDuyq/PL0o0DCM2ADD+Ps6u6Znh45akvtXZDvehY1t/tefYr1oX10O+vir
CrTzdi666n45OuKhi+4rQ3tv5nHemAd9oS4fnRhBdycUoLfWlqK3D9DvfShB
r8kqRH900xsH6B6/G92RWIRe10KvP0dPc9J9r+nb/MXosegD6K479A1F9LwG
+uAletIuevcjek4k3TdBnzHo160H0Zkjh9DR8fQ3vfSeHfSlnfTxfHrxeXpk
Nb2xgd7XRA/20uMv0jsK6K3t9PA99Iwb9LhU+sm79LYt9KoH9DQ7PamPHrKe
HvSUfiuGPjks+0XRbS/o+1fTL4/So8LpJ97Sa2z0r+/pKWH0z+P02mX0MxP0
RVb6s0n6+GL60LT8r1D66S/0yoV06zf6ghB6wXf6k/lynxl6TzC9+Qe9z0J3
++n+IHrcT7pDfFi8fR7dM0u3iU+IX5lLd/2ibxTvFX8+h778N71ZvFDcIX5N
3CL+UnwwkL7EYF8V3yReI+4SzxSvF7eLt4qvFO8Wt4g/Fp8KYI+Kj4hPifeL
B0j7pEOlu6Rt0p3Sa6XbpGOkW6QTpM9K26VPSSdLN0k7pBulU6TrpFOla6R3
Sh+TTpeuls6QPiK9W7pSeq/0Yeks6QrpfdJl0tnSHukc6VLpXOkSaZe023TT
TTfddNNN/2/8Dx/vVho=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt08tLlFEAhvEvJa1MrbyklemQklKCIChZ4BiCklQUJlZqqalZjZphQ42S
JDlW0oWaWtRCKQeJSLpHiRWUBDW10CKYIpJMXKiYYJIS0aLF8/4Hwbc6/Hjg
cK6WkuqtZT6GYSTOMoy/oyP0VtbXo/7WV4k7PN6IwfR/Dgm2w/lBBfDTjXWw
/U4hPPbiENxj2QU7bbXw+5Ld8OaMg3CLoxj2ptXAIzUlcOW2arguqxTua62C
fXz3cD+fbfCUmz0hk31TShkc13MAvnqXfSabPd5SDp8d2M/9NbL7nmR397M/
SWP/GFUB50zu4/kXstsfs/e62OOb2bt62avy2avH2euS2N+F74WbAtnrU9kn
RyvhwFx2az+7n419qJvde5y9oZN93MXecYm9zc0e4GRPvc9ecYT953N2h409
ysMeXMr+6QP7j+3sxV/Yp7ew931nn53DnjfCPprJ7j/BfiWd3WeKfSKNvWCG
fSCFPcGgc5PpBl857yS6zI9uTKTH5tAxq+j4AHp+Ah0ZSK9dSb8Jojvi6OwF
dEYs7VpIz1tBP1xE/7LQD0Jk/dIvhtLrYuT+w2hnNG2E08PLZX7pRdLDFtOD
UXSz9Hrpw9KjpVsj6LfL6NPSW6R7pG+Q7h9Jh0pfI31wqbxP6d3SW6Vflt4l
/bB0j/Sd0oekr5f+W/pq6SFL5D9Ij5U+V3qy9GmxVTwmzhF/E+eJveIicZ+4
XPxabBO/FNeKn4nt4m6xQ/xIfEx8T9wkvi0+Ie4SO8U3xafEN8St4k7xGbFb
fE58XXxefE18QdwudonbzG52s5vd7GY3+3/T/wAVc3lZ
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0dsvF2Acx/EfkRCiMDMk2SS12jrZMrVqOrA5zBrjorBYp1VmmKYyIVZT
8QtrMtXGItXUWqwuWm3aMpWZC2pGDjnlnEati7ben7+gi9/Vs/dez5493329
j56OTDI3GAwbzAyGP2fD2eTikSyrXSUVXetb3fqC/3blRsuAf3vW5wv8Ras5
3CKuB27dZIDXh/XCA4cW0Q/NvqJXRy6ga7P70cbhn+jw9wPouCfz6AuTg+ix
Oz/Q8VND6JyGOXRS+zd0T9csuqh8GB3jS98XMoKuz5nhPN1025lptH/CKHoq
gx7eQQ+yozsFjaF/1U2ht5fSr8bSI3rpqY70Zr9xdErbJPebSA8to28to/sk
03e8HZd56Plj9MOu9E6n7+j9MxPols30yE56Xyh98iX9XiL9eQ39XAY9uJRe
V0jflCvvV9CD0ujVNfS1KfL/RvqDeHrVK3plFN2mhd52kB7yge6+h57dSY/Z
Sf/4mX5yGz2+T+bfTA8coj8KoGeO0p/60bdM0AN96enTdP819Og5epYXvWOe
7uNBt16gO7vTpxfpB9zodw3sRle2pzk7yoWdskTuO7MLLdj2q9gFlmzvlexj
S9kRTmx/K3a5I7tdfH4F+/gy9inxUfFJB/YRa3ae+BvxdeKeNrJve/mf+DXx
evFw8UFxN3EPW/aAHfuQeJN4qrhR3CieJt4oHiveKr5bvF/cX3xB3EXcYTnb
UtxLfFY6QHpIOlC6W3qv9CfpMOl30tHSr6XjpJulE6SfSSdLP5Y+IV0vfUa6
VjpV+r50unS1dKZ0lfR56UrpbOnb0helK6QvSZdL50jfks6VNkpfli6VzpMu
kc6XvildIH1D+or0delC6WLpIpOb3OQmN7nJ/2P/DQG+Agk=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0llLFFAAhuEZ05w0l1yyKSU1o0Exx5ShIFCnbIEkFJPsQluIEJE0ERPK
IEWFgiLpTsOCRJAkoaKCEiKFhFwIKRLbzNw1y300o4ug9/sFXczV4eU5cNaw
k2fTTrsYDIZoo8HwZxzoCu9dKHVPtM5OZb/YOJDwtyciLcf/7bzjM/DWuQi4
I3seXm0Jh/cZHfCtzZvh5anL8JcVIfD5oytwj7pNcFOYEf1w2owuaHZBV1zc
gF72dUWHxgeh7yS7ocf91qNr01ejXQMD0ZV2d3SQLQCd429CZ53zR79up1e1
+aE7c9egG2PoUQt0W+M69IEiD/SojZ74hd7d5cv5SZ7o6GL68E16iYXe8JGe
3e+DPhO6lu9bT0/IpBcU0C1X6Pfs9MVH9FtmemEf/caMN3rXCn2sh/452Au9
5Sl9xEZ/dpvelkJPu0p/d4JeXkIvLqQbc+iTl+llx+hl1+mvUuj5NfRaO32o
nt6xk26+T4+10iMf0+9Y6Ikt9F9h9POt9Khg+kQ73SuI/qSTfs1P7u+NnN+b
fvstfZsn/eN7eohJ1u+jF7jJ//tEN6+i536hexrpmV/pu1fYHt/Y9cvsykF2
0hK7Z4htcrAdw+yZBfbSCNtV/MMo2zrPvjvGLppjp4+zu2fZ4+J28cIJdusM
e1g8Qzx1Us4/zW4UrxN3iB8RT/rODhAvFe/9yX4g3iDeL35B3GtK9iceKx4n
nioeKJ4n7vjBrhDvF68R7xRvEn8u3iLeJN4hXifeK14tPiheJT4lfkl8UbxY
3CidL22SzpH2kT4lHSCdJW2WzpQOkc6QDpVOk46QPiy9TfqQdKT0Qelo6f3S
26X3ScdIJ0tbpfdKx0rvkd4hbZeOk06SjpdOdLrTne50pzv9P/LfIyN/FQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0/tPDWAcx/FTGQ1d5raFtUo4DTOHXDaEMRZjI01+YKhNY7SlMSaLsrFj
i5nMCrWzVEqlJbKuJ93oTlI6TiKX3NmRzZb5wQ/vz7/g/PTstff2ffZsz9d/
98HNUa4Gg2GOi8Hw95w8tzdwZMKoFX4p6dHFU16H/POJ5kF40rxM+MLxN/DJ
ZTnw3sJ+OKopD/bcbodLPhfAR6N74YzCIjisoxsu9b0Dl5u7YNPKu/BMcyfs
ElAKGxsew6Mb7sMRSzvg5cvK4CUv2uB7ieXw2NxWuMdSAdeltcA7Mirh3/nN
8L6EKthqa4JvrqmGb81gD//GXpL4CF511govdDyEP3nVwE+OsJ9JYk8cze72
kT0uuxH2WPcA9gpjN15m/+DOnmFjb6ttgC1Ta+FMM/uCLexHItgXnmKPmc0e
m8fePoI9tZ3d0VcPb/rOHmpln+BdB2/MYo8MYk9OZs8OYc89xr5yC/uGaPb4
SHa/CJkfyz4Qyu6SwL57OXu5mX3nfPZxKez5QexB19mN/uzGLPYsH3ZTPrvn
ePY9xewhHuydpewB7uzpFewWN/YuK3vBMH2ujg7+Tbc10tN/ybwm+pCDXtRK
T/xBx7TTw1/pqMd00Bfat5M2f6LTn8r/+kj/7KLtg/S0brr2PT2rh25+R094
Tv94K/dJD5Z+sVfe94Y22eihAbpMepz0xS9oV+kW6amvaTc7vVp6uHTHK/qa
9ELpdumHpPv0yf5IXy/dW/ph6QP99FXp1dIrpWdIt0k/LX1I+gHpXi/pbdID
pa+Wvki6Sfpa6YHSt0qfJH2X9DHS90t3kR4nfUgcL/4iThK/E5vF/eLzYpv4
kviZ+Iq4U5wm7hCni1vEFvEj8Q1xozhLXC/OEdeKc8UPxHniGvEtsVWcL64W
F4irxIXiSvFtcYW4yNmd3dmd3dn/6/4H4sW6vw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0/tPzXEcx/FTR4mzFSfWIpdEF5dOF5zkElnkVjQrl1CK4YeSxViGMDMj
bBbJlq2yMGYsWchls9xqtWZszIjUURykIhnzg83z9SfY+emz5x7fHz6f9+fz
9V2dmbDG2WAwjHMyGP6sCw8dzzDv6T19xuHO2DKfpqi/Pc83ec6/nXqnB94W
nwh/Z3VGXw1ehHbq0xvdUDYfHR1rQjedj0XbXD3Q1wJi0MGLzWijezR669SB
aEtCFPpUrRfa1zYF7WoehPZ4EIlu7ueDXmqLQC9rGIJOibai96UMQ2fUTOB5
q4ajC/aOR+9o90WXrQ5H3zL6cT5pYejH7fTC3FB0dvVI9IvKELTn7lHoIhP9
tL8/enCWBV1RQX/ZEowutQagqzbSs8roDa70JlMgvz87Dp2fRvdOojdfou90
pw/ooOfUjkWHhAah++bTLWvps9Lprcfo6RH04VX0K/3p2Y30fPsY9Hbn0ejd
9fTrQ+k9V+nFVnpBEf3EAvqPA/SvKfTarXSXTfTqdXRzLr10GT0pj26Jo5tO
0sNm0pNLZD6T6Jsv0LtC6Dnl9Iwget4N+sMR9Id36XYf+tz79HtedL8aeoQn
fX09fbwHPfgJ/ZyJnvuMftCNnvmc/siF3uslfaWRPu8VfbITPa6RvuQX2/Mt
++JPdnETe2IPu1czu7Vb9tMi7/M7e4FN7ucbO+o9u7GLPaCVPUi8TnxDJ3tL
m/xfHWy3D+wY8f3iNV/Z38XTxFd8ZLuIl4tfbmcb7ez14rHigeJ7xe1f2JXi
N8Vt4kfFzZ9k/uJW8dniSeJB4tni7uJ54p2f2SXir8UrxOvEq8Vviz8Vvyz+
RvyMuF28ULxb/Ii4UXq/tEl6l7Sn9DZpb+ls6aHSmdJ+0hukA6XXSI+VTpW2
SK+SDpVeIR0uvVx6ovQS6QjpROlI6cXSU6QTpKdJL5KOko6XniEd53CHO9zh
Dv+v/Dcp/WMe
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0/tPzXEcx/GjMZOtbFYiEbpIKhXd5HShOtG6SmdJUi5ttFOGmmmLCT+k
miG5tYooP2S55rbZyNpYi5lsyJqWsZVrI9f5web5+sFfcH767LHn9t137/fn
MyPXkrrOxmAw+IwyGP6c5W9Trk4rHxs5uH/kx1GX/oi/3llW/vNfe7+ygdNa
SuGRKFu45eY2OO7OBDijrhCu2+0IrwjeCB+qdYYthethl0mucG9wLtxj5wY7
lmbzf6o94SL/lXB28xz4V5yZ31vvA6deSoeN3X5wsiWN8/zkD9sVpMDXnwTC
Z5uS4Oe7FsAeDomw6XsQnNOWAN+ND4H7S5ZxHoWh8Ou8pXDXljDYyxLPfWQu
hAcOm2BPj3C4+0kc3PGU/asv+46SRXBnbSzcPtoIDzuwN5ax76iPgV0H2avD
2HsTI3ife5fAWafYl1SxvxqSbmJvCIiE945jP1bA7vRwMXy5nt2lnv12F/vj
reyFX9hrktjzpkbB933YPcPZ39mzh5jZKz9Hw2OK2I0v2If2sJ/uZE84yl50
hT3/HHvWGfY919g9atn77rHXVLC3PmIv28k+9QX7hWL2tAH2cRb24iH23A3s
zcPsdTnso3+wN2WyN9jQ2en0kbH0xWT623j6YAL9zF72aaJNE+mrMXSiI/0y
mh5xoldF0hnOtJuRLnChfcPp2On05jB6wJV+E0KbZ9JVwfTJWXRWEH3LTeax
gL7hTq+eT5/woCsC6TxPujuAnjib9pbeKr3Wnw7xop2kt0lvmifvZw4dLX27
9Dd+9APpx6U7est9kW6WPln6Ael9vnSH9DbpH6Tvkz5lruxL+iLpUdJXSXeT
XiLdVnq19I8+si/pvdLbpT+Q3in9lvQe6eel90tvlP5e+hHp36VXSh8jLhfb
iUvFDuJisbO4SOwq3iR2F+eLvcRrxXPFa8R+4mxxgDhLPF+cKQ4Sm8XB4gxx
qDhdHCZeLg4Xp4qN4mRxhDhJHClOFEdZu7Vbu7Vb+3/7b3lgfbw=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1OtPDWAAx/FTIidC0Qmd4pjm0qLlkuN2DC3J3ejEZsmMNVtbakbK7Myl
MAvVFEKiiMWMuYwlc6ywNeVOyGW5hZqkmHlh8/39CdarZ599Xzx7rpa4hHnL
XQ0GQ7CLwfBnvBjZ1TVoi/ukKVfPbd0R8Nr21+VXktL/9a+mMnR7aDy66WUl
evDjWPTgkmr0+1l29JykJ+g/Js9Fr7HXoVffmI5uXF2PXtk5HH3ho0/o5kYb
urWgET01cRz6vdpm9NrkMPQJB1vRLZ9GoBd9/YVedzsEvbTOBY40DoNT0ty4
H1lB8LtbneDx8UPgS/c7w1PTBsElRz3ggopAOHdSV/j1tIFw9glPeH7jANjw
sRv8/LoFzjP2gLtf6A/nd/Tieiv7wc5X7B9bAuDY495wm409JqYn70uePxzR
xL7dyL4mtRectNUMf/3GPtDE7ojzgd+X+sHlZezTo9n9TCb4gzt7RSx7YVlf
zneYPd7BnvKUffYM9gVevvAmP/aJNvY5n/vAb1ewd6tgf7ONfVgRu/ME+/AM
dpeb7PkJ7IYX7H3t7JZm9ogp7Bc9evO/CGH3MbNv7M+eGMTu6c3uaWW3dWTv
E85e30Jfn03XNtCjY+i2N/TupbR/Ld26kg58QGck0C1VtD2Zdtyi16+jS5y0
xwZ6WTnd00HnXKULN9PjLtN30unJF+i87XT+OdpnJx11lo7IpK1nxLvp5aX0
lz208xS9Jlv2+yRdlUN7l9Ad9tKNx2mvXLqpmHbJk/OQXiM9qojO3EfnHqPH
7Kd/HqUrpa+WPvMA/b2QLpO+TfrgfHqodIf0miP0Xenp0v0O0uHSF0s3St8l
vaZA/gfpx6Q3SE+TbjpEx0i3SrdKj5Zulp4o3VV6hvQPh+U9Sn8o/bR0p/Rr
0s9Lr5JeLP2Z9P3S66Xvkt4kPV16m/SN0t3Ea8VdxIlib/Eqsa94hdgsjhNb
xEvEgeJF4iHiaHGQeIE4WDxPHCKeIw4VzxKPFM8QjxJHicPEkWKrOEI8tr23
9/be3v/z/hu5BYK6
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0/tPzXEcx/Ev5jLhuGQME0Nky4yRZWjulnRzCTlERdMFjU7Yjrmt3KqN
kWHUcneI4xKJLjjWNNdqy2XMrVBpaSJlfrB5vv4AP/XTd489v9v3s/fn/e2/
NCYgrKVhGO4tDOPPs+rEXW+PxLZe4UdGlltd3k3466e+HhX/OtA2EX2Xixt6
lZMfemhCH/RBHxeiTw/ugm6ODkcPXNMW3eVODPrY441waicL/KCkDu4bYYUt
FVXwgapt8OuCcrgiayec6PcWnvoiGY6LfwWvj9wH17mXwaMsqbCPuYTzMh3m
9xuewM/GH4VnNDyEt3dNh1MCimD73gw47VshvLvoBFzy/D7P7zgFbzEccHnC
Ge7X/Luwc49zcN6bAjjMYoMr9+XDnzLP8z6j8+B+jgucx4pcuDEnE6633oZN
By/ChzNvwbHBl2Drjxy4pp0dbhHE3iqN/dG9m5y322X45TT2RWnsc4qzYb+O
V+D9q9k9ItmH92SPuc1e5rgBD3W6Cq/bzB7vw940id0/gT2lA3tCNntI2XX4
RQV79nn2n92uwUYie9wY9vRw9uIg9oHT2VPWsju7s5uS2Dt3Z7dlsOc2ZdFZ
7KWf2ZML2bs8ZzeXsQ97wB5azl5/i/3ZN3YvO/trgy49Rdva04eO0iHd6JUH
6J696cEp9Nf+9KUddOshdP1WOsKdfmelR4ygl22gV4+WHkeP9qRLYund4+jM
VfQ2LzlfFO06Sea3kt44hR4TQSdNoycvp8Nm0IlhdBtv2gil42fS6UvpPB86
MoR+P4tesIT+6EsvX0wX+dF7zPRBf3l/Ee0bQA+QXi19ZzBtDZR9lP5L+p6F
dNRseqD0R9LvLaDd5tCx0i3S3aTnSP8wn26Qflb6yLmyD9JDpXtLT5I+QLpd
elOQ/G/SX0mvlZ4v3TSPPi3dVfpe6WOlb5I+S3qMdLP0xdKjpPtL3yB9svTt
0j2lJ0sfLj1V+hDpx6T3k35Sei/pNunO0u3STdKvSXeSflN6G+m50ltKvyO9
UewQ/xQXir+Li8R14ofiWvFjcY34qbhaXCyuFJeKvzT35t7cm/t/7r8BrJJ/
Tw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1PtP1XUcx/Ev0EQ5CgLqgRSBELwgKhJ5i0CxMzXkgB71qGjGNKxAE2+E
ieSouWAcxgybGpXTg6JzzKk4HU6dTpyXORO7eFarhFRALhO8g/MHN5+v/6DN
n7577vHdZ5/v5/PeNzR95axl7oZhRLkZxotneI+vvkss9ExIq84Jzg6pj3/Z
YQU3Q17t7a1F8O5VtfC1TeXwki+r4SvuHoS3Z+yFd71VA6/v2g5Pq70A9/Fz
wEd71sFt6wvgUZ5/wSf32gB3Nv4H/9aZDTeut8C3Rn8Gj3B1wr1KlsLvDXoG
z69cDM884M71MuejE8s90evO2NC3PXqjH+9MQf/b5IP2bk5Cu2f4o/fvmY4u
yhuAjj9h4f7fC0TnhU1F26sGohPqJqPbXEHoJbXx6IaLwehdHXFor4JQ9Na5
76JXmsLQm+ononMzhqBn/DBBzjOc8/zFeHRMVQT3u3YcunX3UPQgxzvo0rxh
6H9Ox6LfTBiOTjfRY5roAZ+8jY77egT6/G8xaFufSHS2nW7/hm5rGIvuaKP/
nk+vSB2J3hFBP+Wkp92I5ny10w0HvTo2Cl1opRevogeZ6eec9JZbY9DmG/SU
Y/QRxijOZwm9LJxuz6K7LPSHM+mrl9J9x9LP5NGnBNKHldGjPeidlfTSltHo
9TX0kD/pjZfpO6/Qi1z0q6fojjv0wsP00A76z/vomd305h/ppT3ZSdvYR/qy
f3Kw28zsK1vYSwazazazA4aw7RvZo4bLeeWwD0exp61hH49mb/ycnRzLDsqS
98eLf8pOncTOzmDXxbH9l7F9E9gP0tneU9jmj9i/JMp9f8j++H126yL2JQu7
PI1tmibft5AdPp29fIHM5wx27ny22wfsCju7VrxxnqyXxJ4qbp7JrprL3iU+
Ujw4mX10DrtYPFm8VbzNJvNqlfMXLxOfI35TvJ94QAr7j9lsq7hTPF88R/yA
uFX8mnik+H1xk7hfKvveLPk/iF8Xt4ifFF8oXim+Qvx78U3iW8SLxXPFd4hn
iVeIp4sfEreLnxC3ip8Vt4hfEo8XvyY+UfxX8Vhxl/gY8b/FI8UbxCPE74qH
iTeLh4i3iA8WbxcfKH5fPFC8UzxA/KH4APFH4v3FH4v3E38i7i/+VNxP/Jm4
r3iXeF/xbnEfcUPaW9pNuo+0u3RvaQ9pk/Qb0l6v/bX/D/058Z0iGA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0+1LlXccx/GTQR3LVhoGMax0kcQ5Mqqx0hJt1JzMGpnD5chQcylmejg6
01qnMjPvqpPmzJtEJdOiG8t8oOVsZYlT7IYgWZtZO9VoZSLLSsdGDwa9P0/6
B3x08eINP77X9f1dntFJobFOBoPBZ5zB8PYZsXFp31cFEwN/Cc03bfR0BPzv
tN5kn3f9MuU4evCycPQX1T+hD8UFort8fAf9kqsZvS76CfqmwZnoXrbX6Ms6
ndFbWo3md+0fOwJHfj0DjrM/h1dbvGDXjx7C7Ut94JChu/Cu3k/hhL4eOCAh
AM7uuA6bPgiC3Qvb4BX3VsF585rhpr/Wws6JjbB32Dq+39oz8OjcSHjl9RNw
eVI0522uhas/+w5+7VEDTz8ZD8c8qoRzGzfDqcYK7i8+Cd6SUcr93LLApYtK
4JevrLCvuRhe/jCV860vgs0lafBA2yHu0yMdjl5jh21bM+C7zgfhhlPb4GHH
ftjv8nb4Xn8BfLXpB9jtTT5caN8BZ5rY7WE22GLNg8OcdsLxPbn8PhXs/v7s
8713wW+ac+A51eyPPmdvnLqb96NvHxxhYQ/KZN/Qwe65gP2peyb87HE2POFb
9oZa9rIS9gOb2bf1sF9ewh5j2AMXT2IfNrFb+/fC3aHsnRfZ41LZZ5ezBxSx
O9nYW86wT4tl9+1gH1zF7vI7e7gvu22QfWQe+22nLLhyBvtKN/bJRnbjHPYp
I3SImU4foP0W094O+lUg/fevdG0wfeU2HbOGTu2iv/iGHmqnEyNlvjbaEUP/
00y3x8k8TbRHIh18Ts5LpqtO08kp9IaTdGYavbWOXp5B9x+jz2+nC2vo+zvo
rCr6xk66oZLO3U1PPUq776FLy2WfWfTqMvr0Xtlfqewnm559hG7dR39SQpfn
yH5/pKNy6fpi2jWPHi/9lPSkw7RvPv20iL4g/Xvpcwvk/5WeLf1sId0nfb10
n/30dOlW6TcPyX2RXiz9T+lR0j88QC+UHiTdWfoW6X/Yabv0K9LPSq+V3iU9
T7pDulX6qPRI6dMO0l9K95LuJ32hdJP0QOmzpIdId5MeLt0oPUr6v+J48bDY
Ih4Qp4ufiG3iB+Is8W/iHHGvuEB8R2wX3xQfFneLj4g7xWXiDnGF+Jq4UnxV
XCX+WVwjbhMfE7eKj4svievELeL6sT7Wx/p7+3+Erohl
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1PtP1XUcx/EvNznAAU4XIwgSOXajyNQhTXLg5kiD3KRyuFmSwEamg0iL
2mDZnKMzEoZCdC9pMGla0YXTkRTUDiiIEYjAiI4dYy4gT9TxEpdaP7TxfP0L
9dN3zz32/eyzz/f9/SzcUpCZ52sYRoKPYfzzrDjuvXtTRWBql9/zoRvifk75
t0vyTZa5nZT7BnyVaTR8bhe6muHbnmiHm9x98PSxj+Hxnb/CJwr2wfsmAsLm
tu++EvgvNVHwXvNW+LLgBHjmu1nw5btXwh8NWQs3kjPgh63J8PNPbYQP2e+H
n4vKg88/YIW/VF0An3ZEwq2/FfN9twW+J2MX/MkZE9x8ogw+dtkHvnR7Bfyd
uil0X3Y12ul3BV382VvoazMe9N7C99Ff7RpHHzxUh37klUvoT15oQFeOX0Sb
BxrRnY4L6P7hQ+hXXSNo795P0VmPD6NTrzahJ0OH0O/FfIkeDBhARwc1o3MT
+9HzWu1cr6aP8/CwA520qBftX38EXTDYg357pAUd1PQdus37DXpl41l0yOWj
/F5Hu9GNZ46h146f4Xzsb0VvfYDum9aG/qisC/36RXrPZCfaWnSc57Gdvt9D
L/OeRpc+fYLzbqM/5qTb7qVvjj2JLuo/hT5VSN9ho79pp9em0R3X6LNB9Nkl
36JdvR3ouDx6eR29u4qeU0yvPUI/v54e4KI/u5hebjh5f1pk/Rh6srcd/VoS
vXmY/sU6+vdOem4OPe1z+g876T0f0jftkf1V0SOq6et201MP0H98kW4cpp/c
Ri+104e2yP7b6H9tpCefpkdkyvn10APT6dkD9K9X0zeMyPop9INuevgK+jOX
6FWJ9IZxeuUS+nMe+lQCvfd3ekc8ffAKfeIuevl1evYddO8UPdJKj56lWxbS
TQY7ZQG71Yf9QQx7jR87IZpd78/+KYrtCmA7ItlX57GbbmV7AtntEeyzJvYf
t7BrgtgPiq8JZlfOZ4+K/3kze0cIe6f4pPjMTewcM7tKvEN8mbg1VP7XG2V/
4pXiLeIZ4tPiFvHEMPbQDex88UbxGvFS8WPiWeJu8eXifuFyn4rHik9b2CvE
3eKZ4l3i+eJ28ZfFG8Rt4rXiteI28XrxEvEm8SLxFvF8caf4ZvFu8Szxc+Lr
xYfF08UviKeJj4qvEh8Tf0jcI54k7hVfKn5dfLH4tPh94rPi8eKG9D3SvtJ3
SvtLL5IOlI6TNknHSgdLL5AOkb5d2iwdIx0qHS0dJn2bdLh0lLRFOvJ//0/6
38LD+TQ=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1O1PlXUcx/EDpBCJuiOm3R0h0bBlxwkPAk0BK7IaBd2oI4Ohctu8IZNI
MFMKgoZSCwocYwlG3pwEkVkgGMHhdDJDnIRK7hSiCYSFkIIo1YM23p//oK1H
1957/R5c137f7+Udsy5ijbPBYJjrZDD882z0Opgcn+caNNfD3BQ6s2vxv/1s
6mHb2H7MFgV3RGXCX12dA//I9Ao8LqkSbvILgKcvPw0/4zsd7lI4AI8vGG4e
21UfTLaO7dXeDnhv4Rz4I6/Z4EedguBTQw7BezxegLs/XQK331oDN0fsgI/z
2AT/1Xsr/MWkDHhAdjL83tA8uH90LHzYtguekB4Jf3LqZ/CU+nB47jMH4R+7
LoVfyjkCDwkMhsf8Vg9vWRQID8uywv1G/eDZG47DLXEPwxtqTsLzY+fA96e0
wU29PvAFVWfhXt1e8NYt5+H9z98HT+r8GR5supvz03uB97toGjy69BK8bb8n
/LKxG94TZYT/PcHwX56bDC+c3wdfmDoRbvv9Cnz2qQlwz61/wBNX3AFP7OqH
R7u6w+fPGoB3tLvx+5cMwu+3u8LTlvwJP/fjeLjF9xr89tFx3L9BuuFR+ooD
1+GRO26DF4cPwQevusBLLtA74+nm+GH4ul5nePdP9Enp9NDQG/BVd9Hzyujz
jjnBrw7RV66nb3p8BN7nS3d/j264bIBnNNHtX9B336AXpNGND92EW8Poicvo
TbPo/lvoU5zoPSX0hY5R9Eg9vb2Bbj9Hzymn7xugO+fRr7jf4v9jM73DRJ+e
QK+YRw9cTt8TRPdeSu8LoxcvoFdH0jPN9Nlx9MM+9FUb6OPvob//Jv1lI71u
G73Ine6ZTd/rQi/bSd94k/1OPrvrGru5iN3bz04rYb/Rx64slfPd7JRyds9F
dts+dk0n+6yF7XCwcyvYEefZQ4fYbh3smdXskTPsKUfYD7SzT3zJzmhjR9aw
J5xm19Wya0/J+xxl72yVfalnbz/JvvMY+8MW9rB4zQ9s69dy/oTcdwM7THzG
N+yq79kV4g+K+zeyLcfZn4svFjc2sTu+Y68X3y7eKO4nPskq+2OXeRQ/IJ4r
vlG8UTxYfEDcU3xGs+zft+wnxK3iCeJl4lniWeK7xdeK14q/JN4qHiJ+Udws
fl3cJO5mY08UnyZuEPcRH5A2S3dLB0g7pEOk26Wfkm6RDpe2Sy+TbpReKV0n
HSP9lXSsdLV0onSl9Fppi3Sy9F7p16XLpVOk90inSpdKb5b+VDpdukT6Leli
6beld0lvky6SzpD+RPpd6QLpTOl86az//T/hfwHdMuef
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzl0+1PlQUcxvEDicQYzkiZJ10EOtII8SkCAQUJJwwQkWDDNhXXfGgKJhKm
YgsREQUU1NREVB4OhCQIKHLSE8ggVGaKm+nEVhJG5oSRZxJZ60Ub3+tf6NW9
z77b2c7vum+3xKSYD20NBoOXjcHw73MofZ05pcA+6FHe5Ri/KT3z/3N3RG78
SOd3GJaOdGBWNPor4f7oyW5G9ABLErrzpt64kc66VoT+Rs9F9Gd/taN7Pj2A
3t71BN3yWhK67ZWxsSM9YI1CvzrLG93ZYxZ6yfZw9KzICeifWxPRLa42/P2+
NPTwuMfvj7Tv0b3ogzU/oBcFF6GPH2pHN7lUo9/9sxE9NcyMXptdhe5t9x26
+dNi9OzkLvSYyoPoftXd6IesOegr7veiO4ZmoP9qfIq+IG0revc2K/quLSno
NZNeoBfO3oCe6TQKXlawBl670gG2ZK2C86eOgdfbLId3bHSGTw4kwAFhLrD9
4nju02SE8xxj4fKbk+DI15fAs79whT9Ij4KzxrnDzZMj4JmLp8Dx9uGwNcoD
Puu+CH5inAo7JS+Ed9dPg0P63oMrPTzh2r0hcN3Gt/l/ly6ADx71gsfMDYa7
SqbDjwOD4CMF3nDnsvlw09oZ8Oj98+Ar02bCb90LhIdvs7/qy74heRZ8ozQA
7h9iL3Vnn/rJbPilM/5w7i/sO0PYU8PnwI8ezuU9S9jH5rOvHmR/HsKeGvAO
bP7bDx6/nT27md3hPLsph932N/bkBPYiow8cMZ39oxD2htHsj9aw+/zsC+/a
w76ihb3KxH6rjL2hhd13H/uze+zBqez1/ewVK9l97N6V7539nAv7yXnsiR7s
bd7sm+awb3ZnHxvMnuHCviKC/Zqj3DeOfYYt+4nl7Aee0+2r6Tv9tDGJ7uuj
KzbTdQ/pnK202wP65me0+106N5Muu01fz5Z9vqeP7aNHd9J2++mrHfS4Qrqn
jb51iI5opcOO0NZmOv0Y/aOF3nKcNlymg07QS76RPYvpziZ64Sk65aLc/zQd
2Ch7l9BvXqDNpbTXedpURkc20NvK6Z31tL+JvlEne0mfLn1HBX38HP1yJT1R
eob0slp6QPo86bFfyf41dLX0HOkvpAdJD62ih8/SmdIt0i9J3yO9X3qCdNcz
cn/pi6TbS18v/eHX8n5Kb5VeJd0kvU16nvQH0tOk/yF9lXSHajpa+kTp86V7
Sp8h3U/6ZOmh0idIj5buJD1B+ijpidKHxevEg+KPxb+L08S94nTxT+IM8X3x
bvEd8V5xlzhffENcKL4uPizuEB8Vt4m/FLeKi8Qt4mLxt+JTYov4tPiSuFRs
FpeLm8Qm8UVxhbhRXCm+8D/t/wAjcGVO
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzV0/1PVXUcwPELbBG7487JkIceiIAUGJLconI5NKKbRgoEQSFyhbExphAI
dKWAEFEkkAd5CkNKu5HAlYgn5QIWCGmMKJOgBB8SHE0pCR2Ug1o/tN335z/o
p7PX3ufs+/me7znOMUkhceYKhcLLTKH49+o96fpAToXlxuNJTh0ebtN+/7nZ
y9Bt6l5DOvq87k30LNsB9N9cV6CrCpWdptZGDBtNHXN1C7pVUCl62flc9D3b
I9Hvznag377qgf7g9BS6MfDvLlM/8ZTqtKnzXMbRrUPV6Bfn2tD9WkLRB4Iq
0DcaUtBv3dCht9cVoa+NiEbfOaZHn4p5mfMdNaL/8aUaPcxjBF3p64we13sN
/f77K9DrCu6gq8rM0L17ltGzHr57xtTl2Up43mIGdlxYBdu4TcIvBjjD9tof
YJ98Dzi1+hv43s8+cGZbH3wjbD3sUmuEx1Sb4KYN7bDOQUPnNsOJBwPhC1EN
cHV8MN9Xjx5+bigMfq3iY/jx7jfg6+O18PhLUXBwZg3cnqaFL+mqYMuQWLiy
rxz2nIqDG0PKYL06nufvXAI/rUngeh6H4duuu+A1cYWw38Xd7N8WwLahSXCM
9hA8euotuMEuH067mcz17hyA9y+nwGdv5sG+f+2BXRf3w/ETqTwPZ/aW+jR4
WZsLx+5Ih4db98Fl5m/Dq+3ZH6tkDyjMgbsddXCxin2mlL2i9j3YfInd+ll2
/6i9nH8iGz7Xyj5UwL7PLAN22MQerWGfXM6C3Q+wh/ezV/Wy/1TE/uoc+0AU
+/VH34FLfNjHNOxGJXv9LvYfZzJ5fxF7xgX29Eb2VwzsawfZF46wr7vCrs5k
H5xn74ln97R8F458nf0De/bRAHb/Nez3fdnDfdlPuLMvvcCuf4R9+1b2yZXs
5RHsXlbs/TvZ9yrYLRLYP12kE5PpY3O0g44OvEXbZYnnp8U8uXTuNToon569
TJ8spIfH6LISMe8l2racHviOfr6K/nqYtqmhVw3RdR/STefpX4/ROYP0wkf0
4XP098fF/vvojE/o9V/Ri3p65CwdXE8f6qXzPqPjeuiak/SObrq8gU420qmN
dG0XvaGJvnKGnhd9nehVBrryNO1+ilaKbhC9uJN2aaadRC8SvatDfO+iR4vu
/zltLXqp6P3t9JjoOaLbttAa0QNFXyl6tui/tIn/QfRO0UdFLxX9T9ETRXf8
gt4m+jOiq0UPEd1R9ATRLUTPFv33VvqI6BOi60UfEr1d9G7R+0VvFn1E9BOi
Xxa9WvRp0YtFnxX9oOj3RM8WfUl0negWwinCVsK7hVXC8cI2wrHCdsLRwg8J
Rwo7CYcLuwiHCrsJhwivFg4SdhfeKuwpHCjsJbxF2Ft4s/CTwhphH+EAYfX/
pP8DlBxpDw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HtM1WUYwPGjHYvlEZRLcQkTCVY4K8AEQ0DMKYxNMal1yo3AIwWFZCJ0
wdJgVjA3UxiFzGgC45LhiUhESG6iIMKJw0EgDJCb0LgooAcJbG21ne/z12/f
fbb3ffd79r5OEbGv7l2sUCjWLlIo/v1qfHp2HMt4bNMT+lcmHFwH/f/vXX3u
RtNuiyqD122svW/a7VFOk6adkxEGfzj7Odyuawl8wNkAtzcrvWfaJe1Od0y7
yO99uH4kEh6hdYNveToX7pw/MWPalS434asPlcPTMi3umvayUynww0t94VGf
hsFXGvfC7XK94WH6FLiqyAZ+WfkjXLnm3rRpfz3SAE9p6oR/bxiAT/lXwXOt
5+GJvgXwn0ctp0z7y+Q0uH26K7y36wjcNtgb7qjaD4/yC4SrRsLhnadehz+3
LRRenboH7qYIhB/0iIWn3dkILz73MVz9twd82DkJ/oXSDZ6flwrvmXSCd4Sc
hNcU2sPnvTLhFY7W8MTYbPg7XubwRrM8uOewGedvVURfqYS7nC6G329+yHmV
lqA1Y3NopeY8+uQ+I9qjtBxdGjjD/bSV6MkP76LLIqrQIYMT6EdaatD5346h
c+fr0ElH/0JXT9ejlxeMoLsuXEVbzg2jR3c2olsThtDR1de4vsMgeo/qOtrY
24+OX9+Mtqu/hR7e3IJ+40ofumidDj3S14uONP8dHWRFT2yle6p70DZJregs
7Z/oVav16LP29N1a+qUTN9FvebShQ23pX+XRrQu7+V5YGNANW+maGPrusT/Q
ATV0fRa92LwdHRxKT95Fn7WkH/mG7tLRhX6tge52hp41R487QO9/9gbnGUgv
3ElvcKJr4unjC53ohAx6ag89oJS+tZZuo6PrCuh+t+n9J+iKBbrvZ/TvVnSg
c96j+zvTB96kP+NJbwmmxwXQN/jR1dvp8+70GTXd6EqP1tBVjnRDDP0pa3pI
PN1CRZ8+RNcp6W3J9KAF9qOp7HeN7MzjbMcpdnY6Wz3Ods1kLxtlv3ya/cIQ
e+gHdskt9rpc9vEe9vP57Mpudnch272Lve2sOM8Ndlwx22BgR2vZD/TstSXs
7a3s2l/YTTpx3l/Z+1vYn5xnezeL+1Qm5nudfe4Ce1WTmH852+ea2P8iO6aR
7Vsh5tvAHhe+VPixSvbBq2yH38R6V9hZwg8IX35J3BfhHwk/U89uFx4kfE0V
e/YyO0G4VvhF4R8InxW+XviL1ezFwsOF6+vE/xdeILxUeJLwTuHhwh8IDxBu
W8N2Ee4pXCU8WPhMLftt4X3C44Q3Cz8qvFJ4uvCfhOcIzxauFZ4mvEJ4ivB6
4YeF64THC+8Uvk94n/BI4beFhwmfEK4WPi08VPis8B3CF4QHC18kOlD0EtFb
RJuJ3iz6cdGbRKtE+4k2F+0jeoXoDaKtRHuJthH9kugnRXuKthPtLtr+v/4H
B/S24g==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HtMVmUcwPEXkksFFogNWCiuCMKSBK0oBQkl3oGoCAFKCchlBgFRFDMI
Iy6BGmGFxEVDmBaBDOMWYtxUBIwQMFggJE6UgkIUROTSarW939/7z9l3n7N3
z/k9zzkrAiLcg9QVCsWzagrFP9ev/v1pbag2MZ7XMb9u/39b5Do+pKvSUa0V
cP3q0gdVPUX5yoKqe9tbwjuXNsD1W8u0Vf3lJBuFaocv2QT3upgNf3VqSEu1
C9Sm4TpvpsGjTV3VVHs6/iX4sYez4Af9JjRV+2p6P3ybsgx+J8hYXbXr0t6D
Z61xh7+d7ABXHkqER5TowXs0T8ErPhzWUO3LOn3wjqQ6+JC+4gHVLvLJhXfF
roCH5cTCGwrt4XGTu+BzfTvgecZO8NHQd+AG51bBL2SmwqcqjOBeWXnw2HJN
+IHjpfDdBycXqfZjE3V8Pv1h+M3j7fBeo174idE++GxcG3z5jRvwnsfr4bmV
E/Cangq4Y8wsfPJQMTzYSQOdsrYQ3fCiLvraN7nopkAD9MneL9GNV4zRqafS
0dYVpuhBszR094wZuvqJJN5fa4n+4sg+tIW2FdohLZbzuWnN5+2LQReEPI9+
KjUaXZVui96bGoVW27OO+90dgX7uvh3ab/dbaJvNDmg9q1C0S5Ajunn1HvQy
5Sa0WXAI+uycE9qjOQjdm+KMvrM1EL3vDyXaYCEA/cEzLpxfuz/a0s0VfbvG
D529fTM6s3EX+oC9Gzpy6A10nMEW9JOG9OJueob/65xfwlZ0W60v93PZNn4P
LOij39Gv5u9Eh6505/tiQY89Qo86vQPtqbkd3epNXxxIb1jw4fmupgeX0mcW
eXD9wfRBJT3cjK7zCd33d2/ufz1dt4LePkG/lUj/2NQTneRDb1LSPa3p8+H0
qcX0w5/Rdf7yQo+cpK/vpDu3Cq+mzwzRm7+mb7xHz95PD9B9jec9hp62nG4X
Qh+zopd40Svt6PlK+iOu9Nvr6Mbe9ITV9HsB9FXm9JYwer8JvTCaHrWUnh9H
79Ol9yTS1bXoPvvpXQq6bYaY7312ciZ77RR7Sw676Bb76FF2xhg7sYA9MMLW
PiHWMyzWUyT25xp7SQm75Tf2t6VsjwH2fBnbpJ9tVC78V7aiku3Wy66qEuf3
F/bGH9hrLot517AHu9h/nmYXd7L1zrAPX2Ib/sjO62Br1LFrfxbnXfh4u/i/
eratcJcG9uc/sUeEz11kxzSyo4VPC59tY4c1sT8V3i18pXDrs+xLrewU4R8J
7xJuK9zwHPtuC9tLeK3wdOHJwhuFewofF24p3Pi8+D4J3yB84ALbX3id8Hjh
x4TnCE8RXi48Unir8J3CB4Q7Cx8X/oJwRTPbXPijwg2FmwjXEf60cDXhNsLv
il4veky0k+jrot1EXxHtKbpHtK/oDtEBottEh4g+LzpUdKPoSNFnRL8rukb0
+6KrRO8V/b3oONFlouNFl4pO+K//Bi8L7nc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1XtMlWUcwPEDKHhjWFwii4YgWuhJ4SySMFBJSURAOYokhxamlLOh84aQ
UCMHeEMoBUJAxIMcFUMIw0OETgPJ2ypkMweIBzRRSSFBrra22t7v76933322
Z+/7Ps9+z+To2GVrzFUqldpMpfr3eb0vzKTPtZrrqdl5Z3hah9//nai37VH2
wjtak7JzXYO7lX3kzMR2Za9Ozn2i7BkHjfCa3v7Hyo6Yre1Qdu2tGHi2eyt8
Y5XpL2XrGiPvKvu513p4dfw1+DwXFbzS/617ys6Lzu9S9izvTLjX4AJ4yeK7
8JVWvY/w/lrPP7FeVSm80nEbvHTZevidRZXwo2oPuEXaI/gLZYMPlZ0T43xf
2QdDLsPf/TQYbp1eAO8ZFQcPGN4G1xXnwe9qtPCmU7Xw8CYNfO3WFvjt/Q7w
sqABeN1LQw+UfWa7baey901th+f4usMXJV2D+zX5wnvuG+FdW5bC2zQG+I0l
0XD/mTnwnWkb4YbyXfC1oUnwnOwdcKe63XB17UZ4x7gs+DmrGLpPITxrhQ4e
v+k4vDBTC/+8oRw+Sx8ETwgzwi9sXwDvn3IefnXYF54dUg9PcfaGB5uuwOt/
08BTun6F/245Ex6S2MT9KXOHb87/A956YSq8MKIFnvS2KzzpbBu818wZXlfX
Du+b5ATXpd2DqxImwWPGdMIXvuII/yDwIVz/1B4+YXkXPH2UHbxe/Rg+Mv9F
eOjNJ/BPTk6ED6zqgZ+eYwMvPfs33PmxNbz76VP4qgsTuL5tHzy8Yjz8uMMz
eFjNOPhhVT+8sWUsfHYjPdeefuDrAXj+h2Pgx+YOwq2qreDqZvqMqfSadUPw
PQWW8Iud9Mtu9H1Rw/DSH0bDA+rpDlr6kNsIfPTAKHhRAj2jhD6pgd4RRXe3
eQ5/71V6SjDd/LYF52sKPdlAN1TTvePoqZ304sX0h3Yq9ApX+nwfetuIOe8H
Hf1eMz1wB93+HL04h+6kpwdV0Kv20JN+oZdspce30iuj6Zu66YZQep6FGTp8
Lt3Fln7Agz59Mt1nCr1ZTX/Dkb7Sm+5rTTf606Ms6K8toW8YYB9aztZ1swN1
bJsH7Dkfsze3s79ax05oYXtuYNvdZC/fwvZoZA9uZ/98nT0rUfhl9vCX7Ncv
sT/byTZdZKelsrvOsyN2s+fVsjv2sm/8KP7PfrbeyA7IZJ+oEt/zDbvtDPvW
AbZ/JXtNFvtqBbshmx1fzh7/Lfv90+w3c9maMrbXIfbs79hueeK8nGIPCU8t
Zdfms6+fZMcWsKcJtznMTj/BLhBuKdylkL3rODtb+MvCLY6wvzewVwuPEG4U
bil8bBG7uoQdKnyb8Azh3sKvCDcTbnZU7M8xMQ+EFwqPFB4nPFl4mPBjwj2E
1wu3FW4S/qxYzB/hrcLt9exLwqcLrxDuJ/yw8KXC04V/JPwL4bHCNwlPEB4j
PEV4pPAM4cuE5wpfJLxI+DzhJ4S/I7xcuEZ4lXC18J+ETxN+UbiL8AbhTsKv
/uf/ANDYk6c=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd0ntMlXUYwPGDpWkig9K0wOQEdkhCVC6K3K9KoAmJ4kRNjYDUg4ELE+dI
gpGaVhIQcYRACRBFNG8l4g3zAo4QFFCESCWBA4iohDFaW23v9/nr3Xef/d69
7/N71Kuig8OHqVQqGwOV6t/n84uMbA7rXvBoqliS1WV1z/3/tnjQcljZGzK0
OmVr3m8oVbY6PmqPspeltB9S9ojbgdnKTjB5CT7Q9VqOsq+0zitRtupIHbx8
XNZBZTs/3fKDsjc+HDig7IgVE3KVHXY/Et4dkQf323a3WNnfRqnzlD2UuhZe
k7UbPqZpaL+y68yewRsW6uB+7aF7cX6kD/yM/gDc6dVHRcoeOzAALyovhAdd
89in7M2+EfDs8Qnw+uHWcH3MSfjiNX2Fyo7T6uFfdZ2DW243y1d25dg0+CXX
OfBa7Tq4d886+O30ufAdw76Gp9hr4JlXD8GNekfC3TOr4OFJ+gJldxxtg28r
qoUvXTHE77M4DXf5beyPyt5yshBe5mEFr56VDje64wTvjU2GN9X6w+d5xsHP
BYbCZ8RHwbOiwuGfDoXBewI+htuUBMFnmmyGu2vnwCfXJsF9LNzg3cU74dOO
O8CTS9Pg5uOmwq881sHfnKKBn9++F256z5yeWASPdTSFZ3SWwMcbvwIvvv4T
3DPcBG7lexK+fMoYuHFgGe934Sj4yt4z8E23hsM1nhfgS44Og6d5/Ao/0ziE
nth/GZ3lM8h90Fait3YOoCsKr6FzK/vR20qq0Sean6Cvfl6D/tv8MXrc1Fq0
2Y5H6OSSOrT1xF50o+FN/l91D+/bvx7tkNeNXhXZgDb8pgsdvbYRHZ+p53xD
b7F/7kQft7mNPt/VgZ7fTY9zpJ/d04Rev6ud73O9gzbuf4BurqI3a+nxC5rR
Kb1/cr4X6Tc/o78xowV9zJQetpuuKW/jvnfQfdbQFzn/jnadRD+eSA9pvI9e
UEFv/Z5+QdWK9l9Nz3ekD9rS4yPoCQb0st305TfvoRt+oduW0u1a6Kk76ZMN
/kA7RtMNJtEvB9NNZtOHO9EzgunFanpNJD3RkN6/mR7y11200y56Xxu9Iptu
X08/f5Cuv0xfeoo+eIpefInuXUq/cZ2em0/va6KrdHTzNrpvKn19Nz1sB/3p
E/r0JPqVQXrpFvqz59hVG9lpo9hxsez9RuwcLdvvZbbrR+wN49neH7JdTNmF
q9hFr7PDV7AvqsU8w9jpluxzS9iWGvbCxeL73xL3GcL+0pqtfk+ct2EHB7Hf
tmUffJd9ahp7+ny2Zga7PpAdbSfuL4CdYc9Oeoe9z0G4P/s7R7ZuLvuTmWJf
57DdZ7FHC38sfJkfO9OJfdaXbTubbSf8mPDDPmLezmK/hecIv+7NHuHCjhG+
UriZ8CPCq7zYQ8KThXu5sn2FJwgfLfyE8DpPdofwfcInuLE3CfcSHiw8Qrit
8C+EGwkvEP7Qg31B+A3hTcJPC+8TXiD8RXd2qnAz4VuF2wiPEe4qfLXwAOEh
wkOF+wv/QLibcK1we+Fxwq2FJwi3EJ7yn/8DlX7rWw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1H9Qz3ccwPGSfkxZqtGPZWJXFy1R+JbQV5EfEynsNC0kpq98SysZSj9o
u6R22YWpFrrVWmWrdGYiHKUarimNpS65NnHFvkzRdrvb7j7P11+fe97j3p/7
fN6f1+c9caM2KGKEnp6eq76e3r9Xr6r6+NoCY3V5yFqX+5N7fP7vbxpeLVF2
13DDe8p+npC3WNnZTTZTlV205aNFyu7oWOym7IGCOf7KfmocOk3ZJ2NmLlR2
adsH05VdrvFfoOzKQm93ZUeuifJTtnHqKA9lL5pa7Kvsoc1X4UYTdPOV3Wga
M0PZW5KC4OeMzGYqe1pzrRrvf+0I/HiJJ3xvns0sZdu21vrgfjUH4SunB8Kr
nZ/Dk6oezVN2fN9qlbJfRWfDH/R8Bzc5NBee2T0Ev+7/dK6yzQr9PJWd0FsG
v1SfBq++qYVrdBfgJttU8JxKHTx1xkj4rylOXvDTt+co27UtCJ4VUwpvsd0N
D7baD4/8tgBeMXsjvOH+RXjnYV/4DZP78POtjvDxUYNwg59M4XUBVrMx70Z/
euP+PZPhSYkd8P7IeXC//uvwrtEr4VmuZ+HdgxvgHmYl8CkhMfCuiGNwr8Ak
eLN1Jlw1nAEPG5EMV6fkwntM4uEVLwrhARbb4CE7S+F9BuHwm9ZVcN/GEHjW
43Pw+uBguLvpZfjljGXwguQGuE24P3za+htwp0Y1/HbVL/CiM97wWQfb4am2
Kq4f+A3e1OsOn9jfBT9o5wbPze6Bny1ygbfc7YVPSHGGl7Q/gi8uduT+ffEE
rrV4l/NnMkCvcYAf8X8G//7wO/BTK3TwSafs4fecX8Cdu+y4vvUveM4iW/jL
dYPw3BZr+K4LQ/CLyePgWv3XnM/lY+F3HIfh8z3fgke6/Q138baCf+Wgh16x
2pLfZ4iemWbB9Zf00bqrY9BLd45AX7Gjh79tgN6QaI6OOk1f2/8mul41kv+z
ll7zA919cDQ6dJIhujGLfiWdPtmNfrebHtFmhk5SGaFPp9PjUunLfOg76umZ
r03RdsbG6LY6ur6anpdBr4ilrwuhF5ygF7rS1c10fUP6i2d0+85RPF+sTdBH
a+ljVPQpX9MtVtEPpNG3bqdrNPTVB+gFq+jmx+l/+NAbK+j2rvSaOrqxPX34
Fj3NjH6tkx41/AZ6xhP6iQF6xCDd4CE9wZAdd5edbs7uvMUusWG7NLB1Dmy/
OnaiM3vsj+w1buysSnbmTPbJMra7N9u3mB2kZq8/yX65gD2Qz/ZYwv79GNs0
gK3OZX8WyH6cw64MZvdms3PWiP0/xHZbyy7PEPv5IVvzOftMKDs0nV0axt63
n71jA/vnVPaYcPaCFDF/m9gd+9j3IthHk9iWW8TzJIr9+pi9ea/wrWL9HrZV
JPvL3eyHwps+ZRdp2OOEB29jR+8S8yi8PYGdHMUOFG6wnX17J3uX8E3CHwgf
jmcv1LILhecLDxD+RLi+cFU0+1yceH7he4RXC/cT3ifcXPj4GHE+fsJeKrxa
eKzwQ8KPCNcIPyv8feF3hLsK1wm3FG6+Q5yHsWwn4d3CvYXfEL5c+HnhYcLL
hGuF5wvf+5//Ax/ywvw=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1Hs01nccwPFnJLowt8rWFKkxRHNa6f6kc7rQSjpNp1KmR0xGF5cVRYRH
qyVzSaToQa5FJdVanTinTS5J03RvTaOYdFvj0M7O2c75vr9/Ped9Xud5fp/v
9/d9vpY+wR6+WgqFYuJ7CsW/n0HGsZdrc3SV5Ul2+xtt2+b83265TVViT9cZ
eUBsn4v9lWLPUt1MFvvek+VnxDbXBKSIrfC8fkpsQ++7qWIbHA6uEHvZQ/t0
sUPSHcrFTrFcd1Ds44FDT4rdfCc0Q+yq3YoTYoeptx4Se3WsQZnYvX6rMsXO
cnEqFVs3wT5L7Ff1X5WIbVH9DH7L61Sx2LcbMg6LXbZcH37hM+dssSdMCSsS
+4d1P8FvlHYWih2R4nZEbJuYYLjVwBX4mbT+42IblTgeFTu9PRWuTE2GO+yd
Cg8/1AkfXvyoQOxF6tk5YuvEfA9/YpYIj1y3GH7pdR28NmcY3ODc0Fyx689c
z8e83S7woyMy4XdHhcFVCwLgawo08El3Z8EjdRvhpsEj4IkHX/P7mud5eF8V
ZsfEbrduhJtrnOHjyk7Ctc6ugGf1pMDb7TfB3U9FwJ/PVcMfnlPBf7HPhps2
LYVvGFsBD/h5Jvyv+TXwY+F28Nq6m3Cf06PhgS2P4S2r9eF68T1w1ecK+Lne
fviXG19pcF7ch7APdaAH55qgTaofoFt1zNHN9S3ozAMT0KfzG9BVKyeiHWZc
Rd8LnIz23X4ZbXF/Olqx4jx6wgUl13PxNFppNB9dnXcCndTpitZoF6PHrlyK
HleXj37rtRxd+DqXz9f1REeFH0EvXLOK+7coi/OovNAGvhnoadbe6N4raWi3
Ih90pFcK1/9ShR7vmMzf1/ND9zklobW6/Lk+1XfoqfkB6LRLe9E1UwPRu5Tf
oqfnfY2+8zgR3dIThN6br0bvs9iEvhKXwP2cvBndtTMefc1hC8/z/jieR5Ot
aO3K3ejy3+gPu2PRlUdCOO8M+o9uoeig9Bi0ezvdSIveEBaGtty+C73zLd1/
IBodHxTO+2Mf/UUr3cOafnbGN2j92ih0RQrdNpRe2kbvsKZ7O25DZzzaiQ7Z
Qs/MoUefoK/1oxv+Qfdyoh/9YDvvKy16/gK6c8sOtHozfV4ZvSCd3pZIX3me
Xu9Pf9ZKL3WlF76huzjSrxtGoJeMpGfb0DPeRfJ+m03/8yld4UEf8yv9xXq6
4ip9fgg98CzdKpY+u5BelET/Iovel0VPS6JPOk5vi6Ovr6DbRUrPv0B330o3
r6HP3Uivv0bvXE+vu0Gf40W3a5Xm86S/uU/XLKPP/J1+eDFdr4M+ZCF9Qxf9
/jy6dw/dREl/94qePZPu9pa+bZrkfdL8U+g6A3TtyfRoBTvvU3a1FnuHI7tp
EDthIrt8MPuiHdtXTzovttL/Zwj7mA179TC2qzVbM5xt+DG7UZ/9cjz7gQG7
24p96322tuRVhmz7cex4I7a/JVtpzK60YD+V3FTyOBPpfY9lG5uye8ewkyWP
klx3hLS/km+WvMicfUPyJZLbjWT//RE7QvJSyWsk95N88Cj2J5K7SN49mr1N
8vOSl0i+R/Lbkq+VfJAZe4rktpIbS75Y8p4P2YGSN0uulrxK8tz//B8WbfQu

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd038w13ccwPGvH2XVikTKEda42URNP+gH34wvKpVW+qXNag0n7Khds2+/
SN9Kdf2wa+y7dKUfujr+2K2oI6VNvhKJkl8x+iYyq/BNym632937+f7rc897
3L3u8/683h+n9fHLNhorFIopRgrFv8/sb+eNfHDaTPmd5Yo/ij5p9/2/Vx/q
HBK7tO/xbbGbh9Rvxd68y7Nc7HUzA96IbVMYWiH28gjf12LnqZSVYpdNiOwX
+6cQk3tiX1t3pVfsc2dPVIsdq/F4JfaOu9Y1Yscrb78Q26U/plbsTduT/xa7
yzT7gdipP6zqEbvoxPWHYi/JC/pL7CfuJXU4f8XSbrEDO/IeiW1xNe652B9X
7q0X+8u0k134PldCGjB/R1un2CsXGzWKHfXOC55mcwZumq59JrbZ1tlNYod3
jYaH/HoDnlqV1iF22CufZrHrPrKGm6vy4Ed6zj/FfrNsHot9eJ4Knt2yBR7r
3aUXW/dQB89wzIQ3+tq2iJ2vXAL3KP4K7tw/Ej7BcAqenFv+RGz/hCZ4Susx
eGeeVavYN6wi4G2uKvhvNVPhF4IS4fmFw+B+8Vr41ISmdrHH9hfDCzIL4Kem
tcGTnmXAl0ab/In/x1YN72pxgN/piICH1nnD0+yD4HpNKPzWjmnwyU6R8DXN
dvCe6iR4kvlI+ETdAXiQ3tAm9pkpv8DV8zvg7g4X4baDj+Cu1/PhjoY7cE/3
3+GBE2/AQ3ZX8fwBl+Hj6+vhNt9cgg8PboeXfp0NP976HB7sroUnFfTCr+el
w6+0DMKf1R+EN0SaoLtPatCWa0eg/V/sQqtKx6DTb6rRflfHoX8esRV922cC
2qogEX0u3A59ShePvmvviL46YxM6av9k9I89UejWHBe0de9GtFmKK7po7gbu
z84Nfak4Ar07yZ372v4Fz3d6KnpOXDjaUfspesuBNWivqOncV80qdO2omegw
/5XofftnoetrV6CP6r3Qmn3L0U+cZ9NXf873C5qDDvBfhlaEzkVHBoait/nN
Q5dGLOW+J/mgEw8tQWfo6VkVi9G6E77oiw705gAl2n5nCFrZRD/evQjtHT2f
86LpBj39fs9C9JG1fui4ZPpQCb3Inu7i/Bm6q3gB+qGa7hZHry6n65zoJdb+
6A8agtELVtEztfS+dHrOevqicnrVFPrNd/Sst0HoMrcA9IUq+q0w+tEcuvk2
unEqfSCLnrOBfq+IrgygNzbQU1zpa/rpXhb0FHMV2vl1IDrNmW7bRs/2pndU
0g0L6dFF9NxwekIu/XkMve0k/f73dO0xesoe+k4NfdxR+hY1PUtLX59A9zlL
94ymm+TSqyPoxpfpHqvpiwvpXsvovSX0xoV0Mx19rIp+uJJeqqRra+h9c+iz
HtEPz6LHNNEPetJ9W6X9etAL2+mH3OjdT+nJrvTaTvo1F7q6mz79Q7q+h97u
RLd7SS9zoE/qpTfb01/20R3spPtnoGts6c4DdMuJ9H1v6IU29IpB+t7x9L63
9FhruukQPcaKPiD5znH0egU7x1JqI3b7WPYGY7an5KNNpPtuIc2X/I25dL9N
2Zslz5fcMIbtMYytkTxTcifJByW/OZodNpwdK/l5yR0kfyF53fvsGWbsDMkT
JV8n+UXJXSRvkfzVKLbFe//1P0W7tCU=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd0ntUznccwPHneZRKicyISiV3MWlUp0kmLbJKZGSiJ4+Siugyum2ScEII
x6l2QoVntjIzMhZabStZyahDe1ZySxckpevOztnO+b5/f/3O+7x+l+/v+/la
Kjd5qxQymWyaXCb791pzu2PpoxwdZ711U6vyrB/P/b/3OmlZ5Att0p9yT/TC
gt9MRa8YnV0j+qTQu6NET7KIfij6KTvLkaIvadLXiD464exw0W1rAutErxsX
NEz0KbcOPBLdJGbFUNHXOu1+LLrCMcpQ9DBXn6ei68VeMxC9NqvrGf7/myn6
otddimkUPXDXFT3Rt6gfvBB9xtBgXdGLvc2aRdc5MFtH9FmL57eI3rzTbKDo
5zs9W0UvU5tqi346acFL0Qte2GiJnvJy/CvRz61dNUD03kFt8KTFxxSi74z/
7rXoW40b5KLrV6xsE/2MlzNcK+AtfPkJtUz0hbFJb0RvrbKEX3fRbRc941Z2
v9g3yhLgHckz4W56zfAm49I+sXs1Xm/FLs8NhivMz8HTNr4HP5PYD3f9vqhX
7DdX3DvE3vbndrhuwEG4wskeHmRQCb/k390j9lRH/U6xl94sgusEOcPDmlLh
XvJweGqUEl6zMRPuI7OHlw4ogZ+0MYKvNnsBby9o7hZ7t/bgd/g/z3J4rsIa
fjovD67l4wb3yEiDK+2U8ITaGHiUZhu8fq4K7hN/AL4vzQte7XwKnpE/By73
ugjXhFjDXSuL4Yk5pvAnT+7CbzkYwj/Ir4ff1pfDLy9shdvI2ruwn+Vd8M7e
53DNUm20e4sGbf/aEL3o6j10ztWR6Pplt9Hris3RJ3NL0BZmE9HpJwrR71dN
Q8+xK0DPaLflen0voCenOqCVfd+iT+U5oTONz6Kd/OajC7/ORp/P+QSdkJyF
frjfnd8vzUDXWnpyPWuOo8es90ZPdz6KXq/0QSerDqOfmq5A3/w9lfNO90VH
Bu5HX6v/HJ3nkILu7PBDNzruRXtq1qK1gnejL2Yo0XbXd6FLbNehhzgmof84
reJ5u5+Irupej15+aAc6bWYQ+uMNX6GPemzg/Fd+iZ7gHczz65+AXjN3I/pO
fDznaRyC3pcXh172F938dSw65HAout+F3mIfhi7OjUHPrKBPHkEP993E9x/c
ji6rps8aRXdZvBldod6GLr9Ib1pAnzciHP3j8y/QQWH0zUfo736mB7vR03W3
oAcq6E/d6fk3ovn9PfSGXfTMG/RJS+g9b+gGFvRWq62cT1sUusaDblVKN4qi
52TTnx2n+++gq6/QjQLox6vpW13p7W30Rdb0DoMIdMBweqUVfW9fJPoHe/qh
RnqZO927mu60mp79K31GKF11mV4UQ49W04fvof+USZ93hG58iO6fRY9Mpqeo
6dfi6Pcu0B9E0JddlTwfQh/xi2T/VPTpZZL5+NHVlfTPVtCP3aef86Yraunx
n9Lf1tGL3OgxT+jhLvTMRnqcM13VQv/7I3rNK/phB7q8nb5/Nv1RB73clp7U
RXezobf00Lun0y37Jeu3po+Xs9umsHsUbJvJkvlqsY9MZH84kG02gZ2uwy4Z
J9kfXcl5t2IPGcQOHcseq88OtGSbGrCjLSTnb7BkvebsuxK/M4adZsg2kfj8
IewIM3a9xB+aSu4fyvaSeJfEK0wkzxuxV0m8QeKvRrMXDmOnSjxX4nYS7/7P
/wEge6+Q
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HlQ1FUAwPFllWsRcAlQbhZvgvGoVcy09ShBJ9IUDzLWA5UJzSMjFR0U
ahpFTBSRUCayRQ6n0rUEEVSSBlRAIBTlkFMO0UUWFN0Qm6Zp5n33r9985/Ob
997v997vp1i75eP1UolE4msikfx7tfHVpnSnm6sydhWe/8H34Xv/t8kjO+dU
oSf/oroour1DsYPoS+euyhW9Lfu+XPSEYI8rou+UqWxEX7ghvkD0zx73ykQP
9btUKHrLXZ256M22KUWip932NhV9Wtqcm6K//elpqejJyl9LRLfcs0gi+rq4
9jLRTyVMGhT7sPxpudiLt88aEDu8uKRS7PEzIgxiJ67ZXyW2Y1jVC7HnzZTf
FXv4laB+sXu2R1WLrZnf/0zsvdVl98R2/ehin9g3pNIascesPNIrdvVSl1qx
Gz1i9GLvN7jWib3h8KEesQt7LOrFzsjLeiq21roJntlV2y22reHMA7Gtot3h
P85a1YD1WWzTia2cI20Uu3h85ROxN36YDA9IV8F948Y0ia0OvfxY7LEOafC5
K2bDrzc5NYu9Or6iS+ypNV/DI6aEw2dUtsGbt1rD82NVLWLLj2U/Ent5zlG4
ZXcYXGuoh4/q9IQXtnu1il2mf9Ap9oD5WvjuA6fhgfdOwo8qw+Het8rpB/zg
IQEmD7EfChm8Q+sL/za1oUPsc+pl8KgLOXC/1Ei4zPo4fOaVFHjChh3wBa/y
4HujlsGVJ+/DE11nwNPKe+Hp5l7w3RVWbWIPs7WCTytVwANNn7fjvHYr4UXX
muElan94kEsFfHDOSriF/ho8NDcM3jJaC09ujYCfTNTAM+tj4ME+SXDV1e/g
caWH4C2pyXDtumi4W5IG7lOzE34m52e4i/tWeLz9RbjSPQy+MS8fnnZzNXzx
1UJ4p30wfNKbt+C53UvgucMq4E8CA+FHt9yFq8cFwNeF1MJrP58H725ugMtc
VfAJZq3wVWPf5f6Ut8MHvvGD/+bfBc97S8nzE6GDW06YAj+l7oHXqydyf2V9
8N8rfeATI5/DY/Z48/xlv4CnrxgPf3bdAG9fOxbupRng+z8xGt7xySDn13vB
z+pew+XbFPCDahO07XBPdMh5KbqgxB39Z9sQdIbGjeuXmqIjj7ui003N0O4p
LuhlvfSMS87ooaXmvL/TCb0mwQId603vX2CJvh05kt+Pnl5UO4LzxcrQ0wLo
SSOs0K/+cERbJ9Ft/OkXrIehv6p2QH+xi75yK11RR++U06OnWqPDL9uj/Q/Q
lZvojnfomaPoMc42aL+mN9BOwfQQDT0ogf7TJvrZG/Tvp9OjDfRaGX3WOFu0
VaMd93MR/U4OPf9L+pMEunMSXbaDfiyb3hVE31hFD3qHXqKj2ynoBrPhaJ0l
3cONnt8n5/yT6UFN9Jdz6Ydv0weW0udfpR8JpavP0au207NP09ui6MpE+oNY
esFBo/ET6fP20etT6ZkRdJssev1m+m4tvWw9fVIufXMIXVVAz1pOv1RE37WY
nlZqNP9Cut1f9JQP6LJ79LrZ9BN19H0z6dcb6dHT6cdb6TVKukMHff8UekAX
fdtE+lQdXeNDf/iUbudND+6l54yjJz+jx4+hZ/XTk0bR417SbyiMnu9vuqcn
vWGAfsqdvmSQ7udGT39N17sYjS9hFzuzX5mws53Y0iHsvJFsvZFXj2CXDmWb
GnmiKft9R3agmdF5c2A/N/I+e6P/k/l//Q+i6s67
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HlYzHkcwPH0tDWOcjzaHCNaR5fCkEe1le0Syn0fbQ1LHkKsttxbSrZ5
GouKCkNMTVJtSBpH22zJEYmdRJRS1npiV47aLPvss88+z/fdX/O8n9fv+P4+
399vrOTrZn1jaGBg4NDFwODfX6/4Nc86NCYTb6rrg5WOTR7/92Rd8CuxFw6s
Wil2oVPec7EPhPmGim0dE/5U7D2tkzaI7aDPqhM7o099uNjNUu+HYisjLbaI
XdfdpVrsMOm77WKvN4q5K7aJX3SU2IsklpViL8stjRH7YPbHm2LHRujixPYy
tboutpFfVLzYG0t2XBVbPdUkQexeevNSzMN7/l6cX/S4BPuREL5P7Htf6YvF
1tutOiB2cFLbZbFDymRJYncd63lJbJdifbLYd2pztWLHj15wSOySNPcizP/l
hRSxpxW9KBR7QuLHVLFlBWfPi+2/x+aw2Bd8kgvEvvTB+Qj2d9qP58QOah13
VGz7BtVZsVW+A1WYj+svZ8Ruz3wJr77Qni/2SE3eMcyjzgM++pz8uNhPAxJ/
ErtRapwutpWuLU/sqL5p8LcWq+BvC4afEHuJW1Ou2I9MTsBTXdbAo99anBR7
tf3fOWInL4qC+7snw299aoS35TvDFxx2U4v91/3G0/heapXwpWaJ8IL5D+E7
L/vD+x4ZkoHrB3WDd5cFwVMjKrLFjotPgW/blwhX9auEO/rI4fPcu2Ti/2nU
WHjwQke4vt0Err88Hx4xs/6U2BUXt8E/vdDC/0xRwX/elQKXpBbDtbVb4Ovb
H8H7F30NV7a0wcuf+cA9snprxO7t5Ai3CbSBe27qB7cc5wafvcMIvm72DHia
w+ss7Ed9MFy59Ak8vCMMvunVHbhGtxMuK9PR5yTAe14tgPcsT4HH1WTB5zmp
4ZbPjsJ75OfB7R4mwjtmFsHPH1fAp1jr4PKRu+Dpnjf4fCFb4bPOVMGjJ22C
B+6ugTdcXAvPulEHf68NgUsUTfD1zsvgM+7+Dn9uFwiPPPUKro9dCFcPegP/
znsu3FnWBtctnglv+qMDvrg0AK4N+gSP3DwFPj7OEP3bt5O4P6GfoVtzvNGh
5hK0fKgnWhXTDb2iwgO9o6QHOinTDe1Zacb15bmiy/N7oTManHn/0D7oEJcJ
aFOjvuxz49FmkebogulOfN7bn6N1JuPQyq79uN4HMnSzbX90QtkYdKxsALr7
tdHo5cMHooPqR6EnG0nR97vRayrpdb6O6GTFILTRfgf00wmWfD9aRqKNq+nh
8+gjQgaj196wRy9ood+bSk9aOQRdqLdDl1XT3VfTL7lboVMldNfDdPMcW/Sb
VrrBYrrC6wt0sRn9oIJeWm6DPn6broij25oO5foD6CoferQFfUMk/XGTNdpQ
Qw8opGvu0bcm0As/0KUh9K1Ww9CN3nQXL/reYfQxcnqzMT1tOz37xQh0/kF6
ThU9PY9+RUtPLaOfUdNLH9Dl++m+LfTM7+meHzudH0avMR2O3iinW0vpV+bQ
/Wzp9n70uU501Zf05RPpEhn9hyn06Tb0B7PpywbTVyyhj7Wguy+n5/akh62m
X5fQe2yghxvSpRF09Qd2zjb2jPed7hfFXvOavXk3+2ULuzyefes5W6tkGzez
F+1nJzSwTyexA+s6Xf8QO6yWHZfGLqlhDzjK9q/uNO9j7K6/so+ls99VsY+c
ZJvd6bTeDPa022xLDftsBTsji+16k90rm/3kOnvJaXb6NbYih72zvNPxuf/1
P2NiWQw=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1Hs01nccwPEnqYxouoyK3KYbEqeJymXJrVxyqZAwPYwSO6vZE7JYp2JS
EesilUs3UlOjVCSkWi4rSnSKZurZhRxFF9XOzs7O+b776znv8/o9v9/3+zyf
708vJNorVEEikZgMk0j+/dwon2qmVDTKzublrc4E099t/++c5pNHvhM6q/6k
XPRhu3X2i274W/cz0YPWmmaIXmWRNii6fU99quhTLha9FT0kv3er6I7r3IaL
PVoxJVFsj/BYJbGtAzLixd4+uEBVbItqBZnYBscOqou9aWTTerHTvfMnYL/Z
/dFi5871nSj2osywSLFjX1VqiR2/Wz9C7JTSTh2x087qhYm9Ra1aX+zGrMDV
YseZRBiKHePQHIz1trROE/uiaUKg2OtCP5kpdo6Bb4DYzl2GxmJLHQL9xX6u
qDJL7KNKO3zF3jvrhqnYL2Z0Lhc7JGm1mdhDx1csE3tG5wNzsbWq//YWO+PZ
3Dlib+g57CV2u863n4nt1xLlKbZRUbaF2Lpey5aKXZB/ci7mca2Xh9hje3It
xX7kIXXHfDpus8LzfZLdxA5z8psntqy30lXs9Wsmzcd5LBsJX6x8C64ZHLBE
7I7Q6AU4b2WVi8XekTvCWuxleabwSQ074Yr6hS74vzvUbMS2cjCDB1d8D9c1
r3LG+bPqhW/U8Yf3qXvZij3T540T9v+6CD5kmA9flymxw3peesM3bXSDr5qv
DP9h9h548pprjpg/qxa49ujt8OCP1D8Xe+IZd7ifijM8vnci3DE3Fp66Vu4g
9tvpJ+DG9Zfgqv134PNqMuBL3N7AlUZFwb9I0FkodpPnErh7nR3cJswIfm91
EFxBRQ3enxIHl6r0LxLbLDoT/tSiDT7G9hT8ZXA1fKlhNTw9uBju7HIP/n7M
Abhuo5zfd02Ga7W+hocMyOB3kpTtcf2zCPiXf2rCa6YEwMuMpsKTIzzgO1ea
ww9csIff3mUNH3plCT/8yAkepGEKj/f3hA+XTIVHjvWHZ+VpwzU1QuBj+yfA
u2Mi4IUdavBxtl/Bi4KU4A1xMfAIqQLcxTIebtA1hL6dkIh+1TyIfuy7FX3X
pB89qzEFHdzdgy6Xp6G7B/5gn05Hr/B9gpZNz0LPUezi7+W3D530vAM93yUb
fdXgITpqKIfrSW1Ha8uOoJ2M7qMvX8lDH3p9Fx3eVoCWDDaju64fQ9/UuoM+
vvME9xv+K9drVojOuNeITi0pQpeENaDdxhejvx5Xj873O01v/wXdtuUMevOl
m2ilvT/xfJ67gZ6cWYJ+WnUd3b7pLPrs4zq03PscOnICvVbzZ3Su7zXOfz19
WGEt2mdDKdpbhR6jWsZ5ldWgXffTw/uq+fzJ59Hm39D70ukvFOgJkguch31X
0bahdEcruryKHtFRhdbTKEefSaNvDqVvs6fvOUUPf3cF/bCXfreC3mJ8ER24
hf5ESt/nTpftpRtq07vq6IW9lejEfnprLf3g5Et8/x2iJ9nR38fRo0PoMSvp
uYn0FGu6Tw59pD79/Hl6qRL9XRM9uq8C7fnkg/s/oN9/Q19+nV6udpnv41K6
hi59TwH949l0+yz6FRu6yXb6Qle6VRy92Je+NJo+SUpfKaVnR9Gd/ekOMrqi
J316Ij3Bme6TTD9uR2/dRV9vRb/6I/22OV07h37BmD6QR58yjb78BH1Aj+5c
TLfUpjeX0B9o0hXK6G3j6W3l9JnqdGkFvVaVXlBFP6pMz6+h14364P519E9H
0P+6QS9VoNvdosdK6KEN9Mh37FVN//U/T02BpA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1H8w1Hkcx/G1lWQiTtFuS0T5lUqnH0750Q8rZaSuuqhLKIVWTdLohuRS
6TY6P3bTkBahuuR3KFJ+VDtmW9HKj/xoT6usThiScHNzczPv1/31nec8/tjP
9/N+79fIJ3jHISaDwbBSYTD+eeZyu8/MzZ3pmHvYbjlvRY/Df23+wv77YNLr
B0S21AerNphT//3hmo3UXfTnGFJft0RjG/XVZol61Pdstv6ROsu/eg71zVP5
XtQV5+LUqB83TvGhfmSpUoX64sjxI9RXaUvGaT8eaeXR9q60GKH9Q+ymENqp
CV8GaHucdwqj3ZS/TEnbeX9rOO2vfTUK2kGDulG09csK5bTjzk5G0z5vOtxJ
e9t9YQztZunZdtohWb182itebm+hfVFzNI62euFBGW3fhc/jaY+G3WuEfcnx
TqI978LyBtqherVC2hYCuYT2cNRYMt5/bT1t91yVFNrCg6/EtHO0u1Nhvpaq
L2hHdF5Pox026+dntE3UV4po25k119Kud7mdTput5NXQNuZMy6St9mlRNe20
V063aC8bHXhC+yjfP4u22YSsiraKQ2g2zN+g8TFtQWlwDu2rafJK2pyMXbdh
ngpVcMOL5nfgfcLtKuB8EiX4rzMiH8G86m7epc1zbHwI+5nu/AftXlUb8P3h
neC6W0TltGP3Bd2jfWw2G9xvxSfwmQGpZbRjZIdyaetdsQDnLmgCP5tfVUpb
Xm57H+5/0QHwTh8heLztDHCTwn5w0/0FD2hrOazPoy2eOgR+MvYCOCttIXiY
gRj849OOEth/H7V82pHf0sGlNU7g4p5A8KPZoeAVhrbgSX7Z4Nm71cH57k3g
WWs6i2lPFE2As888AL/WZlwA34/WePCI6VxwN9YJ8LJAf/DuCQ/wFJdocPGO
VeCLJDfBdRVscFfLcvCcK0xwn98awPs5yiLaO3UV4Em8ZvCega/g2w/UgE+u
0yiknSgpAG9nGYD73kgHd8m0AmcXJoDXj9iBOwxFg7eZbwH35IaBT+3cBf4s
+Rj4txhvcIHMB/xLRwC4f99P4AK/EHDXZ+7g8y3DwTM9ueBnnKLBdYQO4JeL
+eC7g9eCMxMTwG2arcFv9CaDB1VbgltWpoGnmC8BFxncAl/NMAJfqnMH/Ig9
B3xjZi74vHY98IKWAvDHDTrgOeUl4Ofma4HXupWDT96eDW6SXAG+L3IWuG96
Fd6fQBXPx6sG57+fBt7CrAOvD1IBd/R9Dv7IZAp6MEEMfVp9AjrvWj20H3sc
ui9EgvPxGIOWWkqhu+6OQm+taoCONx2B1l7VCF3yZBj3hd8E3Xt6CNr2xWvo
Ee4gNLNfBv1m+Wdo5Vgz3ofVAPSTz2+gax3+gjaTteD++H2CzsppheZd78f/
a0Ab9MouJfQx/Xboqzbo1k/R/QR90Oqeb6FvTEcf70F3jvgIPXS4AzqUiS59
i+559QO019ZOPK8punseOreuF3qvRhfONwhdzxc9i43OKUAXSxTQA1/Ruy6h
a9p3Q59wQf/wC/ocDfSPRei7Ze+hT35AV2Sgd7De4ff1FHq4M7rAFT0lGJ1j
jB6VhF4+2QN9vBTd+i266A26ayX6thH0lyL0DG057vdF9NcW6N7B6Job0Ofu
RT+1Bz1mE/qyQPTr1uhe4eimhugLYtG/00Lnp6I7qqDX3UUXDv0JLS9FZyjQ
x2rQD7ehc6ToxVJ071b01jp0mRy9tgI9Vvm/3y9GFw6j591DnxxHT8xCb2Bi
q93EZs/CnkrGfq+JzUvEtp+L7RaHbcHCTriMXaSPvfYC9jsjbJso7IrF2Oci
sF3N/+2/AVqQu3U=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd038w1Hkcx/H1e+XWj9py7gdJxbgoucIglCFEd0WJtih7w7Vkt9+lRntR
nR8R+dn5scL6cTiirkuF/DzaKXJGofP7RPKjdcXWzc3Nzbxf/fWd5zxmvt/P
fL+vr/6Bwzu48gwGw0SOwfj3OpCb/nB5mYp97BGWM8dsyO7/Pixnlb+PdHhE
syf1XC3lNOrxpSf9qf8W/TQGXLg2mLptaYKQevEC4yR1saXpSeprxe/PU+9w
TwyhLn/bMop6GqeKS71f/14C9UyVSA51cdX1dOoyRakX9RLLP0XUaxa/86B+
PjS5gDqzN3Ir9Tm7llLqoqn4zdS7K36opL48V8uWugm77Q51Y5bMgrrdTMl9
6soTbubUo63NHlJ3LJCaUk+08W2i7mctNaZ+q8q8lXrAakdD6iuHH0ioH+R1
G1CXRjPbqd+/ULGceuyCRif1dTtbvqRuqvu8i/o5vc8+pz55mv+M+h8xGZ9S
19vS0UP9QfLOZdRVvZgvqMdGbGBTt9mi1U+dM2q/mLqnz/QAdWGiQJP6rryS
IXg/1xvVqWfNbR2B/8fNlkX9+EjdKHVLg8dqcL7n+mPUgzvCF1H3ZnFfUmdv
clWl/ijyyjj11MCvmNSj1uRMUJ8UrlChHlad/Yp6cp+JMvX9ndGT1Men3JSo
+89yX1PPcDujSP3SCdMpeH9pdxSoT9wYAZfkMsHbxFenqfu4B8hTD01ZNwPf
P7JVjvrwkVpwL1978BJDl1nqvNF7DOprYuvBp32dwdl8yzfUtWa7PtAu+lEE
3iQTgM9FKkpp17ezwbsU94Nzeqrf01ZMLgePjwkGX3j4AdzogAH4gJrzHHR/
r4y2c98l8IqsTPChgnpwlQ1ccLdHMnBDh7Xgwnyzv2F/wbIF2umX/cGvBEnA
LWpjwI+N3QBnplaB+xedBXf65jn4L7w94NqrPoBnz1iAS7frvaX9UlUHXFXJ
Fpx/dmGedthRb/BRvX7wlhY+eHxDM7iK2WXwGZcKcIO2DPDkiAxwo9py8Pbd
UeD8dfXgsdmnwF9s6ATXcAoC13g1BP7Y2Af8tGAW3NtiG3hht9w72vJeduD7
bNTBJ0LMwfOKdMAlfCNwdeuV4J1uuuCV8ybgMeNscJ5sI3it4yfgrR524CFO
iuA7ZE7gqYML0IKlHtAeS6TQxSJP6HONk9BZpT7Q09K/oHWd/KA3pQxCbzzM
/eh5fdCO5t9Dm6s/g1ZIC4H+rr0TOqlQAB348gl04qHj0IPbJdBLBk5By83/
Dl2x7Cz0npEm6By1cOhXGg3QZQ1C6JWhddBO2yKg7yrUQIdlXYRubLgHrdN4
Gc9TeRf3UBcFPdd6B9oiNQa6UPVX6DHXK9D9gbeg+c/ioN+NVELvcr8KLbxw
E3pKlABtZVMBzetNhFZjlUM3ySVBs96UQXerJ0Ofmi6F9lZJwX0qoD8dR19h
WAJd/yAV+rjvz9DhF9Kg92UWQ2+2SocWTxVBr3+Bbv0tOuf0ddxzdSF0NfMn
aPuv0a2j0QcqC3APShnQZg7okmPovKdiaL8e9EE+urJtJvTbpeh7r6EvrcmH
fj2MXipAd16fBe1ijN59Ap03kgf9xW304gL0ozPouaHoDsbZ0PPW6D170b3V
0NOj0IN7c3F/VejTN9FFveg5segCBRHu8dBHvgo9yRW9yxE9aM1H7o8epYme
FYb+SHoD2vca+qI+9PXF6NrN6K416E9uotd3oOuI0OuG0SVx6H5z6F3h6LeV
c/D+AvQBNvqZAPS3+uiju9E1TNFdt6FbWaHHOaBf2oIutkBnuaMLTdG7vNA1
VqNLOegOuugnuOhq2uhcHvpBTfQWwX/+DyQhf3o=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HlM02ccx/EClRYph63YQpG74gWtinbOg6NDRa0gIjI7o4KMoZMORWFq
wIvokG1KZOhsVA4dVDwoHUwcMC0eIKjdpIKogFq5RNRVncixLMuS72d//fLO
K3ny/H7P8/u6RyvDY80ZDIaPGYPxz1PAjLT10bACmlQc0eKpRv//ujvxqtkS
0qcnTZRSj3SLeiknrfirdz719i+lbdTn1CWuoO58YKGeeuaOhljqz/Zt01GX
evI3U/capymjXjM5Jg3Wr3qoBt9Vk0F9hmvPCepPcxdnU2cn1WZT11dZn6Ce
ND4+k7qo0b6Q+nn9pT3Ulbr4C7A/gXY79b2rPX+hfi0vOIl6YEZINfU1zNiN
1G8GdlylfrGIFUc9RWNZD/uv9VxLfdO8Ej11xvILCupTtH0G6kXdBZHU263r
WqiX3ni/FPanm99GXXn5Jzn1Op3yKfUpksIQ6j3KBZ3UBX2mYOoBmns91FXy
/UHUP1h49lGvY63yp27YIn5NXTI3YTb1lnKzN9RXJZTPpH7c7fg76qYNflLq
xlJ2P/VZK9v9qDeODx6gPu10xVTq6r7IIeo8s0oJdYY0kEHbT2H0pV3+0tKc
9metEh+4Hwa1Be3YF6pJ8P03ikfQFgu9J9I+zMmxpN07rmE87fiWJyx4n8FM
b9oT7vOtaDuVrhtHe/1jv5G0C9PCRbQT1bOtaWsrI7xoN1+XcGjbdsR70h4u
4drQVmUd9KD9Sc0T8CmbrrvTdg84ZQvzLMwGXBAaZQff226tG+0dzCFwwenL
rrSdV+fY05a7+oLXLBSNgv/hyCkX2udyC8HN/b3BG3w8uLD+Us1Y2mx1FniE
cB54hK4f/Oe37c60dY4KHu3NIengWwO14DbpYvC9OsvRtPNEbULa9S7LwL1L
fgAvu3EUvLAsHLzLpwX8RAMP3KThO9AOy252ov1MGwo+Q5sP/uibPeDJ9xLB
v91VCv6FRgZebmwFdxgSgKv62WNgnqS8coT1hn3B24314Id8w8GHOGfAJVWb
wN0qDoCvaDsIPrYyAXylrhg8umsZuDDrGvh5h1ngi5IegRuEXuC535nA05ts
wR0trPi0rSZ9EMD8eSUEd33TCd6zxQe81qkJPKx4Drhw9w3w4LOL0XkV4A++
XwmeU14MroyPAx+hOAn+m3wzeEz3YXBBaCq4U0QGeEzqfvAn+3aCL+o5BF68
NRlcXvAjeDpXCf5HWR76kjjw+WI1eJXLGnCRYwm4e8qn4HZp5eBbwpaBt6yv
BJcdl4PnG6/g+UYtADe8uw7ekywD9y+qB59gmgs+xkwPnnXtY3C2ZSP4xc4Z
4LKqJvBzEdPA08QPwPuYEnDW6lbwdabJ4FeWPgZf4TIR/COOEXxDqje4KqsD
/Ii9CPxWZxeen94DPI77HPzQr27gFdwX4GW3XcDvP+8DP8YaC34y/xX4rrVC
8Asz/wRvve8Ivq3EBL4qUYDnb/MW/LYHH5wf+g58aq8D+MuUv8DVt0aDZ2e+
B0+7ygMvPtAP7niHC16d/AF8+PkocGn4APhdJ/TPnQfBI6LswXff+58X2IGf
2TsEXj1oi/PVaxjnXwy69CJ6710b8K1BDGhjGPrXl9HLDBxoptQMOi8WvT4f
fXDAGjqZbY7zSoWeG4ueHoTefAn9cN9InE/WFtC/56FvW45eq0C/cxSd44Ru
24w+/aEV3j8eE7qjAL06BL3hK/RH29GzA9AD1ehveOjiRvSibjZ01wB6Yg36
WfcR0Lxc9FIZetROdEkMuk00+vKd6Mx56PJj6NzJ6EFadPvR6Iqb6E2DLOhL
begLutD3mNADDOh6S0voghr0K3z0KC260htddgr99XR0eQ76Ghl6dAZ6Qyh6
Qiq6XPGv/w3CprmV
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1Hs0lHkcx/GRcRdyHc1gRsmtkVsboqFojDY6DoqMiuycqIgjRdqTTC7d
UG1auiiULrqvLRtbFru6qLa0uaxLJLSsSaSG9uzZs+d8P/31nPd5Ped3nuf3
/L4PLzIuMHoag8HgKzAY/179I3VWud5Q8UzIz6l1c+oV/N+Kvjt9PUin50la
qT8P2e1APbMta4S6bYUTh/r+S1rKC0mH+MSrUpf0GRpTvxLEGXMn7eJ1x4Z6
ha1JL/XHm9kLqSurhz2nbrRU5Ee99FNVPfXarvBV1D0r+beo77sbE009+NvC
i9SV3ki3UI9ReneKuu9YzQ7qGwNmfUf9jI91JvW3Jzj7qMd+fpxL3TXscTp1
Tae6Y9SNx+1TqGcM6J6mrt/nkEB9jUd9OXVbaUMM9eDIgSvUu5h9UdQLa7Ir
qUsj94ipa3y8dIf60aCildTtFdfWUvdZxA2E/Ztz7lfqr8zVl1NfrX/gIXXv
7wN9qccNs55SH6uTLaH+Oiigmbq7sEdA3UqyoIX6w/k8d+p7m5vbqTsblbhQ
L+537KLe0iyZT/1Vxooe6ieqJY7Unzg491GfiDs5j/pBi+5+6mfa1fnUVYQR
b6mf8ymzoZ7vfHGI+rjtZivq3qKmv6kvCV4zh/r94kYZ9bB7W2dT/8AtHqV+
98JVc+ojicFj1C+mTedRZxsOjFN3eZZpRv1G0LoJ6u+TTU2p8wPvfKR+PqyJ
Q12kxpDDfB8uYFOfCLCdpC5Zu20mda0Wzynq89ibjKlfX7j4M/VkQRKLeuWg
PYO2//qDRrQv+2gp0Ja73Tak/W5vK7jB/lED2vH9x6bRrnbzAA9P9FOkzXA9
pE/7oc0QuG/uez3Y3ykpk/a01VHg+Y26SrQX/9KqC+dTfAT8iHIE+OVELWXa
XTH9M2h3Vu8EDxGmgfO6X4Nvn2KBGycJVeD5pqp0aG9gFoN71USD79QdBe+o
NQAXsbxU4X9/9L427TFpFnjWoz3gmbWN4N8wheAJDqpq8P5tGuB21l7gzozn
WrQrJpPAOdzT4N2fysA/jCSAm8c+A9dzEIIX7J8C/+G4KfipUxbq8D+Rf5hO
m9suAs80agZvS44FZ1XdBK8rzgEX/3gU3CPrLHjJq1Tw0OB74Ov1I8F59q3g
ahZ+4PXuMvBKmRP4H0UqGrD/YjPwlDg2uMdSTfDsJ3zw5fkfNWk3ti8Cz7Qc
ANe+5A+uMNQCvjZEDJ7b9ADcYDgGvKSyBlyekww+99B18C3uu8G3rzgHnqp/
ANyi4zh4r3kB+OS8w+CBW4vBe533godyzoP/1pkOns+7Bp5tmQpenncL159M
BE9K/hk8LnQTOKO9HjzVXgJeeP8BuE7KOvCBZU/B2/jh4CPRL8CtvFeCs3lt
4I9uBoL7Z3SC2+zwB//rSA+4QZ4feM/qN/h8Q0vBr7UOgjvlLgGPnzkM7hjv
Cf6CIwP/OscD3K9vFNy3xQ38Zdo4zle4C7ioZwK/v+ZX4CxTOXhTnxO41G4K
fHjAATyPxYBW0rPH7lCAjhTbQW/NUITObpgLvUxDCdo6wBa6OkkZmiuzhm6v
U8F5rbDC+ZhUhfZOt4QuMVXH8xA7B7rSRgP6pw0WOL+zNKGDUmZD/6k2HXpF
0SzoCx3oGx+Z43yUakHv0EZ/ItaG3hDBgw5R1YF2vs2F3laGPshDN3OdgfNw
2Aza9C561Qx0d4EutLDAFNrxBnqpJXo5Vw/vrzGBFkjRgyPQ93Sj72Kiq7jq
Qztd5UB7ZqPLotBLf0f356CfYRngeX3Jhj65Cl1QhP7+EDo7Cl3eiG5ih86c
Qp+Qz8TzwTeEljShu4aizy5FH9yF/i4NvfwsemHoF96I3rcA3WQQvYyFvkDN
CNf7ZAzNs0Bv6ERnCtBfNqArr0SvuoIu2oS+rBB9aNd//g8j316y
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1Xk81Hkcx/FxLbWtjFodUsqVyJWaNipMUi27UQ86PVSutqzZYdGhciWm
xa7YVY6U0qZiVSKJyDUxYx3JlHGXexyhJO1jH/vYx+Pz7q95vB7Pmcfv9/ke
j1l60NvBTZrBYKyUYjD+/Qwp4qda58hb7FRpW6hr2rXx/66x7QnWJ73yifU6
6ikfr7lSNzXhOlFfzj27hfqx+Cgu9WeSQwbUm9hFPOrdAQtVqHv2616lbn/p
3Cc90ixBXy51llV0L/XCFo1q6s48ZiN1zfcDLdQdU94+pR4xeWiYetj5Jfeo
50uSpFaQrtI8kUbd2jhbifrl5uE46mYh9xdT35XtfY56vXG+HvUrCu0nqE/q
NbCod8SzONQ/qc5lU/e0dXGjHnUq3I76ZjO7vdSlc9c7wXwhQ/bU1yzf5ELd
zXL9VuoS83RP6uIAHUvqH4O5HOoi+bRvqC/JyfKnzou7YUJdIDxyirp7qJ4+
9Xdzb4dSH+zU0KZeuiwwkrrz4Qh16r6THdHUN+7ZqUrdeVbPBeqVvEAV6mut
YhOoT++YZlKPV+hJon46qOYr6mVOQ6nUZXcMzqAu/+jONeocb4cvqOvv1/2T
uq94Qpp6rpzbLer3pUSfaPvrumfS5ka9naJ9sc8om3ZCOHuSto9m5T3aW9eW
TNDOdzd5QDvXgDNG+6QsJ4+2H8tmlHb6nLB82jK7rYdp7+T6FtC+K/SQQPMt
Cmm/mXFrAN4nvr+IdmDa7H7aoRrHi2lHeMT00v71Ql8JbRu2fg/ta6+tSmmz
7dre0I4cCSqj/aDg9mvaKd43y2mrDER30TYeL6igXWp/tpN2ltTjSjifgdEd
tHNGMvi0m9RuttMeVop4Bvs9Vt9Gu/28YxVtqxZF8JCgr6tpn+A7ttIWjJWB
J+ZltNDWEB8R0GY+mQWeqCYnpC2ROyambRkeC/70kaSZ9qqWeTW0g5ZzwLNf
/gbuk/D+FW01bbm/aTsd5YE37vUG587QAteaXQte0lH6kvbb8pW1tDcFeIHH
yoaAG9mpgh9aVwt+YFggon38uWod7dsfwsFZG1zA983cDC4QpoCnFCuAV7aL
wJk1wiY4HxXMevh/6rwIHle1Cdw55zC45Wpf8GRpc/Aa9mVwlUgmuMS0Enyr
cu8L2gxLCXizaym4R6JyA+3t318Fb/BfBf7XlRBwHsMB/OAqd/A4lx/BRS+2
gX9ReA78qJcxuKFFKvgCwQJwgVwu+C6RDPhGw2rwQR9JI+0bTa3gxadegaup
j4I/bOWDV6jKPofzHPQQXLFzDnjRtgzwm1HLwL/TSQIXGhqBl8nEgFuKzMEV
BSHgPilbwB1/DgD/I3oH+HSPF3hJ3n7wIDVX8BE9D/AD0nvBtUe9wZXPO4AH
qAaAD97ZBq6ZdRpc3YUNnpB/Fvz3OHNwns0v4B+s14B/3BcLfsnTCNxeNgHn
G1sBvt06Gby6UwucpXMVvMtwKfjjrHRww5pF4FrdGeBphfPBzeoywTPezQV3
9b8LruTHBL/elIP7b6KI92M6D3x8xZfgRb2PcP7dCng+UgvBr+TL4frrFIM3
2cqA7znzFHz+TCnwzXfKwK2GpqEL71VA+05NQUfH86Gn9D7gfXSsgt538j20
63g1tEXfBK73MSH0Gb9x/H1rDbTqojFoe4NaaFPRKK6nax3e/8wRaOmwemhm
wjDud0wD9MP4IWiFyOfQ6dcl0H4/NUJHlQ9Ch295AW32bgDnV2qCjmGhL+Gj
h4X2Q+f6iaCXifugF897CR3MRte/hV53txc6c80raFsDdM8H6Kuze6DlDZuh
OzegGyej59d1Q5+WE0NrcT5zN/SLc9DvP/7MC95AJzJbcF4v9HRn9B800C2u
o7uJX0NXdKNbJaMnabfi8w6iK7ugs/XQA+LQ+RNd0Crl6GPl6CZj6MGX0Gep
t+H3uegtNujCb9Fbj/7n/wD6DCXV
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Hs0lHkcx3FF20XY7i4RQqop4WCTUuuyjlKuFdaIQTMuQ7k1YgzlmpXL
lEtTUSoloSi0rShdNrUx2bIrlUsJYbooEXv27Nlzvp+/5rzO+3nm/H6/7/M8
Gt7Bjr5TpaSkVk2Rkvr3t1otod+hevrGX5ruqC8y6jH/3+K8JddViENbZGxp
V1rllE37+NXAENrtwy24tN/zXyOkXbTp5mbaVwfzq2jPqxCtpL12bvwT2ie+
XpKjPfo8S0K7leFjiTIxr95mtiLxXNX2p7QLnJy1aV80Wl5H++nhs2a067np
nac9a4DpSHvs+Foh7bIJuX607zlZJaA9/Tsuj3bTzmQu7UcGP6fS3qUp8qDd
X9buGO0pnm12tDfnxV+gvU6JYU574a6L1bQPrYvTpz329/ZG2J/UXS3axd+0
Wmi/8deAIu2zPwif0+7q1SVHe1DKul7opiJp2nfl67ynnTtj1lcl4ihZ1hjt
ua7qEtrXvxiXpv50VNxLXWs5KUt98ZPiK2rFs2HzqPvZr9uoNa76KVM3Cw3E
1O3RHerUlg0fm6gdWN061PlirbvUYRsEDGp50+v11E6uNfrUA/3lv1IL+UeN
qTnuk9eot0xRW0etxi24Qm3Y6GIO5xGeXgbrt7awoA7Vvl0C/1fQb00dk2lW
TK0tdLKlttH8UERtnBFrR30ls6uQWqcy1J66o3vmSWrGU0Mn6nE/bxF1Z9ot
F+q4ord51K+X6+ykLvIT5cD67jHd4LzKIo9QG2wO+Zm6rHJfNjWL5cGkPtch
yqQeydTdRe3d8Oow9cTKJ17UFUus0qljPbxZ1NM7bqdRb2C0+lDfmOl5iHp3
1Go/6uTmOanUYzNCdsO8D/6dTK0cdYxNLZ1em0St7nSZA+9zZGkinPdElT/1
8c7LCdRbH50LoD6acv8g9aHx5EDqUbPhA9QrLrkFUZt0akNv/aDKpdbfy4mn
Dn8ghv7qc00cnL9GTDC10uGF0DVblEOomSy+gNr/Qin05kvDsdSbOcZ7qPVq
AqFn3ayC3vmnhA/7c2Hshe8ZOxa61a186OrP5kOPyp0SCt8TUUUMvH/uXtBP
GLpAf5FUC/2d9mQ0dWKWXBi1s3QZdNU3btBPsnyg6/edgt7Yowbdd7QHeoBe
x37qwQCtcJjHQCH08SwmdPYjDnS9WiH0wDQj6MPL7kKP75SB/kR1BLp35tMo
6r5nGhEwH2YpdIUsW+jtcxKhm/BDoPN5XtDLH2VDD/Y1h86uqITueX4JdHUH
MXTZxVOhl7QOQZ+W85oH8/WZFUmdMNIEfVJtKfQflKqg83RMoS94eQJ6TO42
vH91KvTBDBb0a70R0BuWR0A/MOIDfeX+JOjWG52hlxzLgW5VbgndtOAsdgNj
6F6iSuiBV3Shbz1VD11PczF0ScND6Mbc76EryLdBt0meBn17Vhd0M++xfdRh
Hu+gdwxKoGtFj0Dv0XgL3eLrBN4/9BJ6e+d3YI2tbWCTjfLgWwYt4F6VBeAE
4QNwG18F/NC/Eey6RwOcU1oH1hzTAQe51IL9lzLA7u5V4O7hNeC31eXgxxwj
sAL7Ingiey3YgFUMfha2Hqx0pgjMmbMJ16NbCPbhWoJl+46DdTN+Am/vzgff
j7LF9czLxf0Y2IHfhB3BedVsA6vIZIP3zncE2/yWgfO3cgbzCtLB9fbbwQPn
0sBnTHaC57akguW+uYJTFqeArU+7gxclJIHDGR7gkpmJ4Px8JnhH8UFwxpAn
2N7zAK53lRe4jxEPrnP2xudbIQ68kM0Cd00TgGPYPrgf+Vjwjzt8wbN1+bg/
Iz9wtEMMuFhmN7g0JRrn2Yhd9Md+8HQeG59PTezr1TngMUEU+P117DV9PLBk
iz9+P5jYv4ixC9r3gascAsArWNib7mBnvI8EtxoGgj8mY2fmYR/VwT7wGXvt
gwi8flsQuCEC+5dC7IXLsDsPYpc8DweHGHHBjnnYiyP/6/8AwNY+eg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1n0w1HkAx/HlPCRqi56FhCLpycPkEovSA6WnSyiFTNlyFHpCTy4lCkWU
6VxUXDcU0l0i2hRtTYVKlCQP6UGRykbs3c3NzXw+f+2857X72+/v932Yn75P
4DI/RYFAYKYgEPz72R5uZ+lVqCryKhOXK1m12P3fupnZ/QOh70w60Idus0As
RXcoUZimDC23PXcS/fR63bXo10vHb0b/vW5YDPpN5T/s0b8raV9Gb5OrjUFX
NPOtQ5dqC7+oQafZje1HFykfqUK/prJVTwW6PNA9D73N64gt+sVXLonoEf6J
nuhXDjnsQF927cI29EbFUV7oPoc649BX22bPRd9272Am+uRFzVPQjbccLkYP
tz8zGt11y7AqdF91qTK6Vo9tC3rnKqeuATj/0frd6N475I3opRpVqqrQTjYv
K9HHydaPRE9qfCRBF/i2G6EHdksvo1foRJijR87PzURXqzAUoffc2p6K/qq5
yxm9LFgYj97bLluJbrNSfADdxc/eG13ROywM/XxLrZh8g9VWdJMZ94PR96nH
+6PnzDEJR7e4HOGNPsvzSyT67PAv7uiJSjYx6IOMPyxDf2+qcgx9+Ji1Luh1
BqtT0KfOFzmhx1ya+yv6vemHRegOQ6UZ6EVPLGehz1HryEJPzbGxQh/dVpyN
fv+3lOnoixOs8+j++hzN0LMiN15B3xBibYLe3OBaiC7RDDFCVwz8XIxePvOj
Prp2lscNdOsT53VpfRVElaFfMDyhjV4SFl6OfmR84Sj02FN2UvRTg4Uj0IWh
1ffQD2YkaKGPtZj1AL2/2nYo+g7pzkr05ttaQvQQWUI1en31oEHozq5Rj9GV
9k5SJ7dwr0Fv3bVBDb2sSaOWnk+qRBX9ZnBGHbr4hbUKevoT3efo173vKqFv
rt9bj755fegP6MN/vPsCXeRopYiesE/egK6+XUMBXWKm10jnx7Gvcux5aaav
sKX2Xf3YZnoTmuj/nRTI978UNmNHb9fro/2g8Ja8ttTlO3bw0YIW7Nd6h3qx
O/cEt2JfzHjYgz22xPA1nd+bjMitjaTk984e+IatHLG+DXtjbIcMOzfyM/mq
TX7kt9/seoOtmdzUTddfISMPChKTG68OeIvd5fPtK3Z6Qh25anMc+fJdonfY
nlvNyA2Pp5E7JlV+wc5cIiM3eh5GnqHn/B77Q70peYpfCnnczMbPtF72vSQ/
FJ9K3ic1aMfeEe9BvjDJhzy/TYdcx+w0+YvFLV3YznXV5MkRl8hrG1Q+YOtb
7CFfGm5Frmm1lHzwWx/ygc4TyA+ujSUPsO3/ROepMJ/coOEp+VGTGvI18gLy
O7Uycs+QJPLoBaM+Ys8asZ3cLc2SXFLiQW4iX0JusVjE4z8sJp94ZiJ59br9
5J6nhpCbp6WQJ+v0dmJ3rMsmPzDkNXl4SSl5vMcj8qSqKvI7zRJy30tN7Cfz
yI8HdJGn+GWQ/6yj2EHft0wi/1opJP9JdpBcljqW/OzpMHL9GGNyzxFB5Jo5
5uTuK/zIt2jakgcs9CTvK5tHvuD9UvLkyiXkwVMWkLs5upObq9jz7w29yaP9
rcnluzeS67vOIE/0DCR3yjElvy4JJa/ZbcTjKwojF13VI8913cfPZ+UY8vTI
KPJbrsPJY71iyHXThpCva40jv2qrQZ49LpH8n7c/8jOaKeSp7krkWjdSyS3u
CsijpqWRZ+3so57ql07duq6Hus/nHM9PRDePxyyL+oH0M3VoxQXqdKdP1Nes
sql/af9I7R92kTqxqJ3Xw8lcaoPcd9TvjuVTX6p4Q31TXEDdJGijHmrwJ/UR
t1bqzuK/qM9Jm6k9ZhdSz13VRD0+4xrPT38jtbyjiNqo6CV1jPF16mlxDdRz
nEt4PNteUB/1KOX9H1RPfcXtBnVx2HPqT44S3t/Jz6h9x92kTpbUUY/8wN7Y
W0utkVPG548D+2TvW9TipKfUywfc5vF21VAvOss+dw37M8ty6gsPn1DnFLOH
LmIPsKmgVq5+TJ2f95//DdbTGso=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1XlQz3kcx/GfWGeOfqVT20UJRYfqRzmSUqFjUSt06Ka0oxhHq4MU5ci2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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV03lQznkAx/EHlaRhVR5HVHqQrFaR0npyVvKIFNGpQqWeckT3RU9aiRzR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1XswlXkcx/Gjy1IatbWEolpJziqiFi1RLhElUiGUg2pTLkcRsl1QOWlV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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Hs0lHkcx/GRNtUoJOW2SgoZFWoLbQbNVCYkNpotFRIhdHUZXZZckpba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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns0lHkcx/EZhVxLTTcZibYYYVPLhKJo1yVt6SI1SlOrJJeyOsRmiVZN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1XtUzGkcx/GRsUW2XQ2NVSJFoaGtWQkVRy2K0k0lFSq5VtJNRJdVujeV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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xs0lHkcx3HEVqfJaiNNVFOkECcs0ZnosnTVZUSmYl1SKpUilFsIITFC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk01Gscx/ExyFLW3IhkiTIIFcntFhKFphIxZMkSwlgaFSGMGku2bF3d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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xs0lHkcx/FRRCQaJLchNbW5nNLmUpKxKbYLogZLMeVSGKxbcmkoTKgk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Gk01Hscx/HJkrh1lS2FKxpCmxGGYRppZGxDWRtLJe1RCmkmZUllKk2F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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk01Gscx/ERciWRraS5loobYWbE0MiadRhLIsZObiKMxtwUupSKdmnj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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Gs0VGscx/FBIbc0QpHDUCEMKVHjzhBx3ELRIMqIkC6mUkgkKZdUopww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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns0lHkcx/FBGsKIXBPNGLfJNZeJ0LhNsdbStOpIN3JZKdpCSO5HSkmZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV13s01HkfB/AZVgaVy6xI2O1C7i016xoittWaFKNMmVlh8CzrUiibXHZd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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns0lHkcx/Fxi9CuS62KNklyq2ySiErjMpZUUqbNkjuLUblULuWyaO1Q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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xk81Hkcx3FnohpH7GYdGS1ajMqRbIfBrKtQlBnJruRYPFZNEkrlaISs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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns01Pkfx/EJS+SSS2awssTSNnZsUjaS3Mal29goRkuFEEW5hd0kEzU7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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xs01Pkfx/GhXMrl5xJh1fwsZSmXJKwsItefdZfcCykKrbWkWVLskPu4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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk81fkex/HjULYsY4+GChnLPUNJtpslWca+RBTHdhrKpBQzSrbTobLv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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk41dkDx3H7/iPZkl1kV5bGElmyJUO2oUHZ931fBhW5yFL8iGwhW8QQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk01Psfx3GEFmT7ZZfspKkYYy1zp7EvZVdcURKlBZUle1mKkCxZsiWT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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Hk41O0ex3FLEokrTdajqJEsIXoUmuxJSESNlPWxxjApSo9CONImjPBY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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Hk01Psfx3FSDV3ZfmSpZJnRda+lLDF0I/sYWRv7pauFXEpMU7YUoUtx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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Hk8Vfkfx3FKshV+dZXBRVmTwaj8LGW9yL6E1Ch5WEIUIWlcI0yakTVk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk81PkDx3GZXGXRtYrK9ksJsaRthlBhYpbGOBp3jg0Zx7BRlEjlGjla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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Ws0lIsex/HRFIbKqLaQSqgYWxok1wa5X8KQyHabyE4YqTkpOe7JXbaS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk01ekDx/GrLn4hv7EvUZQ12bNMdtm3lC1uXDvNbSK7SLcFxyQtYyYh
Ke4gjCh7uGiRcLWQ/SqUjGQZhii/3++P3/l+/vqe93md53u+z3me5/vI+ocd
CdpCIpFUOUik/z0vnfi4XrLAbcp6tN2BrDNl8v9utFJXiAwluj5LKtkfvMCl
nSIGHjI86t0CHhuw//2jEKKn7w4PS+oSvVob8DAA/ER9Mjka3KPetpsXPOSA
1mg3+G+0ZcXqYKLttXbS5PWI9p++1EIF39A/+SAB3GLU+govuBG3emMv+Ift
8dfrguB7uN1T5fSJPjR04XEwuMC7VqlY8K8d4zKi4OYcBvQOcLqwVMHTQKJ3
SUfViP9IdK9hn1UcOK2S53EIeEtOM7cKeOOZ1PJqcPZG7ruxAKJX1n1itxwg
2lffuvdXcM03C/JO4KSXDJYtONnxclMW+NvMqmES+NU6mvl78HHTuPk6f6LN
xh7W7TUgWk9RkCcCPMYvSS4CfPxtqdw+cFX5rrQ6cO4uuuFHP6Kfl12d/QZ+
V2jEsQBc6HS5s7kh0T6c4m6+4FdDl+qTwRvnbzntBLfm2rOvA9zp1ZTuqC/R
HDOz97YZEc3PE8NzC1yde/FHO/BcoYkn3uBnNttH0sBppqygXeAaEVO/d4A/
j5z58I4K+9O2k8ZlTHTJ+IIlA/wzecDnILjc84qzx8HJ5ODIs+B5JutX1cCX
XjSVNYD/8qk25m8foqsdd/Avg1e196k2gkcql2ermcD+mnZ+cB7cfT7TLQS8
zlWTbA9eHPjR7Da4QPUv0sLgR+vK/PvB1VQSN0a9if7r+XgDnyms/w6NvGLw
aWqkozl4/urwZiT4S38b6VgcL8jcaQp+T0RftRScEqC4yge+2/Hf9DHwRr+Q
tKFjRIcxrogLmMF697JZxeB9NWFr5uhXv3bEgq/ZUOSjwE2iVSKswVcuLuUV
gqtKzHeIgdspsELfgHtVsjqnKUT/ce908lZzoqcmvaIbwLPpcf9ogrcVqDxN
BzfWMWulgjO/TzZQwVvzD06lg3uTtA9rg/MLTgXVg8eldKZwg/vHn7OcAu+T
Ou454kX05jVayg8HiQ4cePO0EnyR5/NeA/DD2iNdqeDzf1rpBIGzPrkd9wGn
XrpflAFe8FYmWwc8QdTrYi24V/8e7+3gTNefutng6rmO96c84fx827zIbUE0
IyfzWjN4RJ5muRr4o4mV7zfALVu227iBd5BOr5wCD9+a45EAPjO6N8YBXNhh
YDQfXLpIOlERnD3waOQJ+NvSn7m2gh8J1XefATcxNxJiHyXa00Pbgd+S6Nl7
1fmN4E7MDKYmuPIyV3kWuOtNuWpX8K6JEN0YcIlXz1RiwemvRAxcwblOWSjc
BM/Kca3XAh+poP7RAO6ZdLJCAJwpNlA+DN7M+XDHggfR7blBxhvgVV8SNnrB
h+rqPaWsiG4S3uNcCe6VcpbDEFzWmU/kOvjcIEWPAh4Umm8bCS5y7PNGPLjd
quOsK7jM3S6XLHDFo2nruuBMq3SjGvDy1K5oCXDJLfWNr8F/EL/hueFO9PHW
QdY8eIboSQYbXK85LGG7NdwH/wx7tIPL/rbSogzOooeHFYEbHZvMswTfX8uc
uQTOV18i4Qd+uSO4IxxccKVSMxGctMbB7Q6+RTxg+nfwqCu6DAPwzEVpk0rw
1LbyO7LgC4bGei/Ahxgi69zgPQzJV5PghWKy9+fciFb6SBb4Dn7rz9SWPvCC
QdtlURuiNYs5lZrAb6dq0tXBv/ZTpgvBZ002q6zB064d2kwH1y1eyKCCR925
R4sGl2CZi8SCl2gZ7PMB/8tIyToDnLf9tYk1uA7Pa3kGuL2gPUMDfOJDWFUj
jhdMpEiCK+sozr0EN+i39COD7xSRHvoI3pB8qXrOlWjRmFOx38D32+/3GAQv
VTB9JmgL77dSsXwMfm0yv1MR/G4iNakCXPxE0XlDcJ6udo4c8LjUgHln8Iph
p54U8LfS74SDwMP5199HgAuYKy3EgXNGPzWmgluYGaWkg0cxq8btwXdVyvTd
Bm/Y/+SZPvjyGdZYFc4vh2tJHvzGqnnhE/BhvQt+QuCLE+EKA+D6dXaCHODx
5+2DZ8D3qISTv7jA/7agNXAD3GJxm94o+KmK5t38dnAf1GiWvACXrNl7Zxe4
AoXs1QD+KH5mXAP81dIdmxJw9UT2ezNwqVrVqCzwKZ7poiPg35a6h1PB5+zY
GgHg3lxlSbHgLRa3kiLBV+3/poSA931ZuXYBnCbRH+EBvtu4mfYr+ImKC23W
4C6KbXwF4CoaWnb64BMPeqKrwMcyJbYpg3P+q7yoFfxkQdR3CfDAk3sKesFd
JunKvOA1/suhbPDrWUlpG0dgPXIn1j6DsyvuS8+B54iVuW+Af2o+NsUGfy7L
Q+exJ/rpcif7JbiKX02MOHiyqBXfY/BudrCBAvgkbcdPNeCzwqwebXAlZvZq
MXjC3G1NM3AxV9HaHPAzQ6mBTuAC/e8LM8AP9GqFUsCPeHq0ngN38bQzCgV3
cOzmjQZ/mB09GQUuE51/IRSc6u3pcw7ciq2mdAxcUiyr9DK48ejA6iHwlcWX
XTfBI9dJywfBmwYL2xjgamu8Uvo4v9NllyvBK5i+P+8D9z98Xq0JnEoNnZYB
961qYnSAy32/nC4CTu9ZWnr9X/8PXcA1lw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1XtUzHkDx/EmbaSk9LQpk0SpbWu6oUmldL8QSSSl60xRTS5DiELCTGQR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk81Psex/ExI21kqSi5qaxNjSVhkj1NmyU7ka2GjGUS2Y7jHtrtqew3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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xs01Pkfx3EkKgn7a61UZMatdSnjlojaTCqXbNFOlEuIZsvIreRuCIvy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Hk01Vsfx3EUrgynMhxOjkw5EuIe4mRsMDQhkiEhHEI6phKVU6hHxhSK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk01fkfx/GLrNGUQteStbgiS9GUJhVRoibiNkmRGi0K6VqyjVzrdV1E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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk8VekDx/GbdUTCxe1mq6budCdLpUW0iAhJJCFbotwYFcJNlnKN0dhy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k0leseB/DNRipTptMxdWy3wSlDNBgyhDihZEfHEMrJUClyuCp02Crz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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k01ekfB3BKUpbByBJRDDV0KZOoZLpIYymSLdeWPYylSKao37WTUBhT
6GdNiE5Nlrh2Wepasl0uurJmC6GEzO/3z3zffz3nc17nfJ7nPOd8ns/n2Wfv
Zey0hY2NjcTOxvb/VcXmlS7PFq5T4++H1Hm7R3/9N876vPdqx9i/scv6Mz1L
cJUpq99I4BdTvf+TAx7WekVxsp3w4G8powvghfak9kzwEpN0f/Uewj/nJcrb
gX8P6z4ZBi4p13B8DzjtXtDxNvBHFmMb/W2EC+5v8xbpJTydouTzF3iszOSI
Dfi013S8BXiCcF9SNrhZgre1KLhDyX/vTIO/lvqpg9FKuLQVqekQg/BAm4Cp
v8AX3K0N/MAfKy/kUMDV6ZviZeCrJWIckuBXjbqOrYNfmIrZZNEJJ4vcydXo
I/yo4XJSFrjn12a32+A7MrY2uYKHsqSDa8C/Ua/HkcBdlCSX2PsJ9zogNbf4
lnCW4NFqMvgXwdahUnDzod6Pt8Hv1jnb3QJvsnW8WgWu6NvtrQPOo3zIdgM8
8R0/Hx94DE9I0XEm4Qo0saM9bwiP5k919gefZ18bTwNnE3oa9gL8klSzpCu4
4lS/wCdw/e0ZzMPgHHmaO+UHCPcYKRBfbyHccnHZxxF8iCk2+Bpc4uC6Xhr4
0ff7JO+Bh7QY/9kLruPBOWgNfily1oJ/kHB/awFRefDwJ8Xxv4H//TKBvtJM
+DWFWK3b4A2eU2t14Oe4DL1LwPfo+qbHg4tebhCbA+dNfVhhC+4+UEr+aYhw
I1KHviJ4fNTEx4vg3d/unN1oIvyA63ahWHCG2Lnqt+D6Lq9r6sDlIh5kpIDb
PW5Z+gJ+j2Nz0QOcmvm8UOE9vG8TfM9OgmfZ7lqwAS9ad2DwgbsnUGnx4MXW
aW6sRsK7+qi76sHZzzk6PQfPbv/z2zK4l4h9Ywh4nZ66534W1O+kbqw5uOOV
UR8L8IxnneXy4MrzG5yR4BQOmv7314Q78c8rlmH+1aaT78AHx8WnJ8F/56qO
ywHXujKgLjpMuPail9YNcNXKMNkz4KKP8k2MwJM43HL8wIe36tfJgrPobdWZ
4CacCnfXGgiv51/36wBfu0T6uwOcbkRq/A7+NUbtSC64eUXKS4UPhLtnqvLe
As/QDdK0AH+gvVvDDPx4J5tXCHhKSFcDCfzhL+fUn4GXtNlkbgOXsIvOZ4Jb
dL3sHqwn/FAwg8Y5QniMRz+lGHx113nfw+CyER1HYsHVVrnbKeAGIlm2ruDJ
MeLvQsHLlm2YZHC7NzE3isAtewQfi4NHX/SgM8BDlLpqlusIN86qaGIfhfvb
Xy7fDi7z+ZanPLgydYSVB84b9KLKGPxpjMdIKPgTqhHtD3CyQMDhS+CBFgau
GeC+J5Ra1MGHQ5JrmsG/x5UWiIK7tUq3zIOLDJAZS7VQH4bdVJExwg9IrOl3
gBdEJc2cBB/1E9leCL4lQJfLEbxchs4VDe7wiN4TCV7gbGrkCs7as2lRBO7n
PzNwGnysuji2C1z4esdTGfAHAi03VsGLnHRq2cE/OXFLSo7DfLczToxVQ/iv
87r+muBGC8vPK8Hvt56PcAb3MauNSQVPEZs5HwWeLaH55Ca4+uehrqfgWVX1
HFbgXQmzAh3gK2dSHp0Al7Fm7FgCn9fYEyAOPjdoRROeIPxjRlrcWjXhZz6q
kI6BVzIDxpjgCWnilhTw2KKd/hXgp/zrtAPBG1SLtFPBD1xgzaaBn+1pPBsE
Xh8ibVYNLqRQEm8LvmNQNWgYz7fjww9k8O0lb5y3TBIe71XUKA2uvTWcXwY8
OyCilAO8z5j/phb4cQpjeLyKcLMP3HkO4EYmPFrN4HZZ4g+DwS/n3mfmg4sb
vDfMBA9PfJ93F/ObLzXVgpvpOzzzAaeKrnB+AA/+cH/aBNyvOnAn+0fCdU0m
KWrgsy7SXVLgslf62CTA50UDHDXAyweH+zYrCZ/oFaqwAp9gCxofAU8sCGP+
AT637aBcEzgzz7ouGXy6zT25AFxvTc63GNzwc6V6PHjYyO9zneAphbmC18CD
W8uVF8DVRp6KUcDjTJLJfFMwv/KZnj8Frq4VKa4AHqYpVyYLLpAtWHMGfM/e
fCNu8H3NxcqO4IFtniILNPjf6K143wZX+rbB0wuuJWJ0MwX8cf34IRq43HWy
aSk4d1MpNRN8XVhnvRNclmfblijwhm0Mn0/gbuw2hd7glAav4p3ThMvcMA83
B/+qH9IiC/7ySdgdDfA87ujCU+CbQlSaLHj61y/2FHBW0rAYL7hF7MlJP3C6
qUb6UgX0v/63GnHgEVXKFwbAKwJ2ueSBzwRbKtWD92eHXqoHH4g1VikA36sW
pTgErslV5pgALlF0t/UL+IHTJNpNcL0jG2SBGdj/raGGE7hfukakPHisYe3E
WXC2sFdZWuC8GfvLjoL/eLA3wQqcWSbzXAr8ZerqRT9w71zKOy7wuiehSzHg
k0l+YovlhDMmBx1zwCtrRMOZ4EK1DvmV4Im+s7sbwPu8/Jt6wHdzpnYVgttz
XK+YA1/p7HiRDG7qWRfOOUt4p4ZqKRWcFFgsLwl+LSdg2AM8dawgWwV8zklH
yRyceZp91QCc3qafTgZv+5lX1hHzyx9TPQh+4oef5W+AUwsq54XBX18u4LoH
TgqIobODr+TMVueCM1LM6TOvoD8oa16o+p//A8hkjQ8=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xs41ekWB3Dkklwjktsm1ykyQmVStnTKZRAhubOFbduG2o7cD7kmMkhl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN02dUFFYWB/BBEREsM3RBWsAygAo6AhmkCYOoFGlRUCJliYTee1EmFEME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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN12k4FIoaB3DbWJOQbDWoZIxjSmPpKKUp59oytiyTSifDQUckpoUcE4+m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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1nk41dkfB3CXjGUSJksr2XcqVJeIS5fH/RVuyhiubVzrIKOF7Pphsla2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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xk41fkeB/DDIbKLsUwoWzj2LUt2xzGyNKlJyJ6scWjscSIaLbgjNGUZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV13s0lGkcB/CZ0FpnXRPZ2NYmOSjUUq5pdUpaqyZR2ESo5JLbMMYtci2N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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns41GkbB/BJtNsyk+ItySHnrLBKjJ11WJUNUUy2MFb0pk3SUDktloic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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns0FFgcB3BDIUIZoYaakkdZakdJ8hivGtIUlUdLk1cNm9JDpNV7jceY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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Hk0F+gex/EfqexJFEn8SjG6tMmSZKt+mFG2kJC9smTQbiqjETVka1Sk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk0lWkcB3BdEqIkrgghV8TNTmOsiaJIlEJjjZiQlEqWuJTtXpGuLmJa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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns0FFgcB/BpQqhZoShpUKKOFYuJjDDDeJs8xjOPTCQqSkwMoZcUklMb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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk0FXgUB/BnyZJnSZOs1VM0ikQlZR1ReS22UhgVIqNFicpgIuFp8V7Z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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1XkwFXoUB/BraaEs8zxlSchyXY9sWUIha1FekUg3XHTpISndV5MtqdBC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1HswFVgcB/CrWo+sWqK8ogc2vSWb61FJm5S2othV6YFEKErbIolYq0at
XsQtyRSlQksvqb1XhYjKK7coZUXkVQhlZ3dmd77fv8785jNnzu/3O+d3xm/a
Zu8+RCAQTJMRCP5ZdSPerbyuIz+/vHHlrAkyb+b9F+vpBnZ0JPz1f1zl2r0G
3ape6Ql6XZF6OHqUfuQf6E2FdefRh9+8F4e++8a2IvTWWZkh6Pv/bG5GX1g0
fTO6bf92hYngCTYGy9H7Do8zQP/SGCpET5KqWaEH2xjqo6vv3epM+5cqqqD7
7TfzR/dUVhWgp/qfjELvrDRqawdvdj8jQj/c6lCHHqDvlkn5nfcqQx9r2i1B
z17sIUZP7PGsQPfuNc9Gv5Zc1oDudFWair7I1+wj+tO5ZiJ0i2M5Q/XAi7Xt
YtFzPByU0V1DZaMo/590dNCtrdeHoPsp6U1GPyG1C0B/6L7dBD3R/r43usbB
EfPR880lbuiGX+SXoHukm69DF8R5OqC3GE9yRD8rEq5F9y/ftxzdOH+fG/qb
fitb9ONmS7zR9+zZZI0eknlyB/rlAy8s0Ue6Bgair8+6ZEr5a7aHoh96XGKM
vtR0yK/oC9SFM9AjbuccRM8bbJ6MLrEbFYuuYlNngG4ya+wJqv+98kR0py3P
EtCDTfbqojcm2iWhKx2ZqI2+1yQoBd0sp18dvcXBM5XeZ+iw0VR/jWY6etIw
81HoT32PXEEXhyZ+gx68tzILPcPFYAT6uu8bs9Efz6hURH/2oOA6uvzFNAX0
lLo9t9CDLpySQ48WKuShbzG8+hXPl89d9OkLGoaiT0tIF6N7TzUeQvNjWpiP
bmmeIECXX3TvPnqsVGuwDfzDzeQC9NOxVz+jJ/q6FqH7DGwYQF+trVCM7lc0
oR893+1YCbqNuOcTul+pQin1L7e2F92x2KOM/qezlT3oltkZj9GV/Wu70ceX
NjxBtzX++BHda6l8OXqcQJNcw1ajAt1Lxu4D+tsKjUp0oVd0F7p92/Aq9Nyg
8k70w+Gt5MZhhuTB/uJq9KzyqA70wJjoZ+gB5R3t6NaiRTXoS1tcyc/92EM+
eKi2DX3uNpEUvcR8I/mkCOFz9Fc73r1Hj59dTC6VBJPvG+H4An1Dniq5ckIV
eepAViu6nfPKWnRtHSfyoHwJee8DAXnakhl16G0pV1rQVZyOkle6uZLHLOsi
d8zVIm8/YPcSPdmt+h26h1cSuZFWPPkj8zbyoDPryOV+EL5Cv52rTz6vOYQ8
z6SjmeZn9V3yuOo75Cmln8n37/ydfPbxOfXol6Tu5DL1PuSD9RbkGW+T2DeO
Jr/4vIz87KzOJvRVrZ/JJxuVkRvZTHqN3m+eQa6luoI8zDiW3C0ogFylL4Bc
JjmOvGjHGvL0CzfId0YuIFfMqSb31ZhCXlD/kfyomhr5tWXKb9D13QXkbcpT
yDO7Wt6iNyy2Jpe5XEMeOdyZXC6skHy5zzbyYpcb5Bsiw8nXz75AftTzOHl+
VwK7YSp5Y0wMeVPVdfLo3n3kyhEF5HP1dpFHza8iXyW7lVyq3kBeemQD+Q2t
TvK1YkfyL6u/kNtGLSO//VShAf3n5wvJHZJUyVflWJB73dchr1AyIZdbMYnc
UzqNPH6REXnnmG/JP2UJySW548iDRVbkRySa5J1KtuRBBmrkOYoryNvrRpJn
iBzJbzUPJ3cpWkvebSVLXnNiE7ncKxnyl4pbyOMlnxvRn0zxIRc1fCIXD/iR
z7fuJt8evov8XXUnuVN+IPncs23kaZIQcqXTLeTOEWHkLoVN5OOUIslddRvJ
d7v8xvdz6g2fH3yQfOrCevICr0PkE0e8JL85JZZ8Zt8LclPxUXIb2efkpTNP
kAfOrCFv/CWevHdXNbnkdAL519WV5GEpInId+wry8dGnydNfPyUPtT9Dbnfg
CbnbYDJ5ms1j8h2xKeThY8rILZXOkV/59Ij8O7/z5CqtJeR5d1LJk9uLySf0
pZFvHsp+bPxF8p16D8nnzUknf29fRD7D4tK//jeiqIGO
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Hk0FXgUB/A3I6QNaZMsKVkiQnIsWdJJqGeSRJpIeHmeUAglKUviyfLi
jZGT5dl6nlBTI56mkjZCi0xMKqWFhJKS5syZM3Pu96/fuedzzv39fvfcexfv
2rvZ90cGg6H3A4Pxz7nleXHuNbWp1hq2g24dH59b/RfvruFEeghe/h8XOSrv
pe6gocqi7jPacoz6EYcBN+peDUp88EfX7amzcxaepS4WZptRn/L5aT11l+bN
etSLP8S1UO/V7leD/EyFHuoltzfMpe4uKHxHvSA1YBp1/QC7L9QbNNcwqEsy
JKXvE3+vdOmTO3FR68hs6hZl9waoS21RUaGeIY7qo66mk65FnT0q7KaerrrN
kLrmAe+H1P+wijGnPn9Gait19tOZdtQNxrVuUrcVyjlRd5ZecZV6X3WaC3XF
MF49dYU9mR7UnYa2XaRuc3mJN/VSbmgN9eR59v7UzW88qaQ+iyXNoa4SmFFO
/d4KVij100VcAfUfY4IjqF99daeA+tspyw5S1x2zz6fuNJcbS31D12Qudf8y
4THq3Y/f5FDn7zmeRP1WtMwp6kXnNFKoLz3slkk9i5eQRj2xs+0k9V0vRRnU
z1SGcalbmhTzqE9utU6h/suTPTnUJV30k6kPjzNyqWtstE6izozm5FE3nheS
AP9Xrs6n/qlAfIx6VXDbGep3ZHSOQv6uu4XUubGVR6g35pQVQ308HGOp+133
K6GeIvU9hvoiN+ky6mYzmw9R5yxNLYf+li0+SL28b7yCuuy1rGjqj0yYQupD
Y7wo6of53ErqaidKIqn7hl8SUd8U3HyA+mLVtirq4RVjEdSzWx+eo97kbAzu
LbpdTT3z6KFw6gs6qmqo+4S1h1FPs0yspT6x2xD861Pmeerpeb/upz6RP/0C
9eEwOXDBpjrwVmbqPuqBNTt/oy6RPRv8W+I4+FBjfih15ajjF6n3OBqD++vK
XaIe0NAaQn3ShAsuURICvlZryu/Uf85VBOfEh4LLmN4Ipq55+zH4sGoUuGKQ
WR11qYmV4AF/ZoE3RQ3upW4V+Rp8hCkC1ysxvUzdyHg/eFFDHHjjCwtwV4Vm
cPUlMuDpI1PrqT+r7Qyifrp0HfhGnwpw2YgYcIOvseDy+TXgRU7u4JWefeCd
Osbgc/oVGqh3seXBO8OswNn9Qxzq2qtZ4G3R7eBzPLjgQokL4GdlqsE7d+aC
Wwd1gJuFxoEnCofBK1TY4C1vZMXwPgdXcKX1y8Ele6zB3XrtwI2u6IEHPfQE
b+pRQrfZB56sPh283DwJPCfyayD1jie54Nbt78Dnm1eCjyj9BW7CFoOvWt8O
nhPbCp60rgmcldoDvl2mDry04B349/gqcKt74+DpIgG4vIZUI/WxqDxwGZE8
+K3uLHCj6EXgm1pSwBt5y8AD1saDL5hmAM43jgF/+8wUvJcfAb5axwb8DjsE
3PW1PbhXIRtcStsZfK6ZH3jkh62YX9sb3N1hB3hroCd4m5kP+NVvbuC8myxw
wSMX8MEJDnjzRyZ4XVco+A0XJ/BoVgR44oA9+JaKaHAj8TrwOaWHwQ2v24Jb
+hwF15qwwvr2JoC/97IE99ZIBj81ZAY+aZQKvr3UFPwnuZPg5fEm4Nn1GeCK
Ccbg99fwwFklhuDdp7LBI18ZgLs188Fd7PTBGx7kgitd1gPfdSUPfP5GXfCg
1Hzwso86OB/mZ8Ada7Xx/pYCcF6iFrhofRH4yiBNcP/SYpw/v2Xg4cMC8EPB
GuBMzVLwweNLwZ3ty8D1q5eAi7eW437pVwe/61IB7rscnW99Fjw/ajH4ChUh
+KoHauAJA+gcM/QTokrs3zJV3G++IvBZ6ugTs6rAzQtVwEeF6Gm66Bdsz4HH
1SuD999F57uiaztXg3uOLgKfcQvdi4++wKIG3MIOvV2AfnJUCftvWi24RDm6
OgvdZjd6phj9izq6n/x58Bd9C8E/7/jX/wb1iqMG
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1H0wFHgYB/B9ue3FS+VlpbZdr1l22V5UV1yxSVedo/RCL5OcKeEuRGEr
czSZWmd6E7nQlk704lDpskXepUiYysuqsym3UghXZOfm5uZunu/99ZvffOb5
4/c8z+9r8V2o904Wg8FwYDIYf5/HpDu6Gy0nuZ5V+UrbNWqXf+9lTQLp9/mv
/7v3uvI8qU/lFH5J3SRZu5l6yec/JNTbDA13UpfEKG2oZ7wLCKUereWZUc/d
wYyhzqxlmlKfphyJoz6sDDCgHhftJaee5rdEl/roGpNT1CMfyTjUZXYb06iL
s80Z1Ou2cRXUDQ2sx0KI70z0y6YekBs7Qj2h0vkadf0DokFweUEBde6oxTvq
ER01RdRlY34a6jouR5TUT+W9eE2dW/W+lLo6JV1NXTJdv5K6X8Kpl9Q5B7pq
qOuevaeiPqst8iF1jnhmO3Wj2toG6s9Vl55Tlx/tekLdVr7lKfXTxtUt1K+7
Lm6hXm8W9Yx6sLtzE3UB/1Mr9fl6/o3Urdy8Oqj7L7zcQH3NiYOd1B/Ldeup
5zUcfgn7O574kPqF1MAu6nEKmzrqE31Er6jvvtpaSz3cs6GbunFEVg318dSN
b6hPDI6vhv2wK++h/pq/r4p6cQtXQ/3iQlkl9dWe3r3UlaEnKqgvEce8pZ6j
KCqnvq07sY/6uoLeMuq3OxLfUc/PkICv2Cx7T/3HiNj71FN/8u2H969rK6Ue
eFo4APkRIAUf3d8D7ttTWEJ9vyR9kHqGUAJurXD7QP1qVOE96icuvgCf4OQC
rhgPG4L/0958l/qZkI/gRk9CwYfT9g9TZ6cbgoeJ3oLvqlQqqV++sXmE+khb
MPhIWSn4hGgzcIvngj+pa51ai6lrQ6PAOx+kghuNPQB/1LgF3EJt8pF6LtMS
/KZ8O3iOUd8d6pnfXgD/WK4ED4p7AR7UmAReu2/GJ+o8ZgD4eKQXuKPAGdyp
Mg48ZYgLPpSVD5694cNvUL+2A3yCYTM4m8kZhfxm3wLfqxGBO7DSwHlLPcGP
a2LBXW1CwU3O7QLXb0wCTx/yAn/ofwWc1+YEbsqoAj86VwiuV68CL+w0Bg/v
GQI3q2eDvwzVGaM+2P3hNvX+WAH4A+Nu8E1z5oHnrHwGzkpbDt4ZVAf+dZM3
eP8PJeC97/3Bj7jdAPfkhIF7dOSAH7I+BD4gOg++cvsx8MlWKeAbypPBWXeS
wF39zoMbdx0Bv7g8F9wxORZcGFMIzq6OAs+YogR/tCcc+zulAnxPQgh4Slwd
uC9nF/ibvU/AZa92gLdqnoG787eB3xxQgZ/N9QFfcFwNXnJ4Pbi8rgd8d7YX
eNCVPvALeh7ghgsHsT8Fq8A3ho2AZ550B8/0H8X55SwHH9PXgkcOuICby5if
qbsFLwUPv/IFuPtUZ3B21kTwSNVi8EuBOuCMpkXgXWN64B6aBeCTA6aCd1s5
gs9RGIAnHJwHPrfICNxgcA548WUueGK8BPybqOngZvYO4POFM8C5fWLw9Dsz
wVsqRODH5s4C/z3PDlyVxAd/es0W86tZAB5yVwh+hmUOHtxhg/PnW4Df0kX3
s7YEl66eDZ41wwrfn2yN+aBFX9VrBW7QbA3O8kQPS5sNHqO0BF/hbQM+OB89
WotecsMCXJMpBF+yFH33Alvw+gZz8F9L0XsD0SOkduDTJqFvLUYvyzMDZ4hF
uJ9b0YdPo7OnoN8fRq+uEoB3rhVjf+PRy35Br3RDbx1C95mMLl9mD97TxAd3
PIw+T4EurkDvD0Ov1KJrVqB7LHLA/OCh6wSjXx+eBb7sZ3SDJnTbGnR1Pjpr
AP3TSXSGqQTcfh/6+q/Qfbag229H3yRFLzqEriNCNz33v3pj9OgidD4DffQx
unsfD7zkDfrtdnT1+D/+Fy3obng=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1H8wFGgYB/Bd1SK5u2IIlyt0UhdX9Oto/Liu2lKZtcltbPm5ClEcoWM5
W5tY2xIlURouW6tLZ9QpiSzq7kjWjxtRXFuNaqMfi6ibm5u7eb731zvPfOZ5
3+d55n3feYFRnBAdBoOxmMlg/L3WFps73LfRc+tYeFK+9MGg679x6/q9hfa/
qP+LO7syL1HvqvDPp/5iZLKauo3RORn14mbtdeqCcraEuutYWgN1B2uXDOpR
oh+bqbeVJRykXtQT8Rt1jXIijXprd89d6hWJdSnUk9SvVdTDTOoOUO/SNPRQ
H16jTaDuG+t5n/pWZmA8dXlWzgPqM45OxFI30J4apH48uWEfdQvjaDV1Ue7l
aOortYZPqbd0t+yh7i9IGqK+XzwlkrrsUc1z6kojfjh1ncp2DfRn3rWLemlb
/TD1ZkFEGPUzhtmvqMteWgiob2J+9Yb6tNbBEOpaI+VbyHerD4b5py4bpe5+
tiqIetv2jDHq3JhrgdSDspXj1M3YqgDqKX8OvaM+0Pl+J3WpzsQEdavHK8AD
941OUr/IS9kB9Z8eeE/9c9sOPvXEvpoP1EO3LgPnh4oYjvT9MEr8qT/juTGp
qzhm4Mzbz8ENxQV+1EcVEh3q7U9swA011lOo+92p3k69MrgCfIGMA97YaT+V
uvn51zzqivel4GWSU+DhYuNp1D+64QkuMUoCv9DEBDdz+gN8g8u1b2G+MUtZ
1EVXksBveKWDu/S7ggs82sANeHrg2ioTXeqt3R2+1C1n+oI7zCwFX16ZC+5Y
ux/85stfwR8UbwHXzGHqUe9NtAOfJVoCbjKbBa4XwQdPWvNoG/XTRmLw8jYl
+GR1BbpUDq6WtoNXbZeCm7W/Ah8z2A+ed36WPnV+cgDuz3YA58o8wbd1ssHl
dqvAXeIDwXkLbMGtvRLABbEm4Kw0CXjVGxb4gUUl4Opjoz7Un4T9DO7sNgRe
zG0Ej3nYB26gq8LzBffAu/IGwffUN4PrmQ2DewzUgpufmQTXXKkCt3PXnw71
r1KAj+sbgw/6lIJbGliCp7OKwHW9bcGlq/OxPo0Dnj8iBVcOrQCPtjgCns11
Ba//SYT9Oa0F58uF4MJcT/ApzAPgLckc8FFFPHjWu23gE/IY8Kuz/MHXjUSB
l94JAE9IjgCftzgUPH/DLvDU1bvBmZxQ8LM6e8AjpUHg2tS94A+ZAeAZdbHg
ihI++PSGePCgKD/wtqxE8M5gHrja5ntwI6EvOCszBTyg1gf8nDIV3GnOVszv
/gHcscAb/NMGEbi9IwdckXEI3ErtBb5xyWHwRZe2gPtezQCXyDaD68/PBL8g
3gQeGZcFPlXmCR5+UQK+VLERvPFuNviL7g3gc/uleP+N0Rk9R8F9/Nngv9fJ
wPsvr8f/Kz8HXG6C7r0jF7wjfR144Oxj4Icn14J/cgtdV4jOCcoDLzBA/1iL
frz4G/A5wnzwEGd0jw/o+/rWgDt9dxx8pRi9aADdeSW65foT2N+Lr8HXlaF/
WY5+ZhKduwu9fHMBuKk9uuoEupXWA/xoP7rtLXSPuSfBe3PR1/qhT4Shj+Sg
s93Q85vQD5mjp2rRhVp38FfWheA6XeiLN6H3XUGPjEF/XIj+NA/9bRq6qhr9
0W50fie6jIteOYLe64o+PuMUeNkX6Lz56B3m6Fpn9I3T0Ue80N+Mu4GHBaPX
PEOPi0MX96MvP4TOvod+Mw/9eRP6wlL0oOvoGZXohZfRh2vRj8jRY26jW5Wg
f6ZC5xags/rRTXP+1/8T9J2Z6DUv0ecfRD87iu4vRB/7gM5IQm9iFeH/E4du
aviP/wXnUAkK
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1n0wF3YcwHGskW5KtjVqPXkqj41fD8roV45+DSNPP6Lk90ulazh6orWy
RNFOZZVcJhJ+ciWF7FrTA7v1QKkWv6SkSNc85Kdso3a73Xbfd39973uvu8/3
Pp/v9/O571RFjF+kjpaWlp22ltY/q2b4zuYuy5HSC2+iZ9++2z7/v/3gQHpf
0eWO//cxLTbzRK/79l636I3FuS6i9/XIX4i+cLBBKvpNif5z0Q1eXnQTXZXZ
2Sn6xeBED9FLcnqeit6yb1gmutxs0hPRu0t9PEWPnBn7WHTzteu9RR82aX8k
epA0xgfx/dY/FL1Y4bZE9NI9U1tFL63t9xM98fizFtEdzHcEiD7m2C/3RS96
TxMoekD5ebXoTudkctFbzeqaRU9dsyNYdEnU4ybRrccWhoguMzKEt6aWLxXd
/pr3PdFTvikJFb0zJPs30dt2ZoSJHndEc1f0jw2Vy0TvTwmF68RbLhdd27T+
juixz9Vw492e8JHZSeGiW3U13hbdNmPCCtGl25TwsksquPehoUbRlePtIkTX
Sc+B71lbCK+pcYc7bxqnEL2wRHNL9OSBrfCSWhX8xJ4H8J+zVsJn3JulRH3O
msNrlKnw9WVdN0W3qmyEx9ufgZvLjFeif+5uh5umBcMrAv3gQ+2Z8DjFNHhu
xVX4tcq3DaLny4fhBUb34eoJtpGiX5lXDW/xlsMTBg/DN0u2wV1MtsKnGxTA
o6IV8IRxdfD264vhMSlP4S0fSOBNGTqrRM/Qn8T8IybC9fJGwS2mzYZ3nBms
Fz1qpDdcYvGMbq2A26qb4F6nNsBNfrwKz61MhVue/Am+Y1kWfH7eaXjbhSJ4
17ZC+KH+CsZ3OgLPNroMD6neD5/o0MD8NLvhlQo1PFadBN9a/QQ+JjwRPt2j
G967IR5uYfya+X34Fc93eQtX2a+G617RXS160fkIuGuVAdykIgyeZfoRvGVM
MHyj4Xh4TK0/fF3aZHhbvQ884LA5/IaFFzzU3QouuyKDGxy0gzcXuMNX7neA
b7q0EH5LOotuLIUvKnKCp+e7wN2vOcOrw5zhradd4QFuc+GXwxfA//CbA5c1
u8GTd81ifU094EZtEvaHqwz+KsQRPtbxC3hV72dw87eecINjM+A6Km94a7Q9
fKmjD9zJzw5enOML9/G0hc/9fQk8IdgGbmXmD7fbbA2PXRAA11FZwdWLA+El
XdPhRq5B8G4nesFkObz8wDT4UA/9xRtL3l9ZMFwVT7dWhMD1+y3gQbpL4c5f
0wdz6NtH03WtQ+EWKnO48gQ91ZP+0DQMbjhgBnfeR5ccp1u/pseE0n0Dl8G/
/ITuXkpf0WTK+T9El/5Ar/NYDt+3hu6VTv9rNv3AVbq9Pl3//XDOv9apcD1n
en0VvWMd/VwmfSCbroyjJ9XSD/vTb7ygW82hG49dAe/4lJ7jSC8YQc9cQv+8
ewrcNpqe1kw/uIu+ro4+dJRee5aeXEXfWEAPvE6PPEDf+5C+JZXu10fPS6RX
a0fAL0XTHxnSryvprZPopSH0X23o/r70c3PopxbRaxbSz86n93jRA53o8iB6
qgNdL5zuYkM3WE2PsaBvjKYbTaH7bKBPnEDP30JPG0dPSKL7GtEfpNCjRtOb
0ukNo+hxe+mJevQz39NXjaAfzaJnaNOlR+i9bybz/5ZLTx6il+XTPf6kf3ec
PnOQ7lBM93xFzyt5531o6G2l9M6XdM3Jd+rTR39URtfppReW/+t/AyoQ1gQ=

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd039QD3Ycx/Hq/Miv9YvrB1KZaedUuomM9fsHmVLfauorSQltrMs39S0J
o1wqcd8Qc8q4b4mk+hpTqYjNN62khIjvnWWjptCunHa723af5/ev973v8cf7
x93LOmpLYIyejo7OXF0dnX/qp9Lc+re2+q5/2dd9eem2xuW/3vpU9KMu9fP/
+/KjNf6iD5cMPhA9/qNDK0VXj1d2ir6w0y1I9GPrE+6L7qJ7RyK63qHQDtE3
+C8KEd0tL7BddK+gfaGiK7Oi7omuiq3+SvRlrXvaRJ9x6f4q0d91XLkreqBL
V5joG+114Db31OGiV2dKWkWvnF0sFd2oTNUienpDwmrRg/fOgltNsYsQPWjc
yV9FfxjXCW/zmQUf8z5xjeivoyubRbd9OjZS9AzFcriuVTb8puWrO6KHKMeu
Fb1HooCfCUmC9x31hF9++wSeLx1qEn2Uq0uU6F6mKrju03y4jf82eFTib3DH
Q0vgtnnz1omel6IPP6+SwSuUHWrRFWsr4dfqS+BFer3wF0k74ft0Z0aLrkkP
h5dUB8HD8hfCVTnpcLncDB50o5g+MHRb9LNnm+HO6ifw/j398M67jfDug8Yx
osd1lcGtJjrAT9QWwK9+4gePl2TAU0yi4QNJMviCETlcb1IM3M7kANxwIBju
LzsF/9PAF57qWwU/s+xz+M3SG/D5++3h5bVt8NTaj+Fhx5/BJ7RYwCvC++Cj
yozgpZOH4YO+4+ARj0avR35zdeH2jQbwHNnQL6K/05jB97wagFt4W8N//+MV
/OKwLbwvpgdeYOwA/2GlBn7ksBNcc/oxPDZ/Mdw77AG82dwdbhzbDq+e4wOf
c6MVHnDPDz52czO81zKA+4er4csNJXB55s/w3RdC4bK+Rrj5mHB4T9Z1+CTT
CPjeVfXw5z2R8HDJNbgqfR38elINfLYmBr6p4Sr3n7wBvmjeT/Aas03wyNrL
8G0DcXD3uB/ho5XfwLc7XoLLnbfAu4xVcGXJt/DV46vgth/i4damlXCpUwJ8
64IKuCx4K7xh40V48moZ/FhpOdwjIBFe/OECPMN+G7wigt75nl5wu4z3X06C
B3nS/WKT4S9vnocPjpHDM4Lp6qP04Jfn4K1WKfDDWfSR4/RCR7qdQSq8pbsU
7pBEz1fQ6+7TYwPoOfO2w28Z0p12033az8L979CTT9IjTNLgI5vp3YH0HW50
72y60pQ+XE+3e13C+W/o6ib6LesdzN85+n4/ekgu/U08vSWB7qOg7wqjN1TR
F3vQi+7S2+fSzfvothZ0qX463ECfnj+DHjdYDO//jG7ZQ1f40ic+oJ8Oo09r
orvG0Z3q6HvldC8VPS+TPr+UnqqgvymiSwvp8QX0paX0EwfpEhX96yz6gVp6
03d0o1t0VRr9WbPW/5Lpxh30dwn08130RVvodRp69yZ66Av6k/X0lF66wzr6
/AGt+9fQcwbpF6T07GF62yq68wjdMZReoLcT3iihV42mZwfSc/XpuwLodhPo
hSvoRybRny+ntxjQV/jRu4zoHUvpNSb0NF968hS6mw/d0JQ+3Vsrf2Z0Iy/6
Y3P6VE+6xVS6swd9yTT6Bnet/E2nK93oLpb0QVe6zQx6sJb3a/k1F3q5FX2h
lkda0698QdezoXtp+WEtf7iEbjWTnqzl3//rfwOw/Xjx
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd03tM1XUYx/EjIiAXAZVLLCIuAXIJFdHACzeVq8DELjhihroBhmiaJMk8
MmvqnAeFk+CFm4RHOcpRCjQ042gIcsJSsMTICwFysQgmGQq01mq/9/ev7569
tmfPs+fzdUzOWLleTyaTeU+Syf55k76KMNXzNApa4tuk117fGfhfnVibtqKt
rfv/WrOubbLUH29VR0u9ePCGvtTDQ8ejpH74m8opUp97PQl+M3+7gdTVWl2k
1MsN5xtK/cj0MHhz7iP4FrUuQuohe+RGUvc5lgh/5m45Vepr9UbCpR6Wp4TL
pxfAvW9OM5b6EssQeFJLNtw1fjhM6m4bO+H+CyvhTtuDTKR+yT8VfkulhNs0
e8GNT3bCv9v2dLnUo8w9TaWuaNHC/8h4H56Ung9/M0oFvzqSCtfZ3odbWYfC
C5dZmkn9h2wH+HW/QPhE9/gyqfctTYWrLB7Cf25QwGOufAtfZ1QNz7qkhuti
b8Pj7ijhGR2DcPf7cviCAZNpUvc7kw5/6bwLfK5dIjxzzUK49eRo+F6XOLgu
bDG81m0tfOSGD7xHsRVetdkZ3rJzNzzB2Rbua5MHT2syg3tuKYEHxurDE86q
4UOlz5ci/w9r4fM1w/C7jlr4vLQB+G+7m+Hp9V1wG/tW+DHVfXjm83tw5Yx2
+BWfTnjAn63wqMZe+OqI7+HBt36Hl8h08LMJT+G7ZjbClamjcO/sa3Bz0wl4
lm89/J3IyeZSb5/9NbzHyxAenVEH31FnDF/ZewHuNWYG/7WwBr7tmQU8ZccX
8OjqGfDy/efhr/pawy83aOBPdtjCPdyq4CFKO3jV6TPwGPnL8FUxanhn8Cvw
deaV8F0dDvDk/lPwpLcc4UYPVPCUKid4SP9JztfvDHc3oe8xfQ3+1+IK+NtW
rnD7nM/hTYZucIc75XBtF73iDfqYxh2epToBn7ZhFvxjF3qqlQe8pLIMnnyO
PrqI7hPkCVf/WMp8aOkDWfSyAC+4zJUeoKIH/1QCP2jqDZ9+kL4phd4VS99/
iR4wk66Y+jq8oKMYbhlHz6ukF+fSG7PpF5rp9+LprZN84B9505N86auM6RfX
0F37iuBB++gaHX25hn7hHH3mbbpBIX14iJ6WQ3eymA2vSae3e9C1q+lxofSU
CPqXCfRP/Ol+G+mjHvRROf2UPd3jED3Tkt5TSl9hQI/V0K1eHIfLL9MvDtHz
m+juffSyVnrcI3r9L3Sne3SDx3RFKz1nkL63hR72jG7YRF87QX9+ld4zZQ48
8Qq9w4TuWEePt6SH1ApuTa+ppnfb0TM1dGsH+s4z9H4nesNpeoYrPVxFr5hF
l1XQC7zovSfoUT70iVL61Tn0wBLh/vPo5UV0m/l07+P0FwvobUfptf70o0fo
KxbSswrp2kX0DwqE+yyh7zos9A8U9vuMviGIfldJ3xxMdxD8vRD6h/n0RaH0
9jy6/lJ6tOB1gt84JPyvZfR4wccE7z5I37ecniO4cRjdTXC54Ldz6QOCfyp4
XLiQT8ErBZ9Q0McFvyZ4ZAT9gOAKwd8V/KbgswWfGkk3FDxQ8AcH6JsEvyx4
keDHBW8QXC74E8HXC24e9a//DVqsVwk=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1GtQFFQUwPGVSkGUoRHNDYx1FQfMjUBd2nV5iRvbiqUygSYICtoS2Toi
ZsSjVMRMjZc5GYiABGnio6EYBcQHNOpoZD5omEAwGRVMUEgTpKaZavZ/Pt05
85tz59xz7r0Tl1sXrrBTKBSaYQrFP2ve+KcjnDT2QdufqB9pq28E/hcX/PZu
aW5r5/+xKr8SXvvzSPipJs2fth64+kiJrc86Xwzf2R8Dz93g+NjW8w6PhRva
EuF3nvxUbOvuVafhtaZ8eHTDmAFbX+oQBX+qPgruesYTvs1YBNfZP95r6/63
WuAP3vsRvkozZtDW9+yugJfsMMJ/mZkJ35eSBG+6Hw+3RhTCc7aGwkenn4av
rZkGX27shGfNc4F3PXrmia072w8V2fqSVjV83PHbcP+Z/vB+3TV4qt+b8KEl
jfAOZSJcOfgd/LNRGfD3H1XAl83KgZt8C+ALLhbDk7dnwy/fPgyP68mEqw7V
wWtCUuHphvNw3ZokeNbBq6zfkgiPd22Hn3OJh9sV3oGPfTsabg59AK+YH0nX
DMBVZxbAY2PthmzdXBVG77GHj1Ca4NVdTvDpN0PguTEu8GznIPjtSCX8aK4B
fqBtArw7Tge/qFDDA9K0cMsZD3ho83R4ra8X3M/qw/sfPg1eb/CGqzXecCeD
Bh7R6AM/ZnkRXjl5BvxEnRc8Zp4Wvk7vCfc0vgLf0jwFvtRZz/7t9ID3HJ0F
b7FOhqe87A9vipsEn70tAJ5qVcPnnA2EN2ZPhOvuBMEbGlTwgt5g+PFR9CPt
s+HPxrvz/dWEwMPPvQAftmkO3DuAfkVnhK+pmwDPaaPbmeml616FX29zg0cq
QuGTMugtafT+KXRjDz3vqiv/z0Um+Bvb6UXf0zeb6Uan1+Dlo+lB0XSvq8/T
y+j5pfT2TvoHyfSjajM8aS5dt5ju4UHv2krX29H11fSVHUp4Zjs9roHuNWIu
/P5++nov+rVc+gkTvTWVHrxC5Fvo/hn0nRH0u5+L+oz0jd/Qf9DSferpfZ50
1SX6W270lA5xPmf6sl76yuH0P4boLYPj4Yscw+CeffTicXR9N71LRVfcpIdN
pSe00pt96ZZmeomefu8SvTaY3nuBrjXRV5ylT3idHthATw+nrz9JX7mIPryO
/msU/cYxek+syK+ml8fT36miO1joDt/S3RPpbYfp91bRb1aK86+mjz9Iv7KG
nnSA/nAtve9r+q119F0V9IPr6YvL6eYUut9X9FMf0l8qoyvT6P776AvT6ctK
6dYM+hcl9KSPxPyL6bEf0w3C/TbQy/bSB4S7Cj+0kV5YRA/fRJ8q/Jbwk3vo
qzNFf4R3C3cUHrWZXlMo5id8rXBVFt1XeLLwhwVif+H1wh220HcINwuPFb5Z
uFZ4rXBn4b8Lv/sl3e0T+gXhc4QfEZ4gfJfwT4VnCN8vPEF4o/AI4deFhwh/
KHyGcMetdA/h7sKfE+4jfKTwYOF/7abPF94vPFp4t/AE4TeEJwtvEZ4h/LLw
rH/9b3aj/vA=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HtMFQQUx/ELyCRIVGCoZfJQ4nl5Xl4Cl5cQenlJEUwyoQANAgqDJUEh
RrRi4YBcieQGgUwqNF6FXF4XFGljEgbLqXNgYWAGLZcxrNZWje/56+y3z1/n
/LZj80JeQoa+QqFQ6ikU/8zRwr7Tj7kZhcSlaTVjX8wG/5eX//Qf3DL34/95
nbNh9GovNjGCJ8RHwlXd1wZWe0HuUXhL7Xl4sEU3/M2QSni4bg5emZoF37Rk
HrPaDRo18ByjQHij1g3+eFYq3CTHEq6XexS++bW/+lf7tRdPw2Pr5uGGtT3w
hHPTcOeQSXhB+UX4bONPcPVSFzz8/kO46XgLPCVjQ+xq7/+jDt5hbQNPTDwO
745zh385XA7fuEkNj3cthht/tAe+9o3D8KuLifCpD7Ph04Gp8LPZ6fDF2pfg
3gv7ud/6fPjQmmT4qcEjcLOzCfAgbSncZzwGXmheAc/P2A0/MVkJ35YRAX/L
pBpeowuFf3PpBNzkdTV8wbwOXlUUAA9Z/gQ+p/ODe7/dAK+I8YEn9TTBizaq
4JmftsBTjD3hObtb4ZFe7vDxts/hlypc4ck32uDfGSjhmunz8MuNzvDchnb4
3nQnuHl4J/xQmCPcRdsFTwhwgEdZfAWvjbaHN2m+ht87/CTcK7MH/nSbHbwu
8wJ8fmUHfE9cL1w/hZ5vq4Vbjm6Hm87QdWH0xao++MhlW/gFZT98OYV+t5ee
9MAGflM9AL9bTx/roN/U0MetBtmfHn2hlD6lteZ/+p5eXkrXdxyC34qi175K
T7Okv9JO/+COFfv/hf6gj55np4MHfkxvfpb+sJAed4w+n0SfaqV3B9Drr9Ct
bekrS/Q5Y3rkhmH41fvb4EPO9M4Zevsu+r4JemIK/eQg/VYePa6dfqyMntRM
z6mhV5+kX2yg366id5yje71DT9bSD5bQJ0bp2QX0nZN011x663X6qYP0oB/o
TWl0w5/pAc/RLX6j702iFy/TryfQYxQj8IlYeo0h3U5D329Mv/IUvdOUPraL
fsaM/miYuK8lvSqYfmQLPSaInrWVHhpAt7SiZ/jTy2zonb70ru10pY9wO/qo
il5hTy/3oisd6Qc86Z850RM96Gtd6Onu9BAl/T03+vOudJ0rPdWNvl64xp3+
spJu7UGfdqHPCI8XXu1Jn3Kme3jRDwkfFG4gPEJFP+NE1wp/RriDN/0R4e8L
H3Gkzwp/V7iXDz1OeInwrcIHhN9zoK8I1wlX+dLrhWcKLxJeIzxFeK9wtfAZ
4TuEG/jR1wm3Ff67PV0t/LbwJOHfCs8VrhNeJrxTeK3wFuHNwuuEdwk/LnxY
eIXwCeElwm8ILxB+R3iO8F+FZwpfEX5A+Bp/+j7hJsIThZsJjxe+WXi08CeE
Rwm3FR4h3F54qHAX4WrhbsIDhXsK3ylcJdxfuI9wX+F+//rfeUumnw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzV0OtPFQQcxvFDMAujRWNRLBQtpBTMSMsYKQZKNyl2CDMFjgInQRxgXERh
iaAwUVEJkQPI5cDxAoWXHM2SnBYDXAYR1qaniRoqomh0W5ae1oua3+c/6NVv
zz7b82y/ifFpRvM9BoNhqpPB8M+9058z5Bd435xm+9MbttkuhvybO9ZW+6Te
uPRftkVGwe2mAvjSkEy4z0cp8MuO7fCt/m/Dzw58CL/VNBcePrkDvvzKdHi0
11l4U7cv3GV4BH5wwiPww32Gors9u3ss/BOHO3xBo2P83d5T4wM/s+1XeFVv
ADxh1TX4X+0vwAdn/wjPWx8Gt31jh5fPiYA7e38Hd9y/AB7q1sv927Hw2LKT
8BJ/M9xe1wG37kmBtzx5HL6scCX8z3Ht8Kivs+E+OUfgiRW58MyANnjIlbXw
sGc/hkf0FMJb1x2An4suhld5tMLDN5TALedb4NfNW+DnBvfB0x1b4VMf2wtv
XVgG78rbDT+7qhyePMYGL4uvgAceboQPjquENxZY4UmtFnhlagM8+NFq+PNZ
9fDxphr40Ad18LSiXfC4rlr2b6+F57rTwwrq4IuX74I7x9TDw/tr4O0TGuD7
59Oz++iBfdXwMRlWeHEC3cOlEb7FUQX3KaYH2+iFt+nWKHpOUhP8qivdq5se
2WmBmyfY4JM20UPT6Cffoq9ro+9/gj7wG934eyX/F7gbPruHXmqmu7bQXXbQ
jSX0wWP0jhX0hkt0DyO93nUP/Jcg+qzJ9Cm+9FPz6Gvc6dUm+sE7O+HD2fT6
EfqtTXTvAbqhjm74lj7tAP2pTnrbMXrmUfrnp+hdh+gpZ+huzfQfBmXfSn/u
Jv3eanrpH/SKcrrDaS/8y1J6gyu9YCN9gzv9xHr6MU/6qny6yZtekUfPmkh/
eDXdzY8+nEWfPoX+YAb9p6n0Nen06EC6byo9YQbddQXdbyb98eV0WxA9OYl+
KZhuf5d+YxY900zvDKFPS6SvfIk+NkH+E0p3iqdHzKU/tJRePI8etIRuDadn
meiNL9M74uglr9Anice8St8RS/d6je4hfkK8Nkb6X6fPEL8s3r+Ynjif/r74
afFnxIMj6EOL6BbxfeLXxNPFZ75Bf1E8T/wB8SPiF96hj4p/Ju77Jt0ibhRf
LZ4rHiNuFQ8V/0LcX/y8uKf4bXFncc9I+uhCeoD4RfE54qfFjeJd4oniR8Uz
xA+J54vvE98sXi++U9wi3iBeJt4svln8kHiR+Kfi+eLHxfPEO8VzxL8SzxLv
FX9PvF88Tfx78RXidvFk8QHxZeIXxM3ig+IJ4pfF48WHxJeKXxVfIj4sbhK/
Lh4nPiIeK35TfLH4qPgi8Z//J/43ol6LCA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0/tPFXQYx/ED4nK2piEqSZoECcpQLtJwEScWiex44zIYCBqIl7yDxk0s
ZAWleOEQwwt6xBsydDrwelhLWTUzRQEVmbhMCFLLKCogCFptOt+fn/oD/P7y
3bPXnue7Z/t8nRNXhy+yNRgMnjYGw7+3739nyFsh5l9zc0tajI/rLTbvNJu7
2p7U464Pynvawzf5w48YHeBTIz3h/nYu8NZAF/i8mV7wCM8x8LjAAHj8YHt4
Wd90+MbjQ+Heh+fCS0bZwa9HxcCPuPXfftr3uiXA8+u64SOmLIW32/0OT9u4
ivtX/QI3eK+Dj6h/yPmzM+BBkT/CV7ZvgCd4/QCfNTQHnhR/D15a8zHcveE7
uLPTp/DYTXfgKWPzOT/rNtxYvxU+70ATPCqoAP6wpxFuTS6Em9bfpL9XBPdw
uQG3m1IMr/i5AX7i6x3wsMZ6eLTfLnhPcx3c8cPd8Prea/CKshLm25u+uHIP
/8/6q3DT/r3wpY218BcyLfDRwXTHgH3wXV9cgZc8oKfMoBfklcJD7lyGVzvs
Z76z6CcK6X4T6HcHH4AH3voWbl5BH2+mP7pIHx5B73c6CI8ZQ69aTI9qvwRv
LaennqOHt9F9t9MrXj4Ed1xOz59FPxtKz8mgn/SgP19KPzWcvvtL+srub+DF
rfTie/RYm8Pwzlr6NCd66Of0DT70Jcfoy0LoYy30N2LpwWa6+3L66Vz6u5n0
sCy6/Sf0rhT6ws/o25bRUy30gUT6inK6Txw9oZLuEEVfY6UXzqUfv0AvNdF9
L9Inh9CH1Yq/TY9soBcZ6S/eoscESH8zfc00+qS79LrX6Xta6GlT6afb5H0f
evZ9eooX3fYnevVkevAjupcnfWYHvdaDPu43+vZJ9Aud9OSJkv8/6Kvd6dv+
pOe50c930c9MoDd003tfo1/qoYeLl/9Ft7rSk3sl/+KuffSzLvSvxEPFo/+m
t71KbxLfIj6nnx4gbhXvdKa/NECvEl8lni5eLR4sbjCUwUeKG8Xvj6eni9eI
HxW3iDeJZ4sPsqEnibuLm8RniPuJLxJ3Fs8WHyZeLD7wiuwv3iF+XrxFvE68
Ufx78cviHeI14n3iVvHnbOmV4vbiFeJO4gfFXcUt4h7iO8V9xIvE/cULxN8U
3yoeJL5ZfLp4nrhJ/CPx2eI54mHi2eIR4h+IR4tniceIZ4rHiWeIx4uni88X
TxNfIJ4qniD+vnii+DrxheJrxZOe+TP/H/4Pr1Uyug==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0mtMzXEcx/F/DiaOSwzHdYWa5BJKqKRDpOQuSUnmmFvLljVLYy7JrM2l
uZVbEyIixlJDZ7lMx5RlphTNrZ5geJDcMg/Y3p+nnvbou+9e+36+3/32c1ue
OM/WxjCMEU6G8aeu2vc+Nci3w+T4YPO2c5mvg/72A59Z7+1uefevr7L2hO8v
DYB/mjcAHjLTD/5r9xC425ox8CwnL3h1x5Fwk8MbXuw6DL6k2Re+9YQHvO7o
RPjY1MFwlzuT4D8uuMKbN1nhXTwHwgMrQ+Dpjf3g4Y5Q+OI3feApyeG8r5cF
7lETAU/Y2Ate/nM2/Gu7nvC+jXPhYcU94JYT8+EL9nWHDxq6EJ6U7gJ33hUJ
X3mkG/eXLeL/uNMV7l0Xxfx29NvVi+FZ0V3gL0qi4bn2zvC5O5fAL4+nH/CP
gXe/ZWZ+HT1sDt0rMRZufOgEt34SP0gvti2Fj5tONz2i5xv0ZV5x8O32jvCm
zfSmXfSKB/TISPpj8zJ4G0+ZD6UnGPS0zfTetc7wYwX0PSX0/Gp64nG6nxEP
j9lBLx5ENyXQc4Lp/aPo4bF0Wwi9WzI914cemEE/5U63nKT7WOj1hfSRZnq5
nb7Gie5cSb/f1AHuqKW7f6SPb5T8BnrSZ/qWenr2d3pEDb3CtBxuf0J370Qv
r6AXudCjHPSs3vTY+/SX/ekPy+iH3OjZpfRKd3rpTfphT/roEvr34fSGIrrJ
m15znX5jDL3tNfpQX3rcVfoCP9lfSJ82gX7wMr2tP33VJXpmAD26gN4cKPMX
6ROC6Hsv0KMm0x/liwfTXcUnWelp5+nmKfTmc/S74qnia6fSzeIt4nl59O0h
9Fni38R/naWvmEa/Ll4mnixumU4PELeJO4vniT8/Q38rXig+IJSeIT5LfK14
iniEeI74WPEy8X7ir8Xbi7eIfzkt7zuD/kp8lHiV+BTxu+ILxW+I28QLxDeI
54pvFc8WzxDPFD8kniGeI54mfl58i/gV8RTxIvFk8ZviSeJ28fXi98TXiTvE
V4tXiK8UrxJfIf5UPF68RjxOvFY8VvyFeIx4vXi0+KtWb/VWb/X/9N9x19Gr

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1OtPDgAUx/GHTElttkSYtWoVugjDbC7dPemxWotISZEVXRgzt03zysql
sbmuRmZmMyNbxqo1HikpJT3dL5Kix4S5biXzgu37+wu86NXZb5+d8+Kc7bil
ZMekjjcYDH7jDIY/tXDoemXkUrvA0ohS67fc16v+5vvFCWkbbAf+5fTrFfBz
jzfC8/PM8Hdz4+BpNlXwRkss/N7MGvhucwx8uL0W/sAaDT8TXQ9PD4+CN+S8
gA/UrYV77n0JX5ZjgvsvsMA/rouEN5Y1w51Na+Bxrq1w96QIeEZ8G/xznhG+
ak877/N8NfxYZgf8hzf9kqkTvud0ODzLqQse4Ei/YqbvPBvG+6d0w0/50mOH
6IvrQuE1GT3w2QfpBR10n/n0sMBX8KT3IXCXC3TLbXrwW3rlIXqDfy/8sIl+
N5O+3p1ecY1uHg6GlzTTje305RNew3eV0a0+9OYiekQU3SOPXptFt9lHf5NL
999K/3iVnhpDD35Azw6he9XRZy2hd3fTl82j3xyiF7nSH47QF0yjR9v3wZ84
0nOc6asn0g+40s+PBsET5tCv/qQbA+ixX+gblsr8IXrRCnqylb4yhF44IG6k
h/XRi030iFf0G9H0y130RbH0oA76pji6RxvdN176W+g3E+hnLPSBzfSpTfT+
LfTyRpmfQj/5gh64jX6kQfaTSj9RTx/cTi95TrdLo3+ro9um0yPFreLFtfSS
HXQf8R07pf8ZfXIGPVz8onh/DX1mJj1f/Lh4qPhn8dGn9LVZ9EfiBeInxN+I
J4p7ZtMXiieKO4jniw9W08vFa8T7xe+I2++S/yHuI35U3CieLZ4svll8v3iU
eJ54kHih+GLxW+LzxEvF3cSrxV3Em8SniPeITxJ/K24j/kn8VxX9u/hP8RHx
r+I2u+mfxO3EP4g7iL8XnyL+TtxJvF98unif+AzxXvHZ4j3iruJd4u7ineIe
4u3iXuJt4t7ireJzxFvE54o3i/uKW8T9xJvE/cVfis8f8zEf8zH/z/03QxWY
Ow==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0d1PDQAcxvEjXdQ06qJ12jCNG0NaK+ail2GmTSxEsxbnlOP0TmrGzEvT
amOnohpnCaut0bQoUulF75IkepmFhc3LlmhlLYa5YPs+F/6Cc/Xbs8/F82w/
H3Pq9v1OBoNh1RyD4c99Fm52j1rnEppt7khPynwb8jebS3o9fs5//y9nZnTB
64MewS9teQgfce6B537ugYdOdMNNpl74t5ku+o3H8MOL6Zv6+uCF0Z3wkKdP
6FUd8Lm1/fBZL/qrzKfworx2eP3aAfgRI91vhP7uZhvcZnkG37WN/vIdPe17
K/zzzudw51v0PffoP1Loue6DcEsAfSCGnmigry+jhw88gI+O0WOv07OMQ3DP
LPrcMPpYHN0lnb51Mz3ATp/ypXvcH5L/0Re+oGc609un6H2TLfBEt2G491u6
xYe+fJDuHEDv7abnbKQ/b6Sv3kE31tD99tEzKuh1idJfSp/OoBsu011P0meK
6MZsekk+PdhGf32OXlhAv55DD7TTx8/Q/a/Qi0/Tr5bSK07QbeX0Bcfp8yro
TUfpSyvpVUfob6roLzPoEdX0kHT6sTv0/jR6XC397CG6Vx09/iDdXk+3ptK/
NtCzUuhLGukNyXTfJrqL+KJm2ZdEnxQfTaRXttD3ikc+oH9JoH8St4knt9LX
iL8R/xhPD2ujl4mXiVvFp8X9xYPa6U7iJ8SHrfS74rfFP4jniXt20NPEg8V3
i5vEQ8VPia8QLxb3Fq8RdxXvEZ89QH8lPi4+IT4m/kt8WNytk94n7i3eKb5M
vFl8pXideKB4tXiQeKX4BvEb4pvFy8XDxcvEI8SviUeKl4hHiReLR4vbxWPE
L4qbxIvEY8ULxePEC8Qt4hfEreLnxePF88UTxPPEk8RzxZPFbeIpDne4wx3u
cIf/x38D/CXYFw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0slLlQEYxeFPbXE35iKKciq1IkoTzQZT0RDJCELMuhoZVIp6N2JOZZnZ
pCgV5lhZZKhFJEpKWaFkN4cMhKDENEWJuIiRgSEVGNGi4Hf+ghbf6uXwwDmb
1+dIZnyqs2EYAU6G8edaHngeSAmzRJ247OFsKfgY+TeP3KgbL1zm+JdrznvC
x37UwueSveCDNvqMlzc863MNPLuf/uEU3T95JTzOnZ4xRd9pr4YH7V8Ft+XR
E7ropcF023IfeNV8FXw8nX6nh+5opU9epTd9kf4MuttaX7hHDN2w0j+tpoee
pR+z0FPv0ffOVsLdB+l+7+mTDnpZL32Dsx88vIOesoI+10h3BNCza+mLougl
5XSXOLpRTPc7RO/Ip9+00U9n0hty6RHp9OQi+vBh+rcS+saD9PIr9EArPbKG
3hdPX19Pn9pDP9pAz9pNd2qmp8XSl96nP46ht7XQE6PpE230qB30lnbZj6Sv
e0TvjaAnddITwumxT+mLw+gLz+izofSiLvrXbfR33XQ3cZfn9F1b6a499Gtb
6N/Ff22mv3pBzxU/Y6cvhNB9XtIrxdvEQ8QDe+X/NtFvideJG310q3iiuLd4
k/hMMH1avFt8TT+9VjxJPEe8VHyf+EPx7eLD4r7i8+Ku4ksG6D+D6P7i0+LR
4qPiVvEh8TRxu3ieeKf4BfFW8Qrxu+L14rfFG8Wvi7eIV4u3i1eIPxG/JN4t
XiZuF78oPiB+Tvy1eLH4kHiR+BvxQvG34ifFh8ULxEfEj4uPiueLj4nniU+I
54hPimeLT5luuummm2666f+t/wazNJns
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0k9I03EcxvFfISnpYSEEM6SioEMuZKiBNiZEmZitrIZ4K5BUoowgSFs6
K0f/VmYSuRa2UVirIVTQRfCw9JASCVIR4Z+p6UoMOlRUEB0K3s+x8/f04eF1
eeD5rD14tKp2qWVZjiWW9ee6lr+ONroySosS9+8NHUu6/+aalyPP3uZ++JcH
nQ/gJQH6t076WBm9YZ5ut9EDBTF4zvgwPHiCnvGE3t1H3xikR5L0ycP0FttD
+G0PfXEzfbqQHqqhb19NX3mSXptJn+ikf/z+An4kRg+m6OsG6Fnv6d5RuuOV
+BS9f5B+6DO9o5+e+ElvfUqPpj+C18fpzhX0vF56t53eF6H/WkMfD9ObN9Cj
N+n5Dnqqi17gpN+9Rr9VRH9+he4rprsu02dd9LSL9JlSuu08vX0rvTpAf7ON
PnaOPllG95+lx8rp3jN0dwXd00bv2Umv80u/Snq4lZ7aJfu00N956JXi8d30
xGn57z30CvHMKvqEjx4SbxO376XniwfE507R58V7xd376I3iF8Td4iPi2eLp
++kLzfQS8WHxOvG4+FXx6+KPxX3io+L14gvi1eJpXvoO8RzxYvE88U3iW8TX
i5eLrxL3imeLHxDPEm8QXyZ+XNwSbxL/0UT3i38Vbxf/In5JfFG8Q/yTeJd4
SvyG+Jx4SHxWPCw+Ld4jnhS/Iz4lHjFu3Lhx48aNGzf+X/4bvrG76A==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1N9L03EUxvHvNidzqIQiSHhRiBaCoCh4FRMamERlziyoTASZE1QMZSB5
E8gCEVHqqqykEIRSApNKvKjIQUHDfoiaJG6pSxFFiDAEpYuE501/wufq8PCC
5+qcc7SupbLebllWvs2y/s7rDX0bNzyu0sImx/3hQMzzL4d+RfzpOasH+f09
9dcz6q1T6l8m1KNr6t7H6mF3gvhQr/pIrvrdTvXDHvVPTerBKnV7rXqeX33d
px4Kql8sV5/rUs8oVa/tV98tUa8eUF8uUN8cUn+Wp+4bVffmqD8ZV+86op45
qX41S/3FG/WJTPVHYfWeDPWtD+rv0tSfR9QvHFK3fVYvTlWPfVWvTlZvnFUf
c6s/mFcvS1LvWVB3udRPfFffSlR/uaj+x6nuXFLPhh+PqvsT1I/F1N860P9D
vQgeho/bcd/L6qfgzhX1uE39Fvw2fAd+Gn5lVd0NH4NPW9ifuPpD+El4O7wT
XgEfhRfAv8HT4faf6jt7H8Vz4VG4Fx6BX4NPwoPwEXg3fBA+AL8Dfwrvhr+C
34RPwTvg0/A2+Dy8Gb4ED8Dj8Hr4BrwOvg2vgf+GX4bvwi/BrTX8T7gD7oMn
ws/Dk+AVcDf8HDwZfhaeAj8DTzVu3Lhx48aNGzdu/D++D8BBdps=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1MFL03EcxvGfQ0ICQetihx2UDgYaO7nd2tYhROkgeOgUioJBUOBl0EUt
dW0sBSdGWhgoiAp6EJUgtEPSIDq0pclKMidjjbGVtqXgkg4Fz7t/4Xv68PDi
OT6f6vY7LZ02y7LqSyzrz53ZaHI+9JS5ox0fr8237V35mwNf9gN1dcl/udKn
3hBTj/rVfRH122Pq9nX1i1PqhRV154L6zqL6p1X1xVn1q6/Ur0+rh9+oP5tU
P3in7p9Q74mpHz9Wb91W3x1VD35Wvzyi3rCr/mFYvSuhHnmk7kiqWyH1iZR6
d1B9Na1+IaA+lFFP+9UvZdUTg+jn1H8PqG98V3fBYz/Ug/3qawfqhw/UQ4fq
d+Hun+rF++px+BN4R17dyz4836fuLagvwcfh9+ApeCO8/hf2Cb8FL/SqP4Vv
wiPwF/Ac/Dn83BH+E9wB98Eb4V3wm/Ab8G54M7wf7oGH4S74JNwBn4PXwpfh
NfCXcDv8NbwK/hZ+Hv4eXgHfgpfD4/Cz8B14Gfwr/Aw8AS+FJ+E2eApeAv8G
t+AZeLFHPQs/geeMGzdu3Lhx48aNGzf+n58Cqqv+Pw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztybsrxXEAhvGfa3LnoIRyOVhYjgwGESGLRMKkTimhKCVJoZRCbrmuJJuY
5R6SEIPLQImiDCJ13MlAvc+/4Ds9PX3inA0l1e6WZaW6WdZPz+3enaO5Ptlh
h772/cqrrN+vvkiYSkq7+fvQU/WnM/X4C/WoY3Xnlfrmkfr9jfrlgfrlnXrV
nnrRvbpjVz3/Ub14R/30SX1uW93mUs/ZUvd4UffZVJ9/VXdtqCe+q/vCaz7U
M9fVOz7Ve9fUm77UH1bV8yw/8Tr4G/x5RX3STX0EHueungmfgD8uq3/CF+Dl
Huot8Bl4AfwWHg2P91R3LamXwU/gnfBF+Cx8Gr4N74dfw9vgH/B6uM1LvQpu
h5fC0+GF8Bx4NrwIngGvgDvgTngKvBaeDG+EJ8Cb4bHwVngMvB0eCe+CR8C7
4eHwHrgN3gcPgQ/Ag+GD8CD4EDwQPgwPgI/C/eFjcD/4uHHjxo0bN27cuHHj
xv+dfwPGJNZC
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyT0oxAEch/H/YWBQiLIaDDfYDLoUA5uSk5fjvNaJchlOskh56SL9ZRNx
7pxzMdBdYjDoNgbCZlKSFAOjSQbq+8zG3/T09KkanvCH8hzHqfE4zk/L5i+u
4s2Fja9tLTfF/qeG379PX5fk+17+/q1d3d1XP+hQn0qpe7vUF/fUI93qJ0n1
tYC6Bx7tUR/ZVQ/2qj8m1MuD6uPwDLwI7utTz8bVj+Fj8Ip+dS88DP/cUT+D
5+Bf8HV47YD6JDwE74S78Hp4Bl4Nv4OXwt/hDrxgUP0jpl4Jf4Z74Q/wOvgt
vAl+CW+F5+AB+Dl8CH4KH4Vn4WH4ETwCP4RPw9PwGXgKPgtPwufgCfgCPA6P
wmPwJfg2fBm+BV+Bb8Jd+AZ81dzc3Nzc3Nzc3Nzc3Pxf/RtXQv73
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyb+LgXEcwPHvsRiMzx9wlht0/gPlGRTpJmWyKYuBwXaLjcVyo1m4HzxX
YpBueBjI8EjxRKckw8XAZJeBet7zjZ/p3buXL5WLp11KqcCDUtdGt6+aEfHo
b8dnlYntQrfPl14eh/rf/U14An6AB+Hek9Of4H64Bg/D3fAk/Fx0eha+hxfg
G3gZbsMrcAtehY/hTfgA3oH/wPvwHtyEd+EjeBs+gX/DLbgBn8Jb8Bn8Cz6H
f8IX8A+4DX+HL+EN+Apeh//Ca/C1uLi4uLi4uLi4uLi4uLj4v/kFJBrlUw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyT+LwXEcwPEvwy+XwTG6QcomdTe4gfLnUvIvdzce3SDK5hHYDFIew0mI
kjL8DBaTySijQeqcJyCjDPer7/sxfKZ3717+SuOzZldKhWxK3duMh7+XGUfi
wdNpHd6O8f/ffi3s9fTJ+plbd2dJ9wo8CvfBq/DfR93bcBM+hHfhK3gdvoNn
4X/wZ/gV7oUbZd0NuAd+cen+BD/DA/A9PAjfwl/gG/grfA2PwFfwGHwJT8JN
eAo+h6fhU3gWPoHn4GN4Hj6CF+ADeBHeh7/De/AP+I+4uLi4uLi4uLi4uLi4
uLjlN+AcUhI=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0L8KQXEchvEfkz/Z6EgJmQzYLIZjVJLiBkTKxGAySGa7RWZGkc1gkMGg
JAaDEhILuQIZqPNcgOk7vT19tjdQqGZLZqVU2KTUZ0e9R3+RsiQ29oxei5/0
b8d92vaVvv66DG/AHfAJfGYz+hnehNv9Rk/CI3A3PAV/Wo1ehK/gdfgQ3oZ3
4F14Cz6AV+BjeB4+hefgc/4HX8J1+Boeg+/gUfgeHoIf4EH4Ee6Hn+Be+AXu
gV/hGvwGd8HvcKe4uLi4uLi4uLi4uLi4uPjf/A1XKwPo
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyTGLgXEcwPG/m6Q7st2kbnmy2Ix03gBJXoB0jw07q9Fm0KUUg3qScHgL
R0hhuFJKSc/iHt1wk+FkOPV8Jy/gN3379nlJ5xP6g1Iq4FDqWvNs/Kyizojl
KWq+4P71/zOW3nhLmrevwmvwGHwM98KP8K3b7o8nu/fhGrwMD8Oz8Dg8AU/B
Q/Ac3A8vwJ/hJbgLXob/Pdm9Av+Fv8O/4XX4Ad6E7+At+AZuwL/gbfga3oEv
4V34At6Dz+F9+Az+AZ/CB/AJfAgfw0fwT3FxcXFxcXFxcXFxcXFx8bv9Auqq
GDI=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztybsKgXEYgPG/w6CMRocyY7F+A4pRSjKY+GJTNhMmi8GglBDiJrCQK5Hz
oZTBYpEM1PfcgXqnp6efVy8lC2alVMCk1KeuTF5bJ2zh9FyPbPy70PdX1Wh2
kTn93gk/wC8zo1tqRl/C3fAePAivwGNwHZ6Cx+E5uAYvwn3wMtwDr8Ed8Drc
Dm/ArfAm/DU1egv+hLfhD3gHfod34Td4H36FD+Bn+BB+hI/ge/gYvoVP4Btx
cXFxcXFxcXFxcXFxcfG/8TfYGejv
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyb0KQXEAhvG/M8lmskjkI+XzCpxTUgYDshiPMpiOstss3IELYDMfyWh3
B5TBoOwsZKDOM7mAd3p6+qUGXndoGWNKIWM+7fqJ2a0TdnLbzHqXvdjfX3nz
p3Gvv3/5Qd/DT/Aj/AA/wzfwO3wJf8AXcGsc9Ck8Ap/Ao/ARPAZ34XF4H56E
9+BpeBueg7fgeXgTXoA34EV4HV6GO/AK3IZX4TW5XC6Xy+VyuVwul8vl8j/9
DdCEKDk=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyb8KQXEAR/EfkyeQ0M1NykAWkwWju2G0KTEok4GyMimbySIyUFI38v8N
7GaDR7BKYTjP8J1Op49dbZVqXmNM0mPMpwP//fYq+3Jz1+mtrEf29832zEnW
n/8fwrvwDrwPb8BH8Ap8DC/CJ/ACfArPwxfwDHwJT8PX8BR8A0/AXXgcvoXH
4Dt4FL6H2/ADPAI/wi34CR6Gn+Eh+AUehF/hAblcLpfL5XK5XC6Xy+Xyr78B
kfHZGw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztySEKwgAcRvH/ZMFm1GKw2DyDBk9g8ACCcVp2EMGTaBMM4nAoQwaDMdTN
smAxL4tBwXcE+dLj8etM5qNpzcx6jtm7W3/Zcsf1QWO2qNbNsv/5VffcHnqP
7zvwDbzyfn0Hf8JDeAmP4Dk8hmfwBJ7AU3gMz+AR/AI/wa/wI/wGD+E5/AAv
4AH8Dt/L5XK5XC6Xy+VyuVwul/+JvwA/9d2u
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGfLvkmCURwOATZnAk8J/DYHsaf36li6lb8HM73
QpNfgibvjCa/Ak3eFk1+NZq8FZr8WjR5MzT59WjyJmjyG9DkjdDkN6HJ66PJ
b0GT10GT34omr40mvw1NXmtUflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+
VH5UflSeKvIATXLMtg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHqhhxrZKI4HLKmfrnxl/OxPYw/qWOVm0nlczg/
FU1+Kpp8Ipr8dDT5ODT5mWjy0Wjys9HkI9Hk56DJR4zKj8qPyo/Kj8qPyo/K
j8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPCHkAAgNG8A==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEx/Ye+asRwOMjy2T9wYH5sD+OHfJL/x1f/HM6X
QZMPRZOXRJMPR5MXR5OPQJMXG5UflR+VH5UflR+VH5UflR+VH5UflR+VH5Uf
lR+VH5UflR+VJ0IeAN+jAwc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANET39bYm8ZxODRvDz067c8jexh/sczFv9dansP5
DWjyS9Dk60flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5ekg
DwBTd4vk
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHHvM07HRM4HJ4YLHj37+sjexjf6pLP/Z6u5/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A6X8w0Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF/Vn685JvE4VCoPO9UxftH9jC+4XVOE8MJz+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAL8Srug==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGGHGtkolI4HCK1A88zv3xkD+Nf+P+n9cjU5/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A1rr5MQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFpYMDh0FO6pXL+o0f2MP6dSYoR7rOf24/Kj8qP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyg8meQDumUtK
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGzjyhsKMrgcHgy0cHX+84jexg/ovyr2q4Fz+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAkLwGYg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEXlW7/rMvicNDSrrrMdu2RPYw/q+ZVhuyy5/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Aq1FWDQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFsjVOdu3M4HHLqumZfPP/IHsa//ehsX+Hq5/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AkKQPlQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHW9/17p+dxOFyf8MBy9clH9jB+hqo6y/YNz+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAjHPB7A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEFtlzXFxdwOGx1uOU++fAjexh/7ss+/Xdbn9uP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkA7SYSiw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHLZh9R2FDE4XA4syS5c+8jexh/5q1/ReK7n9uP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAZtakXg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG3f9Zl7SnhcMjKZtTv3f7IHsb/rCStY3zguf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcA+Vr9jA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANECEZZbTpRxOOSWPA2Yt/GRPYwvoVi2xfHoc/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AYRcepw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGu2z7/vVLB4WDGEVG8Z/Ujexj/y8Nzic6nntuP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAabV0hg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHVIuvcH1ZxOLxz1HJ5vvSRPYx/765Xm8X55/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A/FsCtA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEbijImvq3hcChPm1git+CRPYw/J211geKV5/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ae7Uo5g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFPLyjd/lnH4eCT9HVH4qxH9jB+g2Z9zr8bz+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAsg2J4A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFS+ndV2Bo5HLbeOnRiw5RH9jC+sVzAofN3n9uP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAUWouGQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEBvdPzhJo5HLY0OcRx9z+yh/GPGZ7bPvXRc/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8An3VS5g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGtrwN3yLVyONjnpJsVdj6yh/Frvn7rD3j+3H5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMA7xYc/g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG7PHmYtNs5HDRF9wk8an5kD+Nfn2jVzfDmuf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAlPgBPA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHvlx/zNu/kcPj91XR9bN0jexj/sPm850s/PLcf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIACCI94Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGqbI1Tnbs5HNTiuK89rnhkD+Onudx54PD1uf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAaRPVXQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFRKdb3/Xs5HF7mLvcuKX5kD+MbuDdtuPjzuf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAzLbBdg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH9h75qxPRzOJgyt9zgy3tkD+P/EuHti/j33H5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAaYeWNg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFHFDYUZUzkcCgoEnTfnPHIHsZ352def5Xphf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAvLSs3g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG/6rL2lEzmcIh8Pjc5MfmRPYwfdJjH3ZP9hf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAclnAeg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH6d1XYGqdyOET52f2RiHtkD+OfYuDp2Mz9wn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMA8ET/2w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEp1vf9e6dzOGiv2PHgZsQjexhfpc1wkYjAC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Actk5BA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEzwYDDIX1t/qPFwY/sYXzGWMEjOSIv7EflR+VH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5QeTPAA9MN86
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHnvwc/Xjqbw2H6Sv8rZX6P7GF8w/9bpfZIvLAf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIArpcsmg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEsYXy6m+ZyOBwp29MV5PnIHsYXiN50kUn2hf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAEpbvzg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGWW06U7ZvP4TC9teG2mcsjexg/97SRsKPiC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AkwSqBg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF5Qs0HTi3kcDh1b89cZftH9jC+sBgvR7nqC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8A39/qdQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFLCmy5ri/mcHjFc2ulhNUjexift+n89SWaL+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAamBrpw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE3z30PfryUw0HnXuVNUdNH9jD+CdHzK07pvrAf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAkN1ujA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF8upvmvl/O4cDxIZNd2uCRPYxfzW264IXhC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AsQTLaw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHO3TnPf6/kcPj+bRq/hvYjexg/s5P70T/TF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A97eenA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGVL9UMOdZwOFzZynDeRu2RPYxfuspzIq/VC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Ad411nQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHr3B9WiazjcDg7c51ypOIjexjf+dG98yJ2L+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAZ+y39g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGPl84+orCBw2HG+yVvamQe2cP4L4/v3Sfi9MJ+
VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+MMkDAGS7RmU=

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANESLGF8ups4HP6uuMW5QvyRPYxfHvCsltfthf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcA1RKvAQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF+SQIRlls4HD6t0I+5JfTIHsa/0pSv89/zhf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAdPHAjA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHNB04tdN3G4eDdl3xUmO+RPYzPu3bCi5e+L+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA+Vs9Dw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE75FpfB+7gcHj1hUcjhPORPYwvq7zq/NnAF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AaTqrow==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFva+xN43ZxOExXm5g+m+WRPYyv2Of7b1XoC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AfzRF0A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHKt3/WZe3hcIg1kcl4+f+hPYz/9pLrhMbIF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Aroqwsw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANERlltOlO3jcOgtmsln9/uhPYzPN23egsDYF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AF9+zDA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG90/OEmg9wOEQGrnGY+e2hPYxvlLzaUzrxhf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAx2IhEg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGHvmrE9B/icFjXs/LJr48P7WF8h1q+pfdSXtiP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAAAIyug==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE/gh8vnX2Ew6F43YSHSW8f2sP4KjH7T8/OeGE/
Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/mOQBE4+v8w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANOb5r5ffozDwfgeq/zFFw/tYXzZuwLXgnJe2I/K
j8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyg8meQCbvnWz
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFJAhGWW05wODD+8m51ffLQHsa/q7n9NnPBC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AyJUjZw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHT84SaD5zicMj/Yvd3//2H9jB+d9TZz+uKX9iP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAWjwUkA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFnz4AAh8P+Yr8Ch9sP7WH8KddumYSUv7AflR+V
H5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAAgAC9w==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFM2u1iN89xONxfV3Hi2LWH9jD+hvIbWz5XvbAf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAmKWRUQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHmnY4JTy9wOLS3uH4IuvTQHsbfVWTa2Vv3wn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAPW4KLQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE5z3+v/HiJw+HoyYOXnpx9aA/j63PeOabY9ALO
P4Ymb4AmP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1Q/
PfQDAKnmikc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGLXLd9/nuFw2H2marompMP7WH8Djazpg2tL+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwASZZZCg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHXFxfYcl3ncHDkqCqTPPrQHsb/zG143rLzhf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAeKEWLw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE8TNrtYjc5HOw4HAX2HHhoD+M7rHU6uLfnhf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcALqvE9g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGOCU8vKN3mcBCsOCqasuehPYxvmpiTbTPhhf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcASPle+A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHl++ZL6d/lcOCIzS0R3PHQHsbf4m7/YOvkF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AZRpf7Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFrZKJSrO9zOBhWcEsd2fzQHsY/dfy+odb0F/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AEvIV9Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEPq0TWuT/kcAg4d/tL9fqH9jD+VnbOopmzXtiP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkANblZkw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFiN899D37M4SAQ0vDZYvVDexh/h4PAJuZ5L+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAwepE7w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE+5p2OCU85HHr2/GX5veyhPYzf9eE5U+bCF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ay48EUw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGNU527c55zOLRl7JA4tOihPYyv+Eqp9OSSF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AHSgZSA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHbPv+9UvGSw+FESaFc37yH9jB+gPt3CdUVL+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA7oCSZg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGvA3fItb7mcFB45swWP+uhPYx/zsbxX/XqF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AfMopIQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGKG4oyJr7lcCj/uPCAybSH9jC+0KVWk3PrXtiP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkABTlRVQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFhfLqb5r7ncPgWF2THP+mhPYxvUff1lPSmF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AGK9gOA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHdOc9/r/zI4TCPLa/gXe9Dexg/eXXehZStL+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAo2OpdA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEHTi103faZwyE9NdbjUudDexh/nmJD8ModL+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAp4Lf4A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHfNGL6D33lcJjteW37rtaH9jB+Q1R20svdL+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAlyIxVg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHa7WI3z33ncKibenPD8saH9jB+4z41btX9L+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAdgpChw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEJTy8o3f7J4SApvlF1Zu1Dexhf/2x8dMyhF3C+
FJq8AZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8AQjJWBg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFTnbtznv/mcMgqecvRX/nQHsZnMqxN6D/6wn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAAYYapw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGnF7pu+/yXw+GiVopvZ+lDexj/4f4F6vtOvLAf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAzxynQw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEQwOmgtFD3WXvhQ3sYXyZz5d4Xp1/Yj8qPyo/K
j8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDyZ5AAt5dMw=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGmcbs8eZg4HQK8Fx/ryn1oD+PvEDTV5z//wn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMA1q+RGA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFZe0omS7BwOkjdj300MfOhPYx/PH5Rh+GlF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AoQcz2A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANELpPTvqrBxOlyfYaw7N/WhPYw/sVTomv/VF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Al5Zr1w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFXK16qGXJwOjzpN5u9JvGhPYxvMDdLOevGCzj/
KZq8IZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8A8/o02Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFc1xcX2HJxOpyV3KxwIPahPYyf9DS0puH2C/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AnWH/zw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH2pnG7PHk4HXZb6226HvnQHsYX2eD2ZtK9F/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AFviqrw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGlkyVYwvg4HRo0U1w+hz60h/GjjSvqFj58YT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AGUrclw
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGrPl7yTRLgdDh60e2MUNBDexjf9e172zVPXtiP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAJMODNg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH3/Xun5wlxOiws+2Nn5vfQHsZ34K433fz8hf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAUPMxFg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEi69wfVolwOrgF3ZsY6/XQHsbPPHo4f9urF/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AG5qCnQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFePEza7WKcDtru5bs63B7aw/jJ67S+b337wn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAPiywRA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH1WXtKJktwOoTNblq33emhPYzP8+P91Y0fXtiP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkARslZQg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFbTpTtmy/F6WCw71XyK7uH9jD+qrUKYqs+v7Af
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAE+yLaA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEv1Qw51shwOkySOHFBwfqhPYx/4/Hsg/O+vbAf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIACMxigA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFyra8Dd8hxOix+Fv86yvyhPYy/6p7wo/6fL+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwABp44rQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEhj5fOPqLA6SAprbxqhvFDexg/W4+/sfbPC/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8ADfw7Ig==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGdjglPLyhxOvR7r2W+pf/QHsZ3O/xyefr/F/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A8awTPg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH75kvp31XhdChZevidnM5Dexg/6MfVeD+ml/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A5KNDVA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFf/l6peKnG6VDxOjgpXeOhPYyvNe3uRkPWl3B+
OZq8Jpr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8AXpTGJw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGaMf2HvmpwOnyrKg7drPLQHsavPftomSDHS/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Afyyquw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFxuzx5mLQ5HTgj4/YzKT60h/F/ay50f8f1Es5n
R5P/hSY/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VD89
9AMA2wlLcg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGTJVjC+HQ5Hazcy6aHyj60h/EX166bc5z3pf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAqBk77w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEnyvbNl9LndDC773h1teRDexif/2j1urkCL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwARRhgIg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH/rlS8VDPkdGjZml3AKvbQHsbfwxLWWiD80n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAxuVgCA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHGYMDpcK3pYEKS0EN7GH+LfLqmg9hL+1H5UflR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+cEkDwCF19NH
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEZE9/W2JtyOpwINp53iO+hPYx/dfm2RTySL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAQ2Jf4Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHz3i8/5m3O6XBk3yUFNe6H9jD+0+VaP69Kv7Qf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAo3J20Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGXfZMEIiw5Hd7LX3rQw/7QHsZfld5hMkfupf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcA1vOjoA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEca2SiUqw5Hdbcar72jfmhPYwfo1UaE6/40n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAPXchIQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG2XNcXF9hyOjxZEPkrmeGhPYyf97ysQl7lpf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAn+Pseg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFFGRPf1thzOiTuf+xy5c8Dexhf+t+X/jtqL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAaYPUbQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANErjnmbdzpyOrTnX1jn/vOBPYx/4LHFqmmaL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAtbH8mA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF3VdgapzpzOrzTfW2w7+sDexjf9GzeOV+dl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Awjtfaw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFCzQdOLXTldDgoKnPE/NMDexi/IHgZM5P+S/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AQFXfOw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEeD6tE1rlzOlx2SE/c8u6BPYyfL3w5YLPhS/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AmnheHw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG19qZxuzw5HTR03jCavH5gD+Ov8zy7J9Hkpf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAKBSeKw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGb5r5ffsyb0+GMwtN5254/sIfxgzKD/HjNX9qP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAiG2tbQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHPf6/8eMmX0+HGgmWGNk8e2MP4CutZebZZvoTz
r6HJy6PJj+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9VP
D/0A3PcuIQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEyUSnW9/05HRpuzNt85MEDexg/fUPBn2ibl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AfMqyUA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFBO+RaXwdyOvAKh8oF3H1gD+MLP2NW+2/30n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAY+WGsg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHtYjfPfQ/mdFhsnJl97+YDexj/jrF4/3zHl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ax5JebA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF7SiZLsIRxOswynDwl/9oDexj/Y/YrW1uXl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AgGXw7Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGfLvkmCURwOqTPWDSZ+fIDexif4/xSixtuL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA5v18Uw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHqhhxrZKI4HX5z1SXNOv/AHsZn7YxqLfB8aT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AFlfqnk
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEx/Ye+asRwOoSeUvptfOaBPYwfq8Wsxebz0n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAh5bj0g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANET39bYm8ZxOuTaLwm/cOKBPYxvIdeiM9PvJZyf
hyZviSY/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VD89
9AMAsusEWw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHHvM07HRM4Hfg6tIvyjz6wh/H7ZddM0gx8Cefz
osn3ocmP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1U8P
/QB2O1+g
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF/Vn685JvE6XCQ7buL4KEH9jC+6XyTpO3BL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAsiiZlw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGGHGtkolI4HdZ/jTy1dd8Dexif0/XQAqewl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ad3mQzA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFpYMDpoPNn95+Y3Q/sYfxIt6fBpyNe2o/Kj8qP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyg8meQDBQJMM
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFzjihsKMrgdFA6PuMa244H9jB+/XXJxsDol/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4ABUiabw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEXlW7/rMvidGBfUh+0ecsDexj/Wd8J3auxL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwApj3Uaw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFsjVOdu3M4HZLkhLOTNj6wh/Fbj7vFhyW8tB+V
H5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR9M8gAZDjPS
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHW9/17p+dxOlydzyEtsu6BPYx/ieG61NWkl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AnSVQ/A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEFtlzXFxdwOnQJacSeWPXAHsaPtFmZGpj6Es7v
QZOPQpMf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qp8e
+gE1g6vc
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHLZh9R2FDE6fC21VunfvkDexifIfK2y+n0l/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AkF/m0g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG3f9Zl7SnhdFhxNa7ZYskDexj/f3blXqesl3D+
MjT5f2jyo/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/XT
Qz8A32sgWQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANECEZZbTpRxOjwIio/9suCBPYy/Sbzuyvacl3D+
PTT5jWjyo/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/XT
Qz8A/QKs2g==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFu2z7/vVLB6VCeH71109wH9jC+94NLfVr5L+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAhhxpow==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHVIuvcH1ZxOlRnF7UVz3pgD+Nn1QV8nFX40n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAqc2oKg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEbijImvq3hdChluXLabPoDexj/mP5+Bs6Sl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AWb7O3w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFPLyjd/lnH6XBQ7UDDn8kP7GH8K6zXD5aUvbQf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAp/q64Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFS+ndV2Bo5HQ4vaFtwZMIDexh/upGD5b2Kl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AgGud+w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEBvdPzhJo5HV5eb1Pr731gD+PPCp6c7Vr90n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAsyM6Nw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGtrwN3yLVyOpTX6/PFdD2wh/HldkfGrqp9aT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AFiWSox
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG7PHmYtNs5HQQD/wVptz+wh/FnbucV5m14aT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AGhmFRF
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHvlx/zNu/kdHh5rP7Dn+YH9jB+3U2piblNL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA/fog7A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGqbI1Tnbs5HaZc93t0oeGBPYyfZX7v9umWl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AXyOPKA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFRKdb3/Xs5HSo2i6gsr31gD+Pv2LDsu3r7S/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Ad+OFCQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH9h75qxPRzOmxp7thYX/XAHsaforf1RWPnS/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AoHqhCw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFHFDYUZUzkdJisld8WVf7AHsZvf2yz+Wb3S/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AKrbguA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG/6rL2lEzmdChgnT3PvOSBPYw/pTM5Wr/vpf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAcIffcg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH6d1XYGqdyOrBveP1VrPCBPYz/cp7j06YJL+F8
VjT5F2jyo/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/XT
Qz8AVHlp+Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEp1vf9e6dzOgif9O34kfvAHsY3Xvgo5Mqkl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AoNL52Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEzwYDTIXHHrsA7WQ/sYfwF7q7rlKe+tB+VH5Uf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR9M8gBRHGth
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHnvwc/Xjqb04G9zMLvUPoDexi/b3f014LpL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA1nYRQA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEsYXy6m+ZyOggG36xclfLAHsb/cp5bb8/Ml/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AVLN6+Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGWW06U7ZvP6aBzePeFKYkP7GH8Reb6MaxzXtqP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAPwILQA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF5Qs0HTi3kdNirzuXfGPfAHsa33DW52WfeS/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Aw15k3g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFLCmy5ri/mdHg/+9eH/OgH9jA+f8bv5RMXvLQf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAin9xUA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE3z30PfryU00Hq0LlNCREP7GH8q2dkzl5Z9NJ+
VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+MMkDAOCSGiA=

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF8upvmvl/O6cA86fKE4NAH9jC+u+Lib6JLX9qP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAHyKBdA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHO3TnPf6/kdEjXSGz3CHpgD+OvrtbTCF3+0n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAjQfH2g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGVL9UMOdZwOhROvzXJ3v+BPYwf9j84ddLKl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ac247aQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHr3B9WiazjdHDesXa9hc8DexhfgXvexrOrX9qP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAK5K0BQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGPl84+orCB06H8b9AtY88H9jD+y7QeAfZ1L+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA5p5sYA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANESLGF8ups4HSa6+fIbuj2wh/FlCqa02m14aT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AGl4sjQ
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF+SQIRlls4HXK2aHobOD+wh/E9XBVFSja9tB+V
H5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR9M8gDaPF62
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHNB04tdN3G6TCjrr7L0OGBPYx/+MPk/cu3vLQf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAFBkP5Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE75FpfB+7gdKg++f6kie0Dexi/bpJz981tL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAccuZ/Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFva+xN43ZxOlTWqrJZWT2wh/GfddRWce58aT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AHmT/Ch
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHKt3/WZe3hdLgrd9Xa0fyBPYz/dUbrBPPdL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA68WALQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANERlltOlO3jdFi+bE+6l8kDexg/S3TaheS9L+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAYowBrg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG90/OEmg9wOjDELG4LNXxgD+O7sD6w7dv/0n5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAbdrhzQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGHvmrE9B/idNi8LnJqkt4Dexg/yrP79raDL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAAoyZFg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE/gh8vnX2E08FCaOeEQu0H9jC+28Fta+4efmk/
Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/mOQBDC1EyQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANOb5r5ffozTYfbNxaVNGg/sYfy6/IotTMde2o/K
j8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyg8meQDmgsiZ
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFJAhGWW05wOnCJsDpOVX1gD+MfnXP3q+qJl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AcFOxmA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHT84SaD5zidNDMuvB+pdIDexj/5q9Xxe6nXsL5
6mjyN9DkR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+qn
h34A8yOzlQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFnz4AApwPHH8b6A/IP7GH84mNzDNPPvLQflR+V
H5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAt5GbIA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFM2u1iN89xOtyxn/f6hswDexh/7otnhq3nXtqP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAGlH6cQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHmnY4JTy9wOrg+3Gj0WfKBPYwfLb61fOGFl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AEc7r7Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE5z3+v/HiJ08F3YWAgv/gDexh/y9dXrHsuvYTz
vdHkN6PJj+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9VP
D/0Aa7ytbw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGLXLd9/nuF04HJfJaLrsgDexhfyDjl/pUrL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAPkB+Bg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHXFxfYcl3ndNhgsIHTV/CBPYwvsOoL25trL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA2cRvHw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE8TNrtYjc5HVZc3T83j++BPYy/rC6jnvHmS/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8ADTBS5w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGOCU8vKN3mdFjF8ffvRO4H9jD+UesWb9HbL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA/eAi6g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHl++ZL6d/ldHiktVh9O8cDexg/+gNLnvrdl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ah11RzQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFrZKJSrO9zOqT//yJ+j/WBPYx/znvBS/P7L+H8
VDT5s2jyo/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/XT
Qz8AoX3ofQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEPq0TWuT/kdPDqtznDxvzAHsZ/uZPloNvDl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AIle9PQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFiN899D37M6WDLd9rRkOGBPYzvXHfzW/Djl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AzUFmTw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE+5p2OCU85HVzrP77e9eu+PYyvcH5fb/zTl3C+
DZq8HJr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8A0y9KKw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGNU527c55zOmTt8Dwj9vW+PYx/7L1vR+bzl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AxGijrw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHbPv+9UvGS08HrQ5Z82fv79jB+oZfky8KXL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAmysQCQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGvA3fItb7mdCi+rPfgxsv79jD+ws41mypev4Tz
K9DkF6HJj+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9VP
D/0AKHaEGg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGKG4oyJr7ldFibUMNp/+S+PYwvubHnee3bl3D+
KjR5CTT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8A8FchAA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFhfLqb5r7ndNDa4T5txb379jC+rZlFV+P7l/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AYjl2Dw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHdOc9/r/zI6VDwemKj6M379jC+joT63OaPL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwArkxY9Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEHTi103faZ08H/XMax1sv37WF86++nlFo+v7Qf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAOKW+QQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHfNGL6D33ldMg98Sz+59n79jC+uk6/bPPXl/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4ACCUKow==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHa7WI3z33ndFBbYeRZcOK+PYy//d6N/obvL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAv8fCwQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEJTy8o3f7J6bC4tL721aH79jC+rAx7Tc3Pl3D+
fDR5GTT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AOy3syA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFTnbtznv/mdDB25/mRvve+PYx/5k3Rk7LfL+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA8So1fg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGnF7pu+/yX0yFCTGXLi+337WH8v5n5p/P/voTz
Y9Dk/6HJj+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9VP
D/0AymTeRg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEQwOXQNlV2bc6m+/Yw/vFLnsbp/1/aj8qPyo/K
j8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDyZ5AHMHgCI=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGmcbs8eZi4HLrYou99XnPfHsZ/sMBTLpbxlf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAcTv0ig==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFZe0omS7BwOfwQ9HKuW37fHs6fs6EvkPkVnP8Z
Tf47mvyo/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/fTQ
DwCZTdKj
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANELpPTvqrBxOfycl3yde9F9exh/z6ddbS6sr+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA1MPouw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFXK16qGXJwOTiu0Z42Z859exi/zGU+hxn7K/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8A7Xdhbg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFc1xcX2HJxOehqGlYbTL9vD+Mn7esTU+N8ZT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AFCToFA
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH2pnG7PHm4HD6d5206PvG+PYy/WHPrJhHuV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AAMRpsA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANElkyVYwvi4HMIY0pYl9ty3h/Gf/LO4z8j7yn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAgR2eXg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGrPl7yTRLgcvg968Xjf2337WH81RXW897yvYLz
mWajyq9Fkx/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+q
nx76AXnnwf0=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH3/Xun5wlxOUy662c2v/G+PYwfvPTGx+sCr+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAeoH1nQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEi69wfVolwOdjbx8x0qrlvD+PvrFC/c0Dolf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcABOWngg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFePEza7WJcDu9873G8LLtvD+OvumsZv0Lklf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAPwu/Yg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH1WXtKJktwOXj0rGmYVHjfHsZ/dEymtk/sFZzv
gyb/GE1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcA6ttq7A==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFbTpTtmy/F5fDYf8Ufu5z79jD+O/sb5sUSr+D8
52jy79HkR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+qn
h34Aw7JlIw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEv1Qw51shwOcQu2FPxLu2+PYw/vzZ/YpjUK/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8A/uOuSg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFyra8Dd8hxOXwTu/dhQeJ9exjf4d2DbguZV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ahorb6g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEhj5fOPqLA5VC2jysxLOa+PYw/21NNU1Lulf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAb2rT4Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGdjglPLyhxOfB/8TzKF37fHsaftMAk+4f8Kzhf
BE1+Mpr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8ALjthhw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH75kvp31XhcnD1WCN5KvC+PYy/MOdP8DXFV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AOhsvVg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFf/l6peKnG5XAgwTuqw+e+PYz/dV7m003Kr+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA5E1yaw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGaMf2HvmpwOaTc8mz2dL9vD+Mnrk9W7FN9ZT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AHumwY1
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFxuzx5mLS5HHh0Lk/gdbpvD+OzrD7LmaH+yn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAV3PqsQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGTJVjC+HS5HKZ2StdfsblvD+PvcGpb4KD5yn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAXCJIbg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEnyvbNl9Lncph/PN5rnvl9exjf9mb6c3HtV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A5ehX4g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH/rlS8VDPkcii1f/ouy+i+PYxvPtHjwVudV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AHVJ6Sg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHGYMDlcGPzzwwr3fv2MP61qF89h/Rewfl30eSv
o8mP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1U8P/QAL
9jLE
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEZE9/W2JtyOWwz/byFR+O+PYxfyOj9fqrBKzh/
E5p8AZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8A/q4VNQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHz3i8/5m3O5bCB0+D8Q6X79jD+dgsWzgyjV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A3e9TCw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGXfZMEIiy5HKT7xLbslL1vD+OfWfn6toXJK/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AAJuwDw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEca2SiUqy5HNgURROmSNy3h/E1GA5ncpi9sh+V
H5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR9M8gCDTHY6
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG2XNcXF9hyOQizLzpfKHzfHsY3/+a+5Zr5Kzhf
DE3eAk1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcAZ1ykaA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFFGRPf1thzOdQEWf8P5LtvD+NfSzTZu9jylf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcABEN8fg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANErjnmbdzpyOUw6lfbahPO+PYzf7WDXlm/9yn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAY6PqHQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF3VdgapzpzOSy9vHGCFMt9exh/5mFxQSvbV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4ADFBQwg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFCzQdOLXTlcjAO3/ia6f89exj/QXR+PLP9Kzjf
Bk3+EZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8Ac+BzhA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEeD6tE1rlzOUxfw/jz7c979jD+xKPvi047vLIf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAKVl4Ew==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG19qZxuzy5HL42um29/eWePYw/X9jBd5LTK/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Aulkiww==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGb5r5ffsyby+HwUS3ZM+/v2cP40ruZP4S7vLIf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIA68jUwg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHPf6/8eMmXy0FjQoLu/lf37GH8pHm3YmTcXtmP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkArNpZRg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEyUSnW9/25HOJ5Fz7a8vSePYzPJJE49b77Kzg/
E02eBU1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcA4a28jw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFBO+RaXwdyObxLX2O59sE9exh/LqvB7IWer+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAifO0xw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHtYjfPfQ/mckja7Km/4vY9exi/5NKd/CTvV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AkAiSQA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF7SiZLsIRxOcRfdzuw9No9exj/e+NPESXfV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Am8AzsQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGfLvkmCURwOfyuqni59OI9exifY5dIzwO/V3D+
fzR5TjT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AbXYVsA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHqhhxrZKK4HGo+7Fy+4sw9exhf/ezOa3MDXsH5
DWjyGmjyo/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/XT
Qz8A00r8GQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEx/Ye+asRwObgpvv2+9vg9exi/4EjBt8igV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4At62DSw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANET39bYm8ZxOchX/bq29dA9exi/NHPfG5GQV3C+
Cpp8GZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8Aymn81Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHHvM07HRO4HB5fv+B4YO89exj/m7/K7nOhr+D8
52jy39HkR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+qn
h34AU0oDGQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF/Vn685JvE5WBdkmp6dsc9exg/975Ccnv4K/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Az9O3cQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGGHGtkolK4HL5d2rzuzuZ79jB+QYz+M7vIV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AlMj30w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFpYMDlkLh+76p36+7Zw/jMn467fo16BedHo8kz
oMlnoskzocmPmj9q/qj5o+aPmj9q/qj5o+aPmj9q/qj5o+aPmj9q/qj5o+aP
mj9qPjXMBwBvJta8
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFzjihsKMrgcmB71aXGvOqePYy/fld886qYV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AuP6PGg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEXlW7/rMviclhfpikvtfSePYzfczJjQVzcK/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8A97Mc4w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFsjVOdu3O4HKZ5rZ1ovOCePYwvZRw0TzDhlf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcADJcmoQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHW9/17p+dxOQh6G1T7z75nD+P/EO2oO5z4yn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAESA39w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEFtlzXFxdwOTjYXLqRO+2ePYzfurjYqST5lf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcA1Qo5aw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHLZh9R2FDE5SC0Ycfyvon37GH8GI3q18qpr+B8
PjT5aDT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AJAbiBw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG3f9Zl7Snhcuj9yvd0Y889exh/jQhT9aW0V3B+
J5r8ajT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AQzHpFw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANECEZZbTpRxOVRysPVdb79nD+OXsGR+qs94Bedn
o8kXosmP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1U8P
/QCh07wV
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFu2z7/vVLB5XCx4cr8/0337GH8xcd5g3WyXtmP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAwWCOYA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHVIuvcH1ZxOZg2bxPXqrtnD+NLZHnPu579yn5U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAFV/phA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEbijImvq3hcti54e2nsMp79jB+o3XV1cbcV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Anc75MQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFPLyjd/lnH5TBX/KBeW8k9exhf8fr7n1r5r+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA9J8nSw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFS+ndV2Bq5HM4p157Ynn/PHsav1f7Pc7nglf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAgo2JjQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEBvdPzhJq5HD71F+99nXXPHsZ/0viDv6roFZz/
Ak3+EZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8Ai2Pm+A==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGtrwN3yLVyOYSF/eZSSrtnD+Pfa9VkUSh5ZT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AEPaegL
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG7PHmYtNu5HBoXFayLSrxnD+P3+Nx9daT0lf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcATgfE4w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHvlx/zNu/kcqg6ZLJ0asw9exj/VnTM0YzyV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AyfRZOQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGqbI1Tnbu5HGZIrHtzKfyePYy/YuObKdyVr+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAYAgcbQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFRKdb3/Xu5HCbxejQJBd+zh/FPnLoYtbbqlf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAh8E1NQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH9h75qxPRzOaQxFSeH+N2zh/F/r/SR8Kt5ZT8q
Pyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj+Y5AHVk2FI
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFHFDYUZUzkcrjttKR3huc9exh/573Z597WvoLz
76PJ70KTH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6qf
HvoBn5OtpQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG/6rL2lEzmcnj+PfTfPZd79jD+3+7fdT31r+xH
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwANibkkw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH6d1XYGqdyOWRLsW9Wd7hnD+PfyluqpdX4Cs4v
QZO/gyY/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VD89
9AMANU/8hA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEp1vf9e6dzOaimWa8ssr5nD+PLPr1w6VjTKzhf
EU1eBk1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcA1pGuKQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEzwYDLYYFP9b39ZvfsYfx1nzdVJLW8gvPnoMmv
RZMf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qp8e+gFb
5vZZ
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHnvwc/Xjqby6HmRXAAv9E9exif3bdO9m/rK/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AtpBwwA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEsYXy6m+ZyOXz/EPYnQfeePYyfG558aFr7K/tR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8ANEbnyg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGWW06U7ZvP5RC+VurBFo179jC+nvGEDP3OV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AYkC66w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF5Qs0HTi3kctj8wvInl8o9exh/9wEDweNdr+D8
g2jy+9DkR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+qn
h34AL7H9Mw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFLCmy5ri/mcuB/FuyaLH/PHsbftixvb2zPKzhf
Ek1+B5r8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8ACf9B5Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE3z30PfryUy8EyhOfQXql79jD+g/DCvM+9r+B8
dTT5O2jyo/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/XT
Qz8AqDJQyg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF8upvmvl/O5fDOkTtXSuyePYz/XSJOtaP/lf2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAhFEA7g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHO3TnPf6/kctgj9Ne5UvCePYw/iS3isfTEV/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AfkkcOQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGVL9UMOdZwOZyQali5btIrexift3iSyy2ee/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AO/3KAg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHr3B9Wiazjcrhu9LXCYcorexhfx7chx5bjnv2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcABfg17w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGPl84+orCBy2G/yJWgi1Nf2cP4H/bW71zEfA/O
34Mm/xdNflT/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6h+
eugHAL60IJ8=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANESLGF8upu4HNaVmFskTn9lD+Mzcvlpcv2/C+dv
QpN/z4kqP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1Q/
PfQDAEz1+E8=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF+SQIRllu4HDp/mWt9mPHKHsZvn7RmZ/Gvu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AAtZfNA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHNB04tdN3G5aDo/kazbtYrexif93RCxv2vd+F8
BTR5QTT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AqbKJbQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE75FpfB+7gcpjwM8OCe84rexh/tp6Jse/Hu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4ALFun9A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFva+xN43ZxORRvORA2fe4rexhf1/SL+N43d+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA4Uj/iQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHKt3/WZe3hcvirxNKmNP+VPYy/3bNIRP/FXTj/
N5r8QTT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AC+fjCA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANERlltOlO3jchD+53h8zYJX9jD+zf3Naosf37Uf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAFPC5lg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG90/OEmg9wOQQKtkubLXplD+MfO8noI3n/rv2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAKdDZdQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGHvmrE9B/icvhmf6953+JX9jB+Vd7Jpom37tqP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkAjglP7A==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE/gh8vnX2Ey+FoZwCj29JX9jD+3/rdJ7iv3YXz
T6LJv0aTH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6qf
HvoBCixeYQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANOb5r5ffozL4Rb/0ylnlr2yh/HnTtwj3XHxLpx/
D02+G01+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcAHSNrCQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFJAhGWW05wOWRKLrQPWvHKHsZvfbelku3sXTg/
C02+AU1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcAcsUGug==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHT84SaD5zicsiU6GC6vvKVPYyfM2HCg7YTd+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAulMPSQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFnz4AAl4PLutn3ola/sofxhcXs/TiP3IXzHdDk
1dDkR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+qnh34A
HFA9lw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFM2u1iN89xOYRvuH3l7ppX9jB+8a7NB3r337Uf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAIuFbSg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHmnY4JTy9wOUzQcXsWv+6VPYxv4/3UVGT3XftR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AXC177g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE5z3+v/HiJy+FM7nXhh+tf2cP4EQrnVs/ZdhfO
P4kmn4omP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1Q/
PfQDABF8WJE=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGLXLd9/nuFy8GJoSsuceMrexifVThHQX3TXftR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8A+uQFqw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHXFxfYcl3ncni5Nez4g02v7GH8JyUHJm5eexfO
f4Em/xJNflT/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6h+
eugHACxpJ1A=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE8TNrtYje5HLatMvGP3/LKHsZfwn7hr+PKu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Ax+NkJw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGOCU8vKN3mcrjvIfn9ztZX9jB+2pdFSZeW3LUf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIARNUQ0g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHl++ZL6d/lcmD3/bE/cvsrexg/57DLvpQFd+F8
TjT5ZDT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8ArLbizQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFrZKJSrO9zOaSdOrzq6o5X9jD+zuAjfD9n37Uf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAsf4+rg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEPq0TWuT/kcrigl7MjYNcrexhf67JxUP/0u3D+
FTR5cTT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AmSHwDQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFiN899D37M5XDT7cHLU7tf2cP4d7euaFOffNd+
VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+MMkDAK2b7vQ=

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE+5p2OCU+5HFY78jq47H1lD+O/W2e96mDfXTh/
LZr8EzT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AYKc+VQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGNU527c55zOYhtvbd7z75X9jD+p+Ucu2O77tqP
yo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8oPJnkA4sqn2w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHbPv+9UvGSyyFuoV2cyYFX9jD+3J1623+33oXz
49HkZ6LJj+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9VP
D/0AYGIVow==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGvA3fItb7mcpAuFdVYffCVPYx/X/nCnNmNd+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwA6hIxUQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGKG4oyJr7lcmAU9JJSPPzKHsaPchPKsq29C+cz
o8kHoMmP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1U8P
/QBw80M1
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFhfLqb5r7ncph7+qDptCOv7GH8pzNkZR9W3LUf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIAEwf5OA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHdOc9/r/zI5cBamlDNdeyVPYzvuER2S1vJXTif
DU3eFk1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcAnK3ARQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEHTi103faZy6EziuNN7fFX9jB+9y8HXb2Cu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AI1XVrg==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHfNGL6D33lcnD3mtXx4cQrexjf2GBn2/Xsu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4APYrNcQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHa7WI3z33nctg17Wtg0qlX9jD+zSu79jWl34Xz
96HJH0OTH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6qf
HvoB/MFBNg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEJTy8o3f7J5eAn9cPj8ulX9jA+e07tZf3ku3C+
D5q8AJr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8Av7e+EA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFTnbtznv/mcjhkVZfnfPaVPYy/Ks368L24u/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4A+WmzvQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGnF7pu+/yXy2Hbm6TDm869sofxl0kb9fRH3bUf
lR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfTPIA/E+4Jw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEQwO3wc1u9h+KFV/YwfvnBhTpOYXfh/B9o8tVo
8qP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf100M/ADdB
Oo0=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGmcbs8eZi4HT5vXfOv7+IrexjfPP3som+Bd+1H
5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+UHkzwAditVjQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFZe0omS7BwO3yad+DZ70uv7GF84Xe/3qzxvQvn
f0CTl0aTH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6qf
HvoBwsmbxQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANELpPTvqrBxO+QensCYceWVPYx/jKmYM9Xzrv2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcAMMbeMw==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFXK16qGXJwO3iIfPS/fPWVPYzPLN74Tc71rv2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcACEPLUA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFc1xcX2HJxO3Cobrlke/2VPYzPH1286ZbDXftR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8AkjWB0Q==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH2pnG7PHm4Hb7rre5afuOVPYzfsH2W9Qybu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AH6XZ1w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANElkyVYwvi4HTxFllUI3HplD+O/P+Y1Idzirv2o
/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPxgkgcA/v243g==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGrPl7yTRLgdjBPLp5bcfuVPYy//vzNdRImd+F8
YzT5Q2jyo/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/XT
Qz8AfT8j+w==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH3/Xun5wlxO/yPePDz/p1X9jD+570Lpt7Wvwvn
/0aTZ9uHKj+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U
Pz30AwCZZO9q
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEi69wfVolwO/x6sqPP7d4rexi/TPa30wLtu3D+
TzT5GjT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AsEyl8w==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFePEza7WLcDtNWH49Zc/+VPYzfJ+y+NU39Lpw/
EU1+KZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8AAsWedw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH1WXtKJktwO5hyXksRfPjKHsafHvn0lZ7yXTjf
GE1+AZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8AP3QqgQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFbTpTtmy/F7WAuumZ56aNX9jD+dDPLRz/k7sL5
pmjy89HkR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+qn
h34AXUE0Tg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEv1Qw51shwOxxZIqB28/Erexj/QeWKmUek7sL5
h9DkX6HJj+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9VP
D/0AgfYhqA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFyra8Dd8hxO6zxPfnA+ukrexjfrXQ2/ySxu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4Al4JJ9w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEhj5fOPqLA7eCcOevG3Gev7GF8u+81TolCdxF8
NPkwNPlR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+umh
HwCo5TN0
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGdjglPLyhxOwiKu/P9f/7KHsY/4brLwIjvLpzP
jyZ/EU1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcA+57u5A==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH75kvp31XhdthoP7Ep/uUrexg/UuLwDRauu/aj
8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/Kj8qPyo/KDSR4AlWz63w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFf/l6peKnG7VA93dJs/6tX9jD+tkmcljdZ78L5
5WjyJ9HkR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+qn
h34ATM0Irw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGaMf2HvmpwO6gt/K8p9+aVPYx/xp4pYD3jXThf
C01+F5r8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8AgmoYNA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFxuzx5mLS5HWZuWBhX8/aVPYy/lltFpv3vHTh/
Dpr8fDT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8AJtMwXQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGTJVjC+HS5HZLe3rly890rexif0/7F7ISfd+D8
dDT5z3ao8qP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
00M/AOncFWA=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEnyvbNl9LndsgLze01+/DKHsYvqzx11vrrHftR
+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UfnBJA8Ap9v2IQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH/rlS8VDPkdmjbz9s56eMrexh/2RqPDRIf78D5
HWjyc9Hk29HkF6LJd6LJz0CTH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0ft
H7V/1P5R+0ftH7V/1H5i7AcAQc/EtQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHGYMDt8PZu+Ym3n17Zw/i/xR47fn9zB85/hyb/
HU1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH566AcA
VmthVQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEZE9/W2JtyO1x3SPHx+PLKHsbfayfTeP3FHTj/
Npr8ajT5Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/rp
oR8Afoe8xw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHz3i8/5m3O7fAhokt00ddX9jD+mzcVOTuf3IHz
v6DJ30KT/4gm/wJN/jOa/H00+VH7R+0ftX/U/lH7R+0ftX/U/lH7R+0ftX/U
/lH7R+0ftX/U/lH7R+0nxn4A+P1f8g==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGXfZMEIiy5HY5XLlD5/e2VPYzfptHANPfBHTj/
FJp8OZr8qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf30
0A8A2xQWCA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEca2SiUqy5HZzuRFcF/3hlD+P3Ge52bLpzB853
Q5OvRpMf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qp8e
+gEVHX6d
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG2XNcXF9hyO/AuLBBf/fOVPYyvULNVI/PGHTif
D01eCk1+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcAfMfQTw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFFGRPf1thzOzy/NPEP4+9X9jA+25o/WwOv3IHz
P6DJ316NKj+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U
Pz30AwA88yJW
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANErjnmbdzpyOyhmFmpF/HllD+NH9yu8sL5wx35U
flR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH5UflR+VH4wyQMAM08Z0w==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF3VdgapzpzO+zxPLBw7d9X9jD+DanNe9XP3IHz
D6HJ70aTH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6qf
HvoBfgfM5Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFCzQdOLXTldvjgrZfM9P+VPYxvkOJhKnriDpz/
HU2eH01+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qH56
6AcAxJ39Fw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEeD6tE1rlzO3hbZeWHMby2h/Ft5pX5shy5A+cH
o8mLocn7oskbockHoclLjeof1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9VPhn4Ai1syaA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG19qZxuzy5Hf5fUTy+kvG1PYxvInKN5ev+O3A+
/1VU+RfCqPJMaPKqaPp50eQ/j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o
/lH9o/pH9Y/qH9VPhn4AaDC3SQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGb5r5ffsyb20HhCmP2H6bX9jC+gSpj1PPdd+B8
azT5jSqo8mpo8sJo+k3R5M+i6ddGk/+DJm+EJn8bTV4HTf47mrwBmvxTNHl9
NPlXaPJ6aPLvRs0fNX/U/FHzR80fNX/U/FHzR80fNX/U/FHzR80fNX/U/FHz
R80fEPMB+luNEg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHPf6/8eMmX2+HIy63Rfiyv7WF8cYcp3re334Hz
uV+hyp+yQ5W/hKb/mj2qPCOa/p9o+m+j6V+Dpv8XmrwUmvwDNPkpaPLf0OR1
0eSfosnXoMl/RJN3RpN/hiZfMap/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j
+kf1j+of1T+qnyb6AdWvyME=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztyy0PQWEAhuGXTSGqih9wuhGcpthsGtEIkm5+AVE6go9ogkATTjkzkzQ2
x0djEzTZBLb3/ge2Jz17du9K11rlRtQY40SM+WyqWs9dSgm3GNy9UeyR//7N
2TnsFuHvP9G3R7s30V34PXo2tHsH/Xay+xq9C99DH8Ov0H34Pnobfol+hR+g
V+Dn6C/4IXoBfoYeR5+gZ9Cn6El5eXl5eXl5eXl5eXl5eXn5P/VvK2qKYQ==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzty7+LwXEcx/EPg4WBxU33LSmJUG4xCMO3zCirUgwGMju/ru6f0OUWu++g
fHfFYtfVZXTDdzm7kIH6PP8Cw3t69erZI1TvlBtupVTCpdRty7bx6ZS8hZrf
jPx7nPz9Tz7a58389/F3Ab1bPb1P4btjvc/gv9/1voG3Rnofw5t9vR/gDfgm
/Ar+BL8c6r0C/zrQuw+9BV9Er8IH0bPwOfQRvIH+Ap9B/4IPo1/Q39AX6BH0
I3oa3UaPov+hp9DX6DH0PXoSfYseR/8RL168ePHixYsXL168ePHixT+tvwIK
C4RB
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0zFLgmEUhuHXBlGkBoegRXBq8gfkUG7tCa2B4CANSUtDKU6Kzg5BghqW
1kfgIE0OLoWD6FBigkWC0JCLDRrRIA4F597dznR4uLjH4w0d7YVXjDE+mzGL
m1rvt2dBV8B1GrUFHJ87f3uj+l1vWIP/fRCXfliQnkWfvZM+jklPX0qfon+w
pF+gt5ekb51Jz9xKD6F3X0mPoK/cSPej76DPoF9F70EfvJZeRJ+vSHeiv0df
Q7+L/gf+i74BX0M/gW+WpT/Cv+Bj+Da8Be/CP+D78A68CR/Bw/AneA0+hB/D
n+FV+Dv8BN6FW/A3eALegxfhr/Ak/AWegw/4X/A+/Fx77bXXXnvttddee+21
11577ZfYzwF1EJgA
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzty78rxHEcx/HPyUAmSlEiZgabDH78BzJ8/wC6FOVuuNFsMUhnVsqPI0TO
ue99dWXhUid1ONyhKKW7hcFgkAzU67nb3tOrV4+enWOR0XCNc64n5NzPHsXi
LbVew9DqfnP3fH1l8Pe/V6JNwXr577cH6umceiGpPv6i3pFRn8yrbx6oTz+p
T/nqwYX6cEp97VG9mlZvLKhvo0/cqy+gz16qf6IfKKuPoH+7Uu89VO8vqXeh
P7tW99DP3amH0IeL6jH0X7fqr/Ai+ln4BvoSvPVGfRE+gf4c7qFfgvehP4HP
oF+Bt6E/hsfRJ+B16LPwZfRb8A94Bp6E78CrcB/uw3fhz/AU/BS+B3+w3nrr
rbfeeuutt95666233vp/7L8BTbKm1w==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0r9LggEQh/HXJqmlyaGW2oJodswaQoQGm5witAgMKcnsh6ghgli9ZQZC
VJPQUoM4RATRFrQ2Ws0FQkWNEUVDwff5F7rpOD48011/dH5ipsNxnCGP4/zM
t9vxaHekK5BPtI4fOtvDv7t7nv08q9//7b6cejCu7l1Qr52qv2bU4yn1u6T6
R109tqZ+kVEfXFS/OVIPrqq/r6v3pNRj++rZFfVGUf0avb+m3l5Wnyqpjy6p
P++pF9CHy+oH6ENVdT/65oZ6C33frroHfWMT90/jPyq4L3x6S30A3thRv4I/
oQ/AA+hP4GOuehj+sq1+CHfRT8Kb6KvwS/Sz8BL6MvwRfQI+h74I/0KfhEfQ
F+BeeAoegufhPngaPgLPwXutt95666233nrrrbfeeuut/9f9N9IKJb4=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzty88rg3EAx/Evi1ZWjoglUWKeIjIPsvUcXBwwLoQQao8028yPDEvk6uDH
wWHXRyFlSlwkIyRxccBBLrK0lANJ5EB9Pv+B+p4+fXr1zun2uHoThRBKghA/
m19iXstqTXFau3p8NkvM8fufF4+DkfDt3w/Mojc/HYGH+tAng9jfhdCTBHq/
jv7lRp+bQI+momsD6Ett6NZxdFsmer0H/dGF3jGGrueinw+i39Shp42iewvQ
H7zoe7XohSPolwr6hg/9U0OfGkZ/K0Z3+NEbnOgm6rVSdIP6zhr01QB6rAz9
lfr3anQ39Rnl6EVD6C9V6Cr1H9Q3Ua9Sn079sh3dQ32kEl1Qb65An6G+kfo4
eQv1C+TJ1N+Tr1AfJr9S0a/JT6k3yA3qL8jj1K+Tz1N/Rm4i3ySfJj8ht5Bv
kfvJo+TZ5NvkOvkheR75Dnk7+QG5Qr5L7iLfJ7fLXvayl73sZS972cte9rKX
/T/vvwHIt5k1
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0M8rw3Ecx/Gv1S6+SY5zIFaimMMSw2y0lCwkmRhJJk2L5se2LCK7+LEZ
x8VpKVfi4CLkRiEHiTRC2kXW2hY1OVCv11/g8Dm9e/foeXi/CwZG220KSZLK
MiTpZ1oDx/Fiq2z0mbsC7qyo4Xd/Vqb8u6G7v70qhC6vJcAvLei+iyT4UhD9
5BD73H70vm3snYvozRHsNUPoW8vY633orynsw3b0dRf2I3PoMRn9zYGeP4y+
OYOuUaG3jaGfWtGDXvSHQvQcJ7q3Az17Gj1dgt4zjm5rQY970LXl6OYJ9I8m
9CLqlVr0NPXhRvQVN/pNBfr8JLrOhJ5H/UsleoR6TwP6uQt9UEf3TdF/6tFX
qV+oRu+mXm9Et1HfWoM+S73fgG6iPkp9iPpM6kup761F36F+ow5dRf0+9UfU
d1IvU5+k/ox6NfUK6tV69Gvqv8g/yU3kt+QR8gS5hfye/Io8Rm4nfyQ/IH8n
d5M/ke+JXvSiF73oRS960Yte9KIX/T/vvwH/uxun
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0s9L03Ecx/GvSw9iGORBCBSURDICmRi7zKlt9mNb/mKBkyzMEsQfTAol
podCKIKgCGY7BB2i8OJF6KAVwRCcF8FfUCOhVZTL8gfJIEnxUPB8/QNdPqcP
bx484Q3vT1F7X9NVm2VZJzIsa/99sBZ2VbblVNs2W/7EclOuv/P1yGv7RCTx
bz4YDcJXwpPwpmy64xj79Ah97j37J0fovcuv4IcH6LXFU/D+Unosyj6rm377
Avvtcvp0D/uFK3TXEPtMB73Lx/7tRXr6MftqJ32sgn1VC90/zv5oDd1dxP5z
gF78hn2Wm/4ij31XMz0RZ19aR3+Yzf5RI/3ePPup0/R8G/uTDXTbO/arZ+i3
dugV9fT4B/rMWXpHWv7XeXrrR3rfOXrzL3rST9/9JPtLn7tFvyn9+he6x0u/
vEE/Lv21r/S70heu0zd89MFv9Enp7T/p09KfWqWvSH/nB/259EvS/5b+gPT3
pfem6IfEn63Rh8VHpS8Qb5c+JL4ofZl4ifSd4pnf6XbxXfFL4mXiDvGkeFC8
VtwpPiseEA+K14i/FG8U7xb36P3EG8RD4nXiT8XrxW+Y3vSmN73pTW9605ve
9Kb/7/0ezqG+Vg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0s9L03Ecx/GvokK5YKAkdggVCyFHBwkNAycDK6uLqAcPIWrSSSFRGGVr
atEMIRkJguFBQfDiQU0Q1Lls4o/MSgxyHRIUUoiSTG0m0sHg+foX/Jw+vHnw
5A1vPqkVtUV3oi3LckRZ1r83dCPbl18e7wwk2AJ2+2be0Xw+arr6lT/8f7bq
T8F97gDc7mLvSg3BY2+yr8+dhLdVsy92v4Ffd7Bfm2ef6WVfFpmCXznN/s/l
IDztBfv1LvZbMeznnrE/08veXso+skNPn2FfOiD7U9g7v9Mv7rAPjtBte6/h
2+v0wWR6wjg9Y4Xe+JXuz6IvBuljU/TKL/T9AvrtEH1jkH7rM72jhH5yhl7Q
Rz/4RG8up5+Yoy+9pLuW5X536b55+mgH/fcSPVxD739Lr2ynRz7SPXX0pgV6
VRvdKf2vBvq5d/SKVvrQB3qrm94tfcpTeqH0nvv0PekbntD339N/PqDnLdIv
PKaPS5/0kF4n/aUWul/6Vek7pfc20+9J7/HQh6X/20Qvk/6H9LPSd0p/VfrC
R/QV6a9JnyN9u/TfpI+TPlP6Wem3pA975X9Kvyn9rvQT0p+V3iZ+IH2PeLL0
6eLR4s/Fk8Qd4rHiXvFE8VzxOPFG05ve9KY3velNb3rTm/4Y9IetMax6
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0ttL02Ecx/GfrmCRLGcqZQedlbGLRXbQiEJlWFCu0ooIL1qD3axAAoUi
JYmIDpouOkA3ESElSHSy6SzTIuoiUqTQYl5kRbFZbraIyCC6KHh/rvoDflcP
D29e8PB8vw5fTZU/1TAMV4ph/Dmn2hNDHt/M0vWB9FfV9ljJ37ux47Ez3BL5
d3/rno1+82UneuAZ/bQL/eijiQz07N0h9JFZdvR+dx/6tTv0t450oVs30C9y
P0SvPUZftKcbPb+GvrGxF73dSx+yhtG3nqGPjD9AP1pOX3GSPtlG/66ePrqc
fihK/z5EP7mUvsJB/3RVD3rDE/rmj/fR67LoX++nfzFAf/se/cE0+sBF+ivD
9G1B+uvT6TtC9K2j9E119A0GfcEgvX2MvshL3zLF/mhM/u8Du2Ub/fkf7G/i
9Fmf2MNu+qrv7MGf9LYou28t/aVv7Hct7M0xds9K9i1J9pEZ7DfG2ZMu9sqv
7Mdt7Kc+y/472YOT7JkZ7IVf2J8XsKeI782U94uvX8x+LiHzz2a3TbB35rOX
id88h32neL+D3SL+wFyZn/jqPPbBuOxHDnuX+NZc9g7xafPYh8X/Wsh+VvwJ
8RPiT4s/LD4pPlX6CvH7pJfOZ0+XHl/A7pVeKz5Hep/4XdIvi8+TflV8pfQe
8UukN4n3SB8Q75R+SPwm6RHxLul+8Rulx8Qvk75XfLnOX3yh9O3iy6Rbpa/W
/ZBeIt0uvVh6sfR10nOlr9H9Nb3pTW9605ve9KY3/X/53/VdkiA=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0stL1FEYh/EZwdQsS7MgKMKghIkIKyMZsgwiKIm8ZqOmU2PhpqDLIrUo
aTYqTOhYEYm3vJVjJjWUWl7S0kJKTBdpReFCqYQu1NAFokXB8/0DWv1Wh8OH
hwPveyL2H0nM8TOZTKvNJtOfMyqweYnNEbzlZWlAbH3Yu81/76NJh/K6iif+
3TtT58JzzfHw6B2B8JmZA3CLdw7c/n0XfGSMvTPZDve3sv8VlwD3bA2CO1Ky
4OcnguG15iS4o1z6oUz4Mjf7z2nJ8NHn7DuqMuCuDPbbslPgZ/xnwxe2p8M/
RrHfZEnl/Czs1waxjwtlH9nP/uh29q6zNvgaH/2bdQ/8YCbduZj910l66EX2
sYfpNwf3wjeMyfsT7CPz6YUl7Kce04vC0uAhTro7k721l95oZd9QQi+LYV/W
QV+Xzj6vlO5byv6kl24/xv7LBXpPIHtXG33Gyd5+Wfbno7tu0Fe46X4V9Pnv
6XEe2X8lPaCSfvotveA6/XgDvayKbhmnR1yjv/HQ+6rp50bpi5roI2305hr6
xmH6zkb5X156Vi19aoje0kA/dZc+Lb3tCT1a+vYOeuJVeu4gfbye7rhHr5b+
0yN6ufSt9+mvpH/2kL5P+ttd9Hl1Mr9++nrpC7rFpY+RPlz68B76bulv9dF/
iBdJnyOeIP20+GvpT4jPkv6F+MpeeqH4wAP6U/F06YvFK6QfEC+QvlQ8X/pu
8RrpL4lnS9+p+5H+ini89Hd0PtJX6f+R3is+LH2t+Crp28Qnpa8TXy59q/gH
6RvFF0jvEf8pfZN4iNEbvdEbvdEbvdEb/X/qfwMbtfyW
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt09tPz3Ecx/FfByErpaYbh7LWLGRFdKIyp/T7dZTOIZWilm78LmyltRU1
tJTjz2QtmwtryzKGmS1arkrjgjLDz6QWkUZHY2N7vv4AV7/PzXefPffYPvt8
3l+f3NKkfHuDwbDGzmD4/S34sxZEpY/VT372GIr8u19qOJT6pKb/3/51kgU9
zXM9+tP4BnRj/QH0D96X0c0PQ9HDs8+iFzXkoDevu4Te7bsZfW1AI3rhrQz0
K8cuoh8/FY0e1kP/tj0V/dPwBfSYoK3oVlMT+pucFPSocnqfyO3o6W30bfXJ
6MUr6QNf7EAfmaDf6J+EPmA9j97vHoNeF3wOPdwzkedvp2912oU+m0t/IyKB
91tLb+6kj6imP9kUjx50mL4lNRb9zDX6rx70Psn0Xd30j27TF7fFoZuj6I0r
jOiBXfTm/fTTgfRjBfSjffQzvvSdfvQBFvq+Afrl4yZ012X05Y/pK6z093vp
TV70NVb6siH62g5690X0GTP0Ll/ob16ld3Clb3Rnb/5Gf/c0+4AzfZU3e944
vaWSvWQevcdq9rof9AVm9hNO9G7B7Bsm6MtL2d3m0M+NYK+cpM8qYh92oD8S
zV41Rd+Yxz5ffMs29php+sF97Jn29AM72d+Ld85hf2ZHfzCWPWuGvieTvVB8
ton9nviFGeye4ofjZD5n6e+ksT830C9OYA8T35HKfl38d/H54j/uYa8Q35bI
Xi3eKD5XfEiS/H/ie1LYY8W3iu8QXyI+VPyk+E7xfuJXid+UzN6r97eb3Vt8
mfhX+v7ivcRbxL8T3yDeTfwD8YPij4p3Fv9S/Ij4veKdxA+LHxWfIN5R51f8
mPgt4u3EO0ofFx8ifVa6i/Sf0v2lT0lfIn1C58/mbd7mbd7mbd7m/5v/Bbja
Z8c=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0+0vFVAcwPGrrbViUose5ClyCTUqMSVGJt3rulxcQlae1awHmhu5ZehS
IZOVh8xSkzYyk1aNlVovmhc1rcWLnqY2te7SMlu21ovavr9/ofvq7Oyz7zk7
Z+e4HSyKz16kUCj8rBSKP2PbmGv/sTzrsNGOGNtg+5ndf+c5AdUj45VT/+YN
ukx4h9IFHu6ohmdlG+A/XDPgN656w7W2GviQx1G4TW4a3Oa5P7y9OQ5e/SEf
3mizH24KCoIXPtPCU7Zmwad/pcDN4bvg88Px8PaHB+Afley/bguHXy5OgOeF
psHfGfXwVnUk/ORSHc9nTIGbF5LhDvej4AXl7HekJsMjWtjnd0XDE1+zv3Mr
Ef44in2Zawy8zSURnq3XwbuXsLdV7YMbk9m7aBLgnq+S4POBKriukv26ini4
vo+98hv7vm721lNa+JcG9rUVanjnKHufNPYrStmPmdmPTrD/PBcHT89hb9ob
y/83zT66h/1AMnuvevbqWfY3C9kHqNg/eML+1AL7pBD2WyLYnzWzL1lML7Fn
77yTbrNSAx+2pj+aozcF0lN96Z129NK39JAA8f7C6IZVdP9x+svNdHctvWw1
fWaErvSlv0inT66l9wzSl28S95NLH3KkT/bS873ozUV0Pyf69HW6s5J+t5iu
cabXXKOv96QbDfTtLvSIVrp2o/DT9E+i/9lCH/Sg+52hn3ClpzTTg0RvqKS/
F31sE33Cna6pEuu7ifttpJtEP1xNLxd9UQNdJfo3NfQB0R+vpzvJ/c/Rp0R/
+yJ9fgM9y0RfEL2d6CdF/130DsKvXKA/FZ5US/cWHir6QeG9og8WPnue3i1d
9HuE3xN9m3CnOvH/hNeJ/pJwlej1wjNFXyf8iOgzhEeKvkp4regPCfcRvVF4
l+hzha8RfbnwftEXCF8meoPwEdEfFm5l6S29pbf0lt7S/0f9b4zEDCY=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0/tPzXEcx/FvpRQW1VFyrSgWEWKh5RBHiGjatMkPjEVr7pn7/fKDYTMl
l01uYyaXGRbLjInxQ0caB2kl3c6hpVLpuMwPzPP1L+inzz577vH5fH74vIMX
rUha4moYRoSLYfxerSFv27Yu72o+Y7Fm7vC3T/yzn39v4/XX29793We1taLv
GFZw7d8enVuCPst7KXxsYDO642gRfL7Jhv7yUjJ8rscX9PDhZfC+1rd8/+V4
eP/sevTS+3XwMc5S9JULY+GLLn5CP2hvhE+4WYYeEzUW3i3Ygb43sh0+2Kcc
fcHdEfAr6+rQrzYa6OdCK9CdOeHo5qZadPc97uglxgf0sv1h6L1G0rcO9EI/
mkefkzgQPS2rBv2mazf02dGV6KsfBKE/6UMfNt0bfdN5+or8/nxffjX6C/8e
6B5O+uIB/dD3ZdAX7fZBP23+iN5u64O+JpLeccEX3WU9/Y1XvdG9DPryA37o
fc/QN3Whv2SrQh8cZ0K3PKLPSwvk/N6lzy2mTy2jd6vphT7gLH2UpSf/XxO9
1056t8P0LafpX7uzx4ykL93Obq+hT/ZjH9oQgG5by/4j2B/dsz97SgH9vHT2
MYn0u8LYfbLoCxez+66hnxDBPiST/lkq+9ZD9AdHsb9fQO+dwm5coC8cy14U
Tz8zWc6/TR80nr02mn5uErvLY7k/hn3OMPrGRHazlb4iVnwIvWk2e8gb+gNm
9mW96Y8nyPyV05dOkm6iT5/J/riK3jGZPag7/eYZ8v/s9A/i2CO60t+fzn7r
M33aFHY/T/oh4nc30NeLP+JOfy2evaCRPmUq+wk3+iTxW5rp88R3dqX3EP/x
K32D+KcG/fNp7G0t9KEWdutP9lPiX7WyzxJvEr9B/K429gzxm3+wp4r3/Ma+
T7wh3iJ+nfhT4o99Zx8l/qX4K+ITxA8SH9DOni/eW3yg+BniH4qvdLL7iF8l
/rn4O+I9xZ8UXyw+W7yr+DvibeI3iXdKLxH/Xvpi8S3SHeIrpM8R3yz9q/hK
6dPEf5HeSXq19HHSG6R7Sa+RPlp6vXRf6bXSR0j/JL2vdLv00A7f4Tt8h//P
/C8tQafy
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1OtPFWQAx/GjeDQuIoqXwyYRTlmSOmN4MLzgYDbmDRIqVLxEealkQNIU
URlqUYRyQNicRm6QmhqbSJrIkZsIKHM6Zikz8aioINop5gXFTs4XOr6//8CN
V8+effZ99ux5nj2+cQnzl/c1GAzj+xgML8b+6flhP6x2nfFTY9WkMyM6Ql7O
o+wDxrWm/vVq7mHvZ+7pYwfW+vf0J/Z69HnPbr3T02MyHXBD0g30ow6cg5sb
zqKv+eIJfFnjU/QhIU3w8O7f0P8e8RAeGeEO97n3B9xpSxH8a2Mn/GKnN9yr
5TLcZ0s+fHOcHe6Z6g+fE3wFPn52JnzvzPvwrm8C4SlvXoVb56bDzXkd8KDc
qewLW+BrvNbDr0++C3/XGAZf1XwNviEqGZ45qh0ePDEcntNkg/uVJsA3hbXB
k6LnwKftug53c3wJr7bcgbvsi4BPD74BTzN+Dt/ah/3tefPha0+wd/p5Bbx8
+2345sRo+GTfm/Cd5Z/BqwLYHx/zETx7DfvAwE/hru234EO2fsz7Oco+/+kn
8O5i9ud/jOH932U/6/9l8P2b2NdvXACvG9oKvzOJfVkM+8EBC+FWM/uUvKXw
qGD2lhr2/37A3s+TfZcv+w/Ni+CVK9mnH1oCT3Znb9rBPihF9h/D/oKDnnSV
/XsZ9NZh7N/vpLt6xcKTcukW22L4lDZ6Qzj7hN30pqPsJ9jobgnsiwrpeTvY
lzfTS7exX/UL/e117HMu0kP2sXculj6OffwF+t9l7CsO07+PZD/yHL3kDPtj
pfTVoey/OkuP/ZO96RjdFMQ+soGeZmNvOE53nsC+oI6e28Y+o4xe58d++mn6
CDv7qhP0x2+xH11Lj37A/mQ5PWwk+9BT9G+72H9nlfMxsc+qkf+pm73/SfrG
Yez/q6ZnO9gflN7bk32m9CUGumcF3X8wfZz0iX3pK6TfM4huq6I3O9EPSr/I
nV4kfXc/WV/62IH0ZOmvGOkulfJ/uNHnSZ/dX85H+k5X+kTpvQfQw6WPl94k
vUX6xdI7S2+UvkP6eOmtLvRH4gFv0FPF10vfLp4ofYZ4qPQt4kXSW8SHS39J
/LT0O8X/caafF++QvkD8svSN4g7pC8Wrpa8X9xDfK35EvFbcR3y/+AHxGvGx
4ofE88UrxYPEfxXPEa8QnypeLJ4lbhWfKX5YPE28TDxKvETff2/f2/f2r13/
HIO62nE=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0/tPFWQcx/Fzwgqx9EgBYzJds42VqGtMIinFWGxCE0WqgaAMj5cwuQzF
aNqFAmcTGhSVmcFWOzRnjGjaYRbZJig58HSGBMr9fjlcPUAgQuuHGu/Pv1A/
PfvuvdeeZ/vueSIhOXLfAwaDYa3RYPj7DGqNyPksaUlw0ieXwk3eg5v/mVsO
dK0dO9b079xTt+rlhT3m55E1C3ul96/wHrFl8L/FesIfue7jt7DnF1bDn/39
FLz790vhT7+0Bd5w0ga/ceYg/Pa3XOFP1u2Gr1hZD//tnm3wpaku8BFV6fC5
ltvw5+yB8La4efQ7az6E94psQd8f5wv/jGkW/bWOM/Drw9vR5wO94f32TqM3
f2mBv/xDJ/q6q4/CbwmcQs9ylPL+4m70uOOL4C+nT6DXh5bDVwb1otumZtEL
3JzoDy+5gv7B+33o19om0T/vHEd/IbsS/aGcfvSasTH0r51j6I7Jau7PPIB+
dXwI3eRPX/5RDfoO90Hu7+IAevCno+jFGTb0tEJ6i2cf+kYv+o5bdvRryx3o
Nye70XeWjqDH/1KHvi+JfvOmLvSpWPre8Hr0Q+X0exo70FO86Vfl/IHuP0m/
ydqO/lPHMPoreQ3oqb5D6MbaNr7vEv1qcyN6ZAR9hIk+K5++d+lt9KJk+m/S
W7nfo/Trz9DfOEX/1EwLek8cfcDiO+hzX9HvLKC3hdEbzfR+pfRfhNDvCqLP
/o7es4I+0Uhft45+ZT99bDV99Y1m9NIn6Xd5N6Eft9MnFNG/6UOfFkzf3kgf
cILe7kH/WDx9cyt9RTx9konemkH/Yxf9+a30pkfo386lt/TROwPos13powrp
bw3S3/SlL36QfvYC/aFh+swV9FEu9G5W+sxR+rzl9GlG+ntX6P3H6bMW0w/P
s2+4Tp9/l93gQl82x/54LX2Jk916n73sPnu9nb1ggv3wNHvnLHtJPfu2Sfa5
CfYg8TWN7D3in74r77/HHt3EnjDF3jTKHiI+sYW9SrxxhL1/ht2jjd3rT/Z3
h9iLxKe2s0eLD3Wwm8XndLDnig8bZN8g/nAnu1V85gD7MvGru9gbxXf3s49P
s18Q7xRvFt8g3reb3U36bB97pfRM8T7SLeIvSq8V7yc9RrxFumcP+3PSfcSf
lR4mPkT6UC/7x9JTxG+VbhN/Wnqe+B3Sz4vPll4i/lXp+eLfk14lPkb6O+JP
SG8Qv1v6G+IzpDvEJ0iPFn9M+oT4vdKjxB+VPi/eLH27+CPSF0nfLz1Uepp0
V+kHpL8oPVW6u/SD0p+XnqL/R3qidH/pydJXSH9d+rP/+/+k/wuwYcef
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1GtMU2cYwPHWgDoMCUFHphKMxohRS9AYdSADxYlzy7gMFUSUFbkMjYAI
uop0ihCEUoGB3KtY8DI6RASEeYuGFEO9oUvmBg4kI1RGcES3KM5h/KDx/3zf
Nz+dvPnlf3Le95znzFTHB0WNUygUKqVC8fqa4GX3izFhko96WWjr+ml/er9Z
R+pLmsaSut+u/Xy74LX7Vefe9ZAjUfBPz4Sjj3W8A9e2q9G3NcfDozUq9BlW
M7wtWo8+T7kHPkM5Hn1ZzBX4xBkN6G9Z0uC76vob3/UfVrbCr2++jd417CD8
1hIL+h89GuGOQQPoT1qz4GXZTehtnevhhuFR9DZGHXyfxYg+7qIJfvalHVxb
fxi+ybcIvuL5afgHsz+Cx7gXwBeEH4Ivbj4Jz7DOgkcuL4R3GrRw++4a+KnW
+fDER0V8/urdcMuGarh1ZBHcvKYY/sf0RHjvVCM8oGsZPCW2hN/vtW1w3YfH
4QUNXvCJwaXwsYgYeIRPFTzk9Ar48JQy+IWOSPjd/GPwtdZV8L4G9p2/RcD7
x7GvzfODL11cDp+TtBn+IPcovP3SZ3AXA3ubvZvgE9zY/5fxOfz+U/bzft8I
z+0x8PxffAHv8qzg/0MXCl97lL1G9SVcmcI+cHcIvC6O/aCrP7yihn1D4QZ4
iTd727/Zl91gP6VrPdzfmf3LigD4oSH2Dr7s48Yq4dlzArm/8fRy8zr41QH6
gmL2Ts70xgj26p/p6ifsDSq6jz37zDZ63ydB8Gee9OHrwTyf8/TmVPYtfnRF
PvsBEz34DPuQQLpbJPtF1XTzffYfh9JNXuwdKuk/jbI3baE/d2HvWUxPc/oK
/mQr/Vdb9skF9KUq9qu/oa8aoefoxf296Z3b6dG99HU59Fn+9JZ4euFdelMW
vSqMPnUnfWU7XZ9J74mi2+2i21ym3zhI995Br0qmJzXTw9Lp05Ppj1Poy+vp
bgfEfGroyj302bX0JfvpAVr6Q9GPnqBv+47ulE4v/ZauN9LbtPSFmfSFGjEf
x+ieor+cRTeJPtEg3l8a/WY23WEvvaiCvlP0Gh39a9FPLqe7ir43l14j+tul
9Ef76BMO07tF31Ei5kv0f4neLpX+uFjMj+hb8ujuovcQ/XbRb8yn+4v+xBF6
gOh7RB8renfRe4h+TQE9VfR3iuhzRV8pep3oM0Q/TfS9oi8VvZ/o7UXv8j29
WvSOoreR+xe9SfRDhfR/hceLvlG4WfT/CM8RfavwOtGPCDeK/pLwctEPCb8g
+mvC00U/IPye6M3CE0TfL/yB6DuEh4u+T/ig6C3CQ0X/UM73+/59/z/0rwAL
5IlO
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1P1PFHQAx3EOKwxZ0MOZiS1RZLHOLXTqeliwJbQRPSjMVk5NDWHp1KAp
cSgKKnARKGiCF+HZDDBDPASGUoBZAeLDKagIOJLiphcUIkQg1fqh5vvzJ7R+
+u67197ffbfvg9+KdQuj3d3c3GYa3Nz+Hj+3nppaFjchxOe5tcmf+LqC/5n7
9kys917f8e+8ofEQfDR2qPZuH2ePhx/uvFN3tz/sOAg3THoA/sO8BPjxBU74
0XIbfJbdDz57yAyPSWqFt738KTzLFQRf5p0Mb6n+Dh6SaIUHvhkMby/cCn83
5TjcfUY+/K0N4dx/bSp8LLoMbp+7Fz67JBLu3LIdXuxRDM8t2AOfE7YYPmVw
Bzxlsg0+GL4bvih3OfypwHT4wFIrz29WLnxT0yr4jCcz4KH7P4afCM+B7/Bd
DTeNsh+y58C/tuyCTy9dC28tscCdcdnwK66dfB+fvQd/59kP4S+czIRHxbK3
Gd+He9nZz023wBNGs+HPTNkANxoz4WvK0uFv29ivbtwI94xhPxaYBncsYm81
fQC/doh9Z8923q/H2O9emAgf181+Vfs2uEdPFrw31AxPevAj/i9/pMLrTrCP
9E6C989jfzaM/ck89h6V7BveYP/EkRR4k5n9+JBN8Olx7HOC2DtWsn/ezv5W
GvvDjVvhI6+xr/XZDB/LZ18Vzz47mP3QUvZ9xewtJvbDQeyPFbKPqGC/v38L
vCqA/YJW9hm17Nvq2Mc+zr7EkAw3NLBPyWNfbmS/LIC9+zn2/hvZR3mzr57P
/nwL+6TF7L082XcvYV/Qxr5gPvvSe9kfjWO/t5P9l0HsfdzZu1LZd3Wxv28a
+4f+pJty2O/rpt9vZJ93hz5SwL79J3qEJ3vLCP2bIvbVTnqMgf2lYXrXEfah
N+jjR+jrfqNnVdIzb9IHBmT9IfrkGrrVRXf20V8dpJfX0c0/02tu0lNv0xNP
0ef00sOc9KsD9MLv6Wekj/uR/rr0TzfRI/roxuv0zlv0qGZ6hfR+XfTN0k86
S5/wCz3tGn2m9NZz9CjpTZ303n766fP0LOkf7aBXSn/BQa+X3r+dniF90QX6
Demjr9KjpY+8SPf8ld7YRn9J+m7pA6R/UXqT9Cta6MHSN1+hT5S+WfpI6ddI
f4/0fq30ldJPlX5QPFb69eLXL8v5iB+Q3ixeKn2X+Bnpt4mnSn9ZfFj6TPEl
0jvEH7lE3yUeJv1p8SDp88T9pf9W/BXpC8S9pK8XXy69Tfx38a/E48UPiN8W
rxFPED8o3iNeLZ4mXiTeIV4lvlO8RPyieIV4vvgX4k3ix8QL/+//k/1f5+0L
cg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HtMlWUcwPGDRogCUgh4uMpNjiCBCogcCBByeDl44BAKKgECIiGIaJDz
khY14qIZpEmBis48sAHzmtgyJnmrVPIOlDgo0TaSgRoStbZq5/v7692zz77v
8+65vC5peXEZYxQKhY+RQvHPs+OPLdln1k8ID7awqu12eBT233igpX6RS07n
/+POcY2fG7qfiUZn6I+/GKwx9LyDIRpDv3LjEvqOzRfiDL1a3YF+fNdx9Ktt
76M/UpOIPuZJG/rBKPsYzF86hN7p55FYQ3fwPoY+XbkWvV27Mfyr6Eb0H0Qf
4vwTT6JPyrOCT0vNRX/j+h74s5wB9L3tTvC91kHo/bMr4Hes3Rdj/xJVcBv9
ePSFR4vh9fs06N3j/OAR9T1aQ09dvQVulroWfd9IIDzz/jn0Om0RPKigHH3z
zhD4noV69PmBBfDuc4fQW6sj4G+ZV6J/cSAXfs/hNHq162tw53Xb0PukvAkv
d7mM3jIzGp7anY/++Mos+KTkO+gjXRbCx3amo5/VkwHvmteLfnq2Bv7e00T0
wd+vhC8K7UdfpFsMv31Xy+83T4N/t+sp+gu/aeGb1fPRL9mdAq8oHUXvGxnH
9e+Yi947+Q34rpQX4LWpOr6/OBTuuzSZHmEKD42Nh/tPnAM32bwCvjzBHN6o
fB1erQuAN7cth2ectYQnf8Pez38m78909hXVVvA6TQK8aLcv3LRhGdzrL2v4
cCt7yywf+Ilw9tdGbeFuHkvgkyu94f2/JMF/1CvhYYXsD5l5wW9Ws79taQ//
vYW9V5sKbrSCfXqIAzxriL3fUU/4OhX7J4GO8I0eS+HGP0yFbxpJhH84zonn
R8M+wYL9sVvse06y1+WxH1rjwfU5xX7HAmf4hlL2t3515/+nln1UG3ujOvZV
hewbSsT3e0/h/TjB/ksle30h+6+3sZ92nn3AZTf43iz2FRfZP77OfnsJ+9Fl
7OuNXeBF99iXx7FfH8u+bzZ7x4fsP3Znvz+a/fNU9r4D7JWjrvDwCPaqYvb9
z9g/6mL/spp97QH2VaPsR1vZ9wWwD2phHzOWvrGB/Scz6DevsJ9rQt//Kfth
H/qEbvY7xovzWcJ+0Iu+oZ99vDm9eRP7HBX9/efsD06k6/PZx0yl1xjTK1+i
52bRS9zpFhb0mVb0Uyl0Cze6ozW9YhI9NIl+1YVuak9vsqbfiqd/O4X+pzO9
zoau1dIfONOd3elrbOlli+h+oi/zpNtMpq+aL/bHiV7gRT8o+tZ5dCvRd0yn
2ynpO6Pohx3pP71C3yL6o3PpC0Vf6Ue/JnpVBF0h+uEZdFs7+t0w+lkHuvcs
ulb0l16ll4nezZ/+juh7Q+kpoh8S/RHRu4o+WPT6APpl0W8NEfsr+shAcb5F
P6SmjxH9cdEr7Onviv6hcM/Z4nwKV4n+jvC3Re8hvD2YflF4m+j9hZeK/rRw
syB6hHCN6JuEh4h+gXBX0R8Wvkr0scKNRH9A+FbRJwh/MIdeLXyf6FcIPy/6
KuFnRJ8mvEn0Hwm/KvpM4Z+Jvvxf/xuSwh6r
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1nlQVWUYgPF7ERARBYQQmEsuMBQTVHixEXRcUhN1LMAISzZZlBEFyQVx
RdJC1hBFBDHFQAwKInYLC81EGA1DQdmUJcGNHYGrUs1U8z3nrzPfPPM7M+/M
e745M3yCXfzVZDKZjVwm++ept8a+4OqOiQsV1StMLV99tOC/8+Utbk52AY3/
n+scbA3E7tzxzqdiT9hRYiL2iCT91WJffbUYvnugIBi9fB78uHovV7GnRlkZ
it3APmmz2Istao3FnnHfxU3sriWH4UfdqwLF7lS4G35h9fAasWtMaID32bhs
o9hTet6G74zw+ETs31+d9orY2wLHAsTeUdo7Vey2JtFrxf5558fwB80ebhC7
ruOP8FqGUe5ir9GJhp/wzdh6sZ82joeff26dh9j7kgvgx0Ls4WvaA+AbuqZ6
it2ztA6+pyHBX+y+yY7wN+T58KabBuEH31CHr1huA79nuZ2X2Du/mGwk9tB1
MX5i3640glcPTof3rDCHn276Gnzkd2rwXXFj8C8KZsMnh9X4ir3Wpg89ZcX7
3mKPvb8EPc/wMLyGQzu6b8OX8NcKndFbWlbCzwqqRy+YWQm/J84d/cB0Y3jd
7dfR9xcPw+uX+aP7ez/2wfs1r6A3905fJ/aGXZvRLXx/g9/bUY5+aeBd+Ida
29CXmGXBRzaXoBsUecFnJIahn8mJhR9/5Qf0nzV2ws9YvA/9pXMovCI0Fz0n
MQZ+gX0E+oVAP/izN7PRAwfS4L8+cgjdJuRD+GXlWehpGTnwhzdEol9++h78
RfNM9ET9Unj/6ijuX8RcePues+jGRy7Bx96MQa+6awtfaZCObr61Gv5MZBx6
RZ4VvCr8NHrrwB/waqp49KLKmfCbrL9Cz1p1F97SLgH9Yr+C+6tzCt0juwX+
wbwj3D91Y3hdkzT0crt2+AuKRH4f9Qbw81eeRP9WuxN+9A59m7Me/Ny0VPR7
jo/ow46iR300CX6aNn2J5lPuv/wY+ps12vA/xabwfljTA5+2lT46Vws+0YK+
eVUf/Ae19HNaNeGzq06gaw31w+taJqEr3TXgw8Ppz7kPwlsH0odOUYfvX0h/
J3qI82fQZ6jU4OdMpLeNeQavUUffrUtf2ZSM3uc3DH9NdpzzOcrhvYvplYoR
eFML+rdOy+C7kuiNiukHF9Ff1Kffvptez2EUXrmW3vnEGPoiP/pLWfSRW+ij
lfTpTvRemir0xAj6HU0v0f/+o0A/5Ep/O4E+8yj9uFn0ocn0ZafoLd3oX7ek
H19Dn36e3syc3lxBXyt7jl6fT2/97AX6eQP6pVb0GWX0AzX0e3Xo96ykn/cL
/cF8+iBNer8A+utX6HuP0zvJ6a+H00dU0YcfoFc9Zw87Rr//BvuuIHqXEfbu
TPrGm+ybPekdhtjzC+kLbrE3OtGn9rMrK+gV9ew+S+nX97KXVdNb3GXPm0sf
2c1+9pZk/gb2fUr6/ieS+6mJ3qmJPc6aPu0xe3wbfXQze64l/a5H7KpO+qQW
9qIZ9Icessc8od95T7J/ZvRFXewbeuln32cfNaHXkvjMAfrbUm9Ev62TPeAZ
vWcre4gh/fAD9uIR+t8l3mUKfbzE56jobdvYP9Ojt5N4zxf0ByV+aDJ915/s
v76kvybxWZPosyR+dIxeo12ynzr0IRIvl7PPkfiTE9kXS3yjxPtIfK02u9m/
/i8DnXvd
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HtQzVkAwPErEXkUdl0qeZWdEYudUlnJtmpUbltZNTuzHtUt02O0ZVCK
ZCfaakWWZlq1yA0Zs2g90k0PditK4ha90/uhdyl62NnZ2Z3z9deZM5/5nnN+
8ztzFrv7O3uqSSSSlRMkkn9Gmzv9Y6qgaRvVQxwHvRd2WP43X+0fkr5ZXvX/
XLdTXi36k9rfjWwFt7EO7xf90rh+rtgPzJtVK3pwQtpSsZccGuwVPfL8kQKx
n9p7uE70+611emIf7pTcI3r4muJisR85fve16C7B06ViX73zaLfoDRlflIq9
fVJuveiBtrNmi/2NQ9Fdoqv2FZWL/aUXKQ2im6UXzxD7+Oh7naL/kaCsFvvn
z7wbRQ99uEJT7Hc4qKP3N5j/WuyzfbWbRG9xmqUh9pkynzeiy3yGG8R++V9J
6L1SvdXFfvRuc4fo313xaxb7ot3zmkU37DNQE3ul7X7044ERrWJf/u0R9J65
xhKxNzafi95Qx7Fd7BcsLkffWxgzLnq4waN20VPHXnaIvlVi2CK644klY6JH
qR1Gf6h0Wafoq1We6BWanSOia8+1Qu/TvalLdEuzRPSaZxrfi55cPxN9iYd5
t+ifxxSiD0xSQ2+8tKFN9BQrzR7RfxgdQO8R89U70afkZqLvTFeif/STtFX0
6WfODeN+lCSiv7N2W6/oP2qZoDe6oIU++/hR9HPCX6LXtXVAX78mfkj0i2t9
0RupbPpEv1Xmgf603Wr0vnau6LP7FOgXfLUfff/2V29FT9pkg15pNoTeZiwC
fbHFz+iXp5vy+1PX9+N++Z9Gv3GGDP19eyP0CR8OoC/vSEKfZjwXvfz6IvTS
W6noTyivoB92bRkUPTdBin7rxDL0YQtvoj8ly0JvXqGFftvkEfQdtvfQfy1N
RB+7bir6z1J0BkR39H6AvqIyDH3GqYnog66ZoI+59BB9/msv9E8zxrl+zhb0
Kr18eFiUE/o5Ce/hLSG7uH/XE/g+B0v0W2cPwR+7BKDvWVMM70tfhX7hzAF4
YmYY+oyREvgH7yXonQ72woumxaA/v10F19GUoj9p0w33ij2LXulVBtd1noG+
Rt4JN43+Df3o0lfwLeqT0MsKOuBrzS6j9ztfDu/sGIMrvNvhy/Ouw0OaKuCD
lUPwlRZt8Ay3NLjpSCW8+3ofPHB9KzzI6B48srUK3rixC/6pWwv/n5USLkur
hucFtcNTFM3wmzlZ8NhdNfA4ixb4kUnsHR7kws8OsFcdbIRfC22CJ9j/CZ+9
txbeo18Pz9ZgXxKcBzesZd+vUwcvT26EP3EpgId+WQf/xL0GHubAXtb1GO4R
xf77tir4qUnsD9sVwguL2EdcroRb5TXAR/YWweUar+FRv1TA1ePYrwp8Cv/V
jH3c1XL4MTl7d/ti+FV39vl1r+CXLdgPqz+Dxx9jv8GEfYAe+8hk9rYK9jcu
voRrS9hPNiqBR2Sx32PIvqSlHl6QxL67lL3f/TL4/Bfsb094Dpe2sX+7g708
h72lC/vAd+xrtdlb32IfkMR+jwZd92kp3FVBX1HF3m0OfeYZ9rIEep32C74f
C+jOcvbVJ+k9FuwdltFvrmNfHEn3lLPPWUlfJGX/JpxuHcFe35ieNayCTw2l
u11gf9Kcnl3DfsIB+u509iYb6HH57O8E0puK2K+yop+9/dH5/el7a9mftqZ7
Kdg3+9L9utgHb6bHxrM386abjrDvt6NnRrPv8aLrTaZryeip4fRROd1fi17j
QJ8STP/G46NeSvdxpCsC6PVu9A36dKUT3dWXfmUXfZ7BR+d3pnd70s/t/Nf/
BpuLXAw=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1HlQE2cYx/GEcBjCFYiggoSIqFRQKqjlFlNLUh0FFA8KEkBFBTU1SjUY
BE9EKlBBtIpHRTwK0dYiVscKRCp3FEGkQwOoHGqhgpbIYex0Ou08v792dr7z
mX123/ddQfSWkLV6DAbDlclg/HNN5CkDO+SceaK2855FDq/8/7tP3ecbvlrS
+v99zPF9bwtJt1qWXBBJ+mnFXQ/qTy/Jk1F/e4XFEPUiw8pM6n3tDrhRf9Sy
9iD1LW7vR6l37TNMor47qt2FemG45wnqdU0SBu0DUU2bqE92uuVMOz95wSXq
jVmLWbR7t7VEUp+nY06F978iLKbeqLPRgHaZ3f2l1Id2XppMe31hYin1R2Ss
MbQXRISJqRe0nZtEe/Kh6dXUs37pZNOexAqbR71jSYcD7W9rUhuo95lxgAPz
Lcr+hHr30tV82luulrVQzyvvNaFdLtR8TP3aMxb2tKsddG3UW/pONqN9ntrS
hfrfJ762o52ZK+mkPnqpmzntkh7uVOq7GFpb2hubDF/C/qu3saC9vOvuJOrT
u/ngRZnGfdQPKdvAf+jR51OvcVk3gXa2NqWf+oxP07m0S4NqbakPqK8YT/sU
9+S31B8WCyxp91miP576z0K9wfepx2qpP/fXOfCV+/OsqU+9pxpHe4x18BD1
HAuuFe1dRWk82H8Hw8HPDvcbof6FTgp+WXCpJfWbolng3wf2jFKvaFSBT0vz
4FJftOGGDe29nJU66vPDODyYv05jTv3mNzLwD4/nfKD+Jzsx+L23SsyoD8n0
wudXXWTQbipNAh/cf9OU9mksNnhVWjaT9o2JheDtBlpNaOd4aaxpH9FK9Ghf
6tsIXjVqD36n6GfwxxO5LNrTsgbBB2rlHNr9ok+AF3VeBq+ezRtLu9mKXmPa
jZsV4LfudtWnfbDOFXyIqQx8ntk68PsFZ8AndgvBWyewwe/ZHwz+pD/TAPro
cvDlYiWb9rnV/uDZ70LBH06IBS/KjARfIncDP4l/Bvz5a9vBnzpmCz5mviN4
T7EGvHQoBfy75+1jaHd+YgM+7hHPkPbm7HTwg3OU4F+PmoL3eCUEv+tODviN
2/aA95UbgO/Ijgf//kIeePn34eANBDroc37IAG8hz4e+kOMD/nKlFrpYTwk+
IfIK9KQ2PvhxiwegF8ysBF+WcBW6LN0IPPtoL3RmtQa8bet16N8eHjCifbni
Bc6/eAB8zcUS6P3r28HHD3ZCXzmNBb2+7xZ0j9IH0KtfPoUuKeZCn6+6A/2B
lwr6KXE79KoF9tBrPEqhmx4pgb5KXwOdxXeG/jKoHPqanUXQt5m1Qh+jmAVd
7HgP+oSKfOg2Eb/h+TzqBX2kuALnD8iD3tX1BPqOjADo17j3od9WHcPvc74Z
ul9uIPQ/fCuheztn4fqmP8Zeuwj69IAq6N+EpEN/cbIJ+uyFwdD1BdXQTZxS
offUNEI3dg2Fvugp+sxD+6AvGYd+8sGV0GccqsH9G58C3UfxCLpV/BfQA8fX
Qr95OwnPn7YBetOrCOjFOejdN+yCfmMvehFPAt2JWQe9LVYOvZ2P/vP+KNz/
EejPFu6AXlT1ELrT1zHQDZTon7l+hd9vN/qG12ugz3yDftOz7dCH/dA/cVyH
52NGPfSJv26DvssI/bBLLPSEaPR31TLoWc0PoPdy10PXHUE/MrwVupsS/XfN
6KXF6BcK0SekoQ/dswF6/mP0Bflf4v8zDv2dsRvxfLxBr7RFPxSEXi8HvbmJ
GtfvghTXzxN9h14c9M0C9EH+6O2noL8Xhb7DHf1H3Vtwfh565XX0aiF6s5Po
pxuijxtGnxWMPmQV+pgh7Iq58dC3RmDPckC/qg+7dzz6H2Ox5/65GXrDc+xl
J9BnSLH7VaDPbcVuVYZ+1g7spWfRK5qw6z1DX5eEfVYK+jD1v/1vWejysA==

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1H8w1Hkcx/GN1pZVV5Ffd/3gTCX6cXRJhKmpm3L5eUWiXM3KHP1Y4zb5
sadCFim0y/7Ij/zanC3ZfiB03BmaMpKEnGMTzsiRRLK4ubm5m/frr+985jHP
78znp8mx0x4cDQaDsWEeg/HPtyQkMGU4ku2kKe9Rj5gMOf437jd5+DzU9/f/
x8lj3+6mzjHgO4URP8mrH6U+ZnFN50fiQrbEjXrHSKg27V/r2PZTPyRa5Ej7
+qM8H+pJWq6dZ4kfMdLsol41bRBEe/7okuPUeyUWpbTvUE69oK5wjk2hvV1N
6g/UHVL3JNN+LmmikfpBpY6S9uulq7jUjZvHT9E+yaa9nnq9lssz2lc+eMmj
foyd40l7dfz5Wup3Kl4M0v78gZYI6qXqBjvaRy7uqKLuEWXM4BHX2L4hmvq5
6U9raF+Q1lBOfXe4QJf2hl9OXaTO6mzRo72szP4+9bbv+Ga0f2y+9xL1nmUz
82lfLTRTUt+v2mtN+8uGGxKo25paTFLXDOKWUE8osHKiLrpfmkSdue6LIep3
D+nfAt/Ic6b+08L+ZOoDclEPdZ21C4ph/cz3HaAuSW6+Sn1jVGAb9TKtHUWw
v9wuP+ojwfxU6s0qThP1VcHFcurDA94c6n9kj6dRrykMbKAuVbkUUn+5tSeI
upWpnZD6YJRrLfV3b1YUUA+ISuVSP8T0FlF395ippO7coJtPfUFvAo+6T4Zb
OnV5vXcZzD/dIo+6pZEqnLpZpHkG3P9K57uwP7P+udTZT2/ywSv6oc/sqS2h
PrWt5AZ1X+bkeeqdHYli6l6HFQrq16aXQ7/jQnsMda3hzyXUX4Wpi6hbnriS
Q33L7OFL1HtviKH34eTKqdt/MoI+P/SygLrSgyWlLhgRFVCfF6vMhvvjczaR
uifrBPT+no151Jet8oE+r9H0MnV1fAX059gOudT3rdSBfnldejL1RxxNGXW+
XJVDvXlxQxZ1Z6uuK3C+P+6EXqm4k03dtjgJ+hizqavUc7jh0LNC5FnUgzu9
oXftG02B/7cXQW/NrMmkHpRvAX3R0sep1Hm6rdBPGkxep37baj70K0pi06gX
vJ2CvmFgD/Sb61WZ1O/vWn+N+ild4+vUWy0VMuod1b9CP7+rHHo9k63QO2iv
hT464Sb0SetshNQ9pC7QyxilUurbFanQiyPyoG+fOA79nMoZelYFH3qvbk0R
9VAxD/rc+jEJ9Rb3k9BzjL2gn+6Mg75hQT70OSZHcP7lWdC/ZQuh77X6Hnq2
yg36af1u6IeDc6CP1lgDfZ/bbugr/fXTqc/YFkMf7zcmpv7ZdjvoAzL3QC8t
uAd97f466LnBVtAP3zsD/d3uKuiPqq9Dr1u9Hnr1aSH04Tp10I8rIqA/rG0G
vTDiHvSrXZ9AP1vtB73nVyuhT+A2Q8+vewb9k+xd0K80MIJev20Q+kxBK/Rt
Ly2hP5GrB/2V1XPQ25R2QC8YN4R+6pcl0Psql2ZQX+HZBf0yKQv6fX6LoDf9
0wR6WVQP9JVnP4J/HagNva7OZvCnTr3Q++0cAs9pYUEvOmYP3nazD3rNym5w
xzQm9HFrvgHf8dsA9KWKVvADMk3oLRPdwDUkg9DHDjwFj+ubB71LlTd4v/UQ
9HLHOvD8AAb0zDdHwZPEb6EXplSDpxrOgfubBIBLmofBL1aVget+mAE3SwsC
71X9BS4pVIJXTajB7T3PgPOaRsALbW6DNxtifzAsFLw2cxQ8wvtn8E1e0+Cb
9MPwfHm+w/WfLAS3v/UJnOEQAR7yDvslzHzw58bYv5qNAjeLGAO/HXID3Foy
Bd7BiQZ3fo/9pi3Z4JPm2EfxL4Cb+L4HH3LIBF/Y8BH8oUcMuPgB9lcFMvQQ
7B2HYsEDWePgE2wp+KJ12Je4XgLX3o8985EY7+fAJPZx8eCNAuz5sgx8P25h
ry8S4Pmsxp6RlQ5eHon96wsJ4HrD2DfWiMBj3LEPd08E5y7/AN7EwL7JAvs6
ZhJ40TbsOd5C8EHtf/u/AR+6b58=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nsw1Wkcx3GUpVRClK1NKaWQbmTPdCOzURKRrFSolpGzcitKSu4chzSS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1HlUzWkcx/G0KEoqTZs0pEXqhhYZl5LWSUKLCNGqopUuohlXqpG2udGm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xk0lXkcx3E1TRtSXEaSEu4V6RJF6WZrU+jKlkEhS8p+S4YWayIq0b1C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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nlUjHscx/FRV5MUUdF2FZGrmUqXEGm5RZYmpA0tpppkLGOpSFHaS7cr
FC0IGUtKFFc1JaZVJo3MiEormlZqyoyl7vHHvffz/PWc33md9zm/83yf53d+
c71ZjgwZEolkOIlE+vmM7tvyaE70VCvOco7KhH6f5b/rUC328Rz7lv/Wd4bl
qD3gGoevOGnQ/nfGWL7sOPjN5eap+dCnBEcYi8ALu7YcVYU+U0JT/AGeHHB2
xQPodXqOaPWC+5MbFJWhr6K6Ur6DR6z3YRVBP3/1lGHsZxd3kBWht3Kt8PwG
LjzLtC2Ffq9Y/0EfeIPlyp3y0Hvt5GR/BbfTjikvhz4w6pxfP7gJx1dpMvQb
pid/k4JLZ1T2caHvO9xPHgB/fjGfLAN90cISOvaLc0J4VdBTlbPTsa9u0Fk3
Ac7vEAok4HlqTntrwc/zpukOgpcmudR8B68ryHLBvvqdR30duMc2ehr279mJ
EV/BVfyGO7+ArxrTkvLAdX0LyUPgaVrhByXgRnvKg7Ef3pP8+QV4BoW8F3uH
L/6nx8CXBc7WxN5Tjsbhg7Nqrauxz101+FYM7majyR0DN3h+2KMR3NF+ueYn
8Dd8LdoI+NqrE4exT0t71vQKPD7rBgN7bd9tXZ/B5TOUqdizXpeZCNHtrW9j
v13RO/0T+EAdu3cUXLBr/57X4J4y13qwN+aas4bAaz8a3MX+VHNeXBP4exWP
uZ/BLcNMvQbB9d1UgrGPmFBJfANeVjLshH3uiHDXAPiUiU477Mdejh55Cx60
qTkSe+327ph+8Ctqv2lhLxoOdGjG82NrZB72l7pdivvw/1oQMiwG746NmtEC
fjyAJsCey9tKwv7u7BM87EOedD/F3oB1VoL9ZZqhay/4Ds/mHOwbRYt9W8Hp
LWz1Yfy+1d1LReD3KGv+xD5c890Y9vlDfFPsu7eHmmCf+DjgIPYJGZah78Bz
5rltxj4tcsP9HvBo7iI37GXE8aPYy/GD/LEXOGdZYK/7cJE19kUFAp828IQq
xgns9a0PCT7ifHwsqdhrfZ9bgz2l3PUM9g5jzwOxd2Cu1MDevN5Frx3cv+NY
NvbMpY1zsO+pGyRjn6VnF4S9go60EPtptSUvPoDHxiyVjICrCe8/wX55loSL
fU3Zi1jsy1d8FGGftGOdXAd47qxMPvYyD/3XYs/gvW/BPmwb2xZ7pemy77Af
9xlSwH7EaCYfe7Kqx3HsBWYbRNi3Ln376j24rMyWKuwTSobysS/LPTWCvZ/S
nWvYTzDiOdgbZgrasJ81v+079qmLRoKwzyzJLsC+0CREoRPPF+Ptk9GPqq1z
wD76QFIO+rF5NibYh+1XVkLvKLVfhH3liyXZ6Jf0Yp2wT/lbRRX9RmoOGfuj
wsiL6A9rLgRgX28ToIne8GqWqBs8SpF1Hp1i9TQZ+4xGK130x8V2POyf7vyY
jK40sfYO9rr8mAXom8U/CrAPkW9PRJ/i4VuBvRHL0QB9o8xEJvb1dFocuvM8
x7fYx1bmGaG33leLw76uaX4Ueo68zSD2J3uv/45+lT0jEPsv9e7h6PmLGaQu
vD8pWC9DL2uv8sFeKbo/FJ2d2KmMfVhonBn6bLqSE/ZVcs+D0b2tO3SwLxZG
mhPmX12+BvsD6uIgwvkxHmmI/ZtxM0t040nlK7A31vcMQB936DXDPn3lPWt0
krSfSpjf0l8OoR/vWLwGe4rFkA26qjN1HvYdje0sdFrdwU3Yu5tJ16BPWsZQ
x37FjKF96C4VFW7YX+5qtEP/60f4dOz99hnsRTfytKRj/zUmcj26teYeMvZ0
fhITvdF01B/7timKG9F1m5RJ2MtGq+9GXzVXwsJ+g+SAPbqMKV2KflS/Yhc6
080tCL3r1AMaemyR/Qj67qtJfoT5ZswPRQ8uaHEg7M+5cgC9hRrIQPd3ZJ5E
r9cQbUKfbFHWg/5kZaAvOjffNAadQ2ndjH7tJaUbnRya6IP+By85gfD+fy3Z
gp4YJtuObi985I1+rzQuCf3i5yhH9GfsVS3oUi8JHV2Qq3cG/WWw+Vb00/F1
TeitO9YT+nNiZgr6VK8uQv91SY4AXdv09k70XQv9LqBv1wtxQr/JbHyJnhyi
QegLKdoZ6PwFk53RZ6avbkAPaE/xQu9de/Yiet71CELvWN3FQ3dZMofQ91D5
l9EtKsWEfmNEeR26t9c9T3QzpeYr6BGJ7i7o0qb6WvRmfwdCr3j5wTX0qL5i
Qm9rr1CD/oop9iDcX6iM6+jnOcquhP1V7q9C1025SuhF6QNsdPMqT0I/dEpS
gX7IwI3Qyx5xvIk+xrlO6LkW2Vz0WydUCX2fNPUWer/tB0If/2z/U8L+RoXu
P/0fkTj7XA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk81Hkcx3FXx0zRGJlEcmWMq0KjyDUayvVo0IENUSTReLDF6sC2NLWj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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk81Hkcx/EZ1SKM0pItR+OYXNMQuXNkHKVckWFCbiHHzMSYMkyr1hBb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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV13k41fkCx/FjnaicW8icY4sxsmZ3ZSf7lmM7tkoG3WMJ2TIuZe/kkrhu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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV13k8Vfkfx/F7jT252dfJMldkqZSdLMmSfUmiLElZZogUIlHiIlt0MaIF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk81Psex3Eiu5DiIBRH9uWgshtbUdYJZau4xppS1rGFbnFwDcKktOBi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk41PsCx/GZLHFFKmu5mUo6hrGGQahIcW05eIwUOhTVyYSbpWzHlGwh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1nk41NsDx3GSyhKNrmyDbKFBilA0xtZki0KmuskSYUiLJUtuaLT8UkQl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV13k8VekDx/GLUOHmFrJLca8tyiQkXaGbpWRL2ZNIy9jGNlP65fK7YVrE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1ns41NkDx/GJonJJli6K5E7jXiqaCd0W65KipSyDEQkzhUwxopBV8kNG
+bmkC7ZVWrIKi18hKkZya1xKkWtNRBK1v98fvz2fv77Ped7P63m+z/me8z1n
vWeQI1OEQqHoLqBQ/vf0Nuuzv8CTMP9utYHns3N0+//HoxvS7p1tEfwzjph/
2PlBiXS763Mde2O7/xm/62+ypIH/qPo51PY58RaF/csV15Eu+pfkQk4M8Wfs
Pl2VA7+hPv2ZbCvxic13IqzA9zjpL7p+lnhzA5s7YztIZ74JbH0BfrtzoEoI
+C5+QuXzM8TXRFYwa8FX8fdfTXlBvKLyWrEc8M2GyTKLwNezDldngXe4stbe
vo1439oQvUbwDOnhftNo4gWJWQ/CwLdrZU6KtxN/XXU2ZxI85c9DCsFRMP+L
B+z3gT8QXXW9EvyDwnHPtcqk93OaM4tOEy+vPXZKD3yqQcIJVgfxM2fdODvB
J43qOAkjiU+fSjJdCr671/C0cifx+u4qw/7gS5UdtY3B+37uihu0JL2RpvD8
GfhS2pvSZPDJ9XILOVziV6pNuT8EP2Q6EhnWRXzrzMp3ZeCpMqr8mgjifxza
VJUD/kB6UobyS+LrciW4vej3i3CkwPs6/JDLBa8ktDWpA7+/tjdSdD3pBSyR
0YPhxHNtNRa5gefrVnr4CYjnhccLNcHXPzL+ofAU8bpyWgNm4KvjBDpLu4k/
xe5ptQHPb3Dro4CXShXS14CfpshczwevUxqnGwR+gek07cBJ4vMXhSz7akG6
ZriRYGcP8UmxsguSwb8qX6VUxCE+90LdPgH4aZ/k3l7wne8H95aAV1wSGSQB
PmtSZkkF+NML58tDe4lPcbFTbQcvEc9R8Qsj/qz/ZWom+Da3h6cl+4g/IB4c
9hm8vPOQZsMJ4sVYleVc8HM9VVtzwGuxffavUiF9Jm8jewN4/cKPxR7gXbIP
Thq+Ip7OW/VgC/itGdbCi6HEi89Wy+4AbxqUcr8GPc3r95/BNzqk8KZDiHf2
eNKmDp5+fo5n/5p4K3kxvTDw2u4fXNzBxxvWzi4G76rWcFkAvvNlvgUPfEzS
XZ3GYOKXaoVGjpmT/vnS0wZmP6zfX7qH74HPG7o8bwJeO7WMwQfvHhZp9B58
wJk12i/Ab3vPr7txnPjZlLDsEvDnA0V7g98Q36L/dMEE+FPGb06uAO/mVGxy
GbzuY432L+BjDcxDl6mS/p/VldLxx4ivYISqc8ErTx5Wi3hLPHV56TkqeN9n
N0/Ms4mvm+j18wI/Uj3T8g08bdjFzAq8R4j5rePgS+1Xi1iBZ0TXvOMOwPmh
tDuJCT4ylZs9yoL9Z+QxpgdebM4rcB782nVn46PAz6TftGaCt940pyEP3nYT
PfDkIPEqy6S0M8E78WyuvQoinrprR9HX7aS7qQd8mAI/xW5klYHP0LPJcQO/
XCk9th/8LXrzl6B3xOs9TvNsBS+R0rilO5B44yd++Q3gAwRil4bAa2nSKe/B
n6s09j4E3lDPWO4ueJ0L4Y/dh4iXb+DaLFaD71dppNAbQHx1wsnH6eD3OzAy
2sDbpi3ZrQLeVafYkQG+ULHl4WnwrTeK5KyHiV+RH/3RDHz9vZ5Fg0eJHyt4
vtAPfH+KkVkleJfaKHsn8OGd8tSj4EOU1H/dC97nYoS8/gjxV7qSGYHgZf/9
uXLSn/grhmGOpuB97WcKssFzfEy048Abc51KwsEXicUcUgXPSBB8kx4lXlz4
Oi8b/ImjJovFwT9ul8qTBP/bDWOFCPBm3pS+P8FzOlr/SD5C/NbMHoNpOum7
d/QvGAH/JGKiuRn8CwGvcB34pvr6mT7wrS3Z5U5jxN9QWRb+Dvx85JqJQj+Y
/5G8+QbwnnNzP1WD3/jXtbffwK8UUz9JA68VyqCXgI+S8S7XHie+gfdp6Qp1
0tUcbm5v8iVe5Hjf/SzwdfsUJJPBU9VpQir4BOfybR7gLWlyQfHgKTYWO7+A
r3YpurQDfNftfP/Jw8Qr7vpyKBh8xWSHr/t7uL9OhM25gFdUfVkXB960JTHa
HXy+sJz7CPxUxX11Fvi1P7/+URF87UNBrzV434LfftX6QHxH3wXZWPAbooPH
in2I72eMs0zAP/rF8l8J4EMUljzKAN+mGfC7Dfhjih2bVcAfNxbljYNXEtti
dhd82se6M2+ZcP9g/GEkDf4nHYccOyHxMvuUOXXgn8RkBXDBj7tleczSSDdX
YN29DV5HtIYrAP+KZcBcDd6su6p6ELxHemKT1Efi9+TK2grB81Z1Mu95E39f
0sKxFfx8Z8VXf/AHw8UHFmqQ/v2+tL8j+MxDe+WqwVfFTWxrAO/ekrBnNfiX
7CMsoRfxkjbqYoXglXnSaeoTcH6Lx4bogk+yy2RfBK9mPq1xBbzX4s6lUeBL
u9qDLMCX+wcf0QdfxhQJjQNveetblgB81DmXzU7gDVZ0OPM94f8RdX4iGPyD
9jXOmyaJjxF9+9QXvNyXWqNj4KP5ggxP8DkKxcaJ4MPl9xiGgw9zdJ2VA895
a8Z2AJ86YmQ2CH7gvB3zIngpg9qCMgbxd6Lm2HTwaZZTQbRPxLO8avxy8f2L
7Whu4B9w2ZlU8Am7zNtSwI+/YWy/Bz7woNNdEfAbb0xMKIAvadsdOAye3zQ+
WA/e28VWpMCD+OQUAXsJ+D5NbTp9injXCCXGS/DDA1VUB/AqOQmrZ7aR/slh
ak8y+FOiBbfHwE/mWOvOuMP+r2QOD4IvacpLHAB/zIHO/wb+xVQW5Sp4azf+
qzbw6yWo8lumid9ml1Ano0n65pioa9bg6103fX/0X/83m3qOqA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k0FOobB3DhpoayTGi0amSp6MpWYpQrsrXOsVRqiEq5iBRCcUUklL0U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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1nk0FHobB/BxKSOExpaQeW3J1m2yhEKpEW12Q1ITGgnZ1zuj7rWVRMju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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1nk81VkfB3Cyx7WEaDJ213bJlkSWmyWGLFmiJEvWdBX1IG5zZSueuCiU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1X00FPgeBvDxLi8jYu96yS7rTmMGWaSWKe9uhhaz2NRyQ90sMlJpmLxO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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nlUDVgcB/BXKq1KT73IUikv7XrSRkkvodEb0c4byxiSNr0iaSEx0USi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Hk4FHgYB/CRWsqQzRVFxjHkTI4HOcIaahrkGErEqJXWEbHS6ciw0rXK
lpRKinRRVDpsRGrDVlNyZdQU0kGo3U21z+7zbPt9//o93z8+z/P+3t/7/liC
ON+VExgMhqkUg/HPeWyN45S2Yrn5B3y9mCY/Djr/l8OHX5ocGej4mkdcSq9+
GXr5NX+3YXVnT0z31zxepvXWGHxwZsQ19AUnAyToWZtez0LvkaL+EL39wjlO
R8EPulbJMIb/9wX9jeuegL90/8U19D5bJlagd9rrZIB+t/jGs27wm/1sy9Bz
DFaoFYPPmbvMDb3Xoxeh6AUaTfnoi2eXJaA3nhGzDH2jOLG/C3xYZ6AQ/ahE
5iZ6PqMxAf2J5s7N6MXMc8noTV3zmMfAlwkqheg926q10UuMi1ajD+PP56HP
2p20D73sm1t3O8HvU/4zFP3OogEh+pYd3FL0C7eOpKGXj8n3R7+rb3EN+qr2
qGr0T1sdnNFba/tz0ac8Yvejr9Bl1KPnrK2TRr+wb5ob+nOO0t+WgD89bNuC
/k7GlZYO8Mri6nlkfnTjrdHfNbZ/jJ73NLEI/SkzA2v0sXsGA9BnHNTvRT/Y
7ZWEfkMZzxy9v7s4Ab0oUn0Avd30K97o+TtUjdDfla7IRa8cOWcIfcAxezP0
F53X6KOXSFUVo7+xPf09+uolyxTR207mstCnj9tdQh9hrT+Ofizgylg7+JyX
+zTRP3fJvIO+9HtjKSnwaqWfutHPXMXTQC9XKOpA36B+fBJ6vvaDJvQfw0LU
0Juzlg+gvxx3bDL6LJfRKvQWA9eV0Su9CXiPfu1zS3n0cd6sEvQcw6hp6Jt+
k0gdBx+eFqaIfmMyKx998Dx/RfRn6ucy0cuNWymhFyvWZaMXaqQooF9ULFBB
7yupUUHPG364Eb1q2j0m+vvxeZroz9f+pUb6J7JKQB/+OFAOvVS7WA/9dINx
dfRWoppV6Af1ZKagX5ceYYw+VtwwA/2HNx5hZP7GOmTRs3+wsEB/ZCxEE/39
A7VB6KP9W2XQx5mG2qAfaLqthd5ptawv+nOXxd+gT3X7aI9ewUBBG31budwi
9Bu/yBHPdZ3ujH5HoDkLPdOwikP6H+g1ieyPQr0relVjCx309W3vXNCL5pdM
RB8zWZaDPk5WTRe9Q+kFR/S3UhWIZzu/80T/7MMz4p3dX9mhV9fIlkYfnrWN
i37/6QI99Oz+XBv0TzmKxI+UdvHQF/7sqI/e1nSbJfr4hJIJZP+TX3ujV2tu
Ib7mVdcc8v9YcogvH7y5GH2qhw8bvYp6ihn6tgXDUuiHnKL80OtcrCd+uCjQ
BL393hLi08Z7/NF3HDEyQK/kHW+EPllVQPyYihkfvUOEkHjm1VpD9IUD+sQf
GgkMRG9o8Zj4QjNHA/RxbkMM9EkZ4UHo+2axDMn7bZfoo6+N/ZX4EI7XEvRN
+gLiP3Mr9NBPuLOX+NFg1lL0EVqFxHNCinTR2zTEET91ezfx6c2txEt0y3XQ
j/TwiOcGZAajr+z9RLxc5D0Wuf8Jc+J9BjWWod/znj0bvb/HVOJzqpWJ9/U8
TLwkn0u8ubVAG/2SivEvRuBPmamFoPd3iiZevf/WLPRMjz7iX5unEW8c/BPx
n/lOxHuZi4jXqewh/rp3MfFWFfVa6Etm1xMfP2oZir5qbQ3x2UF84vPGzxOf
oLSFeGuVVuKrO0c10XckHif+DrOO+FcpvcRvHj5IfOOKAuIv1H0i/o+eYeKD
En2ILyjeSfyjz3OXo7+ymWGEPi9UjvgJ8kLiJyYJiN+fJU98U2PzTPRFqZuI
X9+QS/xutjrxKt35xOf1JhE/c0sl8ZJ0XeI/9q0kXlM1jvhIloj4vFoT4pVd
7Yn3koki/onmO+JbPloR/zlQifgzhyOIf9DODEO/0s+B+MXHh2agl/o9lPic
s3rE6/W4Ev/k4j3ipTOXEi98a0c8u8qTeAu9auJtKvjEb+1dRDxrgEc8e8dB
4k96+BG/vSGE+LJcX+JPH80ivsvBh/hDomjav7N84lvVEonPEPKIL3JZT7zP
8qXEbywXEJ8yg0t8u52Q+O7SEOKf6vgRv3vEk/iG57uI1/8ljPidC9xp/TIe
xMdGFRCvYBVB/PUhW+JFPu7Ev5AcJT46eyXxVW9Mib902+1f/zcroHgd
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Gs0FGgYB/Bh3A1lYm2NQm6VrdzKTotKqc1SubRFpptIKJzqsJHWaRDV
mhC5TDSlIrWZTNrN0eZI2jXoSuMyx60YuVRUVrJnz57tPP9P7/l/+H143+f/
Pqa7IryDlBkMxkIlBuPf80XDB5/uIu0VjhXDAQZxA8v/z2ESGz2fBtmXvPKq
t2/ogOJL5oddlISltn/JnfrcH6m3TjpqR/25lSU86vVL01OoH27etpF6947j
G6hvs2gMot7nhlUg9ZWVq3+gvuRjSwj1A6V94dQfGipeSX2+8eM11JvpK+Kp
DzCZeYD68CvR5tQ/S3zjSr1utWU69bq742Oo9+tgalMvXyJYTv1U34CI+uQk
uyPUi4qejIYSP9ImdKI+MzG1jHqZi0cC9drNsZ3Um69gLaM+33ZdFfWb/eV8
6r00C5qor/vQ4Ej9eEzQQ+oXG00mUz8qHbhHfZB96xLqjZgGT6jvEpSnUl9u
xZFQL0i0cqB+8ExSK/Xtz9mnqJ+0Hy6mPuDWVTvqH33o6qJezjNLo759yraQ
+it5O2ypLyj37KfeYc6IAPp3rDyb+hPvl9tQb/WwdwjmV5eQTr2iylNAvdmm
1YupV+bWvqP+yBt5BvVuoy9SqN/4MWQR9T0CtY/Ua9jrnaFeY4LLp76msngh
9RFb7kxQL9jAyaJeUOx9lHptdSZ450PvP1M/14OZTf2QFyuW+pniqG+oj0l4
oORLvFKKFHzGBu9o6k0Z76ypVzN0UqH+4fMjZ6lPu8A+SL3PKT74zXo71Kh/
dtwwh/rHQuco6v1Wm4Pn1zprUL85UQje6fT9/dRzfZsWUH+Y26FJva8PO5f6
gtPnwqkvsEoGv9RtnTb1LZYx4J2WVYVSb8dbC76pOpFFffZAE/isWM5e6l/+
MQ38+ZIcHeqd18/Jo/7niOt7qLdZI58P+9MmVZf66Jqd4FfZRwZT/15ZAj5Y
vnUa9bqZ+eBZtf5B8P+sBeD9StjTqf/c0gje5XXIbuqlrEjwAhUx+NbUT+BH
DLICqZexfMGfHHbSo/5wglk+9Yx1HbuoN7j4HXgTrVvglX5yA9+r4wK+MMAS
vIHQmA3vbxAIXrZNvJP6isYZ4NdeigXf0hsHfnvOt+DrLjDBz+r6C3xTcAZ4
/6iGHdTfSR2bB/vzqd4M6lVUL4N3fxkFPm5FP/hq6XrwDsa3wTtyTcGLUzrA
S8eOgR9VfwD+bI9sO/Uiu2fg6z3E4F3Vn4J/lCkEb6MrBX9CLAPftVUOXmoa
Al577D74WYpJ8Ced+sGHp3DBK2rugj8jNNKnfqzlDXiRYjr4we2/g3fY6Qj+
uv84+K0Jg9uoVyuVgHe6tR78RO8U+ERRA/hj6WXg3XQCwUflqgqpN//tJvjM
qWvg8+sOgi/M0AJvtyof/HhnCfhmZz74lH5d8Acbk8FfXnAFfE7FafDGZWzw
hhOHwMfVF4HXiBaCF30yAK8eGQxep/IC9rf8MvhPrV+DX9i9BXzg8HnwvqIb
4NV4HPDcGZ7g63mF4GtDb4NvOzEbPOuBK/ibU+fA37W/C17zgDH4vnou+J8b
hODHZt8HX8UxxfmN24KPqMkHr7LmT/CTp+aCf2VpjfNrywPfWNMAvrrJDLyX
gwV4dzb6v399DN5EYQ5eU9UEvOquXPCJs56DD5NbgH99lAPery4H/Fv9F+Bd
JZbgF6UZYn9c0WdeawVfGmEFvslYH3ye9Czef6Qd/GL2PPAOpnrYvz3ov1LI
wbcWoH/F1wWvPQ39PlEneB5nPvjvXVjgr97LBu81txv7m4ye56oFnhuPfiSy
B3x3D/qiZA3w4avQX8vsBV+xdAH4i6rq4OdPR8/IeAmeFY/eQqIK/nB3Fnhx
5Cvw3Er0LWkq4JMq0Y/Z9oGPeIt+joAJPi0XfYwMvdjUGvdfmTL4sTj0m/b1
g+9xR988pATePBB92CD6xv3o97qhv+SBnslTgDf6Bf29MgZ4LS56zyr0e4rR
K9uiH7H6z/8Dt1BF/g==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HtUDnYcx/En6mg9j9JZSFu6sFhE5UzKVFOWEc/cWZNM4tH9IpFSYiqm
G3NZSro95aHoovAoyjGztJ1yexRLYlHHpVXMxs7O2Zzf21+/8/nj9cf3ez6/
r8U3wfNXD5BIJDZaEsm/r77NyUNPCqWuunNvtqTEP3b5P3ckfJlsXKF5m2tn
PMp0e/DobZ5U6VB6P6/1bR4Srbgtek/fkDTR95f0ZIn+flt2gej1+201ordy
3rpP9Ea/lxwW/YXc8CzRF56yuiV6tfR4pug7vayPiN5nTMw+0bu2u90UvUXL
0BzRD/0xIFf0qtTdaaK/k7v1hui3ll3PE/3EqC15oi9piNsl+irJneuid5n1
nlL0fjGKfNF77LVPFH24eh78jZILxaI3aLUtEP29nTu2id7FWXNN9GnXjI6J
fl6VBj4ncU286A1CIuBLtQ1KRN8e6F8o+g196ljRLy83hR/hdq5U9G2VD+Bn
e27cLPrHjU3Nojcssjkp+pk1cqXoKw4kbxK9rGUPvHexX5noNU5F8BmjO6JE
b+a0Aj59YWi56P+M7IXvNordIPrORDv4/oSFFaI/q5hcJHqtCZ6Roo/6QQ/+
tyHDKtH/c4HwL1I91oveL7SzSfSWfafhe+5lwsuTFBGi97BtgK8J9TiF/sgu
wtf6qMJFrzOyAr7HvAY+ye0hvL+jFN4o8zC8zPijKtH3KbSLRd/eHR8m+lWj
UuD390XDZ7iYwv/RK4Nvc42Dr3pxEf7ZGnt4R3lRqOi3pYfDt+noVIs+MMgd
Xq5YCF9fvxbeV+0Er768AH74UBl8TOoK+Fdxa+F17vrA20VeDcH9r17C/cem
wIdoB8D/1HcAvllvHnxkRSn8uoT18LJpgfA/L5sN36XVAB99MAZ+g6UH/Ka4
z+FbTTvgn8Rug9dSWcE/8Z7O+ZUv4cd6J8N3D5TC991y5v8ZIz0t+ibvFHjD
iJ5g0ftopsJPG2IC35GTAT9p5V34QE9H+Oo6K/gQt33wph5X4T3NHOB/2WsH
7+V1EH5qRQ18vvsn8L82OMFLX2fCx80ug59ROgneTzkdvvnTbPg5VUr4+iX2
8J7LvoDfbpXD+1GRDe9mbwefLZPDV146Av9Mdz/8lCm28JqHC+Atx+WxP7Fp
8HarJsLrSZfCP12WD6/u2glffmwCvCLNC77TqwC+3GYHvNH79I7p3vBlDoXw
CZYJ8EtTbOAdLFbC9zyn31O6BX6kGf1k+Sr4qHQlvOv5zfDxNePhM61Xw680
KYI3/2wTvDSIPq/GD37cbvp6syj4grH0KuO18I1P6cfLI+G/7R4HX+CsgNe4
F8MvrouAH3OGfoTjOviIXfQjwsLhp6XSR+n7w4dfpm+cHwZ/zJ/erZ7e/296
Pe9Q+ERPetMVAfAnPj4Kv/27EHiJPf2gdvo1cvoHt4PhfT+gD1sQCJ8cTJ/k
Tj9Kl96mjL4zmT67Lgi+ut8a/rJ2ELzzEfozi+jPdtIvnkVvVklv8iIQvqmV
fvd2+sGX6Jcr6Y830b85RR91jX69L73eFfree/QX2ugzrOlVdfTfDwqGd+qi
n/EyAN5PTX/Jin50L/3MRnr9KvqvPqM/9xd99FH6LWX0A5fSOwxUwb/eRZ9V
Qj/Hn/6sLv2bMPq5KvqL0fShg+mbv6aPLaI/n0QfYkg/YBa9cSH98b30t4zo
nzvSD86nv55NXzuc3mM8vTyXPk75Tn9M6A+Z0zfn0LeU0C/6kP7EMPq0w/SW
lfTmI+ld9d/Zfzb9xjP0SjN6vUH06Vn0BrX0veb0jyT0Vw7Rd9XRG1rSl77y
h7f4z/8DNewj+Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd0ns013ccx/EfS0ub3PabsV+l+sUhKYXorENYqbEoaUfWDqZMInayNrdR
dHFtqq0jusxZflGabi7HVrq4plxqRUhFCZHUWXSys3O2zvf5+et9Xn88zvu8
L9P8w1YGqstkstlqMtm/1SU55NGo6j3H6j6j1FNJvQ7/562no2NSslve5omL
Ri9Fdj55mz2ffGJSWN72Nu/vbEiRet2cx7FSv3py4GWpV71YrpT6bsN98PIw
gx+lfsC2HP5KVsF0qc9O8odXBenHS31n4vgrUr+4adU0qZ8Wbgc/pt8F35/o
DK/21NpY6reGyOG3JGcmSL3CNRL+wfwlU6W+3/XvZKmfVazcJvVHtx+GT0qL
myL1NzTvwesmZsNXqS7B2zu3TJb6O3dr4a9pqm+X+i8e34OPLfaAn6RfBj/j
5Gr4Z4tewSd82q5Af6MT8EFLs+BzYrSuSn2RZhy8XtQR+EVWN+FHvKfAK2vn
wPfU/wz/0E8jUeqVvhbwOS39H0t9dEU6vGvUbPiz4+3gF74+Bz+mvQve9M7n
8LfKFsNbee2CXxezDb7tYDB8yfVl8Du8A+CdWmLhHc7Hw4fs9IC/UOIMH/nm
B/jswb3wC4294U9vNINPqPoOvnQgFz630gfecac+fJpiC7ybQxG8xrF18Fme
avBhDyLgK1aWww93+MHXmA0ZSX2HZji88e6r8H5pX8MHpnbBN8aFwa+1qYdP
qV4PL9duhR9YEAo/uL8ZviE3CP7aqkb4j0w3wS/tvgPvNjcYvkq7Fl7bJQR+
g2c75/9+I/z7467Az9yxET7rTSe8bXIIvPnrP+GHeoLh67S64HXDNsFvqyuD
V26gjznwCL7AIhT+kkcx/Gcj38BXn++Bj6ihLwk+C196iF4tqhe+2D0MfpXa
aXhfL/q4oT74F6X0qWOn4PPk9F3mT+Fb5ZvhJ3oVwm/tDILvthyAj/OjXzZ4
Al7rHL3du4PwoYfp3aoK4Pv2CL6Mvq6ZXr0xH771W/pxns/4v7Jw+Aka9Ld8
6POv0ecq6aN9jsNrLKH3sxmCb3KiT6pTwRdZ0/+eTD+wlj7Um97VhD6+ib55
M73ZcB78ciN6R+3n8NYJ9BFH6Vfo0L9ypC/IoA9cR68+gd4rmP7MQfr6mfSG
avQXU+hLfqMvfHkMfs3oBvhwFb1eIX3IdfrUl/TuF+nVz9HXnaT/aYh++k36
yjL645n0TgP0v3bR771AL4+hT+ijX/OcPv0yvW8wvd0T+j/e0N+vpC/1oV/x
mN5pwjD8sRr6M+70xd30ljr0L+ro25zo13fRV3xI31FPf9ee3u0hvYOCPvIG
vf88+oAH9FXG9NUN9KYW9Ifu0x9Q0nc30vea0I920teY0jc10WdMp98i+EBz
+n3N9LKp9BqCz7SgX3CTfryCPu8efYAlfbngMwzp1wr+/hz62bfo4w3oFYJX
WNHvEvwNOX13B73ZPPrbgv/yA/oSwWvOpzf8i36WPn2m4K8KfoXgLfWE+wve
15o+SvBf6Qr7F3y74I8IPl+H3kXwHjb0FYLXEfw8wasE3yb4Pdr0MwQ/LPgh
cX+CNxD8XFv6d27Tt0+i1xK8v+D1BP+L4McJPl3wkwUfKPixdvo8wZsI3l7w
I//5fwAQNA0x
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1FtQFGQYxvFdjORgtMKG7KaCCWiC7IIwqcRomBcV2OCNmYcMh9nGBoyL
pkEk0pAMGog1l2kg06iYJZMkJhMIKZghToMIyEGSiMMu7JLJKZNDTRcx+3/v
u/Pqm+fiN/POe/jWxB/dneCkUCg2KhWKf9+U0cBQl4vu24vC15VmZtu2/ZfP
lpSmJLzXu5hLViYap/rGFnP5UtVBdecvi/nhAg28S84kfJnuBLyy+vIBRx+U
6wG/vGzDMUdfm5YHf2l9AnysyRk+I3UP/LKqc/CVU4HwFTELlxy9R18qfFWa
Gb4zaWq/o3/z1XvwE4aP4fduLYMvSGiC/844CZ9ruAw/t/sq/KyqBN7zqzvw
2cN18Ce9r8FnLeTA+6fb4U9VdMD/WVcL/5YyBd5sG4V/xzQAf9hYD38wwADv
3GGBj3WxwzubG+GvF70EP+03Au+aMQUfFtQCn3MrBt50bQh+zjAL3xDeCl/6
3A74vPOD8FcVylRHn9x3Hb7p3Uj45Cu/wR/9wBk+O/wGvHFTBLzP/QH4c1Gu
8K4x7fBtnnr42EP0cVHL4N11HfBnrEHw8YO/wg9c9IBPstBnZq6Ht6fRv1ys
gtendcKvrg+AzwiiL4/2hL8xQ9+WvZbzt/bDt3zoBf/J3pvwjZVr4LeU0Qef
V8PfMtOPRPvBqzLpC48/Bu9mo69S+cKHxdMX67zhZ3274L18VsM/upPe50f6
+efpPXetgjdspNc9tQLekkivLlkJr9fSa/Lpd2bRd/nTn3Gjdx2mj7tAn//9
4/BD87e5f/4+7H85ffEh+vxJ+ro99FG19M9q6Lfa6DNO0Jtahe/Xwr8xRP9a
EX1BD33EN/Tjt+nt1fTVA/Rz79Mn99Lv6qQ/YKUfPELffJM+3UL/wzj9F3H0
3e30T8/QayfoA6NE/W30kU4a+M+n6TOD6d9upZ9xpz91j17pSz/WQt/lRd9z
X9yfmv5CM/12LX3NHP0T7vRnm+iP+dK/sCDmt4S+opG+Zi197t/0d+c18G7C
h6yjNyq64UP/oj/eQD/5JP1hJf2+afqlwkcG06uc6EMm6M0/0y8PoS8UvvAO
/X7h83T0jyyhzxqnXyV8s57+iPCdNnpbvfi/Qum/FT59jP4n4Y1h9H8I/8oo
/afCP7OJPuAheoOV/qTwbcK/KPxnFvpE4beE0ycJrxJ+n/AfCX9aeNMIfazw
vcIXCr9Z+GjhVRH0XwtvHabfLPwO4SuFLxZeL/zrwtcLnyT8BuFPC98m/Dbh
/YX/Uvge4bXC+wlfIXy/8PND4v6EbxB+SPhh4bXCdwtvFb5d+BXCW4S3C18j
vLfwduF/F/6K8GrhZ4S/K7z5gX/g/wf/D/e4Vg4=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt00lIFAAUxvGpg0TqJGkulLSQmto0iiZTJjNuaUmYS2laUmmMK9oqGpSE
hhYulePSYhFoajbkboVIWRmTCgm2iCWJB0kNOoQFhdEh4f9u3ef0+A6/y/ve
W380O/rYUoVCoVqiUPydxrDP+XZGS91Q6fA954oZ7b9s0Fo3Zp4YW8ztNUX1
re+/LObGum6XiJmPi7lOPQjv6OAEb3ItgY/71gAfG2mCX5q3AX5i/jJ8y+Na
eNPIK3jbaXd4L58y+Mqgcvjw+gH46ddq+PH5cnir+YvwKV0v4WvO+MIXJl2B
L08pgF/z8wW82l0D35p/FT5XfRZ+YzK9ysEffizxGrxmRS581Oxz+LS0AHit
shI+wXQS3rOMXqvTwlffoI/wOQ5fGUwf2qmDN1ga4L+6ZMPnL6MfHQ+Ej0qh
by7Kgq//0A+/fCAI/k4z/Tv/TPhLHfTXC4Lh903SF/plwLtW01fZhsCfVlbB
F+nT4cfP0yuL6TO96Qv60+BTs+jjpujX7qGvCKQ3JdHnqELhVybT14ylwvvG
0B/R0+edov9eTG+xm36XgV53gT4mnL4viN74iH5zKb3DKvpfO+jPvaUfMYj+
ZvXwWRr6iDn65pv0GYP0w770+gX61Xfpp9rov3nT91jvhNc30D+po7+vprd3
on/TRN9dRv9JRe+wgb6whV55gf7EZvqt7vRNRvqFXPpIT/qpLfQHH9Jb5NBn
eNDH+9C3t9L3ptF3u9OP+9E/baM3pdC7Cd+yjb62nX70MH3XJvpJf/rgDtHf
IfoE4R8E0A8Jr06kXym8vZZ+eye99wH6MTd6lY6+TPiGOPoHwisDxf0Kn7mf
vkT4Z8JbdNGf3Cf+X/jIIHov4Y2x9PHC9wi/V3hH4cOEtwqmTxf+dgy9Rvg4
4QuE1wivEr5c+Arh56LpXYTvFv6W8A+FdxZ+QvhG4c8K7yj8D+FbhY8S3k7u
P4S+S/jtwtsIv074XuGdhFcK7yF8n/A2wlsJ7yt8v/C/o+gthdeYvdmbvdmb
vdn/h/8DbwLNoQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1E1I0wEYx/H/EgJRkwTLjNRJshgMu5lhVGBCSYcipJIsx9zcxJUIi96W
Oc2cL8teQFxFW1gUYSYNSgKJBpEWKNissFkOipRe3DI8jejQ4PucO/5PD9/D
5/C7PFrj0b01yxRFMWgU5e+N9HuDeYMp25qy/EXOK/Nb/7Ur6/v88ar3iR4P
pWzpn5xLdHmfvveMEk70UsAHn7/8J7y2PhV+6Z0OfsZKf9i1AF/0iT55uAB+
TSH9xN0o/OzmNPhI5nr4IQ19WVcMvqCJvnIiH94XvgkfK/kFfytAHwhp4bue
03uD9NEwvS6T3j9AbzYswk/H6a+fzYM/eYN+v5O+efUK+NxU+ngP/exT+m49
/cehXPjKC/T6b/Tbi+kVO/3XJnpHxm/4a6X0Y5voN5yi31VIb9pNfzud/rGD
vnUHvX4f/dyPHPidjfRPKugtB+irpuj9x+iTTPQNh+gbgvS9dvpiO73nCH0o
QJ9UT69z0C8Z6Tvu0b+soy8/TT9lon/ho39rE/vP0ZeZ6dO99DnC32mhN1ro
p6/Se6z0jW30JbX04R56rfDedvqI8OPd9K9q6Us76M1WelsnvVt4Tyf9mPCX
3PQVwl/uos+2if/RTm8Qvrqb/qDwsTb6NOE1Hnq38BnCL1roTwj/QPia8/QR
4SeFHxX+cyv9G+GzL9LPCO8SflT4PcIvCL9R+GfCO4WPCx9toR8W3id8ch39
iPCPhB8RfqXwfcI/FP618KuEbxZ+QPgPwq8V3ib8feG/CL9O+GrVq171qle9
6lWvetX/F/8HfjR0TA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0j1I1HEcx/G/p3eJZ9dBIdIgKohRXWGLIGrHRdyQU4JDk0inQp031NDQ
kGJIlkrQcBGG5FDUoAjiEpKSeOczSlZnT5KUj6gp4g1H4tDB+7O2/qYfn+HF
e/j+8mpCVwM2y7I8KZZ1+GanVbk8fU7vzsiQrye8dvHf7kqx59ZeiSX3+77v
tyMzq8l9/G4oNnHiW3I7B+iDFfSxKP0RN/2HN/S9zfTFC/TDgw3wtd30th56
/zL980Z6Vyf95yn6k3/ouyvp/WH62V/09+L0tiL63if08/v07r/08Sz6xGP6
GocDvjz1B3x9Kv1uB33YTR9w0L/aDcIH2+l92fTD6fRPV+j9bfT2HPrWDHrf
In39I/pAPv2Sk34zRv/uofy/AvrfmfQX5ul94gtP0b8+Sv9iln6pld46TV/q
ot+bpu8Uf/2M9MXvTNLXib91lj4hPjRBXy7e66EvO0Z/aZw+V/xH8TfE3xyj
zxB/+Rx9u/hIlD7+gP6Z+JfiK8Wvi/8i/q347YjcX7z9PH1UfL/4r+ILxc+J
vy/+k3iv+AXx1eLnxF8T/1N8ifhp8UHxK+JzxE+KvyN+Q3ym+HHxTeI3xdvE
j4lvEb8lPjFq+qZv+qZv+qZv+qZv+qZv+v/bPwAguO1O
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzty00ogwEcx/HncZN3tSK7cGCaXaTVc0LRFqVsll1Eq11GpBxJs7XMntm4
qZl5mUg5jHZzERdR7LKi1FDETW4UOVj9fne3/+nb9/Bp9Ew5vCWKolhURfnt
gKfarR2XdU3sBJ3ZxFvn3/t8yZRRuy1+s3/t1HD1Wvy9Xmvcabov/vAW+ocZ
9ONB9KNW9Ncp9LFZ9Dch9K1m9Ecb6E0L6FcX0X80oS8k0dtD6O/C6N+N6O3s
w+gvl9Drdejz6+j9EfTzEfQ2A/oA+ZYoelVH/1yL3kZ+aBn9GHlzDfoG8u0x
9GnyL1XoPxPoc+Tz5L8r0T+S74+j/yLvIJ8jv0m+Por+ogL9OfkC+Tby0+RP
yJeuoNfId5DPkreQ7yGvks+Q7ybfR/6pHP0heRf5QfJn5A/Ie8m7yGfI75Of
JO8mv01+l/wc+RHyOvk0+YB48eLFixcvXrx48eLFi/9X/wOi+1FE
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzty7FKQnEYQPG/gSAE91rp2NDkdCfdGnLJB1CETCeh0Sv2BGIFgkubU2W0
FriUEUSXqMFKIigQwzYbcjB8AnHowndeoOWbDmf4rRXL6Z0FY4wTMGbePe/p
dPNqMdmJHk6brfHG32e3rLOD2MD/dKl6VO/++F+Lxvdj61/+78K3c9J78NUV
6ZPw59vS26709rL0q/CFvPQpeGtJ+iD8B7wLnwlLP41InyhI34B/saX/hq/A
n8CX4Yfwx/AX8A58H/4a/hI+BP8O/wx/A/9rSf8G/wl/Bz+Af4UfwT/A38P3
4Cfwj/C36tWrV69evXr16tWrV69evfp/8zMH9Wik
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE75FpfB+7gdhA04X0SvuS1PYz/rGU7X7/YLTj/
VlW4o+yxV3D+PXve81G+9+B8TjT9fK2o+p+h6V+Gpp8ZTb8umv6PaPqL0fT/
M0bV74am/wea/iA0/X/Q9Aeg6f+Npt8ZTf8vNP1RaPr/oek3Q9P/E01/PJr+
/2j6DUftH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0eo/QDU
zZmz
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHvauxN43ZxO7y8FRX8c/lrexhfiKdhlSbbLTg/
7tHqpguHXsH5C5lervwTd89+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qH566gcAjkgEVA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHKt3/WZe3hdljO/+9T3erX9jC+8LqPTR7fbsL5
LTuerJu//xWcH8/sziFVcM9+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qH566gcA9V2l2g==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANERlltOlO3jdnjxvUzk9brX9jC+WF5u+YNnN+H8
zz9zSzr2vILzty6/wLWv4Z79qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/q
H9U/qn9U/6j+Uf301A8At6DWCg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG90/OEmg9wO3Dpxeyy3/TaHsZvb/r26Pn1m3C+
pPncCx07X8H5i5V7wz5NuGc/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VD899QMA5M7sbA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGHvmrE9B/idlhuGLqsbutrexi/SO1RRNjJm3D+
BuXtjPO3vYLzlVYYRuxfcA/OX4GmPxdN/3o0/epo+kftH7V/1P5R+0ftH7V/
1P5R+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7WfGPsBuHY/Wg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE/gh8vnX2E2+FcLk/Kyh2v7WH8V4EqBSq7b8L5
HRP+Vp/c/ArOX7XqSoXOhnv2o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+q
f1T/qP5R/aP6R/XTUz8AxTuDzw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANOb5r5ffozbQSTmbuDB3a/tYXxVubaZ3mtvwvk1
HowP2Ta+gvO/N2x3d9h/z35U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP
6h/VP6p/VP+ofnrqBwBMzYTd
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFJAhGWW05wO1gKnV5+fN9rexjfdoXiv6Pzb8L5
+5tW/whd9wrOr647NZvh3D37Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/V
P6p/VP+o/lH9o/rpqR8AivOoeQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEz8oSaD5zidogSU63de/C1PYx/ZoZFSt+km3D+
Zr6Zq7eufgXnT8u5tq7ozj37Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/V
P6p/VP+o/lH9o/rpqR8AVCAs6A==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFnz4AAt8OEftWzi4+8tofx17b8lljQehPO91au
+aey8hWcf1hzq/HsV/fsR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+qnp34AZJEdhA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFM2u1iN89xO0z9cKCq+vhrexi/4aTxvW8VN+H8
gC0+fIuXvYLzC84uz6j7cc9+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qH566gcAC+K7CQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHmnY4JTy9wO2ydcjHY9dRrexh/ug/z7b6cm3B+
/1UZXv0lr+D85hfT1BTY7tuP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1U9P/QATT4T2
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE5z3+v/HiJ20H0yn5hprOv7WH8C6Wy/SkJN+H8
4mUF9icWvoLzf3fdfNssfN9+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qH566gcAjVnc5Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGLXLd9/nuF2yF6x/7UTedf28P49WYMJ0pCbsL5
WXMZfuXOfwXnn7H582GNwn04PwZNfxWa/kw0/RfQ9I/aP2r/qP2j9o/aP2r/
qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2o/MfYDADtCmL0=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHXFxfYcl3ndnj2e/uzsEuv7WH8/2nnpu/xuAnn
b+i4NF9+7is4X3vBM9l5uvfh/Kdo+lnSUfVvRtMvi6Z/1P5R+0ftH7V/1P5R
+0ftH7V/1P5R+0ftH7V/1P5R+0ftH7V/1P5R+4mxHwBoNFp0
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE8TNrtYje5HR5eeaj24cprexif7UKDr6XtTTjf
5PDMBXdmvYLzszJWqUZZ3YfzH6Dp50bTb4qmPxVN/6j9o/aP2j9q/6j9o/aP
2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/YTYz8AArJU/w==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGOCU8vKN3mdrj/QHd13fXX9jD+5HqjvBeGN+H8
bx5B5UtmvILzeVjNmx+73bcf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qp+e+gGzRRsc
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFl++ZL6d/ldjAWrnjHdOu1PYyvdTli/XG1m3D+
1hM8K8umvYLzU6crNtoE37cf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qp+e+gFxSmHp
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFrZKJSrO9zOxxcMCmp9s5rexif7+yBj1ekb8L5
sjseHw6a8grOz5u73C49/r79qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/q
H9U/qn9U/6j+Uf301A8A4ryrXg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEPq0TWuT/kdrBM0yt8d++1PYx/oMLIlk/wJpzf
/FYozmLSKzjfs5d7S2r2fTjfCk3/bjT9jWj6g9D0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj8x9gMA1BNvwA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFiN899D37M7ZAkvqwm7OFrexg/+vKCPYVsN+H8
pQU6ouoTXsH5Z96kbLMsv28/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VD899QMAfmCiiQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE+5p2OCU+5HUymbXiw9fFrexifU//irr+/b8D5
7cppvXJ9r+B88Xc/fj1pug/nG6Pp50PT34GmXxhNvxGafmE0/V1o+rnQ9I+6
f9T9o+4fdf+o+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3j7p/ZLgfAFZu
61k=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGNU527c55zO/Tx//vE8+y1PYyfuSpj/oaPN+D8
LUv/FMj1vILzvX/oSGX23Yfze9D0F6Pp346m3xZNfy+a/jw0/dvQ9Dui6R91
/6j7R90/6v5R94+6f9T9o+4fdf+o+0fdP+r+UfePun/U/aPuH3X/yHA/AOd/
VRI=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHbPv+9UvGS26H4wSHmmBev7WF8LbvANx3Pb8D5
ovkr8tW6XsH582cqTjo+8779qP5R/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/q
H9U/qn9U/6j+Uf301A8A/HDuQA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGvA3fItb7mdqg6YRS3+NVrexj/sVOWdevdG3B+
0lwlO7OOV3D+N0amk4xL79uP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1U9P/QCoVhB9
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEKG4oyJr7ldjBtf+fx+M1rexj/gUOVzZLLN+D8
e2Hbp/q2vYLz64yE+CU33Lcf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qp+e+gFmr+vX
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFhfLqb5r7nduhcl8om8/61PYzfnBe5+cnJG3D+
ze+PjXNaXsH5z+tbFvDtvg/nt6Pp70XTfw9N/wU0/R1o+jvQ9N9G038XTf+o
+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3j7p/1P2j7h91/6j7R4b7Abu7
8rc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHdOc9/r/zI7XCv/f/NiU2v7GH8jLWyyx8fvQ/n
z9PVu+r78TWcv2aKb5nrgRtw/i00/VVo+uei6d+Ipn/U/lH7R+0ftX/U/lH7
R+0ftX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7ibEfAE4FA+U=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEHTi103faZ28FO+43PvoZX9jD+85trrWdeuA/n
G9wP+lDx+TWcb640Mefothv2o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+q
f1T/qP5R/aP6R/XTUz8AVed3hQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHfNGL6D33ldvAvvxDyse6VPYzP2JWcbnD7Ppxf
bTqrf+7X13C+tCJDb/LaG3C+D5p+ATT9VWj6FdH0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj8x9gMA7ypWPQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHa7WI3z33ndvDedn2PVu0rexh/Q/xflVVP78P5
et+OPt/9/TWcP7P+2R25JTfsR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U
/6j+Uf2j+kf1j+qnp34ASvod0w==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEJTy8o3f7J7TDR60dQVvUrexifIfNeIvuH+3C+
y/UzWld+vobzfxx4nfdt1g04fwqa/o8ZqPpd0fR/QtM/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/av+o/cTYDwDRG7u8
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFTnbtznv/mdvhSs//5+spX9jD+yQyO/x6/7sP5
uzbwdTz7/RrB3yKR9HLiDTj/I5r+a2j6d6LpP4Cmf9T+UftH7R+1f9T+UftH
7R+1f9T+UftH7R+1f9T+UftH7R+1f9T+UfuJsR8A0FVwrg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGnFrpu+/yX2yFVUsnvd/krexg/oPX/C3OmB3D+
zvvNOp//vobzU5y/PPjWccN+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qH566gcAibLBYg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEQwONwJSgw2qfslT2M/971dJAd+wM4/1XSC6df
/1/D+U1HtijINdywH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6R/WP
6h/VP6qfnvoBuSZPHg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGmcbs8eZh4HDjKJz9bVPLKHsZ3446QteB5AOeX
qD3+/JvxDZwftaQ5Ia78hv2o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of
1T+qf1T/qP5R/fTUDwBK36EJ
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFZe0omS7DwOCRzK5z8V/TKHsb/dq9oiargAzg/
4Llm2g/mN3C+aPrFF9vybtiP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1U9P/QAEZOgf
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANELpPTvqrDxOHh//3c3vvCVPYwf8XKyPbvYAzj/
NMeife9Z38D5O0J2cKmn3bAf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qp+e+gG802Pq
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFXK16qGXLwOGzNecV4LP+VPYy/u03N6a7UAzif
bU2dwiP2N3B+s1+O/LrYG/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9dNTPwA9AdF1
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFc1xcX2HLxOMh5GAsb5r2yh/HzC0//Xi7/AM7/
6x+z9jznGzj/VNW2du/QG3C+NJr+MjT9f9D0n0fTP2r/qP2j9o/aP2r/qP2j
9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP3E2A8A14eNfg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH2pnG7PHl4HC6sXP5xQc4rexj/59SpO9JVHsD5
ehZRrTu438D5D+ZUr/7nc8N+VP+o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1
j+of1T+qf1T/qH566gcAw2jcvw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANElkyVYwvh4HCZPrK4TzX5lD+PrizodlNF8AOcz
XzQ8Pof3DZwfJ+Dz85jLDTh/Cpp+HTT9LGj6I9H0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj8x9gMAIuY8TQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGrPl7yTRLgcWj0Np7Tl/nKHsaf9So7+rjuAzj/
mZPPhBr+N3D+rpo/Txfb3LAf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qp+e+gGnSguL
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH3/Xun5wnxONxs6tfjyXhlD+Mfnrf7ZLrRAzi/
IP7an3DBN3D+ggK3N1NMbsD5d9D070HTX4imfzaa/lH7R+0ftX/U/lH7R+0f
tX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7R+0nxn4AhfOQFw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEi69wfVonwOLy6XCXVl/bKHsY/lSTs88/sAZzf
y39ZXV/4DZxfpVXQM1PnBpz/Bk3/UTT9fWj6S9H0j9o/av+o/aP2j9o/av+o
/aP2j9o/av+o/aP2j9o/av+o/aP2j9o/aj8x9gMAIFubnw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFePEza7WI8DoG7friKpL6yh/H3vdgu3239AM5X
TtXRZhJ9A+frvfjlvVHlhv2o/lH9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of
1T+qf1T/qP5R/fTUDwA2fQCN
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH1WXtKJkvwOLzbIzpjXvIrexjf3qmsns/hAZyv
l39Y/qLYGzi/QTN8622ZG/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9dNTPwAX9fB+
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFbTpTtmy/F4xC5+8YPnaRX9jC+FOfxxR0uD+B8
xzd1snMk3sD5f+PmhUuI3rAf1T+qf1T/qP5R/aP6R/WP6h/VP6p/VP+o/lH9
o/pH9Y/qH9U/qp+e+gGPQd6a
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEv1Qw51sjwONi7mAbuT3hlD+N/4nl/6KfHAzhf
+0uEdbLUGzh/aV/gsTTeG/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9dNTPwDqDFpc
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFyra8Dd8jxODDf+9cVGv/KHsY32yMrmOT7AM4P
XZ/drybzBs5/0igz8xjrDftR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+umpHwBvpdYh
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEhj5fOPqLA41Cge3fC+9hX9jA+U2XngYOBD+B8
HoO/es9k38D5r6TnZpv/u24/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VD899QMANoYeqA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGdjglPLyjxOPi+cPDrjXllD+MnsXYxSoY9gPM/
1HfpLZJ/A+f/b9C7u+PbdTjfA01/Lpr+d2j6uRtR9Y/aP2r/qP2j9o/aP2r/
qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2o/MfYDALjUX3Q=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH75kvp31XhcVBujlyvF/3KHsbX0N/IlBH1AM6X
+nRxYZTiGzjfcv/2CV7vr9uP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U/6j+
Uf2j+kf1j+of1U9P/QD7ZOF7
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFf/l6peKnG4zCxm3vh5chX9jB+4r2HH9bFPYDz
X564M5tf+Q2c/2pDrc6b59ftR/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/qn9U
/6j+Uf2j+kf1j+qnp34A5eUA+Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGaMf2HvmrwOFgsfC5QE/HKHsa/vjz1+9ukB3D+
NxsO/YMqb+B80RvfI+c+uG4/qn9U/6j+Uf2j+kf1j+of1T+qf1T/qP5R/aP6
R/WP6h/VP6p/VD899QMAXCXtvg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFxuzx5mLR5HMwYld6qh7+yh/E3MDA6qKY/gPMX
fOTNzVd7A+erfF9+NPbmdftR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+umpHwBGg2X+
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGTJVjC+HR5HN7P6FK5HvrKHsZ/o8v2OST7AZzv
+og7XUrjDZx/2PCLnO6l6/aj+kf1j+of1T+qf1T/qP5R/aP6R/WP6h/VP6p/
VP+o/lH9o/pH9dNTPwB4RWrF
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEnyvbNl9LncXg0tXVZZ8grexi/nSPdvDb/AZyf
f6lb95DmGzi/t4VZgvv0dftR/aP6R/WP6h/VP6p/VP+o/lH9o/pH9Y/qH9U/
qn9U/6j+Uf2j+umpHwArGS15
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH/rlS8VDPkcTDMZEm2D35lD+PPXHPUaF7xAzjf
2qvrQpr2GzhfOn1O6vfD1+1H9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/
qP5R/aP6R/WP6qenfgBsZvMg
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHGYMDj0GNW7/Uj8JU9jB+t3sK5o/wBnF+vXhvP
ofsGzu/OZ93/cc91+1H9o/pH9Y/qH9U/qn9U/6j+Uf2j+kf1j+of1T+qf1T/
qP5R/aP66akfAJhtGLg=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEZE9/W2JvyOJQue+e7JeCVPYyfY3753qnqB3B+
yenIl8v03sD5EZee3/259TqcX4GmPxVNfyma/iA0/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/aP2j9pPjP0AvmxlhQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHz3i8/5m3O48Apeiyu2P+VPYy/SP/AlWv1D+D8
769n1TgZvIHzC+cY1/Gvvw7n86Ppn4Km/yea/nQ0/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/aP2j9pPjP0AXhYynQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGXfZMEIix5HKaJvcsz9XtlD+O38Djx3Gl+AOd/
5nNTv234Bs6362CNM1pxHc6fiaa/Fk3/FzT9Fmj6R+0ftX/U/lH7R+0ftX/U
/lH7R+0ftX/U/lH7R+0ftX/U/lH7R+0ftZ8Y+wGnxex9
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEca2SiUqx5HBh89hf88nllD+NfPeW69Fb7Azj/
+dYP3wqM38D5DwL6bJMWXofzmdD0X0DT/wJN/200/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/aP2j9pPjP0AAvHXXA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG2XNcXF9jyOMxp/Bt2yPuVPYz/lXvXvkvdD+B8
bvujP5hN38D5mZm/782bdR3O34mmfwuafmE0/XZo+peg6X+Cpp8XTX8cmv4t
aPr3o+kXQtPvgqZ/BZr+W2j6+dD0R6Lp34Sm/8io/aP2j9o/av+o/aP2j9o/
av+o/aP2j9o/av+o/aP2j9o/av+o/TSxHwDYCHSR
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzb9LAnEcxvFvDrckCHprQziKSP44dLlzCmxwEBenVBQcgpMGp5aGcElC
EoLcoiGhwdx1SsJNiGgVQQjJP8DFwsGDe/8FDp/p4T28eI7Ldq7qUUqFD5Ta
7mWtvbqyvGkj8Km3zpbWrif6Y+P9bua0/7qZ6hi/Th+qkvZz/+30Gt4XcPsM
/HxTdPk6/Cn+g/D9P7efwl/g34Q/gr+F1/Afgr+BH8I/4D8Jb8J34RfwEXgb
/g1+AJ+Az8I/wX/Bn8BX4F/hR/Bx+Dz8M/wUPgp/Dt+DH8PH4AvwL/Af4sWL
Fy9evHjx4sWLFy9evPi99f9zDZO3
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzc8rw3Ecx/GP5UZJKeG0g43ma8yw0vLjhlzccFCKq4tEOyClHGbNdlly
kpqT2xyU1Wr7Ut/SUlx2kBPaQXKQluTgW+9n+Q/ep1evw6Ond2l1dtljjLHq
jPndbGl6eH+8ccxOOMfzk6+jfz8Y/nw5Tz26v9aZKXojVfe3RU43o/EH92+n
pV/vln7OL/1Vn/TNSekn+qVf8EnfOiR9IiV9JiB9C/qhkPR59HNB6Q/Qrx+U
vgn9yx7p3+A/0G8/lP65V/os/EZY+lv4GUv6CvzigPRT8DH0L+C70D+DP0G/
DH+E/gr8CPp5+Bp8Gv4OfQc+B78G34F+Ab4KH4d/Qv8G3oaPwTegX4SvwO/B
v6N/De/Ab8F70C/B38Pvwn+hb8OX4Xfgvy3ta1/72te+9rWvfe1rX/va1772
/+//ACzWqFo=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzc8rw3EAxvEPB5QVNxwUsQO149QOsrg4iourFS1Nmx9bWn5sNiulpPZt
h6kvZvpmMutbXJSbms3SsnZgNWoH2sGJCyUHq+f5E/Q5PT2HV+9um3N8ul4I
YaoT4ndLvQ1+ZcRgbYk+VPpH34b+flhpNCuRcu0/pr+1U0u19psDDqGGirV/
lkBfdKK/zaG329FbVPRd2+jbMuhtK+h3NfSvHvSlO+rPod85QJ8PoU9Tf38Z
fe6Y+l70k9QfcKEvH6IvBNCbsuiDHvT5OHrjKnoD9e/n0asx9D0b6GeoP+ZG
P0x9xxr6F/L6AvqmI/RmP/og+eQS+g/y7evos+T7FtFbyV/40CvkJ6ifIe+l
/jV5F/WnyM9SXyXfSX2dfIr6l+Sj1HeTH6R+nPwX+Rj5AvV18ufkfeSN1NfI
V8nvka9QP0X+ivwm+Q7qn5B/Jh8h/079JPkb8lvkW6mfIP9EPkz+U/ZlX/Zl
X/ZlX/ZlX/ZlX/Zl/5/3fwBElinb
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzU1I03EAxvF/Su4yLUx2qCxFjciyad6UJpJelhDqdAQGDb2IJZGppQMx
igkZhAylOhQdBSk8FYvmJbL0JkTmyxZqaqkQw+nBFzo0+D73br/Tw3P48M32
tVY3JVmWde6AZf3d9Pvhzy8r7GWfap3RncpV17/fPZt7u+1ZJPFDW9c2ikt+
J35mIKXR3vM18f2b5+EDo3nwKTP0F3Ns8G4X+5fS6Av/0HcOs59ho4/00x+J
0sds7PuL6D359O51+kCY/fhh+psd9I4F+pE4/fQZ+uFS+q1f9I5J+hkHfWoz
fXSRfneNvuoU/V4lfXCVPjhFf/0o/SEffWyJ3rlMH8yhz6+iH1uhT/tGf+84
/eUG+qGf9O8W6GPZ9HNX6MulH/pOH8qkv3WVflv6Iz/od7Po7TX08WX66ln6
rhP0YS/9BfF3ovQt0vfW0n8R75qjX5H+x3p6j/j3EXqH9I956N+In5D+2ZP0
BdJvFu+W/rz4Iem/EH96nr5e/EQdfYf4g9L/ID4i/UHxXunfEP9U+n7xi+Jf
i08W/0T8XfF+8e3ie8WPi38lPkv8Y/F94h+K94l/IP6t+OfineIfiR8QHxDf
YPqmb/qmb/qmb/qmb/qmb/r/vb8PpzR1Yg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1dtL02Ecx/F56KiZlZAiEpKiZevCTCU8tJzbKmUllrqa80AinRQ8bZ5K
dBKBZWikZJk2MFO3PFDomqEQZUcxSyIxZyYlq1wniLCii4TP5w/oalc/vhcv
3g/P73l4vNOy4g7ZCwQCoZ1A8PcrMxe66aXO25NFJyueRc9G/psN2tH+2MbJ
hbk/bpWuL8yyMJd3x2dpNWMLs68uD/yjBgv4V/Yu4OUNGeDd1pSCf6x+Cf6U
zhV8ZWoieKOqALyj/h14SRX2XxjSwTd3FYPvrRsHfyYY+0E9CvCDBWrweYEz
4Fumsa8YS8X9Gy0C33luAry3dSX4SwEHwZ/214Df1jQNfsQT/fKOFPDtUuyX
D78GH3MXfZO7Etdfh33L1TfgdRHoB+ZU4B0+FYI31U+Cb25FH6LH/vkJ7Ls4
Yv9KPHqzBvvLbmF/yN0MfmMd+g7nZPCuTug9GqfAl6Whf74Z+1016H9lYn99
FfpYGfZ9/dArVdgXH0Gf+xt9Wgn65ovYF1aitx5DPxGK3icE+w+z0Veb0cuz
0NcasT9Uht6gRe8kRn/PC/uyXPQ9T9Afz0BvfIp9hxPo9bXoPXejv7MC+8X5
6B8Moh9JQZ8/jv2oEvQ+l9GflaPXOWB/sgC9xIheqkRfNo19/2L063ToVXHo
RfPoB9TotTfp/x1AX/MefX4R3d8W9H7x6IN/oJdrqN+NvikJ/X0L+kXUF19H
L9mHvu07+lbqN3aiv52IfvgjelMhnZ829PPUd/6Gfor6h2+gD6C+xxz6auqb
2tFn70e/5Cv6xeSvGdA/TUA/S/0c8ooO9H3UV31B70U+gPq11M+2ok8lb6T+
DPV/fqb3g/xbPfpc6vdSP4G8lfp25E3U30K+h/pK8h+ov4f8WvKryV+gfij5
evJ7yS8lH0NeSN6LfCn5MPIV5CXkvcnvJB9O3pf8UfIR5NXkReQ3kZeSl5Hf
QD6dfCT5HPLh5LeSl5CPJS8kryAvIp9JPpS8iLyYfBL5QPJy8jvIp5MPJh9N
Pop8Mvkg8rts3uZt3uZt/r/6P3HlV60=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1W9MFGQcwPHriL+ehziTDprIhmE0KFGwlng2WmjJplGMZXMEKnOaVpAY
AgICAw4EnJdxyp9DQhJKT80xiSlKf0dMb1wFgd6JcohyRgertLPWixjf38te
++rZ78Vn3+15nj1PcMrO1zYrFQpF+CMKxb9rjjZq47k1qlWlYY7u1pfGtP/N
4WEblgQftU7Pj7stNsesvDM9WzWpDu/0n6bnL/1S4WsufxQ506dW3r8y059v
Trg7049+0QevdRxEv8wahL4uqBL9r4cy4fvr0tA3L1PC5514Bv1l7Zfgndkd
6Ge9HwB/Jb8N/czzRfBFC1ajn9vkAT/wmT/6g8nt8B88b0G/yTwfvnvBBfQ/
dKuE7/Zfin6JwRu+65gn+hO9J+FD0kbQfz1tHnxo9A/od0bq4YfVi9DPPzgL
/vTUX/DbulrhC65OoO/8bi58iNMCX55QA286GYj+CyMq+EDzFLx7Sgt8b9Gf
6Hud9YOP/fYX+PF5R+BdOx9D/9g3s+FXqifgO4Kb4auND9Afcs2Bt7Vdg794
uxa+NNYP/aCNanjXtXH4OcYm+BwfJbyjgP3gl6/Dez9ZD78hSw2//yL7uRdu
w8c3HIUPXf8ovPVZ9sOUN+B7f2c/oU4FX+PuC296Ywz+1mQj/Pwf3eED7tFX
h92Et+xr4Pklz4JPiqSvSL0FX1jA/uf9HvA6C33ar+y/YmM/u9wHPnod/XjX
KPxT0exPFnvCL+qkfzdjBL41yAjveOBNv4neN5H9SDf2D99jf7CNvqqH/fg1
7Gc0sJ/+Hr1azX6Ejb4nzgveZaTf5GmH12ymT36b/cQs+j+G6DO/p0/aw36H
gb41gr45kz5uOfuxefT2Tvr1HfTttewP6+mtq+m9CunDA9l/rpA+p4U+ykT/
6Rn2Ww7Qv/Um/avl9Du82B8spl9qoE8/Tv/3Jfb3VtHP3kJ/uZrefp++voT+
eBX9b5/QL++l962k73uHPldPX+Gk7ymljy+jn2ik97LQa/bTe6YLf0js3zi9
vkzsXzH93Qb6Q/30GRX0hbvoP66h147RP6ET57+PXl9P3zJI7yH6P++mNxno
u+z0u0R/bT79iTr6U1fpO8vpU7Lotx+m14zQm0RflSfeL9H3sNJXiP6WPfR2
0VfepO8X/ai99Kdrxf8h+ttFX5NNv+II/Ys36CdFvzGXfofo62z0iaJfJfrp
ot89LO6P8KtEXyv6U6IfJ7xN9A2iv0305wqvEP2For/iOn2M8P459KdEP0r0
A4TvE14l+ltFP1r4GOG/En0f0V8o/BnhXcLrRH+J8EnCm4W/I3yI8HXCO4U3
Ch8h/FbhB4QfED5U+Erhx4Q/K/zTwu8W3ip8j/CLhS8RflT4cw/7D/v/o/8P
T3nE5g==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1WtQlFUYwPFlIUtCEFS09QqjRgZKo5aJspIVoFGiGKUOprlTMJQpWLJc
lXughhIEDCgoFxUBF7WUBCsxNC/UqpmMsuLqcoubiCaz2TRTzvmfT+88H37z
f+d5z5zXae36pRqlQqFws1Ao/n3q8rtLzyy2WaA5cjsnaWG7+v/Z8s71m10l
hidzcJF1Yq2688m8YZvnwZzQ35/MK9atzhT9tMDVHaK/dHRevOjNk62Oiv4P
pQX6QeobBtGHRp9KEH2lY2O56Bt0478W/ez0yjbRT+rXov+GXXW16N9asOYb
0afUeLeI/qd56ejPsO84JPqcxr3oW6hjW0V/4NcS9HVx9TrRa/f3ZIu+2N37
tuiPBH+E/sIYXYXoHwcos0Tfe67MJPqdNfXoezhOQL9lSSH6uXMG0R/5uR/6
wUPVlaKf1vs6+hVl9ug3JjSh76YqOyz6i5pg9LPGaI2it3X1QD9gVBH6sS1h
6DtPLb0rev/mdvSn9wegrzF7oZ+6VY/+Bp/p6B9qMaGf+yATfR/HVej7Hb6P
/qiVKvSrXpmKviLJ4Q72P3MK+sYRz1WJXuVTjv5k9+fRD/E3oz/frhd+drED
+uFdnuj7nZ+A/pVaD/j3jn2PflirBfpTDyvh9f16+PHXrdD3nhuE/oe+KvjV
bgHwZYsa0C8oMsFXaofAv7qxDr7AaRA+3iccPnLsaHgXjQb+aFgjvG7CFfi+
KUPh75ur4I3e/fB5+nh4442R8FHJG+B7Zl6F93NogI94+ln4WRdL4PvDuuFv
/rwdvtR3BHz5SC18jNd1eBdDLbx+hQ18yJ7dfH+bTvgpcVnw9a4O8JFj4+Cr
x92AH6P5Dv6R7zDenxm58GNL2+CNPXnwinX28KdXJMBbTWqGN+ir4ZP62I9U
ZMPHDZjgN57ZDb/16nD4Z95Php+RZoBvzquCfzvYFv7l6Ez4PfV34d21RfDn
N7I/ZFMq/Li0W/AvBVbAK0+y3/btTvizXXfgi9fsg092ZX9X75fwEeoW+IGT
5fx+D9lfvzkDPiiQ/VnHi+EtBu3gz5jT4LNq2U/PPwi/y4neJ/sr+P2dRvgl
B0vgVdfoz51Ih39xzG34Rb8dgDd40uc+3AG/qZD9vuWlPH919IPqbfCLA9m3
X8h+4jL6CynsR4SyP+0i+24V9Nfy2W+IZ3/Szf3wDmvpFXPZn+jNfptzGfxA
If3jZvad9rKvyGZ/aSh9tJL9S67s5wexvzKHPsd2O/yc4+zfWsf+tjD65U30
Xir2j6Ww77uLfvMM+vMN7Kd6sb9vM/3pOnr3YeyvKmHfcgd9/pv09Xr2i1zY
94iiDyinf2TJ/ms17CvS6TvfpY9tYl81mv0fY+j3FdBHmenNZ9k3pNJ/upb+
noG+xpr9tDj6vzLp2x7SB11mf00KfWoI/S9Geksl+xe20L+wnb7iPr2uif1l
yfTqz6T9m6TzP0hfuZX+g1T6j+/RNxnoM5PofcPpQ9rokx/QvxNP/3ci/aVe
eq2R3lbqT/yC/od2+qh++lNSPy+evryH3s4k7S+R3imC/lgH/ZI++uEJ9O1b
6Ju76Q2t9J9I/WQtfVAn/eUeem+pXxdH7y/1ndvpPaV+UiT9Nalf202/Xuqb
Yuk7uuitO+jHSf35UdL9+Sf9gy76dKnvK/ULpb5O6j8l9U9I/RCpHy71C6R+
awx9mNRXdUr/X8nbRNNn/Nf/B4UQQDA=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1X8w1Hkcx/H180LKbYlUykk/EENSKZ1cdUL6oU6udIiI8iub2XP2CCtx
c/3GuhKXRFvZO9n8TH6HHObkd7ehNj9iV35dipubmzPv11/fef3xmOd85jPz
/ei4+x/wlGUwGOtkGIx/v+KpTGnTnrlWZ+fxlD2s+7/8f0+kXRTmZolmd7Cl
+vOt2wdn9z7L7oNmJ1pmd+rSn9qPE1947vJKIfFudrJF1BfJMvjUqxVMytH+
J6PkStqvCOqqoV43XOxK/SOLHSLaF+1O1qB9zeKBYuodnH9NpT6aozJDfZhv
dSPtx8dufEZ9ic6Lk9S/9ovspb6mc1KV9tcEOJVQ72YhSaK+aI/7FPUd3EXt
tF+qOF1FveMOdgD1pg73xNSzVjQo0v6TbM+n1N+9sPEq9VrizEnqF7pZi2g/
QU0d+vvavFjU696Q66deeSdHhvZHIoxKqd9kOPEz9fNP3x6n3tCxtZf25415
VVK/RZnJpr7z4dMB6o/svfCJ+sL8Muif8K+Pp95ArDtG/cc7Vm+pd3EUV1Bv
Y1wbSn3fKtV31Mc68z5Qn/uLaRn1A6GsC9SnGCqOUj/aXt1PvUlxDPQ7zRvD
qPcLlhui/sp130nqL8lEQ39yKPc89R4dJu+pZ0dlDVJfL7SCvkTvwI/U17Pz
oW96vG6c+sVbSqGvs8w3hvoPi66OQP+02hD14xIV6GcaBYRTb8+2Hqa+vzNh
jPoHecPQ14sP5lJ/qkMb+pfctIap98nrLad+Om9HBPUlMRnQd0j+bZR6aczn
4NMPFkVTn15cJaVeQUYEfftrVeATM7uh75kyAv0UqznQF9zRB//WeAP0Y+Ri
oG/SHiSh/tU7AXhrhcPnqJ/y1ZdQfy8r9j315vstwZcrNESB7/sG+hmTf0H/
8YtU8C83P4Q+q9sR+rk8A+jPGNuBv9IWBX1tw/XQn1E1kcL5X10Dn6MogX6d
IAj63EevR6jncA6BF36yh77mDU3ob3E4Df3gmXjw3utWRFKfdT0W+tcqBNDX
WO0CvitUF/qDInnoX17Ag767Jxe8+thX0C9M4kE/e10c9Mda3NHflod+jfk4
eKPDBdCPC4sAfzTuGPTbLDPAbw/3g34k0wv82ON34NfvHwCfpvYn9I+2hoEf
tg8Cz03LBi9v4gz9IXMf8NsFneAPbeoBr+P/BvqSL0LBM6fCwbveEIL/7shu
6PPjT4HnKzWAVzLrAh+oPgp9/nI2+Ls9ceB1nxeC35hgCf0WGz/wPmmV4L8v
aAX/cfM09GtvhYB/Mn0FfGlGCfi/W82g33PZH3xm+hPwM97N4N3KFMDvjjoL
XiDPA/8mqgx8pbMR+JXnA8CzgvPBy0mbwC92UQEvymaBZ3NuguenV4AXR68F
77YtEHx1Yi74k0sawftz54OvXoB9UWMq3p9FFfiLw3rgayuwL8r/HXxI8R/g
595kgldNCQYfbXsb/Nde1eANduqC99UPQp8kAG9YUA/epn8h+L022E9bcQd8
3a5n4DVsdcCbsLC/Uz4bPOfDc/AeKYvAd36G/aGwDPCiQewfbFwOvoSP/TUt
D8A7+mLfuFcD/ETLGfAREXfB23nXgHfK0wav9AL73hP3wUsZ2Oc2a4J3zcG+
h3UmeJly7Nv2LQMvHMW+zn7sdwvqwIvOL8b/dxL2hY3Y15tTCz7HAfvnVNDz
mvngV4VgX3ueFngbLnqzrVngqyyw39KxFPyZpeifsbHPscP+mkDs3w9B7xKH
fR9X7LO42Fdeiz5+A/bnGmC/PB/7TafQm1Zi//gP2J/ZhX1PU/RtstgfYWI/
UIr9Mg/0L6XYX30J+z0a2D+8Gb1x1z18f2Wwz9RaAr78GPpjTPTJt7DfPIo+
cht6w6fohe/R225Cv+9b9OH66Bfy0de3o3e2Ru/OR9/chz7XAb2sE3qfregT
c/7z/wCq5LOH
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1HtQzXkYx/Eou7mMErIVaZOTomLKtVwqm1wqHSGpttuWEqFCpyGzZ0Wo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xk0lXkcx3FLEteS7YrIrmsLuZbcK9zKUpN9nERSncwoQhqFdG+2spdr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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xs4lGkDx3FjFM0wWUxqpcg6NVibSouccsg0Q0hNltpGht20chxRvWgb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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k4lWkDx/FTmmhscXCIDseeLKNwocjYsvdaC1leg7c32UrIZGnIvhOn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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1Xk41Wkfx/GDThRPKZFlejjFJFtkGSocOQfHki3RWAqjRgrJdpRSjC3N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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k0Fegfx3HaMFNXyI0sk5iDe6VrSdQ0WSP7GiE36Q6aUJY2NUrZsvWj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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1nk4FegeB/Bj6yASqmOpXLtuNFpkK2sS15J9pyMcOiHZokaGO7LNFYbG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1XlQDngcx/FHEonKQ7dydEiJbbooKVKteiodzpKorNoSyuraSo8uFk+k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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HtUD3YYx/FfycpPySVG68KS2+pImlukjp1xtHRR0SpF++lCZUQpfs2t
Zo10l202tJZLF3LkdNNFF1HKdJOlC9OqZZSQ0c7O2fJ999dzPn8853XOc57n
mbbJ306mKJFIDBUkkn9rqeXCwxbuqubOoy8q63h3Lv8/2xtEDtS5tAzlIEPj
GWEu3UNZ+6SHx+GWuqEsd/vbqn7cu/4+z7z9Lz5sHco5q8ttEk3f9eu1Wzir
xdYP5RCf6JGiX75vx6Dop8gr9UXfyj9CJvrO7hOsRT8wds1Xom+/WGYr+jY5
PetEP2/6SCXRj3BTGVEv+KblB4b5up6i75X0AP5PCWFy0V+k0wD/bUyog+gb
rW5TFP2U07+MFP30aiv4txas9BL9aqOdNqK/uWDRXtE3XGpgJ/q3nbLWir6m
kxr86IkxyqLfZzUDvnqxrrfo30ttgx/s+Mke0S+p8Yb/o4O3neif2P6lgujr
tQ+oiH6a+yj4wVb58DPqjG1F31oWFSL68zri4edXBNiKvrL1oET0NawVpaI/
YX7fdNHvcjP2Ef2jYb7wZ3mMgZ/VmQV/Z2GhjejH5Z+Hf31OMfzSiw/h//x5
OPwne4/DfxmUFiz6MROr4aekmsGPP+YHX8/VZrTo565rhN8RVQK//VkW/Dnm
XvD1y1rhh19pthZ9SakF/Me5WfD1VWrgp+v0wk8dqILfWGcC3y2nB/6ygOPw
Bwemwi/aMkJV9EOeVcBvCNTYIvp69Q/gfzBfHf6KhS/hS5Vk8G+/VIF/7O4S
+OPlpfD12gzgO87thn8wqXe36FfMGoS/xHk5fAXZi0FtwU+VecCfYVpMv8gM
vmTxc/jnAh/An2OmtFb0e8r14MeFdcJvnbwPfkt9AXy3Bkv4HXWv4dtcqob/
tF8Zvn2iOvxTmq3wt9XHw18/+Rp8A18H+GPTJXai39ZaAj80Qwr/TY0EfpnJ
PfiNRcnwM6vzeH/bXDh/UyX4E17kwTdKV4U/XdK/RvT7Z9bC/9bnEvyallz+
n5iN8K/9+h58/Y+uwn9ffwz8+Ro98P131sAf1ZsNf948+iaOMvi+2Srwr3Zn
wq9doA4/dGUH/ICCKvgbjAvh/5CRw/lP8oKfrSOF71iTAd9skH64ykP42iW3
4K8oKYEfbEe/UdMH/nG90fAHv0mD/ypqLPzL3S3wL9jehH9A5wb8SDX6UbFb
4Ee30U9tuQBf9oa+RnIz/FyLCvg60TfhazZlw9c6uxX+F36q8I+knIcv/Wwc
/K9f34efHHwDfoJrJfzZV+jH7vCFX3SX/qjr5+CfPETfrLgJfntHOfy3qVXw
tb+jX63sB/+Krhr8LC36pen0E5vvwTeQ01+VdBu+TTh9xwD6cY70l5w+C/9M
FX2ThfSlRvRPrK/m/wmif6OYfoGc/tFV9Jc+op+U2wi/tr8M/qn79E386Pe9
oT/7e/qP36Nf9px+1yb6vbfoWy6rge+3mX7kLH/4ly/Sr65Lgf9QYTz8RdPo
r06jP+Yg/Xx3+jkr6e8qpH8mk36hlL7+0wb4TQn072bRj3Whf2QDfYVK+s2J
9M3H0e+spO8VTr/iN/phTvQt/ekH1tJ/HUZfcRJ9rcv0XUPox7+ib7mO/qEQ
+slN9A130987hb7pKfpHttP/U+0O/BQH+vKD9Oe20Ffzpy/Voi+LoT9lK/0a
Lfq77OlLI+jL2+mf86T/uzZ9m8P0PTzpZ8ykH7+Wfl0k/a5H9M030V+hS79r
H/0nHvRT5tJ/ZkffKYZ+5mP6n24Y5k+lH7pn2P5vpC//mP7uYf5fccPu7w/6
rs70B4f5+4PoR7jRv7mY/rRh/p0E+s//8/8BiJLjiA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0OtPDQAYx/ETqQ1zN7mzWdSohpiYW0oIk4nNmiTllo4014mmi0wsLFlr
iURD5dLook613DOMZBZ1kiyFZibWYl449v39AV6dV8++L5599jyjg8L91ncx
GAwTbAyGP7Mju+3Z4qCes51rK42ZxuZZf3v6fv+qdN86S/suKaspX9Niaa8J
Uae2Pqm2dKLb/ZwjPf7tv+6f4zZjYr2lw742t+dO+7f/Kqnt14gzLy2dvKcM
/oCsQPhVGSb4H95Gw0/r9xB+b3M2fM8+LfD3Jnykf6UEfsfoUPgZk+jHzYiB
H+39CP70yRfgu92hPyi3CX5mQzF8J+/N8D1bS+HnlcTCd+pRBd8l6jz8dR6t
8PtOa4Q/trQI/qKPYfD9TPSX58fBNx2iHxaSCf90DP3rWQ3wV9rSv5saDj/t
HP03fvHwf9bQL7h+Dr7hBv2882b4domF8A15Rvg+SfR33aTv3vMx/NQ59L2e
0U+yof9iNv3gwG3wT8TSv/Wd/qfx9G+2n4Wf2ki/KKUe/rg+9Ac+pe8QRb9y
1CH41XPoOz6g/62NfsUK+n3bCuD3GhwBf9lu+h0e9F2X0t90mf6rH/R/OtN3
r6VvP5/+vB30CxfRz19Jf+tp+uZO+jm96cc/oR8ULPdH0g/zp+8UQH9BIv2h
XT7Bd++sg7/lHn3HnfT7b6c/M4B+RiD9o7H0x9rSH/qVvmcFfYeD9H0i6Kes
pV8TRD/9AP0d3eh3baHfXkr/1mH6ldvohwbT9w6mb9xHf6kd/U1N9Ktv0794
jH6E+K4h9F3W09+yl/5L8RPe0T9QTN90nP5M8X1D6ZvEd9xD38We/lUz/awi
+f9J+sPEt99Af2QIfb/d9EPEj66n7yC+TTJ9O/H3i79a/Kpd9A+LX1JH/3Yh
/efitxvpPxL/oPiR4meIP1f8GPFXnaL/WfxO8dPE9xA/T/wvb+kHiH9N/Gbx
B2+kf0n8IeIXiG8S30f8BvHfi+8qfr74tuKXip8u/lTxu6fQfye+h/hF4n/f
Sb9c/GPiu4o/XPwG8WeJXyz+N/ErxE8Q30X8keKbxfcSv1z8JvHvih8p/hjx
p4hfL/5C8SvEb7T6Vt/qW32r/1/932IdWZc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzc8rgwEcx/FnVkjKiZTHag7KYbSD4mLOfvXMY6y5zY+LwmE47EZSRmop
1xVZzQyl3CQHc1gODjY/Ci2jRTmMUkIOnqfP5+Av+J4+vQ+fXnb/RO9IkaIo
Doui/K6zNK76hsvb98JztdpM3vXXnZHAuKftzujU6UnTlv/Z6EK6WlWPL4yO
fRUm1WLzv+/JbKy67s1/v7WipsX8H/YFb0djaaPHVtB/iKI/RH7zFfrn3+jb
dfRnB9DPauivL6NfEke/gfzANfpTyhv4B270H8k/6kF/cwl9PYF+Gfm2G/RT
5L9r6Kte9CPd6NeRP7+D/kcS/SD5n+SHyG8l30p+JoS+cxf9V/K3ya+yoO8m
v4P8aBf6CfLD5OfJPyO/nvxG8nXyp8lfIz9J/hP5l+Q7yLeR7yV/kPxF8nPk
58jPku8kv5J8H/ka+Qvkv4gvvvjiiy+++OKLL7744osv/j/+D6Y9x/I=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFpYMDjIKH/Qj2x9pU9jO/qbvo0zfABnP9Ocf+y
8NQ3cL4dh+EHnq3X4HztirllbowI/ZurOR9O9H4I5+/1DxE/ZIbQX7g283fm
5uv2o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2k+K
/QBJuI0J
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFzjihsKMrgcZh9PcL7b9Mrexg/yubM8zrVB3B+
ysqaNdfS38D5J44+2PppxTU4P5fJnOXpn5dwfkmQhX5n2EOEeW3/F04zReif
ODljW9nu6/aj9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j
9o/aT4r9AA+UF04=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEXlW7/rMvicdhbI/jdpuOVPYy/b9I1pzSpB3B+
96Vbcw2z3sD5j9fcnDtr7jU4vyc6fdX9Hy/hfOmP9w9tTHgI5z/kkAvsN0Ho
v6jS+2T/oev2o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9
o/aP2k+K/QCgAwPA
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFsjVOdu3N4HFbO/CVo2PvKHsYPqlxy5hv/Azhf
JXfj97ycN3D+pYD75Q8nXYPzO5k0m1S/voTzq42PHTXMegjn13mcW7bUGKHf
9fyVXRknr9uP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP2j9q/6j9o/aP
2j9qPyn2AwAjxyhm
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHW9/17p+fxOMT2eD98OvGVPYz/PXbqFRG2B3B+
atz5wsl5b+B85eNlG9Z2XIPz+69ruK36+BLOX75s/guV4odw/rQky1dXjBD6
j24pvdh1/rr9qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/
qP2j9pNiPwA0eR+T
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEFtlzXFxfwOHzel704ZdorexjfvP0lU/jP+3B+
ne3K2YsK3sD59sURf1/XXYPzt79/sj3l3Us4n2nHJpYF1Q/h/M+tT7okjRD6
Gy7mlFtevQ7nv0ez3xPN/gY0+03Q7N+EZj8vmv0f0OyfgGb/NzT7NdHsr0ez
3wrN/i1o9nOi2f8Rzf5uNPtHw380/EfDfzT8R8N/NPxHw380/EfDfzT8R8N/
NPxHw380/EfDfzT8R8OfuPAHAPxduR4=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHLZh9R2FDE43BCmLNly6xX9jD+mevrg0Kf34fz
l5nXW84vegPnbxL2Se4tvQbnP1Sdttr39Us4f4HAL+fNzQ/hfBuB7sMFhgj9
px8uXNN86zqcfxDN/rdo9i9Hs38tmv330Oxfhma/JZr9t9HsH/X/qP9H/T/q
/1H/j/p/1P+j/h/1/6j/R/0/6v9R/4/6f9T/o/4f9f/Q8D8Atr02Qg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG3f9Zl7SnhcZDqjTO9Pe+VPYz/yeLbW65r9+H8
HP9ndd0lb+D8p8KaP1pzrsH5egUv8+JfvITzv4Qcr87ufgjnCwZMjb9hgNB/
hPl5fOn963A+P5r9qpao9ueh2X8TzX5NNPsZQlHt50Wz/xaa/aP+H/X/qP9H
/T/q/1H/j/p/1P+j/h/1/6j/R/0/6v9R/4/6f9T/o/4fGv4HANRX4uQ=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANECEZZbTpTxOMy6cD3k7qJX9jD+zpc5PMlH78P5
jrvtTDPL3sD5y/a+FzyTfA3OD4qMSZn69CWc7xziJ3B50kM4/7H6oil+Bgj9
JZX37SWeXLcftX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7R+0ftX/U/lH7R+0f
tX/UflLsBwBD50gD
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFu2z7/vVLB4yCzds76fcte2cP4xiESk3y23ofz
L5i+vmpZ8QbOn/s1d0d49DU4X6Fi477Xj17C+TMuTuv/NPMhnH95n/+Li/oI
/UceRHmWvLhuP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/aP2r/qP2j9o/a
P2r/qP2k2A8A5eK+hw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztz80rwwEcx/EfLspOWslhNClFWpJ5KiwHUxNtN6VFcZPMlIfDys1ByMnD
QZrD1p61tVFLKQ77RcSEA3Obdt5BTXLw0+dT/oPv6dvn8O3V2zg1Z58uVxSl
tUxRfu6qPjSUW9ENXDnirjX/R//vfthIdqSOX7W9XpU++FouaLsvbrY0OLLa
9vaqY863vLZtcWvd7WFO28bFa8Ok6e8/7Zto2So8ats9jH42jb5Hh34+jP5l
F/q7Z+g/udA3JNCvGEXf7UX/k/ozMfTtPei3J9HXu9GfD5NvQz8aQ3+Q+s1R
9Je60a8+RX9mAX3jCfqBEfRv/OjXkl9P/UXyS9SfIb8UQT9B/c4w+m3k71F/
iPz9FPrb5HfG0LdQvxpAv5H8d/LvybeSHyF/M4p+kfpNIfSbyT8n/4L8WfKP
yH8hv4b6d4LoN5F/R75K/jj5PvIT5FeS/xyUfumXfumXfumXfumXfumXfumX
fun/v/8bFGScnQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt1PtPzXEcx/ETmyJRiXRcG0UuLY1hs+RSKgrNpXLZamuVg5RYOqa5nA1t
JXUqc2lkSqgYc9tR2KnoaiVDsdDoNrkci0OZHxw93/+BrZ++e/3w2WPP9w9f
x7DowPABCoVipplC8edbFBuZ2rl3qKcur9p/ekHbwr+7alL+21MZr037Xuxi
7S11h2mrrx8yd17eYNoWCWaqzqZW09YYhpTG5Tab9pXeE1ONrv/el62blRLT
9cy0z2Vdh59l6fyur7/C1wu+38c4+HmG7i19/bMXx8H/OjYN/oaCdfBdgvTw
/bc2oD9q9xL4J20S4Zdu74GvP28Dv/BIJvzgQg/4Pel34GdnDEb/tnNL4R9O
jocf3fYDfvsmB/jVV9Ph65UB8KMT78Mvv/EB/TnN7H+k2wu/Z8Yv+BERdvCP
ajLgu7gvhV9ipYMf3fALvmYT+1VWCfDn3jbCr8+0h28M0sJ3OuYHv+ZDMfy2
xV3w263o3y1Tw3fI+wnfI2kkfKWS/bXx3vBtR9yDP/pnN3ybRfQ1l9h/chj9
lY2j4A88w/4yB1/4LZ7sdw/9An/2RPqOYexfEEP/1kD6xZ30N0Ytg2/Yx343
4zf4gXPoP+5gf+Ms+i3J9A/eoT830Qd+mpF+cf5X+MVT6M+bx/6sEPo75tCP
fUn/VCX791yinzKF/fFu9EvM6as86Xdsp+9TSj9sIfs/v6L/0t0Av2ka/RZn
+h6r6f/wpf+mjn62gf2NOvpOtfQTXOk/saUf7k2/MpT+uAr6rk7sd6+jf3ML
/ckz6FdOoB/hTz8ykH55Lf2YQfSj9PQ9L9O/MFP8/+zpN/vQX7+R/sQq+l5K
+gHV9L/tp18g+qvG0q9YTv/TWvrqGvqJVvSPl9Off5p+gOhf40C/1Ze+XQh9
g+h/MJK+TyV9bRL996I/dQz9CaJftZ7+x2r6u63pv39EvyWDvovod1TSD/aj
Pz6Y/irhPx1BX1VBvyiFfq/otxT9DcK3DKJ/Q/hFNvTjHtP3TqevFP27RL9G
+Drh7xS+vei3E/0BqfQthP9c+HeF7y38bOFPtaWfL/q90ujbCT9T+FnCTxP+
AeHrhd8l/O+if6jwHwq/UPihwtcKf7PwHwi//jh9a+FfFn6O8NXCTxJ+uvBf
CD9U+MOFf034ucKPFX6y8DXCrxP+QeEPE/5N4ecJf4fwjwl/j/BrhK/tv3//
/fvv33///+z+vwG7MHaZ
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1n0wFHgcx3H2OFPIw7manGQjD7lcLZ2Hu7KJ5OxSGzodprbyUJNctwY5
VNpay9YK65xCkpyHskXaE0nbuhJWD6uLOanogdw17nr0cHNzc+77+es3nz++
85r3fz8mfxdvG0NLS2uxtpbWP++gekHv21QDtqtF/bFG+XPP/3bS1uLJkUP9
0zv+oLQ0OmVkehfM0PGKWKWZ3ovliW05vc+mt+FL19KHNQPTe3SF1K7Y6f/7
xv2GzvP+7JneWfti9lKfVbdR+IL4956ZlVN/db/AifpbPPovUX+iZ4+C+nFG
v1lSf0Dkxqd+h0VGHvVbL16zov6aZsFJ6qsfzVpO/bLhX5TUfxcwr4L6Fe+/
WUj9D+czPKmvsVUKqf/ApW8H9evF209R3yXInkV9WdWDZupvmGVWT/0GTroV
9S3O+YdSf93DjGzqO451OFO/ZHQM+gdz/D2o33Pc7yr1k9Iiq6hvns60oX6T
psqH+g16LSLq339SHk79Tfn60G8b5uZC/eLuycvUv2VWco76Y0axTOqX8nhB
1O8pDjxC/YuBMSuo/7vao4z6TP4VN+rPmPqulfqd3C9qqH+Pvdua+h7xfD/q
v7gcI6a+/Y3GYOpLqjXgl52MWEZ9W/+iFupbmHvJqW859Af0bzydtY76yV0m
h6lvWszzpv58Hh/8NPmgK/V5L8evUD8+h32G+l65xtDvyxb4Uz+IsSGT+u0G
vHXUv+CkAH/pKcbn1O90fA39tYZptdQfVLsvoD5zofZa6i+p3SShfiOjyJf6
ISGJ4GtW7oD+2vyfof/CZ7egv9/mPvh66YUc6pd/2Qv9IbF9AdSfc7kCfB+D
COi3qbMHvzHUFPqtBHzw5ypsAql/8+1EFvU7Zwr8qL+n8AD4Ml076A87nge+
X4j1WeqndDaCLzVmc6k/9MIGfGZGCpf6VrJi8IfGpdBvEugN/h3lXfDH5yaB
zxj4KYD6Pq9U4HtOJX1FfZPdmeCHTmpBf432PvA/la4F32WoEvwj1wqhXz7F
BT/mnYJDfXbyj+DnbaqB/kz5evDF2nXgOyuE4B/fvg36w7gV4N8c1/en/vmV
R8BvujkMvkAYD36DMgb890knwK8c6IR+50dbwS+f4ED/09J88CdYTeAf9A4D
P3XJCfAZrVngP/DyhH4913zwG0LDoT92czb4k+P94N+13AV+uzoB/CL3Y+AX
hg9Df1vZt+Cz2MbQP2kgAz9IRwV+t/5m8B+el4FfUiMF33HKAfpt5RLw38nF
0J8gPQq+KupX8PMkO8CfKEsDP4JTgP3L30O/qiURfOPIUfCVi/LAjxy9AX5u
/Rbw63ql4P/VdxT8gIWW0J/CF4Ef/fok+KHuOeAXXLoLfqk0Bvxh7QPgqyvz
wY+frQO+UcP34G8X9YJfW50LvqiqA/yMpdvA7yuQgH/GLBf8FPEc8P12CsEf
MTgHfmI+9jvJb4M/LogGPyruIPjmrTLw63RmgB88kgp+h043+Dsjsd+b1QX+
Gt1I8B2vZ4If1Yr9y/o+Ap/blg4+e0gB/kg79idLboH/RBMF/vr2Q+DHsLHf
QakPfrjdXvCb7dvB9/bEfn0DNfj+ydjvpBKD726dB75+lwn4n/TtB3/R6mbw
7Z9h/9Pn3fj/SsX+yiwR+Mw36LtxDMF/qcH+usdt4Mc5YH+sEPs/bsL+jmXY
zwpF37/SGHytUOyPu9ACvuAt9vtKsf8sF/sT3mD/nS70u21nga9x2wd+tqkK
/NXzsN/sOvY3DWB/2GAG+D4J6DvqYf+YEfb7mraCL2Kg3x6O/cEs7E9xQX+r
An1hCfZ/vQv7dY2ugb93NvrNo9hv9wr7D19EX1eE/tpqI/C9n6A/dRv7ZXro
n12J/XOtsX8kGP3BavQ5j7FfLkH/QKoSfIUp+i0foC/WRj+7GP2wbPRPJ2F/
jhp9ffZV8KNnoj+1FP0fzNGXRaP//BT6DjPRLy9CX7UY+4uM0Y83Qn9A71//
b6T2Ptw=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV13s0lHkcx3H37BlMl0nk0g4q0QxLKBrKxpBxFyWb2RhZShc6GqG2aFRq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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN2Hk4lHsfx3GSbJ2Jks5EeWw5kcqSOkqDnOJorpHp5CTHMHZlqyFkGSdL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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ns0FHgbB3CzEpZZZlmkza2Ru0q2XKLVRfu+tss0LVuvtVvTrElLLtm2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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztz88rw3Ecx/Hvd7TUJrWdlhzETpJwEFuR0ixLps1FUmpY5Htc7bAm2VY7
Ofh1moNamxWzH9gkRaIoaX4UkamNtcTNbXLw/Xq/yn/wOX16Ht6fV4/aMWHQ
JuM4rpHnuJ83ZVTKGrzKLnnkrNKWKXT+dmCjwpQsPIrds7b1ce4qil2K16yU
d9+I7TbuNBmyb2LbzLOv7evPYrf4DrpMHcU//x9bnOlbsdUl3UA4IO0rnFr7
de5J7JMp+YjGK90rNN7QvlraN7da9cVTaT+vqyu7uJf2TeOcKlAv3VfN9znb
mu/EdoSpXxuj/jT4Z7apv7qX+h0W6ld5qf8wSv15Xk/8wWnqj4NfAL8P/AL4
XeAvzVE/D/7RBPU/gD8Zpf5dA/WbrdR/5KF+IUb9ERn183bqj4LfDf4F8A+D
3wP+DPjfQ9SfAn8W/IvgD4LfAf4E+NPgvwT/0CT1b4LfD/5l8PeD3w/+PfC/
gP8T/Dnwu8C/Cv4l8IfB/wX+IvivJpif+Zmf+Zmf+Zmf+Zmf+Zmf+Zmf+f/3
fwNNGDKp
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEflh/zNu/kcZBSj5y98fYrexhfqM3jx+KT9+B8
9p5k7t11b+D8dbFyUYwu1+D8u1N/M5k/fQnnh/IubmWZ/xDOt/Y+/cXcDqF/
a13AlVPLr8P55otlFpfNQNgfYXpv1QzWB3D+AXbec8adCP1vFomemMiJsJ/F
5fU25aMI+1cYlsSGPEXYf3CXYtZyJYT+CV4H1WfZ3oDzVdD8/6gV1f/MaP4/
gub/l2j+t0bzvwua/1vQ/C+P5v+JaP7fj+b/j2j+50Dz/3w0/x9F838lmv9H
4380/kfjfzT+R+N/NP5H4380/kfjfzT+R+N/NP5H4380/kfjfzT+h0r8AwCF
8fZr
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1H1UzXcAx/Hbw8SEWGzJU0jTkGtta2GLUq1SC2lhEpXbQUoPSJEerhE9
7Sbc1qPJKGEeKhWidFCtZWmOnnRF3Z4TV1Q72zmrz+evez5/fM/3vM77+7s6
m3euclMWCATzlQSCf391RxyMM41QN9Gz3TEus6Hl2//30VtLDP++UDu0ra3G
Cxr3tw7t/aH1d26YVQ3tnTrv23e/aB7aB9rLU2ylDUPb9YE8V7Js+Hz/M/fC
afGPh3aDW0VfXOzw/blZo7YmatYPbe0pwQs0I4bPi2uPTTwrGL5fuaY0U61w
+P6jq3N3bG4bvv/wk30OS3WGz9fOCngwYF49tJsTcysywK+kdt75CfjFHmMm
of/Jr+u+Q/+AbmgG+kP0kg3twF/3h70Y/VsdOxqmg9/oVdLB4+Bf7G849xfw
a6z5whD9Rs5Jvengr7uplIB+u1BfCfo1ZVVm6O+MCtcdBP9rvQMK9Csk4WnY
P1156Uj0qy52PI5+YZZFFfrH2myqxv7XJzuno3/nA9P56DcUyeeh/3Jbcyf6
O79KWoj+zyKzRmH/MV4L09G/0WR6IPrDdWzs0P+wo6sV+9u4zqpH//2HeVrY
P2ewRQP9aq/euKF/34ZReei/fnztBOwvzD4Vi/4TwSWJ6Fd8OXsz+j0ee/qg
P16rfhH699lq9mN/g6tzk9GvvsojAv0PWnMs0Z8Ttl8D+3dGeHegf5GDXzn2
X1vtPxr92aUbwtB/Klv8EP0B+vI27L9HmJ6E/pXJvo7ov2/6uwn6ZS3mheiP
SfETon/UeMEH2P+F7OfT6M9UKTtI/Z8/sUG/zO3TPuzvlFH5HP0iI50B9LtO
lI1Fv2eTqTf68x30C9HvZluqiv0drHzj0d9euCIM/RWrrjmgf2lhXjT6C1yc
qH9T7wcC9E+9U5qCfjPzx4fQH3l3uRX6l5kLR2L/ZxG1cvTfe1daj/7xjXnq
6I+6ZRqE/t+aM0rQX+Cz/TX2b/9EmoD+3sopIvTnBoVYol9jQ00W+tMs7lN/
nbA5Kuif1huRhn7RD+ph6K8ZK7NGf2KR8yD2P3Zqwkv0r35v3IN+daOPqb84
KccP/TG34+6iv26x3yD6d/huPIl+gXvZXvS36pR9j/6pe2wT0N8tnE39i4IN
lNAfdNInFf3FIk8x+i8+raH+wcYtqti/Z6VfC/r/mJP+Av1XpEvHoD/UxT8A
/RbX9e6hf9nokrfoT5m6VYp+T4eLnujvK4m3Rn/xrhNn0S+7LKf+/lHblNGf
ensW9b85qYP6+0hDqH+NwlMJ/YFxvdQ/yqOtHf1/rS0mf/fGwN3o11p5pAj9
f0536kf/MsX0U+gvOJHhh/5AYa0t+n/Jr0tGv++icdT/ueI09XefcJX63+is
C0d/2cfa5D/8NlEF/VVZTc3oj7ZZ34J+xx1e5FfVX78X/RXjIovp+xdpv0O/
t7iN/If6LL3RH+9WboP++Ds5v6J/n0xB/Q1v6VB/48Q+8ltILclvMXMD+Qe0
v1VGf7fQjvwpocZt6A8QnSH/jNUL9qC/pLqF+qvKQt/T979xO/kr+j70RX+T
22Tqf+zHzFT0G70cQf3tnSqpv0ReRv6US+nktzf7nPwmi6ZQ/8suF8hfGbld
jv7woDDyFzvJyW/ibk/9y7ekUP+g8Hzya7jY7UL/uW1WK9FvfS3+NPq7tAao
//YEVeq/e1ML+U93byN/TZcN+XstYqj/zdhd5N9VEdmK/hWlJ8kfIfElv/dr
DfL3XDGg/vJDR8hvoO3ug35rrVLyKxK2pKHfOVWF+geefU79lWb8Tf6uwBjy
HyxfQv5H0S/Jr6l3gvxOXtXU39TjKPlHf3GT/N/4fE3+Tssq6v805hz5rd9e
o/6u/QHkF32uS/23fCog/xrtt+QffN1I/pCmveS/0W1O/sbsS+R3PBJM/sCR
1tR/fqWE/HPso8l/S3kG+VP2jKX+67yOkz9TRZf6l0gukN8/+jz1j3dUJn/f
s1byb9ar4fef/RP5J0hMyJ+w4BH5vTZFkT9TTYX85Yej+P3fyyR//oAB99eX
U3/fSWnkd62ro/5C/Uh+//1vyG+s4P7S6Ffk7/JsIP9F0QHyn5WYkf/yoQLy
D4wRk//AioXkn/s0lvyBZlLyn+nRJb/YSYn6N8ySkr/x+9HUf8tPqeQPUdwj
/+AjJfJH5Xfw/39BLfkly8PJ36ixnPyeMx+S36c5gvwu1R+Rv6Yomvx6TWfI
P8N0HvkPe/RQf5OZyeTvV+2k/gvz4shfPLuJ/JZW7I8t6ia/1s76//z/AB9K
s8I=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k81PkfB/Ah9zGtc42Eid0o1RgqZ5QjybHVpuSoFCpUSmEtpTZJlDtb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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81Psax4csKVqEOjd70dRoU2Rf0mKrJp0YTRLZTnKNtBhrF2UtZWuQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lHsfxsc24cSbLBWlsSdby1QK2evIMpkmhbyJtNmVOllSzbEUFZ2U
JTSDkEhc4TReMdkq6bQpKpXskWUou/d6/3jdv79c3z/u63N9rvs7z/fxqHj4
M72EKRSKnhCF8r+/NbSioCMJC82M7lhaKBb2mf5/7nIdSc0s+Dw/d3/cQs+P
75+fZewkDWW63s7PudUCszvlvfOzaeN0WbJY+/yskS1wyliOfIQbJWe91/v5
mfOwpcx9FHxxzWpRhkvb/Hzc4W7QgjPIy9XfsGY4NM/P7Hv6fUYj4FO9Lr40
jf46P1eY260sdEBecqLrhAfr3fzcEBHvc+4P8OkV6ot37f4yP/fGj4gYX0be
SrKbXiaAv9a7gD1OVeAzHS6UDIyCf50na0dVR75Nsvq8qgn8R9xLs9d/A38o
XNdYshD+h2SlJ8b+RF67XtQlTQv+xW2LqOqfwJcLo279+gD8Jycyk1+bIG90
dHfp30XwX3NUnmeaBb5c71x29Ef0X2JNc7ZOQJ6bOXytqB3+LgvTU/ml4B95
/8KZJ4H+2/lpOlWKyPdk+59w9Id/5o92fu44+PW3Vvi5WsP/8pynkXQY8k4P
pNIYzvAPN97YpTMO/sjg4lKpEPjbRj36pbgLeab374nSxvBnKIXO5vuAP2q7
lfo9AP1LxJVebYlFnhMctVpWCPzpjz8fNdWDfy83bl92B/gHmy4pi+kgTws6
f0V/CfzPr4/8lfoKfIMXq9QCZuFv7cku07uI/JtdQ/f8JMFPN9PeL/oc/KNj
KWssW8B3bkiYqDVAnmX1m9beGfhXxKabq9aDX8gVquFvQP/HvgwdEMQhr8+d
yeuZRP8Xkj/Yu9WAn31YUXVVP/gT03cPvdJCfuafHq3YVfCP48RIm7SCH5xv
8yK6Bf6N4gmMsWjkNxRNr/+gAP/+hh0nu1+DP6UlYaX3FPyCtQ2iXRuQX75W
e3DmA/yFo6LElcrBt3EXM/4UDv/mumuTV64gH+7PCLPuh/969uZ9qyoI/vCA
r+gs+Kye4mFRGvJBPpJZr5nwP9k5ZB/bD77ydx77yln458dxcz3OIa/GMkhM
NIK/8U65zTI94C/p0/lRmwa+tVF3Qd025AuavhVWRcDf463S9PZL4J94r1iX
qI79f9rsIf+aeP5/Ml9wcW0n/GUmfbV1ied/kfwh63wqfv+sG9RaNeL5P9Wa
mP/iMPwPKDZPho6BXxNVwO1kwb87psouOhz5i0XM58sc4S+TNGxQKQD/8ed0
hS42/P/lbBX4koF8iGxqpYoD/FVvTwydDgZ/y50Su0P74L//+YLie5eQH5j0
iH/yE/4zEawRaT74fT/MjusPg5+zwCA3RwN5JY7CCjs6/NNpKRVun8H3f7BY
cKcK/rElQldso5Dn6TVJr6IR+98cyZFoAb/qmNmT7krw85JuBu3dgryOsPKF
isfwP+VbvZpaAH7WLm5CfTH2PytiQoFP9H//sNOHeKL/2RndrgNE/+t4lsUb
if45ke+D9xL9q10Lbi4+BH85frCpCNH/B/Yeffoe+Auf/Y1WSfRfeiRTuYcB
/zgX15mlRP+nvilNsiLhLzTKVttN9J9lrf66cSf8fYN3qNaeBF+kWULkgDP6
f3c3cLyf6D98LnRt0Bj8exjdaQ7V4G+QaDR/OQJ+U87Yq2Hi/tdUnRrQMIT/
ml1zNMmv4Pf/p9skthz+f1T8/FUeiXyenHakqxr8T2hINDe2gm/YlshbwAPf
R6fArsUIeVWxUO9oHvyNrvU+35oHfsNpD9u6GvS/x1j6BpW4/9nFU7cWdcDf
tNLM+EIZsf9WGTkLxdG/ys0KPlsJ+WXv0yLXeMM/sEpNve8n+FVBObOd9vA/
XMLU/Ezcf70NT+mPWfA/Yy5nUz4GPsObzj4XAf8w1zXJto7IX0paKCGyDf5F
y+9zogPBd3z26XuKF/rXuvrGq4e4f+2d8nTNKfinKBs+iCDuX+rxBNVP38GP
OWZ1dYS4f0NTm5I/asFfKUw2f6gF/Nv+Ls0TrfA/qOBOkYpBPkAt5Z4Tcf9E
+BzddOL+ZfgoCjcR949NU6zJJu4fxb2Gtu8T/Es8lix8SNw/05mn9h0h6H9b
u5FmCHH/bpbUfHlE3L/IoFYdX+L+Ja3o6PWbAV9NwsJzO3H/8tvfCvs4wl/G
xWLj8Hfwm861vDzDhv/EVfkNHOL+3ffmHDPcAv9EPu8rs5t4/+kQLTuWAf6U
YlGiPnH/2uO4MsJs+OcEpk2/ugy+l0GohYCG/gMPddkMEs8/Ux373X8R+6+5
7ofgFbH/lBuWdT4LsP/Bt+7QG4n975wUmsw9Cv+vITFBVsT+V7ZHtC5yhP/m
/Z3XdYjnn4h+35Jlu+AvZsNlvhoF/y8Pys2z5+DfdpdrdWsn8nTbekGRDfzj
JGLaHY+DP/cPI9DvAPy/tS5StCaefxwVyhvlCfhv/r3A1O0x+E5RFmudfhD7
H/jNu10T+TTZzsUcPfj7i7lPBH8En3lvWSm/Cf618mXK5sT734uHrpRnivBf
7WbFkmsGnz7y2OZwLXH/H4YlPdtE7P+O7rO3X8J/Xf6JKK8S8PNeSO9zv4b9
b0mTdtAg+q+y1V9N6YW/c+A6S8eH4D+8H5QuIoz+dRXW0Y2VkfejZo2F7IN/
slnt5vwh8K+XHnvr5wP/RD15Xm4E8nali5s2WcO/w1y/0GEA/K2WlA7dq/DP
LlQo69qBvPsgp1vlKPzfbDGbPnMe/J3iSnKDJuh/XMD0qiB+/280WgLsvsO/
7+hj+5s88PU8DpTQ54j712N7Jnwl8nU9DYVFu+F/f+qlVO0A+JmK0tsSQ+Cf
Mf7vuq9nkR90VBg/uBX+hZLq0sm9xP6n9DM9U8BfLlUjOrsdeYuaUROF0/Bf
stJ994qL4C/dPl0noQt/Wc4UNZ7o3zy9LSuP+P7hlOOuRfkb/Mbp86zPoujf
sr7eU0C8/3ybWWro6wn/uRjvpgwB+Am5GvRZN/j7zU1VuxHfP1jay3762sHf
+4+k05uGwVenFb4/dwH+kotUPHvskX+9f3/6rb3wL+de9rgcAn6jivPz6J3w
j04uqbxGfP/wXyjeWTtM/P+//qq36SPwDXJFU+1+gT9USs2YVkX+TwZTim8B
/+diBau4neCnNETFb+LCf03AKZos8f1DK9S9LV4X/uUbfTkfPvea/hdEwrz2

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41GsbxwdRUkTHZDBH2bJlCSdpYSyvlEpCZV+TGlneOAcpRBOlBm3S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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlmk81GsfxoUsk5jsiaypEJKtsrRMGKmQraZEHjmWSMoSQqKMQRzLIQ2S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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k41HsfxqdGtooMUbZK1pPqQXVQlhCVOYxSWQplrXRyoinDnMpW1CQh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k41Wkfx48KkZFjki27ytiSnUIiZEuqaSiEjlN2UUliOtbsUTpaLFES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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlnk4lGsDxkeStbKlUiYSc7KMcE41laWUJUMhS9JQmcPJMpSTbPGVYVSW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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk01esexncoaivKkLmoNmJrkCQkaZJIUYiTOce8Mw87w0UKRyLzWNgR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmGk8lesaxkVI7AoVpS00GFdSUmaSMXNFq459kETJIpS0iLSUIekIlXm2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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmGk81fsWxrcI0WBoQCJFpsh4ok61hYylMsShIk3mKVPaxr1D0TZLyb7G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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81O0axiciRFEiJUskqWSrlC1ZjxRiWm0lu6LUEGUpS9mTpVdZylKW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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41Hsbxmfs01GWqHhtTVEdS0UbWSPbREKUHGMXjSickA4lSZF9iUlN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k01HsfB/CpRCKylWSEse9bMdeSjpuslTCGGrdrKaHRGM3k2omrJksL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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0Psv1XEcx/EjSpviUItibYU2ThrVGbnMJZfCDlOLTDc5LsslVDhRbSpM
t62JMktHs4jVTEkLx1qSkmNWrQ46jnK6EKvYFLr80Pf7fn3+gH76/vTZc599
9nntsSo2LUI+TyQSORmIRH9P/+Jk/c+aRT73hgaOlO/57P2vjQp6tm6O6efa
bzLwi2nIKNfX+4ocEnNfcT0lPpBboPzEdWeWr8hcpOVavi70z8m/rz0/VzGU
9IJrhwibHO3pj1wbjjSHJZ7Qcd3WtXNZ+RS/L9c6WGMf9JrrsXibVqd4/l6j
OBOocuf3m0aNplj78/+vXnr7q1LJ719p0plT2sjv3y+Vp6pr3nJd8zzph4Ts
z+k4/iw3ld8/6FvSdqWI339X7fWwRMHvD5sxD30zze8L16l7W6T8fp+ma+Fl
xN/kXd32bcTf+Zd4gwXxtzsU4biD+Md+2vHhGPHffDE41Z74W97sGaH+mk5V
JfVPHGpVUP+N456h1P+lscyK+g8+7VVT/9NNkvvUP1NaG039FXJJBvV3d47R
UP9zmZpU6u8xv0NJ/W8Wxv+k/nkNIx3Uvzo64AH1N+4I76L+bXfstlB/hzHt
CPXPT6uKov71umEJ9d9X1+5I/VvWLImi/hUz9nPU3zM22p36++/qBX8/xybw
f+/UDP6TVlvBP981CPwtZFPg/+zQJvBPEMeB/8QlG/C3LawHf69igzTq37/X
DPyTLfeD/wXXH+DvrQ8Hf5m1G/gvT1gP/juPloK/58kC8J9enrGW+vtVD4L/
iorMSOrfOPF6lvqn55l5UP/dkejfFIL+zb7of+PLFvCXhqG/dc8k+BsGoP8u
Izn4p3ehv0tKHfi3LkB/u35z8I+zRf+Gb9Pgb9mG/ubp6H/MFf0bFGXgH/oe
/c9KDoL/KV/0Vz0+DP6W02/Av9t4MfhnMv4+jH8G4+89jv5aGfoPq9H/FuM/
LkL/u0/QX5qO/lcXov/qPvR3Z/wrv6N/FeOvT0N/Wzf098pC/9lh9Hdbj/5a
P/QPVqF/4ST6B4rRP4PxD2D8sxh/KeOvZ/xbGH8l4+9igP6PGH/dQfTPZvwH
GH8vxv8843+Z8Z9h/K0Y/2zG3+Id+ne7oP9Txr+V8Vcx/u1mgr/gL/gL/oK/
4C/4C/6C///w/w1vO68m
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN2Gk4lmkbB3D7TrIbTQil3uxbRZYJiSFPlrJkLeSxbylF1uxrSeaxL5U1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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41GsfxhGVLY10vIhS1jQdS8aSlEZZQkwppReJyDZn7GIOUoTKlrJG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4le0WxjcSxzxkPHZkylyhkLlDhkqGpE8qMlUqn5BCIdVOROZkCG1z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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lHsbFklFpcWSRJZEGQ1Jp8ix5FDKVpY2Wo+xFyXbYRrKMjKHLNli
7C32DCUOUURHNeGQUaTVclLJkqVzfX98c//+cj3Xe93Xvbz3PO9D4YSXzWlB
AQEByjwBgf/9lZ5vt5RSJmbgteLB17LwT7/+f/7i2WQ3GvqGP2eYLruaNjPE
n500GQvXaXTzZ9ccZefQU3jObT2y8oA5jz9PCXYlFFgO8+cOindUrcs//Hk4
5USaFnuQP8euvqzyTKSPP++PStVRKQO+3W+nXLxhB3+WrXV4ucoX+pWKhvzO
3oB+1YUi+V3voe9R0lhQSRb0lxnlXoln4XmqFvNThUcP/FO7Wgxkwe8iKupJ
De3iz2MBjw//kAc+6mmPvEVuL3823Da/1SUKeIvNAb2nFDv587XAS4eHJ6B/
WaV6VH5MP3+mfn8ZmugOvNH9xsU2j4HXsPA9oG6N/Lae9fte0YD8BCO5LGc2
8D666nL5mcivU0c8wL4I/GPl0bZ3qcgvOXXw4kVV4J9pO52/bAD/pc6aImFC
8N/em18Wq/UKftRpB1+lAP+Pd+su9kPwp0sn6Zc0gP+VgnCVpiD4F/pc/+as
D/xKqV5OZTP6U0CtFh/6G/6Lxqi3qn95zZ/ZVAWb9kLgMxRCDTYcAn89VYj6
LAz8Td4Cj1dHgb9KMaFRbgr+rtGM5PsN0J9/bd1v5rjhecpI9zBPBf2/xLnj
M2oK/j2Xevz3xUO/42qqSWAF9Ouvm3BLKoJ+y7oHtj6lwKt9FTKNMYH+w5tL
6f5+0P9Bh25/NAf6tcK12b2foO+oWFhwbBz0i0bZKvwdiefVNWNq2Uz0/1i3
UwZXCfxO5821Fh3C+z/JTa27tBR4hmfu8zUz6H8eTa9lcQLwlT3tceHvod9K
eeW0Ryf0+5l94Qp1o/8/bL27ta2Al5hl6VT9jvxEpz1KazKI/bHMIslMFP1n
nnvSLEfsjxVCZrRaYn90blW21iD2x6oPeed1if1RF2TXP0nsj4Ssu/T5xP4I
uC2taU/sj3Um0lPfPJGfWTpnZxyxP+Q67JV9LyK/uEPtNw2I/dEda280XID8
aFco7AFif9C9GPcr5fH73yofa3N2HPqpIneOjMciP0sXRp6HG/CO2VKBTU+B
l3mgPUM/gPx+pKXECNxHfldXeMmXZwF/q1JNzDoZ+Yk4a2xccRP8A6tb1Ge2
Iz913ao7Q0R/Ave1FdAPwn9xtPk2c6I/93j68/Rn4X+hX2D4JqI/zE01r9re
gb+C4+IqTPSnry/XbZDozwm3Jr0O4vvjLVW1pJmG/qhKUr9XZ8L/+oTy/sGF
8K8w66SsTPRHa+jaxwyiP9W6vG9riP6cdG9yOUH0R6UoPLuf6M8E+3gEnehP
XOA271CiP/P/DElcSvRH9Zolw57oj5hq+coKBvKz/qGW+IjoT0jIwSNWechv
R1dVJ5PoD3es1D1XAe+/xyc/iEF8f+bK2+TiWcivfuvBF8bE9+e07Ui+XCvw
jZKd0jI2yM/436hBVj3ya/SftHpIfH+cGi2U4q8jvwKlktuKheDf0Us7Yb8F
+X3+Ile5bQPwTy6s+5dpCv+sSHEt1gL4z2nReh2uhO9Pi1ul1P5k4HNK3mQc
agO/r9TTY0XN4J/NEZhvOAH/2c9zi0yNgT/80/jaaCFxvzhm2zHq4f+jfyKD
cw77u4539NiSEuD/Eo6RDN0H/hspYmcM/gD/60UORjop8G8ZXhbd8Rn+jCsa
GvO90R/GS6sIzWDi/tiQcC6uCf15euV62ikt8DtUajlGLUZ+mhd58+qHoH98
/WSLaz7yS3lRnknJBd6fOfZhFxP6g4LFd/HY0E87W5RTaw79K/fLjg/KAN+3
uXHjmSjws61n84SUoN914/JnKonob8jJusCTEcAvZPcfeURB/6z6ijhb5sB/
VDzyZwod7093ZGzO+Syx/95J0M8XAf92V6LsdmP4N5yo1X07gP5eX+QW5pUK
fPwjWq37A/iX/LMgqbse/EGszxnbFsD/9z6uU6Ie8AqvvN6XcdGfnjz/fjoX
/Ca+8aF0RfTnRaYite028fszmdgx5QR+pivH3SwC/B46b0ZLGOC/87Ig1GoW
+Ubv+8Z12Ij+/DgSarH8JJ5n8RTlOTa4X/LflqRttgb/yeFPUZbHoV+x/McV
hXToL5zYQglZjvysYlxrFhP7U3A3hUE1gv630jlCPsT+/OWmS/WNAui3Epdq
tvwAfazifI52JvQLO/QnlcbgObOvRdvCG/2XlahL8FhLfL8YO7ltQeif2aTI
LfO1wBeVpz4rLEP/hMJNI1WjgX8zdIsSL43+6B36yzzoK/SLJC/d2pqC/plw
AsR304AfSB+4Z9IP/ONzm9MDjiK/1hsL6Br5yE8zk7N8lPj96Y2NHRi/jPwi
9qil2WaAX1Gz3E7LGvnpN9kZrpYGXrX3U3R1Mvw3TOTOHFeD/6dT++5a+cJ/
rJJn9mQo8J7VTVnxv0G/TmTe98ei0J8ybTgrcQL+vT6LrzYNBF6xOZq99wLw
u1aMvFmlArxpX7FsrArwf8iq3dUg8veQrHM8S+Qv2mYyRSPyN++5Zz5O5G+X
58naTuR/J0JqOpXIX2AytyyPyJ93tWppcx7x/2fiLbGfRP6tLO1jbCL/hh1X
apSI/NOXCA+mE/krpMgc6pcC/qHyi+LBFORvVPD+xmsi/7kziyp6fJA/c4T3
8zqRv5DzXjbTDPpZS5/O9ohBv/27B8W3neA/MbCCJxxE7D/jVZ/W+QCfHFzD
61YCvrNrU0P2JuBrCjZ28oj7oXqtwWgvcX/m6Ny/cJm4Pzc83qjYRNyfXwyi
TIKJ+zPYRXTYlbg/n0w8s7Im7k9rwU3fPIn78wJ1z0gmcX9q7HRVrCLuz98k
tA0tiPuzTHl6yp+4Py8ahd1UVwZeR0p/sbwD8lcwyoosX4L8c3W/PqcI4PvH
Pf5BiE7cn+uN5zS/DoDfqDjYfaId/D20iIKdPPifKRa61msBvHph9aCcJ/Zn
+5yN6b5s+P9Az55pFYR/8aRXFHVify6J11P1Ju7PoPYlzgLE/rxetac7jbg/
JeIiG2qJ+/O1V3L2jmzsTx9HzRcPifvzZTs3hOOO/blA5p3NzzXE/+9BVz5e
DUN+jTt9A1nrgF9bLrLl9yz0t7Zy12kRoj+ykpJrY5Tx/l32ZijJTUE/V4Yz
f4aJ/Ci7X9uHeQC/u9VpWrkR+PiO1v0hFoO//gf8hdPx
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlnc41e8fxkmkpLJyjpyMZCajZCQjQvUThVBC6GQ2cIxkhE5GZIushr0S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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41HsbxqXGLoTs2sjSodJkO461oqJEJ8or6yRa7YXIhKHGPpReWbIU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k01V0fxc2pUNQtRYRCpihUGqg8hmvMkERXEo/MIUTIPEa8pkjkktlV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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlnk41Gsbx21RqMtWKepY0yI1R8pWtqTESRhbQlkmOkm2KUsYErKkbGdM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lesXRWQeQnJOnYpEZJZrTrmUkFuKk8hQhihdlCjpmFWU0KAylSkd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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHsspsrUYZcvSiIaaouWUZM1S4VQiQhFOKFtahGStQQnZTsqS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bRenLm51sJYWGlBaSZAuVCVmyJGpIlspWaRK9yjKylq3JniQV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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k0lWsbxmVKZDp8kjlJW5kaJEXm6WCLBinkmKKEDJE+UkpoUkJIhBxJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41esa3QcZMockriEZIylHm2SsENlFCdeWJDIPx0zELUM6SAkZKhGp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k0lXsXJoTITIQ0uaIrhdBwTakjcyEZO4rzZbwyZWqiRDh0o1CUMUdJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lG0bxoeQGJo2IlsLhaxJKVtlSaSGCAmpLOGbsu+ylSVSJrt8Kntl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lHsbHrtE9gqdbCGJHDIHx05Ilggn80UkESESUTpGshukrClLJaJl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk0lesbPaTBcE+XQoaUUhkyXTqGTF2J0A2ZpYyZ5yFDkSFCk1IZSkmm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lPsbxickSfYULkmWZK9QlGMpjSGyZ0tI6UhZMspWCZVkJ0tZ0thS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlXs81Pkax2dc1uRSW8cKkctkw3Fd15KIoiS1cinlkrKUoqnWpilWotDo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lG0bHrxJeVGyREkITXgtJftyaCEkiWxZQ2VJJYSKQihJJFmjkc+U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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4lG0fHRUpesm+b4UyhTIqJJIlVJZqJEvLDImpt0IJfcquxNsnxUiy
jLJUBjFapEVaGDFIpGSJQlENIXqv749vzvPXc/2u5zr3Ob9z/85935r7/3b1
mUMikVYKkUj/++bYVPyYaRG3ZKcM+fsUDln8v650GWxgz+kU1MLzbGsTNYcF
9QUx9WdC0e2CuiAtOM5sI/AbvBWbczS7BPUHOYWkm+nA89QcFnE/tQrqoEcN
Ot/4nwU1w1WFHXDjo6Ae5T0Oq44B/mrJQGOGW5ugfj79tfwW5YugNlzL8BxQ
BH78fFLx/FLgK08ye8U9wa98xHjX5zzwf1G5mOzi0SOoHWNFKZ0U4MmHdEzI
Sujf64xvPV0a/XdPXJagiL4X1ENy11Olq4Dv14jOLDci8Eu+G05KBL8CqUB9
PBn8RqlhEmx54AdpGyXqq8A/SVHhpLqBP+6rrkLX7XeCOue1Armb4J/m4Yt1
XVT4p25Ld7Mj+Oer+nO8RQn+zbUn59WzgZ+k3jrt7QX9iSILLpexoL9xnL6U
6Q79YitntZ4aAy/3rldTTxb6f+YqUfUWQ396vzzVRRr+2St3BjjeBd7NsnuE
swL84a4HYrfFg5+fXKirmA7+F9ob8vZJAb/uI/lAWRv4o/bXGO6kgZ+xZ2is
IhD+KTXrn9sYCvxD9XtTW9LgX8/QLOeAG/z7fmGh8PkX3YKaKpf9Wu0J8Ee/
VNPFp1oEdUbuiJ7WQejP9JUTyuiE/rVXlnCjPkOf59cLzqFlbwX1RM4ae6FK
/DdIcqU71HQI6lXXTjn6/QX+9uvFcVuG0b+p6en6mQDgW1uLDEzt0H/WwVCa
zlHgzdt1/vJ/hf7PtrFcDY+hf06wU0D7WfS/dO/aJ5H1wIsn6XpMP0H/Kzb4
yFraoX+PN6tyh7V6BXWTT9E87yroG781md1Uhv748q+MyxcS8sWbavYlwZ9E
Fm87PxD47dl/Dq5UQ3/N+qL/8fQDvsFg7FLGb/Q3KEkJYJxDf7yN7jaGTuhv
UzulzKwZeH2uvxM/B/21eGjMNV+N/k76LnmXtw397ZGXL85Nhz7m5YiyyN04
f5nG/8jvNcH6W59++7BFCPt3/JzU7CZR4L2YQflXLZCfvWpbNn+sBv7s0sIT
B6WQH5lfPxVWhUBfhFIEP/Ue5o9U93y2eAbrN0mtvzRiC38XGVqxKMn4v3vk
QeboP9D/3iYn1sEO/G+eJIlHlL8R1FvK6z4s6Ie/+2NkL2WMQL9Zz7EFFYT5
4Rv7l/Mew9+4BjehGFvofyDhlxy4FP4OyBWk2HOgT/9XZmBMFeYnTKz8ha84
1g9l0AsMJwj3W9j1Sy5HgB+mf385Zoj5iXRlvWcwgL9Zcj+mux/zk820390S
gf7MI/saC/0J86OoGf27EXgNMc7Br7fR30N2W3CMKSEfd6Y4Qeboj2tLtXHO
h76HY2FFWgrw/5i+uWisLtY/GZ5ttYOG/mJUHla4GQHPPkqn9x3A/S2iOz4a
lgd8s82vOM8CzI9pWcVMSjP0icq3h66ewP2hyig9keYD/PR7v1AJcex/ws6o
s+Yp8Od99oB32nr4s5AvFLCXB/zs0Yf2u6/An5U8dbaQPvhfCGn2+brBn678
i20yKegv0iV+X3U4/Ln0WHUJxQrrPwtR2Z75Gvpygi1mZL9DX+z1U88CbmI+
PZMdzPc/B17trqrLk07ou5DkxTKjQp9+Mdsyai705bA6x9UboU+EudMo3BLz
meW1Ir/1E+H8k54z2PEI+VvqMf5H5j7h/dVvbX+SBTz5ZPpHXxHo+yhtYFAl
D3xcleuI3CngMzcvzp/5Cn9GdU2FG7yATwna9C1hLfy57kB/8+MG/On4c1ep
SBT7JztpeYrfArzUvmIz4xTCfA/n9mgugz+Ss7dC4mnwR0Irrq0nAfrKgmq7
Mouhr7udS1LbhvWVyAPBpUnQV7gu45oJD/rcPWnij60/COq8DZ5crSbgn8qU
hjgWQF9fQ9Wg/RroWx7L07Cwhb6EwX69rizokxNyTvluQji/p5slHxgS7of6
Zer1hsif7THqfV9V4L9PCNP025A/FWVZklUZ8McnQngiO5G/CguflNJrBP+W
Cc0/Qcf5bZV1+fW4AfDHUmXuixuDX1tbd9xaHfzK+ofm8OrB75uQzFEmvJ9Z
cTwzpgf4e7ZH5OYR3s+5XjTuJ8L7+V7Q8tFzhPezu/eQzAdl8Ftd6U/WkSHc
H/fOqh+ah3w9168RucEBPnCwT1J1DfhjVwYyhZPA70zbM9WYCH5ZfrfJGUXg
lfnKJV9ug//KFa2u2O3grz7Xm5j6FOd7yA1eOTsB+Oh9x685bcT5TtPxcDi9
DPOl2qT39xtjnH9FLHrNo0Lg7/248zY9BvrvWqvYX30A/eq2I9y92tD/NJTR
Y+xMwMctb5WLwnz7x9MWsRvAb1vjtqdyD+a7X4V/WY/wPgmSj1fdlYv5Vt7W
aRZOeJ8kOwT3aRLeJ4XVAxRhJvyxYXpNRO/CfNPS3DM61mF9A9Xoz+R58Ldu
k8ntpAXAr+2jclabYH/jm15MmRPeJ+pGDDFpOfjj/cWPfTQU+th9d87UVcAf
jveJhiwS8HvJFNPZNTjfSuzIKtqE8yNSZHLyRAn0t6eufbXICXjnB5UzpxPg
b2IZi1vzGv5635es4TrD316OUm0m4fzYmk9mxOTD39Ldt1yiKdB/xn3/9JA9
/LVepFahnQl9j6Te9+lthr6h2bDvCYT8OLZ7zv9CyI/iT6NDZEJ+kiMs2ncQ
8kMNeODMIuSHM2LKXEHIzwK/lwslCPnxquoouEfIT+67rr5EQn7Spqzligj5
OX+7tohByA9L0WW1ci3yE7vqp/BLQn4ajkfYPrNEfqi8jkEKIT8ddVMDUWuQ
n7Gelbf+S8jP1THjoPxY6D8/eLh6fTX0by1plRdeCv0iVIXHXYT81OXXRwVG
EPJjIRb/4xX4E/pfihj4YX9HN3qSggn5cUiQ3FGYjf0tttYhH1wF/jVnDmd4
OGN/ScqHIjzT4E94620lw33YXx8uVVnNDOsvLs8ilU9AX+31Abtvc4GnX66s
1diJ/e3tNNjxo4aAb2GJxIjAn7GWambnEegLULFhUl7Bn9hlx5b8/IH1HXfS
uj3DkB+lEA2FRzn4v1pHo6VBD/rX3/APzVsB/kujVmO2dpgPrrHWZjNd4LOr
3hZ9yMP94mS1rH66GHjJj261vSHQ/9vXqUixAvqPrHMzfWsM/f5Ck8s1Nw9b
/AuS3Uoq
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41WkbxzFTJISxFI3sIktOojOyJFuyRXYdTSTZW6REOUh20WQZ2bMm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV0ns81Pkex3FRctdYcpmO6xzZlRy3cT3iWDYdTu40GEbuBiWm5FrahEhL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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81d0WxumW3JJImTOLpLwhkpCxV0hFpE5lbjAkYwNKRb3mDBHR8OoY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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lWsbNVYURRnLNkVJMp0MSaJTxKHILErJlDFkOG21MxzKVNucTJky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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4le0a3RKSKfE5ZagQSsaUKIeUKYkyRMgYncyiskNRhpCMIRGZ58wN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lWsXxnfIEGWWjCFKJyWzSqZTKJkipHYyZciYOVMoouIo21RRO7PM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41VsbJWWKzCJzKhpMGUKUNDgdUyp8oUiGDNFVhgxXuaVM0cmcKZJK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lHsbxzVSlJJlqFCNUnQ0pciJIxSp7BERTVmKsceUvXgZLWiQzjSn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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k41WsXxlGJQkhsQ2Ej1eakQaYOsZOxCCF0yli2IsmUKQ0oTqaEFCGS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41G0Xxy1tkiUe21MRaZURyqCsRaVNUwkhWdJ4ku0ZWZ5iZEvJkpAl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlmk81H0Xxi1lKgopRNayjyKRLGmxL92S7VZZUsk0JMVtCWNJhBI9QiFZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41Gsbtn7KacGRyhKGLMkJkS1LUdOXQYkW2TOVipxBGPuWJSpMqmNJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41G0Xxy2FkWRLQraIZLKGpCYP0ZQitCnUZMmSJ7K/KTUhstOjiJRC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c41X8bPhQqJJtwQigrRdl+ItWJCmUlW1Zakogkr5CRUWj4KXvLLkQk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4FOoXx5Eu2Q1ZplR2bkiWmkRIIZSIYpQYS1KkECWypQxREZoSIpWh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41esaReYpM+2QOSrjwTFmpoOQCoWSpIwhSSHzkEKRTCVDCoeKyhRC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lHsbnsraUHZKdMSHUhJli8qoLBNjy1IphnGUULJv4ciWlOXYxlK2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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41PsbnVyViqaJy9iyJutlSKHFEkmkkFQoZFpklEjJkKIS0YaQrtKN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4FPwa1TRKIhWJoggZJrqaIsoSRVJIJUn0lRKFcK1RCfls+YbsVJYs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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k8lWsXxikyV3bZKhSanE4KZQpRnSRss4QyJUORSHkpIpSKSKaSk6FM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k01esaNiRSOzuZUhnKFJnnRDJEqEMSkgyXCNnNEU5UmiTrEIXKUGYZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlmk41Vsbhw3JUGRIGTcZKkpbQpxjJokSEUopQ4MhQs6hMhZJm8rhzeFE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFZe0omS7DwOrS1sW70X/fCHsbn29NW3Vj5BM6P
img+prD/FZx/PcLZVu7WfTh/psXml++Z38L5CZz5aycsvAznd6OZz4Jmfgqa
+cvQzJ+FZn4Umvmj7h91/6j7R90/6v5R94+6f9T9o+4fdf+o+0fdP+r+UfeP
un/U/aPuHxnuBwASyLdC
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANELpPTvqrDxOhR9ajOV3vzKHsY/+8/+USb3Azi/
7rKZhBjbWzh/z8tXL5ymXYbzf4RPZZdd8QLOd/0U6KTU/sR+1PxR80fNHzV/
1PxR80fNHzV/1PxR80fNHzV/1PxR80fNHzV/1PxR86lpPgAjF2aI
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFXK16qGXLwOix6fuLqp8Uv7GH8GduntB6Y8ATO
Z7/DFiq0+hWcz2xxhYtF4QGc/9DizIs97G/h/N3+7hqPei/D+R1o5p9BM//i
bVTzW9HMv4dm/lk086ehmb8Bzfy3aOY7oZl/H83842jmT0Azfw+a+Q/RzI8f
NX/U/FHzR80fNX/U/FHzR80fNX/U/FHzR80fNX/U/FHzR80fNZ8m5gMADA+L
4Q==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1ms0FGgAxvEx0jKW1RLVYCZRiVlDqVXZZOkyaJtYrVsxjktEdqaW7MVl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANH2pnG7PHl4HVpVGeOMt76yh/HfpAsz7OR8AOfP
Sy9lsOd5C+fz67WlfCu9DOff1K3vq5j2As4X3Fkkz7DuCZxvMlf3tNoEhPnH
T14+p5KMMD/kaUzyO3aE+UlK3Cfr+xHmJ3R4npywAmH+hJlNrtO7EOaPun/U
/aPuH3X/qPtH3T/q/lH3j7p/1P2j7h91/6j7R90/6v5R94+6f2S4HwCAr/sV

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk01Gscx/GxlrFzpagciSJLMjTpaLLvGVkrDnIlbdxSaRzZUlEIg0Fu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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13s41GkbB3ASopw6OKvYTckiQw4l55ySKGzi2ik5mwkhpxBecj4lxjTC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV12k81Ykex3FbthANikJ2xx5ZysgyYixjV4nD5NqXk7UUXTSWhEQkKctc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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN2Gk4FdwWB/BjekkUMqYMIQ00SCLkVXrMFJHhpRSFqGQqmVMpZZ5nyRyn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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk41Gsbx4dGnSJyKEsnakIhlZTdsYVQZAtH9p2yJRGJnDY1lpKUfSlp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41PsXxwcp21iGmMK1VFJXpUImWW4qRaWQZK+QFluhlFCkUl1SXCSR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41dsaxze5jjlEmZJZ5umax0spKkmK0hYpKsoxVYZEhtNRpiLjIVOI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41PsXx8fINrKmhsierm5IuNaaCEWoSFlykVxbUZamLNd+K2rwhLrS
ngipIUtCGVnaJKKoaJB9TYZC3ef3x2/e378854/zmnPe73PO50vpYJC9N5lE
ImnwkEj/+zuspi1YKCey9aHsHLXt+Rjt/3GG4T7KYZ52brxFYdO+scJhbjys
vv+yC72XG/O8U+rMCkD+mTviWUdV3nHjlMfXwtXYI9y4nONvUGvbw43v6v3R
pCozzo2pDf2CW3TbuHGTlBKLFDbEjSONL+qe+dEP/kbbU5I7wQ+7V/XMUJzN
jbM2pjCfLKC+CouGk5m94OvnT9SenAL/q5iIgQU/+JHmS2G/WYxy48/b16jP
OH7ixlEnW2rJwwR+xmd3zu633FgtlOm8zhj6GfTLb+QE9HFjuaNT11obwZ95
Zhk+ntfFjaXejKsr2oIfy1xSbGmGvm66bvUmuoR8RXrU0ULUN7mszWTHLPJH
f88rrhNEfe56G1KyKajPLHxk/dsW1Hdj55hRcyj4iV2LHfnuH7mxzOOyHXNV
4Jd1kgv792B+SNXMsLhu8INWdVeqCmF+3mn2SQvcQn7xjdgvHWzkD62Q0Lmq
A3+TYiRPsi3h72NNqoTeOPJfSlLCbA3Q34i3g86D9fh9nXrr+x4M9PfK2d05
vhD9WUpF9V0y+oD+R5dVkegEfn765/HeDszD1A8erSeob8kpymNyEvMd0NHN
vCWH+Tabb3fxVMD80WaZhQ3emL/nU3uyKqhfuLFLsy4jRx38NaQi/QU39L/C
snfebIDgb+rN2zKe6J8q4B3+3gL9/5P8IPu4I/p/RIl0lO1E/wqiY18pNpg/
nRybjxwt8H10EpSMj73nxiwzsg0nEvmPQoyCVuthPmKrG0SXSpD/pfRDT0ci
/FXr5DWvXSLcF5e0gPMs9Oc+lESOYiHfMLvIuFsb+cI52+99fY58z7G2erYu
5qtcpstxnIF8lW7L+HoX+BfUyL6fRoe+ve1TqzVyP3Njf9apdlNx+Be/u3ev
vB/8I7WNdalfgn85nfdoUfdxP3ToJScjssEfW1PMYdqBL7buSuMo4f4F8pmb
ZWuBX3vRyv/6MfDp8Qpxy3gwHw82S3aXbQPfzTXZ/4gS9CNb5fEen0P/Gvmt
X0YWCHyvW9u7eKBfsl+wV3Mv5oOT4RMu5g1/lYuSvaOZ8DfvjfR26Vfgi5me
59P7hvnLXr0/8dYt8DUYey8nn4E/a1WnhU09kU8JsG5pdcN9C1+S8t/4E/19
EIy1tanu5sbqoUeOy0pAP6kX2hzxQ+hv4edz2+QL0C85NNYprRz+0C90rBpO
B/+FXUHStAf8GdXbZhMtDf7WGvVBqgH4Pj7pV1/Rwf9zYSRs7Sz4Fab2DPU9
4OtW5jXM8MAfHlea2ZpfhP2t0WY8bAY/0z7yzeNe8IszLVWllcGfoH+/4/Q7
/LnpUpBS1In7zxzNkaEQ3r8Z+p2HLwfAX5ReTvKYAd95k5CGOwn8fxmpd5Os
wR/x8lB0MAJfTSD0UXU/+PzXS4X5/OG/XDBrtnIn/PetLUsQssJ8/VUh/Dqs
F/zvfP5WDBncH5p4s+suBfCV4mMf7XqF++Pu4/4r8ybyg24XU8b8cL+NmGo9
mfHIH/77ZuThS9j/qMr131Ky4I++6LomBwf4v11gIjCTsJ9XMjI6L2pDv937
Aj+uCIF+Yizme5Of0G+O/mKsxxL8HmXeOOHV8L/6xIFGx++ob7XgB+ePU+C7
TaSP7vgBfuLgSPmOr9DPz9LV0nI/+p9z3lPRNI/93MqvPDnRCf71lMgM2zvw
54A+JeR7KPwJO66osHIa+7n8BNOpRhH5Ne3rcnzqob+ncmCL0zX8vmlhb59U
BPQfsCYLCJ5GfvwVhxn5OOhvrLrN8sdZ6GPjHt/HEwr9TYasbjJXQf+zx2hG
7WbQ54Dw2d0Xo6EP66nPkNwA9C+usrfgPQg+Q2oi0KoL/CaSVmCsAPg9koo/
RC6Dv2yWlkB5An5ow7rBEh/wR05buLEGwbeW7KCTNfD+U19yjlRSwb+WFPd3
oQn48y0S65UiCO9H4raNVRPge1XbRbk7gV9qOuZHnkb9DZtaLneTwd9fR/0Z
VwF+vsLdpJ1t4KvYFQQYmIJv6+W7mCsC/6JFhQ7XBOG+dl4xDGVTwP8W5JJG
OQP+loaPTweY4M8b0thP4sHfZal9yO4F6hdxp/UEPoQ+Uj58x+UJ30d2VNmB
WGXw/fMjGeK+4A+W9SxzXoH37275B7UHmuCbM36Sd9hjv+r4aso6CN/nzFtG
0TI2mH/zaZmCUX3Mv+juT6U1wdivPlvxxUQW9Ola2zxsU4/7xK4wr7jtCP7O
SzO8wlfxfoVZlJ5/tAb5SvnxA0Xy0Hev1sr30wT/+CePaksQ/Js/L71ysRX9
d9kODLwj+HdC/GO2CMG/mJLmuIZg8PPUW7TUhMF/13CnMfgU+LnKgvfq74P/
KSzZfzERfM5J6XnyM+jrQrUfYT6Ff9Mp7yk7CP5JpX0eP6ME/tOEQyquPuCf
yNrVViIF/2I44v+qaICvpz53YNCR8P2y1yahZgj69hROypyyh39s2ue/tU3g
36HU6zsb/eDfASlfwcRn0CeKb9vS26vwz+iJ20sXa/BX0lLzd3XDP1E3Xb5A
Y+S/mmsdqDqF929x9rrc9inkuzqkeW5WQ33XYp3upcmjviKaYU52Lur7LfA1
tfUC+M/qqlmyebifEwbyez3Og59qFcrYZ4r7eZa/IPysH/QzKP6wmd6E+8Aw
65FoJezvL5UtHd6E/VVVDgxZV0z4vjCcmd1K2N9LRbOlbwj7y17eLjhSBv83
9MVskCL4L5aatuUxcX9jSIGbCfvL2expwEvY39wbvZpULfBV3Zi3D+6B/2Lt
7HOyI+jfu6RKLtEa+mpG8yZ0/wF9tRR1vnwNhb6VnNy550+gb/hoyHJGM/yP
0OwvPeQEfme6Ru7tFPjfqEm77L4K+WFezbXvt2G/Aktjcur40X+DVWxO8HX0
/9rJR0y5Dv37n849l+wJfdf6Zv45PE7QNzKLEyoKfaVZ1q7ahPdvxnfFaIsF
+Cbr3QxrYwn/P6YeK5pkg68u7X0p7y/wnfqFAuxeYz5ErSI+pQuB7yumtu9x
Kvh9C09pruXgT/2zonfmBPilAixjpw7wZ31CrBTjUX91yquyqdXg55+LJ51R
B9/sW62ezhHwVQuyjicIYT6cirX0yUbg+6lE6AkbYD5y+/RXBUyP0f4DVI2V
Kw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41esWx7c5QxLa5jFTJzKeRMKRdoWMGcqUSsZskSFEl3BVKBIJRyLa
lLHCOcYih5AQkllmCSnD7ek+94+7v7+/POt5n/XZa32/631/ltRZqqUrI4lE
UmIgkf73Vzx63qJSfLv+xtl3qmMTc3r/j3/usYnxNRihxykLocHVwov02O/I
QJysYjc9Hh733t7tO0OPWyXXxDmZP9PjHU4ZjGIG4Cs6m1Q5yY3R4495jIGa
6wv0mNRf7zi0Dn4/myklhmEWvze2njc6OUGPhdoik+Rd5+kx84a1Flv5J3rc
viaQ6t4J/riN70H1mR56XCA9IzORBX5SnBRDYOo4PVYVi2+Tskf+D8lI9fl/
9dHjlyJTb2k78fvjd4ybyxyH6fFmyn2fY5zQr/antC7bv9EfrX4kZ74M+nnk
uqvti5qkx8fZFBLetEO/qybzklHF8Ed3jEWQJA5+n7dwU7Yg+HqFj2tunAW/
xFOQ5CIBf1xSM9/ckwbf84LAgwgq/HETGH37fBz9G620rzkGQb+VKQ3m4zbQ
z56p9COLBvyZrW6N/7IKfezMO6Nz/x6gx09cL4bKMYDfPmsgcv8yzhujY3lm
p5CvrRZvYsb0kR5XJlsXvhZC/o6GOre0xX567K5ncjunDPmCjGImGyKD9Ngr
Oirxni/y9/EKG41vg791rY2yd3uhT1GjX6J4HPTPTkjylhOD/koR1OpyMeh/
lOWuxeEL0P8SmWZOEYT+luGSkf2/gc96iyrr4wD9mzKb8ptnUJ/12GmjJivo
/156Xa9NF/rvVL514akr9GcTdWl73IH+BRznExRioF/PtmKytyH4G0cPO0sz
QD+DkM0x8xPIP6Ekvkti3xA9DmAtMOqdRH5c+7aQOU/UJ1pj8kzIFPWpm+0R
djmC+ihO4aflpsEfkSl0YWJEfYV+h+9bEfwNrM2ZZv2K+tizmZszypF/qLXL
pokMf/9e5TDeTUW+8ZFELYGd8HesJehawwD0l2GjCEVdhr8F7uNMiaLwl9L5
gu+gFPxdia+b63eHv0EPzS2t+eDvrLrUaqIK+GTBljOqZvDX+EEGy9sFwv06
u+S6Wwf6vfSgznIoQ7/n/lHuZTHQL2iarT2vAv0nDAiyGexE/3IzAtppF8E/
+F69pUsI/X/cK0LbN4z66oJblHOd0L+Snct0twjh/fe8pJkqi/6FKhtc2L3R
f83SgIT2dvQvxN9RnqYJvk0Bk9WQLvrXHLnTe2MZ9SXsNZPYL4n+J1RsRwxF
0f+7eM70V0/Rv3aV4YGHd9G/5tZl19Fq9N+kG/Ru6z74kgX+A9xiH3DfpS7I
y9sS6vu57su7Norf//NzwDZm9M9EtUlmLEf/cw/m5NW60D+ncVjuIAXvd7s9
NZ3Mgfr6ClQtuqLwfXCuryXRuMEff1Los+oPfqVl8R+PcsE/x6OycfpP8AMr
aK3XSlA/e+2ylrUE6j9kaZ53jPB9eJzAU7NEBn/hkOqgiQv454u99tdJwb8l
kVeF3RLgL3Rayg4FEN6nmz0MmaPQVzg0Q7YgCv5xzCwmnHSCf4IGn/OnpeHf
PFcPjUJCfsYbCy/nK3j/3R0mzxbPQL+i4U7dsg2cM2nIMYeRkd+hruNF+4X3
IcK9cWGoCvm/F/vFUdfwvqRejOGpcEW+na6ixjkK7seTW4OL17+h/x+C+YG1
S/AvpYzXN4wMfccWW+a9j0DfeSqXiloU9F2tfBGUOQr/qBb7E7Y8wFew/nA6
qwX+hZNypD5wgZ/L/ciqIxx8w9OkH05F4Bf7zvlL3AZ/Mu+7ilc9+N3h3DLb
lnG/M9IGV0oJ83FYz/63UH7wtcvWpSOcwe/QeyioLIv5cOh14+0UAZ+7diNQ
NALzkTZa1HBtCPoyXwg7NZKC+TDil3VQ9cR8MO1k1k5kx3zc1oraz8eL/OsU
fucpAfjvI8WZ4/8K/rJayetpNsLfD/zU0Sob5F8N8ZgtTIe/8SQt/gQx5A+X
qF4ul4K/hiZ1RaYs0Ifz/BWzwELoU5rX/mKmDfqEf6LY+ltAf7OVGt+/fkGf
Z18MY2pegt/1o2N7PS/4WV9vbBbYg6+ULDOlkwz+r6U0JWoD+H7CMspyt8Af
MnqiJh+E+dEJ+MveQxB8xeaK+m9a4LfqS3WMhoAfc73RpvQr+KolAzJsduA7
dDZeZFoFf4Q/rCGE8D7yfY/NdywBP61H38WuE/y3xwPS7xiBf6ubrSGYFfpH
uNp1radAn2+xlUp7eMA/5Zjjz+0F/pexcfFjWQT9YwN6egvBr/M1tDB7hPr3
HhxZsdFD/UL3yT+WCN/3P3q2nqyLg39ToumMqhv4VK4g8wgy5r/itVDstCL4
As96s2m2mH++1vjiQ3OYP9dA/c09xpj/DwsB53i1MP/XnY5UlV3C/E8FGLCa
NEGfFwq7tttUYr494kZlmqzA5zlGPmlQiPm2jxNZvySL/CpNrkc1G/j/LVgl
SXOchP7jHxiw5Teh/7YCL2H1YfR/++I/A2WK0HeANShOZzf4DoMhsl+Z4V8/
mbVCgRH8afLEpnAt+FFLte+W+8FPjlxvPq4J/t0FE3kpIfA5lxzaeQ6Af+9T
Ul82G+H+FHNtVWSCr7HcPHGoEXxlksOphvPgp2dNCacvwD9G1XAheQG8jwJ8
GxFlhPtDi6Et6h8Afyr4jWDuFfCrI0IV+FfBpwxl/7K1Bv/OhH+W1QbmL91z
QkWICfyjHnzONyvBN0k/E8rTC75rlY2vgB74n5PkNLII+6eiylHNFcL+uas/
xMqUsH/+k/TeYDIW/OlBjp73hP2Te87XyJmwfzqYccinEPbPxGT2iZAS6HO8
/EwEM+H7MV5XGBZD2D8tfsb7BxH2z/eF5W3RhP2z0fvGZy/C/pnp3RcyTtg/
nbz5w1MI++e8AO8ZkWDcn7GoCf0mwv5Z2/6fhZ9quD/7i/lfP/sGfdS3+DgS
K/H9sLp6PrX0F86LdfKd4sNwzkxz1hiaxfl3JuFI01Wc32wIcTLiR332ts8d
qjlxfl7Jyy2/Fvlc3wa+jwzi/qa3nDQ54YT8PodGGtkX97fDpY+dhR35PAGx
8spx8LfD6ZyW2A7ofyL88gDlEvQXFnWLqc6B/ie0TiWIPIK/PvG/WOOLoP9J
19DZJQXMJ0VHtnSDsN++WfbYbCb469fE2vKY4G+3c2jkXoK/EZvPRHsJ/lax
3Bxd8oG/k3cOV0wS/PVz1F4zCoS/6zxu9+5aw9+ho493RP8Of59WmXL2rczr
/RelF0GP
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41HsbxieKI5TIPmSpbCmNSpZj4jhRxp6kRC+VoWQrpNCJ7FQIk93J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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk01e0aPY5wJUqZZThFSJKhQb6Iis8Rn5IppROKjxRlbiUllSRDhszS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k4lWsfxYVjjEKKkvmgrW0sGcvxpolkzJCdOFHYZiFlapJEXIbMHfPU
4EjYmhSiMmQssSUiW8ZkSvJe74d3r+eT63+x1nOv37rv535IOXmZO7OysLCQ
17Gw/O/nsztblemyfPr7HQsEyyPG9v1/Pmi7127y6xfmvNM8xMX1zDhz9orI
q9LvGGTOyVPuibsEJpkzz0qow8zZTubMmC4Nns+Gf+77zLTlIvhTdG8vLpbC
n6NBZfUlGf77VWobp2Tg/1PmLk1luYM5R+pqUy6awl8mUDJux4ER5vy+ppFH
/SeDOZtl2bAXtX1mztsFlU79p2GCOYtvs3j+UL6bOcuS+CRm30KfJig1+nrP
EHMeuJ3fFJYEvZ3mz1hvnR7mTHVyT6zwQL5Wt4E4izrk21Mh1zAihHwSiqmP
GDbg125VveqTjHzP7I1mop+Dn1yv+cybBPh/z9So2HsW/m1pfLxckvBPo7eG
Xt0IfzW7lVKaI/y/ZPxcOP0n+M20uSoKSsE/V9eIfi8A/HgYAke8RpG/nUE9
3e7cxZzHcvnNhUzBj/X+nKGB4TBz1v9L21ty8htztrEJCRf82sucdeR79X4J
w99J4uWPB5z4vYeCB//YS+i3kFqUmt58ZM7dboaV+g7QZ7xL9L3n9R7PPzDH
eo0f+iXVwf2zfgPMOYi38AWV0I9HSbtFzQnwuyA8WBeUAn69o73bkh6jH58r
IUaCKeBXES5TMEVBP/1Rs49mCP30L3GVbeaFf1j2+7pqCvzNFFi3cJLRz6gj
aURUBP5nWv0TLKPRz2GZ3l/2n5DfZXTO2/QW+pFLkf/jiDv6kdeyo2nxoh/+
sc1SHzZDr7uxN2OeFfyd5o9pcb4Av/Izl3J6usD/i0kFq5YT9AKvFBanT4L/
X63ibFYc0Be0mxtLZoK/57PQ2f7N4HNPxeafvQfBZ0+R7pUHUeDTl8tGoX4A
f7aI1fA7QeDDmI5MsS0G/+GlnRpiIvC3VfM1aNsH/7UwuRyjK/BP5SgOGR6C
f+AQvzkn4XyzxGSNTdXD/1a2KHsWYf+8cytal2QH/yavw0X5t+G/skFbVe0p
/K22htItk+GfQet7IukEf+urO5YTCftn5VfKNh0++BfWN2w96gD/1cDuFHYS
9k8DfWgwbxv8lzrEs5QuY//Ycz8YUBtCf97fc7MehGL/FBuWSXiewv75szle
JEAa+2d2Ko4UzgF9YvKQULk99k95RKFD1zD6bz+8vemiKPaPElnsuLo89GKb
82LvFX1gzlOF+k67M6BPGknPfpTSh/zuDReSbkOvaeuuF6KM93P9+OQ1XsL9
Jnb9s6BEJ/ieLmlh8BDuN/sYv6NjruBb5l0gVZgDvkl3L1MyCtGfZdCFY273
4O/Zkv95Lwn+z5NZWAVl4S+7WWuSsoT77bF/DffgMfiLZ988Z3YQ/XnGfIlr
WwL/aNvk420d6K8py8d8vg75aS4n2I4o435bEpkLzHoHfcDqXI4NGfdbnm+5
LS0Neuniskvnt4PfSEf011l75KtbSo5fG0c+j8FGfZP1yMe6602t4DXwaw3J
PfWsEvmKKq9+nwwDvzevxJUbeuB/g6Xtny9Rn/C+nP2605TwfaAaYVQ+8gv8
lKv1c3QsCO9nsxG7eX3wM1A5UePFAn/zyh0OQS/Ar6/mmBDHW+RPMojV2ckB
fh2OZq7iVeDn6ZezidcF/H7qxIaqhEDfpe8spfkK/Ex4P/fQqvF8rtD+hTJ+
8ONL6MuoJ+yPJ0uJ3Ko/kO9Sm3L9K2Pkiw23LiEfRb5bNarptbNY36vuMKt3
Q8hXkuO/Q/0p1vfLsUwh6jjyzfoXM9LHoJdx1b0TvAh922BGq3QF9HsKhr7z
REPvTj1poMiFfLIOJQXdD6B3bZ8+P90OPcnfIYBOx/sleJXD6kUmnj+xNDXU
nwm+Lxxu5ptRoM8b0auLD8b90jh9+X27EN4PG7ePWurb4n45fHPi2e+N4Juy
wfehihv2J/XxhbWPhPPdLPnNUYNwvmuaTU71EM732kFlWc0d6G/W8ebLbYT+
LtAq42UI5zskebW2gnC+TSyDHHIJ55s01rnVg3C+dUxIg/c7wW/rWTmPFML5
Xujc8NtZFfzDqv6uH2+Hft368A8+JPAjawmkKmRAr6/kLqsnjP3Z9Glv6VEb
5Du/QGmdmUe+GF2azCI38p1LlTReTgC/G/K+G1Jqke/sRHqzNRX8vL7yFJeM
w//1pkSV4/I43xL3fWTzJeA/wf4ooUsQ/v6+Z59S/ybc/3Q1Gzlp8KsOKto1
IAv/mi1Uj3EP8IsV/iFnziDkl+gQ77PE/vtAl3F+vx/89NIfc3NQcL95m5Cb
yX3YX0c13cwNDuH+KrJvjS3RgH/2yaSPn8xxf71R4OWPCoSeXdPB9YxtP3OO
0rJye0HoV6/x0dNAFfS7ErBHyYbQb0314Vs0RfR7czS/9Vo69ComsqIDIujX
6OrDB7Z24ENlmPKJz6LfjBGWJFZe8H9ourCpIQb8Na4cXFR/Av7XDa3/FT6H
fuP9fOS7PsM/eiCQpm6Bfr0WAynRUvCPXsfDGswJfxvtNir/Cfhb2vvzbFVD
v44jLopigvDXrH4WKJyKfheS9gf7fER+bYX8Oam76HcwNuL2Qgj4CSx2xv4x
DH7ZbBcFVlWh/3ogZm2Aiv5C6OYN7ZfQH5+Xn/5JcfRXsjErUbQKetWI12HD
59Ffz0jSr4lVPJ/BRrFRbsT6VysKrtCaoJ/9N7r2lhD05PWfKwOeQ3/k6sz1
GAusv235UJV0JPSP8wbq4mLQ/xXDLMmsNPDbrxaa/toa/Z90DOnyIvRTf4K3
UJyL8H3cZbkcSeinqE+mQU0V/VynOpeSheCvo8u/OycZ+TxFXdit+rC+7TsS
FicL0A/bBOdyWjDy5WxKFj0wjnxdG5rfqpGhD5SzaPSLJHwfSqsWq8ein9H6
1LzkIXwfhrtH1ocWQ1+yeywqrAl8+YwpKpY7sX7TGyslRfZY/6E4rrWWKcL/
/yR7i+RdWP+P369Wjihj/VdzQ0SMbuD9oZIrlplahfV9W7DercWJ9WkEfkyt
84a/YB232fP1uN+Mt+T07qZjfZe7FWkCbjhf8xbOZyjS6C9CS/5bPCv6u0Zy
t/a0Rn8M7qHdvzXRn2TLZO00N/yN2Dc+eVuK/ImMkurgTqzv6ZpWRG8X8pPp
B5y5UpBfW/tc9qkS9LdpmEXkrRX0xi1KZl/ykO/U06ItcgrgQ2JrZzv+nY6/
Nz7WJMsxue+/wkFPRg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k81GsbZrIUobFkaSrJlhJCOkgT2SIhVKPsjpMsLadI6XDespS9mjDI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k81P0aHVrsS0qF7FJSCpVyi0k0pEgYIwlFlmyRrU2WVvdeXRSFJMko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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41PsbRa6yZi1ZE5F9J2NNbohkiUKSNO0Ml+zdklSmrJHqilTGkrUQ
peRmncqeibFHGBTdcEtyn98fvznzl+d9POd8znvO+3l9P+SOkJyJHGxsbOrs
bGz/+3nomS0fhyq/Rf2AzpLINYb5/+vvLrf6Ci8MM+tnvxVdfyA/y6wF1TYb
/POrk1nHfU0YGHGfZNYl1Dmh1u3jzNqYWuRMWQ/+vCj7L6T7I8yauGbTa9GB
GWY9LBBluy67m1mb1z8QVo6aYta5sz21nxijzFrvUFVJlQ7wpGm63Ve/D8xa
iE63EoubZtYqApdzj63pZ9bcH802SD0FviDu4pqDf75n1iFJQ25iXNCfL51q
tq8K+nfbJ76o7Aa+Q3RUmqsT+gf31Khl/wX9+8UZ5wMp0O8SvdZG8RDwvxtK
XOiJoDFr1xN/kfM2Qb/8VBdRwXKQWVtLheZ/FEU+XEtmRNH9Xcz6dqjLDYc7
yGcs8O0pz5oxZu1Zt3SbloH+FIjdy32uyN/YOVnnmRL4V4K1B4M+IX9aZFNL
gTX4ufUs5J09kX+vxildvk/of7G6Q5CPHf2n6HlU0SvQ/15CiHpGLPzvWRLr
OsUDfYoaJ+mni+H/auixJ/EfgH8wyFuZ8Bz+O42mvd0Zj/M1LAIt3zXgfGP3
csPG3cA7n5WZqpyA/1zvrxdr7oH/t39NOUkYDzDrF4zAnI3/AF9L8RtPkMX5
eTnNLmcUcf6bqDyp+XsfmTXnnzz35gvA70EN2OXlSEce72hBI2Twm320fTkT
1cOsk99YHzBNhz/sulsWfH2RX1iuVWyGIvLz8Az2UJhFfgV6XtG59siPOLV4
7JMT8tM9b8N+cR76d643DJOfgP9+a8UJR+ugT658uaLYEvltjG4dWBoBPn3C
otOUB/5HFKapZpUBf5VmmrUlE3j25yaBK+Lor69MfGb5Os53kxucGhgDPojm
GOwaBP/PMBi6Lodwfuj2h00rKvBfpSM4yYYL+FLl2wnGvr3M2rblgJr6DPJh
xCWEPZ7H76usitPTZFnmJyDci+MD9o99TJXQjQrgtY7/XFezEfkKNmnOHI8E
vvUqxUL1PfINGf6bT7sR/WeddojUHh1i1gHHm19MqiDf1ZcNy15dyPfrjw0a
R4yQ72CGxDaNEOTrduTwk7l6+OPEtu+ziR1LPvS6ocvJ0FeuoP1lzA369p8k
kMIuQt9qCOWCcxrmT5hgkSwmB307JSfHTQWwn1ZItL2aROiTJNbsNJWHvkvp
cXUSyuAXYqdxUI8j/+EyVV7iPPTV0RRUbigjf/2rl85qqaO/7uPpVu0pyJ/8
9/CtuErkUyMlQLgljHzIpDmnpXDwl3mM5HgOoH9Zk+jls1ToqxUozTd4h3x+
cdikVrHko9zawHa+G/lkBIStNyagf6Wn5Vnpwejfusbbm9EI/VbLJg09u5CP
LCPZreMG9OXf1/Crt4W+lNw7QoRI6Gvw5I/NoSCfxKorIzky0Gek4xzaLoV8
ugP8dk2SoE+dMdBfKAB9hCe571cswC9dkxJL0EI+z0t6EtrZwe/z/axFRDP4
497Gi+QzwL8gvmq7KIm/TxV7ZvmjzJDPQWUxs/uXsX9tOqRCvH+h/8aidUWD
/eCnamZfa/0X/I5t3JvkVpH/7k47Dml3lu+DrDGzayv4PqDM+1MWJsFfuDfj
kZUn5ovnh4GynwPyefjDg95hD/5oV70rHrPgHw5TLbafxv6wbD1P9JYG//iT
2QyjMewPss/dmrhnwJNLtC4YrfRh3+RX5jCCWPLfkmhVvYr8izebDBr0I5+N
W/2PZJ3FfFKUaJnD25BP1dFTBxOGMJ9vBAKHYizhn2/Emftrici/vqQ4WqkP
/bdrdFW0SWI+6c1Zok750BfumkSVacV+F860jZXWh77iNvZghh3mp6w6qf77
d+Dr5QkhY4vIt55v6Hw1D85vNA3K9OiD/2/jOabZIuDf/GwzLdwZ+QZk/krx
bgb/072mJvwS0BfVV80z2wz+yPaqPE9L9Ldq3K++5SbwDcvxX6NM4L+iTKt+
fxD6o9IUbxlW4f5x0TaETUjC/36LklIDdfRX5JI2xIiE/yL2USqxS7gfnwjJ
fAGe4LeLyyXLfgV/x8/yuwxBlvt9Z6fXK3/wHzUibXN6BP5qIufsyB3wxxTT
20JfgX+ikNRl9Qvz07iHtMiuCn55wS9ZjZ2Yn9LhXSlz28GfuuMZ75pQzM+B
bbEFE69Z7o9gbSd5D/ydbfaYdkqCv6fX5Ti1esHfk3WcdKvL0CcZYfrb9uvo
//P8+OiOLdBHb+pO3b4W/d+La4hlOwx9Zq37AxXUoa9R0IccKg1+d7v14YUX
MZ+7DvNFh7Dsh5QfQhVah7Af/rixTsLLEf2dD/xWVmGD+UzuynxPmsN8/kzp
Xb3Sh/2Q06vgfHUj+NfZ1dwM4MTvrfXJH0ObgHe/nX5p4Sn2gwnXolaGN/Da
FZN+d/7A961qpLVvrhjwqg3mM0fc8L546fxFq28D/Gs5LRfmbQf/lOy/mvYm
w79Qnq0bJt9ifkbHZNz6yfDv8KT4BZ1o5ONtt6ifyvK+LOXsW793lWV+SMaT
Wz3Av7JrTao9y/tyQeGuj4Ug+CncAyUC2chnozlB5hbL+1KswEiBKxP5yCtr
zuhHIB/POWt16S+YPwl6atGUJvAtb3WL489hP6uOcIS3JMK/c261ndLD+H4Q
HcuQWCgGfqUne4JchP3Sll1xU2QL9D96lC3IEwb9A22PKcIzwKflCcvO20A/
Xf/fTGNL6E/8crgq4xjmS3VA7UB+L/QFUYT0Vl0xH1f4oo4K7QC/TCr/M3YZ
9CdSqb19nAg8r0545O7n2J8TavwUKRZ/U80V+PvuQV91/JwML8v7nXfJK0pp
Gv4qmZY/iGd5v5uRXt8e8cf5aV2VQVEs73ffJHclG3ac78u2u/ZeJfAu+j6V
itHw9xK36NirtfDX4TH3vphylvejf+JP3R7g29RmdB1boF9lQqlN+Cb0m/MF
yNx6DP3+o4ufX7oBL/kyyz32Ie5Xn7/Jhcfq0N+uNEQ90Y/vFzaRd70PuTH/
HyInhjju4H5p/B6ZJUrF/PNLOCqWeuF+fZsn2HKuor8SXaMPts24vxcl6311
NoM/JmZeKF4E/PRvJW/ET4JfIlXzbq0k7tdLB4OAXm3wb/O4vBLtAv8Mqa7L
5Uvo34jrnLADJ/xbeDN0/5MIy/2aNmw/0YT5NA+zlYwgw5+nyqv6wj9xf/Ic
unwCWP4/YP8jZ5r7KvINlpKgDvAyzP8DZNEUaw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2c8lQ8bx63S80SEJLJlJUciylZm5En/jhJyin/ZFbIjIzIatoyoKDMN
s4iIjhXJlpGRmVVRxjNePOd3vzqf68X1u7+/a933ET7vYmrLQEdHt4+eju5/
vzE8TORt+1g1Vy+9uvBBZULj//E8vcIQyXWMFg9x2X72bJikxZKW4z1yml9p
8bVtKbJaSTO0uNyzrk9YppMWU3cwuMc7TtFio/0r1OcNQ7R4cchlpoZ3lhZr
l4Wdt1Rsp8VJoWKjcUHgC+XwkhOdGqXFGi5tnBYEfd2nu/1VG6HPZnimL4eg
H1o/LrxE0FetWt/CGAz9o01Xz5pMQv/63xZGBk7QX71Y07iFCn1JY3sTdj7o
x0ZJMccdgH5Z9zkJg0Doa+bIlz+dgT690T8Vw+yg31KdYbvUBv32qJRc513Q
H9UtenRSDfoe5kdaKLegL/AkO25wAPp7JLJGpz2hX/ZZXt40H/ox/JrPCwSh
fyaeY2F5J/Slvgd1sjlDvzGo7NZLTsyHWVz4Y2Y16K85KPEWHh6mxREMGqQV
Ouir8s4+H2qBvgjHtH3/PPSbz3zcX80O/uJ7bHWdhtO0OHqD/pK6wRdabJpQ
H3lqGfOnrW63Mcn8mRYzZLjOCfJgfisrM2dYqkZocdGhQ4Vl0dDXNyk6FPup
jxZTut7N1OZDv3RugWmuqIMWW+nIdHZKwn+NrKpUuh38G3LuM+xcRH5q9LC9
twj4JFYi2aWlwRddFdAReB98adZVI6QX4HPRU6YU7QVf/O3tFxcDoZ9MV1v3
MRf7d+N72lvdF+CrZW96tShCmF9PG9EgGfSH29hNm73xEy1uGjBs6FJAf9IZ
tePkAtD/ohNaPurl4LeOcZQ0tMF9kHT8dV/iJvjak+IjbySBb+SBL33gU/Cd
XJyfLD0Mvq3Ou8ghe8HXs2Kux9QGPv8myfITh8B3+ItGbYsH+C6Svi+V1oIv
XP/OKL0x+Izdm+SSo8H3pzKZSc8UfIrj9s+oN8A3x2YiLpgIvs1NrGtVIoT9
D1a+F7cJ8y13qbQnwBp8FClBrrx94ItzEx3JE4D+y6WiNv4bmJ+MYkUe5mnw
kV6XPAz5F+ZHP7vkCpsB/AnKOgRGnCHMz/6DqbljmB9Bw6KWLu5eWmw73Gt5
SBb689qjO56EdeO+kj4buscjf8hu3WqwEvPnaW68sCUb+X6dfTx6bdiPhIjA
Uaoy/G39IfM15ij8yXuzPJHYQP5rxWLd24Oo35DJ0ff2a6hfwXDTb7Hf8CfW
w3PY0xp8j9lYQr16+rEvJ+uzno5CXys9lH/DnVA/nZxfvRTUL9/vw1qDGPTb
Kx6UF7EgX9S1Sr5Kqwf9nthwsh3G8xebEzkZZFHfe6WzwcuKyP/Mozp23xL1
zWz/x/BcEPKLjqn/vCgE/mW6ePEHb5G/3WjHm2vHUd9+EZ+JP1Pgp3SITexd
Rn1N4yIizd4g36qi41MQBfksuhY+kb+Q/6jZLeJnP/JXLj2Ira9Hfpii1d4N
AeR30p8539yM/KMsNbNVytiv5DzHzK2pyC/S1vx4mhv7tfNCS94pa8xHwlp9
X8U37FdwwKs3e3Zgv37pxa6MkTEfkz6zJt+SMR/lrzvOFpTj/ZEgt0oNToe+
2LNpE97j0Pcq5hc0k4b+j99vHXi7cV+YV7fLPlKH/gEmD9d2J+wvS4vAVYE2
Qv0ajI+R98P/7d0C/XXphPlx46IfpoP/R+8ShSX/Ap8Pic7emwn1/67I/Kxn
G/g4OOZ0HHzhv6br9GprMfg4qmMFIkPgf05VpflWN/TDdMe/MYUP0uIK8umK
G4T7Gsd0eXAX4b5uhPMtUQj31Y1D/2wh4b5y8V3qHSDcV79TzgH5RvAfGlni
Uk+4r3Kzn+0MTsB/9ZIrVY1wX3fwvJFyTkJ/0q9U28UQ7qtUm6pb1mb4/+/2
ZBhSwLdWTC6VlgEfdXXZ11UI+mmPbTqZ/FDfj9J3hxxnwMd4p07eUB/3wdW3
a3/0EfibuqapI26L+5Alc335bT/218eG0VBCD/vvNZQRoKoO/ZWNR98CSdj/
HCbySKYL8mtu5lpGhmP/r4a2Vjd2EOo3fbdCohl8Dm7ddab3wbfJec9gSg7q
L1VM75JqifyQ9UiWAP8uWtxaFxf6iR/PJ30g88iSBrBPF7eeZyDsH6Vwoq3U
DPUfZBWy809B/TnzI3qDyjB/ZaJZdnUZqL8qvyU72zH0t9DPRiuSsH/6be5B
fZ2YvyDv7m2v1KD/7hdjeawL+mvE+FxosQX++ZLdE+QPwr9JgfYRchr8xxbU
/TW9DfMXQeZnErEA3/Dm1vncBcL/BwebFVZO8Hn1dxlbX4B/qsXNyyOPwWdz
+lQ8Yzb8m7YUpTq+hL6pogKnuBD0exydIhIJ318MLTMv7jTAf/utr8wehO8v
I4Pzd8YI318BnI2BZ8vgv9cn2FTrb/gv3l7WyxUC/5+Mvy9mPIB/pfFz3NRc
8B2I3a1ULQ8+R//TbycI92HwsZvNsxbwubtHSN5TAt+Qgp3uTh/w/TsxeE96
FficLPU1BMngU3nPydQQBb6m41XVX5zAN/5A9Pj0XfC5TSqt1buCLy/CJYpb
AnwK4+HjKdPg85FriFM2JszPVKrwSVPwKV6m92hdBF+AO8cWlzHcB+MDTtvF
a8GX9XOsUkQB7z9vtUG2/l7kty5QC/z54M9FVqbEOxf5y7eduaRrkO+vrUaN
kYO/QF+LP/lmeP77UZ0uzxXkp4VNjJLosf/TzaLcYZx4fgxZ9ecdKu6Thbbb
16hw7PeCaNnejHV8v909t57xsQT6Dh0S15t9wHdVpJWNshl8dvzzb8ZKwcf2
YmokqBP58e7rSosfwCfoO/rkYQKhPvyfVK8Xoj68vnlRm82R320WxFwWg/uk
qUpmjJEAf2+94GTeOv7/eZ2dN05lQ/+rWYQyBzywn57KDaP3XqL/Gj9PFa5H
YD/NlENmh9oI828VdGwiB+9H8dlVZk3CfmrFNx151IT5EjN3ZmQ+CP2HGYmH
f/thvviCv+hvqoD/yClbNWEr+E98fXfl+i34X+CkUhxuYv7fWRWrqKeB733/
le6Uk5j/QBad6AUpgv89FV98esHnXDn/zUETfBUKL+s87cF3PdO16kgH+Fpy
n4SwSoIv+GD2D+tMwvtjsonPahzzcdE06dfvo+Bb4sin8EtiPpz8+ng3bQaf
Lt+lE1OF6E/tLqOBhT7wZc45F5BU0B9Wrp3ZJSLo/xYOFV5zbryfvJPjSOc4
ZjX+A0eCsSc=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81P0Wx0mULSpkm0QkxDykyMhWkZLt0Yib9SKDHlsRT3aKSspaYRSR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41GsfxidpsiRrSaRJtqwjGbJUypIcskRElkREDGkQcVQ49rJURESR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk0lQsbRXU1mSpCpkIZGpRMmSpDTmZJ3RxlzhxNwhEyHUqmyk0iyiyn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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHhRH2Uo4dr5CqWQZW3LEleL47Gm1bzmSVpKULbSgJlujIZKt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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41G0Xx6WQ9YnCoMmSZYpsEUqSFkV5s2QrKbI8tBiFZImkok3D4ElE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k81HsXtqRR9IrGLtQoLXYaNJZslSVCyE1E9uxp36y9V1dFEq4GZanc
SlkjNKnsyh7XtYwtQlS2qXA/7x/vPL+/5nM+389zznPOc86Z89vkFmjjwcXB
waHIycHxv9+2A27rD2uv2zOl9Ug/68ak/v/tT/LTTL+QTrY96aKWkZz2mW3v
0FNedd9xgG1759KmqnZNsW3easdIo9RWtv2Vto7KkBhj2zvNg8XbS0fY9lyW
W9+uC+PwZ8C6YzA/yLank6Sy57TAr8k6Tk3BoYttL3yubi2JnWDbhYu333Et
97Dt28ndVstvgDeXeZSzqNvBtouLTRIaJxDfhV4oMviLCX73eid73wF/Ynsh
hV8deMpp1+UNI8BPddB1RPjB39ioTaK3Evhxo4KQ7iPAq3HtreVbBl6RlGnq
1Yb4q/bPN01+BJ4sZLwusK6dbXtlCY6W3gd+t3+yKk8G4oe1FjTPBQK/0azy
RcSmj2xbJ3RPSfYP6Nuh9V7CYaqPbQ+lX908rQJ9j+RTIp1eQF9lK2bGqAr0
3a32sD49DvrKz6nVWj8Dvy96SfG8EeB33zlL4Pdw8HuZu1ITXIH+8/1zfVd/
NfgZ7UuWDf/Sz7ZLN/MfstIGPxPFaLnuaPA7uy3kp+1aQv+JaWeKdYEfo97v
Cc0W/KKv+wgJWwyhvoUnk+//RH/11G67uiG3m23vSTy+nUwGf7OQhMsNFLzr
RJ/dF8EEPkLXStdP62+2nVy3t9ncBPjCqPueykLob9bfXCOrA4D/WlMhz5v+
D9t2+rFzZXoEeCvuoDTyGfTHUuJLfiN/5JfJxy1zlIz8yIL0BVU54Fds1pCf
1CO+ieB147IKxO9vqCF5ssA/4ZSv9Psw4L+NCV5Oeg39XG9rRq6vg370azrL
L4agn1xkoJ4BQb+yI/tVlK5Cv1x6omciQT93N+9rGR+h340kz5Eegn611B2f
X5khP1PDCGrmL/B3s7falpQFfTbmHg0RFQL//tTGgwwlvPMW02TrRoB/mO7i
obEJ+Y9uME9P0AVe8JJripsu6jf2bVOBczjwnmWi6ZXa0K9Q7WiiYQvw7U1d
phdmoJ/JAIUW+xL5nQx3K6H4YH7WjW1zjbgJfLmqFumkP+q/2u6cLTMV9S+V
amNRj2F/qww/M9Uk7G/1iPevrqeh/oP/CX9ntBH1l3yRc1OhCPUnadQIm4aD
X6lwT5PIOPjxkcrt6wwI/y+f2jo6t6A+ybJD3wZOoz6N4zWBb4JQnzLphaTq
f4DnyIgkLTxGfd7Ihen7xiE+vfHRaflaxJ9bFldUcQB+vUSJYM4T7L/qkLTz
nvqIn5S4eDE4rpdt5zQtnlhZh/qI0CwvFMW0se2au5OF+fWoT63O9PFTnsNs
+5LhQeUIbvhP23cqpYuB/epi/1VsSRH+nWnbvcXqUf+cF7wfLfXgf056OOfs
GdTf8W5M9fIH5E8ddQ2IoiH/W5aNrGcPkH9AGesKbRD/P/csPWMeHEB/fJsJ
/jAngf8fw6kaVqYw+MneUv8m5oT8ddo5nvDkgh+tqM7v1gPkf7BCcbUGA/6L
qXk3sknoP5E1ycetCfPPbOEsaCTsb3P3RW8zwvxvkYndtYOwv+XNaDQ5wvwX
aYsv7SXs7/k7D7kvEfZ3pOlmeSZhfx9grQ13JuzvLrJYqOpmvP+l0JPNHAD+
qUlJUhsN8y8nWfTFdy/wRer+R0b50N9uJMZNxRPAG1aQ64afoL8TzL8H1IwB
z4j9Hmjvif5+MKMovMsN+Ym3jv0SV0B+u3I2cRpsAF63QmDGYRv4M6S2ZpsO
IX7w0wWJd0rg39JwfVbcEPjgPE/6Bjnwt03tyxAhzKfSq0K/0VDwbxDOM6T3
As/sFxNc+xD8txqMhO2+Dv4F0Wq3JD+gPzWym9YxbIBvcZ3PzKzGfO7Y2+mj
bo74nOLFZsW2mM/mCztz5HgI98nSEI9fJfqT2VxJG5xG/0j4LGmrS6I/nxeE
Tt+xgH/NuY4TsRbwnyK7051vFfyrjjPGvr+Ff6k4u5SQWfjnys7qGxCEf/f3
b/TM7ODfwqPYKUkG/h/5erkP/UL+JK973kHT8G8Y7rvySRD1M1yMcjDqgP5R
d+/RWX/A/6zem+opTuij/EPFeugt/AfpeSS81sL8c4XlcSaPwX+ax1ASZRX0
GR/eMxJbBfzBD/djXPcC7x1LiZ6dAT4kRk1H9Sv2x4OHEXSpBuC38vkWBZCB
59ONyxJvBb7HtOZ5IxXxOYIdVovkAl+c8lfa8Xbg357UfJtpgv3yyaKIp04R
8S1rhZxerod+gvKOrl7nUN9JXileoVfQj864NF9+CfqVWt7dyZyAf+uuQT8l
TdwvnW0ClG4N+I8In//jXQb219V8rf1z0vA/3V4itSYf++tM3vcF52jkH0Qn
UTUHkH/Vh7iO7H3I/6yG8ywHD+bz1/ho1Vpv6H956/AxnUror2LAX901AXwo
1WVG7xDmU7aTvFnVHvFHZxN9a0zQX9N+mu+dOIAf7gu/ohKH/XJh9an/Zq3F
u7GvP6XKAe8rei/JN+bAbzqGNGTVgPfnqb9dZMkAL8apaSwwiPzODBYlm9YA
n9vAabu+GvvLqcCVvy4Y+FWWEiflRLE/jlqVL7rNEb5fa/NDn5Gg3w/qeY+z
atBPlN6rJpkH/Q6EpZkMbId+bh8tTSvo0M983MbidjrqdzOeaTeTA/1aUs92
1p8AP5tiJfsd2uD33dLC7OZq5Jc/0KVy+Tnug8yax3l9CuB3qLi0rq0Z/O5R
WLyuRuD37E9vv8/+hO/rHKVoZg/hfiylpbbJgt89tZZjPwrBz/Xn4RbzRMyX
xj79+XhZ1G93TvmsZBTmSz/9WbfCPPD6288JUEXRXxTHG3rSioh/NMmalngX
/dVqnay0pRz5J0xU6jI58f0+UJX9aXck/PuFxk5VFOC+ZTT325W/Br+q5GOH
B7lxX+SfuuRgT7gvvk0s1D8l3Bf7GS5e6oT7okijOOgQ4b4IELg9MGED/kJm
5+cqCfdFhsrwg82E++K5nlbUh8fo75ZPUcKCwuD/20Ud28PSeLerCt3k0g/8
9Tbua9zG6O+QK4k9EqbAz3qNNLf/Qv+kF3X2WrkDz2OkWpbTgvmn73Ne8pkG
PkUgcERZH/ocOOhP3bgf+UmEN2kUHEd+HPEewanj8C/jpyAdwA9+jqKpdvFU
+PdgVRpEuWN+Rxa8NH6/BXxVvEm0dT/0PU0u4e0rB9659MnMaS/0X7+bLEuY
B/qG+LTI2bxB/7WSzKIi+yb1/wUtarHS
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k41WsXxiltQxwiQ9pRSYcMkZlCyZCpEOEcNts8JcR5zTKcJISSsg0V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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk81Psax0mHNiqZ7GVM6lbmythJRYRQk5RcOZU1UrZGja0a2Ys6lbXF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k81G0Xx2WXfaskS5QlIWt3tzApZGkxRabQYKZIy20rCmNaqMgaUpFQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41dsXxk0l40GRKEOGyjFPuVQilIxRLipRMkQyhqvBeMu9SYYIcU8R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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41G0Xx4dEGJFUZN+qsYSXlCWjUj0pabG0kn3NNHpKKVlTyFL27bGk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lG0bHqkXMyqFZClMpkS2REjGrpRdhewiVJYQUlkiiYoKld1rTSSm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHc81X0bPshKGZFSUVlHVlZGWRmRrKzScyiyShmpUxm9bTIiIyfzqaQQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41VsbNZToiNI1ZMqQQlcyHMmQY0pUPolPg2TIGFGcKG7JPHSjDBEN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmGk41WsXxomO+UghqcxjIfNQMsvJWBxFhSSi0t5ql1cRclISoijDNk+V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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4FOwaxkeLRgujJOSTJZKKqFCW5msSny0tKgdZxxYtyFI+J4lKi73y
HVuhiJIkKVmi7LuQIQxlGkokeznX+ePM/f4113Nd876/577f537nHRn7UweZ
CygUyhY+CuV/n4OzGaPNJivo36rqhoR1v+z+f619NWU+NrSfV2dPUx/d6Bvi
1T9Xr95707CTVxtQ52uFbYZ5daBs09EHke28Wtjv6PhKPaxPVBor/XK5G/t7
trpslPnKqw/VN/mErG/h1Xa2hxVKozhYv/Xxgp/9A7x6cOwA/3QEl1cnOGVL
yoT28upipZKoCj3s7yj0fUxFv5lX6ySuF3TmDvLqAYnIVfkyn3m1Q9xrYyEK
/NFjfspaRQW/Uy2p6coZ6CsxLe5+kdyF/h72LL40A3/SNX8EBC9r5dX5Mg9Z
b9Wxv6lRZhLlFvxXjgj4SHmP/Sme6Yue3IT/xRktbQ3e2D+CHblqpSj8X6hT
7P9qCdbrlftzRUo/8ur6HS4HvffAn2jmvmR7S/jDlf5E15yBP5lM/rDvi+DP
GSm+gNWK6F/pyQbZgWfov4s2PqTxCnzPmXqRKnEW9Dn/HT6TgP5TC8r2lm1s
49Vve+nB367gfM/dXWx8Iw7nK2AnM6PPQP9pnzf5WB9B/9evji4wnkD/7QHC
LLHl6N8qViNeTQr9p06csI2qQv8awo+Pn8tA/4yK/X01fuhfNMspOD4f/Teo
+6wSi33Pq5t+dJx4o4b+M3a6X6Q59fHq0qRodqAI+s+21KsIOY35lzRtZQpU
Y/7PpRTNrfbB/IXuWON7ix/9TSy569X1DucrnFrH6iLOty6kcWjwGPy56MXy
NZiCP2abudH+VPhjPkTv2S4Hf7ZZarEkiuHP8aapzUFPwTd44CMRagB/Kjfa
rWt/CH9ar/uImPXAnymTkdPM4/AnRqio5vA8zrco4xojayv6zwqS/SBYgf5d
c37wUUzgj6LD+MwTt0/4/tKCYL4x9O+2O77CZhb+b5B3cM/vRH82oh0CMRXI
Jyu/nHYhF+vPnnJJHL3M5tXv/9ByFI/CejeVnZOMk5jfWaNbF6YfQ59id1Gr
gg70iQ6GsBWMoc/h32d73aWhz2L12qbqGpyPWq9IWPkxnI9HbouJew70x430
Rhx9gPm4HsTmqraA/+bgUuaPih7cl/Gcpf4m4Dsp10XbiYG/pKShkfkWfA/X
2jsbHcF3unP0W30y+CcKPvYbVIJvdOxGY3w2+KlFucdua0F/dccXL21Cv+Li
5Jtf1oE/8u3aVXtCv7dCaUqgBfihmZFt1k/AP9DUnXcmA/yr1IMrxxvB16DS
gwRboP+i+ge5OEK/oMaccOKaZqJf2x3V5eAvG/7sqMsEX1zzftXOJPDvLZxm
u9SAT6MlNqhkge/Adg6dZEC/2V89G94YgZ+a7iHXLAs+NW/lPzl14L9ytjS1
MQeff+vQnMVz8B9/a20OSQD/bvdr/oRu8EsDPVdoxED/Oj/F86GE/36MV7UK
UuAfLdp0fq4KfN0UEYtfluB/m7bKKMwC37rtRlj6E/CtTP35tarAPxxhJEOf
Bn/YbjilifCf+k6IoycKfl36y20vysDviWy8I+8M/ow+35LT8eCrp2mwOY3g
C/zu+CB7H/ycA+KUwoPwv7DZ26XMEPyc9ozKXkXwPRIKZgObwf+zOcGq0hh8
kyM2P96+AT/afi7g0SXwY+3FW29Ngj8l7U+xWwn9dpF8ksH64E+3jzY80AY/
tv2shxQbfO7fR1SfbgWf/Y/S5Fcu+IcivL3cthH5r9qckmOA+zluRSVX8yze
X4Nb2VrnpcDvHPMYSN6O3x+315kiMYnYv99969fsWuw/wglLq3wIfcJjSz46
6sPfqhKxgGvEfN+f1P8ptR76hryWpRXUQ98Ssynfy4egT42+pmRxAfgXIiRV
Ve+Af05gJFOrn7hfubP2u/zgr2iekFsZwR9tm/GvJvJVs/phSCaRr1ABtpIb
kS9zRWUdQyJfLkMHtdOIfM3dDnx/nshXcJyJSheRr735DZ5hRL76L21IFSTy
FdC9468vRL5uPvOLXmcF/qmSNy1hRL421L0OWpYDvvT2rqLGSvCzDwVNGc+C
/4Lbu7+ZyFfvWGzjn0S+RjsTR58R+eK8DXbYROTrs+r1q85Evvq9vydOE/kK
9g1k0oh8PTV99ItD5Gsw3X5VCZEvzpZQ2k8iX9oNx5eHE/k6lnf9diaRr/6R
yDMjRL4293ox/kXki5oXMDhM5Etkg8XrJzTo/8XeT3Mn8hV+b8/INh3wC/jf
11wn8qVAo85yVcAPC2OpU4fB3/V44SolVfDZOma2LEPkK33TbM9SN+RLgaqg
2y4Jfm6cttR5XeRr3aNM/co07K/tOV3rWYT9teQ1c4+8hD5VIesYYxn4uzDh
5KLDxPmOBrqtYYhDn/tEDkP8HfRtiu424NpD37lux6m798CfzLKaeFQOfs0X
1fobueAv7HNQGFUFf4vRjVN5xHwL6if1UP8A/576HEOcmO95xQseUdbgfzwQ
lXTyIfjp5TsKtfLAly04IrK/HHyb4P9cKqeC//nQIvlqQr+EtHykFzHfJ3de
Ce8i5jvNq3hiwAn8UeOAsnpivk1suySUifm2nN338jsx3xrOvgvemRH+u8+t
5RDz/Ztq68pHzLfrGGtRfRP479z2aSw2Bd9TJbxirgR8qp8Rbc8V8C/Kj9P7
foD/x3Npzd/rMd+0ZEELHwPwNU0r03rVwe8TbDGJ6AZ/l4upK0cTfOnUNgFG
D/hll5UmNhuBXyHXpH9bFfNtHnNWTHIY832CuXNETRn82hY68/d78AcKq9X0
jxH6bDryt5njfX54aONbz+XQd+o5VYxVhPe5Uyqn/uo43telwtV5FBW8z2P7
WHpcU7zPg6SdGhvt8f8kcoVYcucv9J+9J1iInf2BV9/RrI5jbcT+XxV8b4cV
dvBqR7/ma2Y1WL+7Q3hoTRn+f3stKjneegnrL0Y17gl4iff/CU36lHAH9OVf
cZkvy8b5FelKv5Ag85vkR0uWgH9T4UndyhU4P4rrrNicLc7P0FBO1Ju4PyJn
w/3Ei3F+AVXz9+4WgO8l4KshIIf5ZXNsTu4j+CvNf7fFEveHoIehuCVxf2yu
pUueJe6PKKEGhkkK+Dnx8XqWZeAP1Yubzz8DP8Rr/JazMvjPkrM9u4j7w6S0
23itJPjWT8NOWFWC36zXMME+Dr4znfErOJ2z+7/m5q/v
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk41PsbtS9lGRmyFCatUtZQEyJr11KMiJKtkFBzLYmu5aJQKYoi4dYV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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4VQsXPpE5UalQZiFD5pQKGRJKySwUQi4y1UHDMQ8VEddcKaIuyY3v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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lWsXxlGOWVRkCIXE2YY6pmMeMkUTyjykDJVkyBzlkymZIvNWUTiO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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk41G0bFWVJG+GzdMkQiSwRWSpa3hTJZE22smRJajBRUaJQtowsWZIW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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lXsXRZJ5qohKCn0hIYpKUqLBWIZIg0Rx64TM5FIJZTqVeToyhwx9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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVmk4lWsb3WZCdqXCTmYZtnAcpBKJjlkhMpTIcBHKcDIlCSlTJ8VB2qYM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmGk41e0Wxg2hDk1kTL1JpBAikWG3qa280k7JtJOIDJ3KPFUUigYzvVKc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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHlYDHoXLn0hpKQUN5Q2MxVd7ZFSKpRScduUVtcYWm6hhbRoT5pLWoa0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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lWsb3ZQhZSw5aXCEiGxDhqIyVSLJnBxDmZIhZaxIQuEoh8gsIScJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xs0lPkDx3GX9JuENKzdXPMTJRmUtuiiojZFcltyrcl1XcZlIpcuv0gu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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41HsbxscWYqyVLBGFHGMpUtRYGkSLbIciIrI0nZCtpOxkCSPTJEqU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k01O0fHSIkTEKRpagsoSIku1REEkqWorKXXSFjrSwp2xTCqOSVSBtv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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4VesXPuYiSpwjRWbKEKWSdOMiQ4YQUnJCjnQj3Ygu0uASV4oyhBKK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbHnxZYkRhspUcRYTKchSZiBapJB0nsqasJ0sOdSbrJ8IgshVS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbpiwhiU/JdiiFspSUObYwKoSxT7JTjKJICRVCWSJFOkplPZJE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXRXWFKJGEyvgpFBUpQ6ZwkCHkxJUpQ+ahzDKdyJzpM1SGDHGF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41esadY2ZSh5DlE6EDBshW4ZdSqaQeWwbkumYMxSOlOGaUjrJkFSi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4VWsbxtmGkiRxCJmSDFFmRaYMe8uudo557IsoM5m6ohRCqEQItSnj
CZkqQypThnPMQnKISBkizZq+6/vjW/f6a1/3ta73WfdzP7/1vnstqaN+Fsco
LCwsSqwsLP/7LchqkSwP5DEQtLGl9IjN6v9fn+FYXrZkQp/0mBB/2Pya0PYq
ViZyu94QWmB1o+meRzOE/uWS4Xui8C2h+X4kBO+omyL0lEOlUnH6AqG3j3Vr
mXkOEVpD53i2XfccoblrTK052F8S+idrqXFZ4CKhKewVo7L7+witKHiuJ2MP
/J8X5tCKCID2tqw8uZMfOuPrrFhZOfRZ4wZrpXz0S68IpZk7o9814/c+hbmh
X1H++ZQjIvBrLMkmM109Sejda/qK57fA7/uEYjsN6wFCd98zlts6hPr71mg/
pIdOE3rM5NIza9l5Qks7sgUFm44T2jrCKqHDEfWN9nOoqfYhj0ijjsCuYvR3
WHfwtUUF+qNe5XUsMsf9LzVd26kah/5mSocVwhcxz/5Nb8Ist2Ce4s0nKZFL
mKe1V4KHh/sgoYM6Q6x4U7E+TzrwzPdprA9WKyj8dhrrZVnzmJR1w4Q2M9hs
FS+N/n15rmt9tkP/qSmz06XO6N+m2d/9civ6n5sKyzfPQf80zdSj3E3ov9xN
zr1DBf3fer+V16QW/ft7rjFcKYV/LR0n5dt34D8lwFPkbg78axdeSHmnAZ7X
rbHbvbMCfJyn7ZiVpYNnxtS9VQF/+E8o613Wtod/k2tz3Duo8O9KPyb33B5a
fFSur4bEe60DPxuNxLtk6vWkeBLvmZfu9gmTeD9s2HlHrQB5CMbVidQ5Io/w
0IV1ER6kPCz8y3IF0c/9rSEW6Q3gndfP4HyYMPoZffFRi80LvLcmpNfunUH9
keRMljO24D1Us2v1iinmbdZ3N9Ii/19CM5kzVVNmqN9AX5IQMukndNLqnzLP
OFH/wAGqtxcX+ouP2hcebYh5diT1b+tNf0Xom8mFujGfcf85728d2V+fE/qy
Q1mNsAfmvf9ndlnsOfCaodz1K9YF61VuWKjqSsO/Q+j9FWdN+Od6+7CE7yH8
i7zP4VFzhf+NpYw4dgfkn3H7myDfduRf7xUyXHQd+buy9J+iyqL+t3zTkmwh
5K9ys0NGpAj15We45BYHkL8YXYzKaEH9SAVfs8Ut4FUhsmLiEGn/LRc/99aP
Dl5TZqX6LuiAL9UV2wKqL3Rjk690yWboJOWi/LpC0v5slK69Wo15MepS7nCa
wm9ffuqPxavII1OWpal1AvNkDCcmX9HB8/lrbzHLzATmxfwVFsfXjP3JpIhq
Pd+L9SfshSkaTlj/tV3jp0g31v8lsNZGQfEZ9qOopoUsfuTFTO+SymzBPOhd
q1J5gshLtJInnDcc87jQoX/j4nv0V7a74ICePuZRrOXzOobEk/N6TXkaiafJ
6b+fHCHxdEk4uYqTxNONWkaZAomnQHHJcgEST2IMoV0/ZeBfSdLq8DCJp8GA
LEdNEk8bEzcbsG+G/2iFSS4PEk+dFCk2SxJP/KO3rVZJPJ0fP/ibKgqeqg2Y
UfYknjq09wjsJPH0l5HC9kMknpibsk3ySDzxVEu185B4WnUwkm4oIu2P2T7/
qlaBpznxkuUWGvy6aq9zr05CHvsyT08GvwYP7AtlG+wVwUPN+rjezFnwwCnE
LWtzDTypVMcXSFZhfWu6vbNgDtY7nL1rW1OI9QPWA8dZeXBefDNK+7VyHXlt
CcqQ5I1BXkecJOLqPZFXou1QI/U08hKiMJNeHUX/zyUCjgsqQuuGSDwdi4Wm
25cO5S0gn5X8F+YN73B93O93YIEGrsv3/EjWYEN/PeM0kScimPdoRPtQ6nnw
qrfH59N9zzFCFz1j/6AgAP/rc10OfbgInt4KqIju/YH5HKxkXFWWR/1thvyH
R4NQvyUgvM2gCvVltK7kXNiK+mqlaWKO6qjfrpvLbt+A+lxtTEuPYtSvVRzW
rF9B/k22scWfDk8Q+o+Fozxmfqhv93K1XNYF+TNEZ04zzJHfcoXi3MyfpPO4
3noq2AS6/uGG7mon6BEeysSkOnRdfP8g4xS0cbypwxMO6O4KjlPBT6G/t002
+57BvCpibM1GM0jn4aDzbpUV9Du0JCdsdgv9Lgh1ilT6g7e24FSV797oN2PR
sMXNB/0+DYsPNrHB/fdclmhv0YeOSPbJ0vSAplJ019Zvg7ZR1tVeTYH2F7FN
TRuG/2mPdo0/NsL/1bEvN+hf8bweHKZ2yNuBx0d5IyUax3CeJyq7CKlJ4Hl7
3MwWoCGE81yhQLFThx/XJXm76P12uO7FOTyrroTrUpnzMm/aR7DecDDZ5wN4
FNfjZuRwjUKbFZd/8cZ6xqMIBvsR/F84+VXEZu0hrD/sYm1udQr7O40zWu++
EfJfSlT60OWJ/X1n5OTNoG3IZym6LdaiH/l0t2+oK0lEPmLq4+46n7Af+TZ8
UeAKgD/5UA/KIxr83VJ8sdbHCP70//PAOOse/J3ZoJ7AS4c/gbMSph1a8Cdf
ORF68Afmq/N6e1v3Fsw3ekpx2Ws7/GV/flm8sw/zi2IoRtxsxf1Hgi2Yt9le
ENpz6dxYWT38J55M9/XIwPnsVaIzUGkFvnuTnCN95HG+uXGWCC7vJ/kX5a0v
1IN/3oFstsesyLeAws3etQn+TQ68eBeoDv+38o2LrlTBf17dlXmdCfiPV52f
ORAGPs7dY5lKSIb/raWXBMqScB4c1ZHMrZmE/wyTg76uhdiPnJV1LLoD4N+S
77NH8iHS+0+iub6iHvLXNKTlT5yA5nIVp6pKQu9miEZ6ZUEbjtCj0jrRr59G
dUIYibeGplNK5iTeaj6uT7lP4m2DtF6LDIm3H4XPXwmReNOg3ag7QeKNlq/Q
vo/EW++kuW7IffB28yKriyKJt/lu6sxmEm+B6q55Td/h/8Hvbbk9YvB/5Rgv
kyIDf05uQutkBzGvd42s9azNuH+Keo5POx94GyzKPfHgMfzfs3Tb1hQJ3j5G
tRqHUzGvfZ3XAqTMwRu/q5KulyH8O//64v13GPwPLtEXHEnfV5waE6WGGpDv
QHT08QXS95UD10Ni19YiX884ZrJLBvyV21Yz5NzBk3ZWzKlN/8BfQc9kUBkX
9vvuR6m2+aT/Y6+6ODa6kL6vmD5miWkjvW/eradf3UV63xznD3CvIr1vbqUF
lD+7Cz2Y+1m+hPS+GfNPYSMr6X3TZVr19sRx9Jv0xiXtjQD8zhi4PUprRJ6d
kU9HxoQW9f8L/1bgTw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHlYzVsXx5snjltKvaiE3DRIg9JD0jwpNJ1upGgeNaPS0XUihQZD0aBB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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lVsb3nUyhxCx1UWmZDhIpgbpmO0MoUSSkzHzrHQqs5KxRPHJtEuS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c41fsfPxnZOzfJpjIiWwdFGTejQSWzI1FkVmRTiWscSUbdrNBFGiqh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXNTTIUJLMmccMoUIJGbslwzV1kxuRKUPCyZRzEUp9mQ+RT1E3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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbRpJsxUG2o0WylDRCUQ6yVXaK0GKrRPalSDikzZKt7MoSSrKM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lWsXxhGiDCUkIWSHkGorhGSMiAyFTCWcEG2hMs+ZMnQakCgZ68iJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bNZUsY0myZCkkS6HsS6QkZEjWkFSk7CLTi2hRWaIiRVKDkXpl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lHsbnsKYyNh3aXGEGmtoIRJpkxItJlo4GslY2ixRonKyjrXFUiTJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0blS2Skq2ERqJURGVfEuqlJFmzh7IlFcqaFruKqVdeW4mI+LJV
hKhskWgh2ZehsU5oiNfS9F3fH9+c319zneu+5j7nOfd5lt9W5wumLqwsLCxy
q1hY/vcbMWlStiWC96BaeWcD9T/D2v/HZanczfsWJpn4tZzgVQmObiZuCVeg
KYXQmHh67OqbExs6mJir/X38UVXC/xcX6dOr+pk4d8akoNXtBxPrvrUNVU36
wsQNr6U9nsSMMnEiv4v/wMIIEze3KqxUTKL+LvSwC+8R1HvOn5wfmx9j4oy9
iVFfD35nYvHAHV0iF6BPPbq4/95wLxMrGOjfLtaCvr67Wdyk1FYmZrGgeEhZ
o//nPjLfh2AqE9tmrGvz552APy6yukt9FCaeoJC3Km9B/4AnjKTrNm1MPKLx
tu/TGPrfp6TID9tDv3ldx6CKKfRrJLFV7Qjug39G3ocNLdE/0i6oxJwd+new
q2lKDsG/unz5tJs28M/RmF7g2Qd+vtIZRc3L4FeaIT+9rA7+YydipUrnwd8k
ETMR7gr+5vLKYf10zFdicPyY1R3w8/s+dFKngV/5ym0xZwbqL0qG7Fq3oz4V
5uDKIjPOxI1m53UOdiO/as7rjyx/hL7AxRP9GRTk13I+8U9NLfIrZryy/6xf
OxPLq4n75Jpgfo+Ct8U1amF+t1NfVGacxPrsqppjRFawvoiIx5dCeqC/xSL9
RbIr9O954WZT+AH+WgXkhdskw196R/1ipSD0j2ulNDeVYf9kpc1p8gWCf3Mf
/ba1HPirKPyUVHnwL8RtyKsh+D19MefL9UnoKb0qduLmH9TPls1JF0mh3u94
voVzN/x+JpRC62mD39d0jb2zvkJvveVTp/oa+O13i/7zVgX8Pl0cz5v0FH4b
TAZ6a/vA7+RTggXV04NM/PvOsry6J9abIPmee2cY1ttTd7BAPAD65dz2P1AX
Bm5UuigQXQF8lb2Y2p6B9aWSZp7k+mAee6a2+tkfxX5es07Jd/Ao9LV3Fy2N
GSEPFDPVTqop9JEKBKOURbDfvh1WjJqkg9+jhOMAVQP8cqJJVqPc8Nc/aZOe
qwjysL/yEL9gAvxd+RJH/y2C80pL+5n5L0Hwp456lnr8jfOkV1hRUn0D+nuQ
Chmia9DfPZY90SsT/Wv1ctSkW3qYWMB2RJ2DDf1nXMiGdgz0bxTwntGzR3/f
a4r+19yRD52PJxtU92D+uSdnK162doKPV8SUwYX61PF8SvqjLpxHX1jMZGxQ
l/qTkS/ZjfvGNTHknGwq9HMe5fRyWYT+omyRTWG8hP3C2LjH8A3034rcPCGz
F/pD9qrUDryD/s65ZevVg+hfQzKRjQhHvp0nIuyO50Cfd4uCuZr4N5y3jTmx
A8+RH54bhoWlxsh3TMkdhk4o9L1WnKJJzn1m4l05FhusGMjLzfLWMWMK8lT7
PH2Kyw71/M0Lyho9yPNIkGd4SSDmvUmFtadLCetRqY1JI6/D+XLpu4K5jgf0
GCR3TtuRsd+4BMaajoaCX5DvsnQOO/CSBsN5Swew0PsbjmHnoa+r8dTg4hvo
ExYtF+Aphr5Yo7R+22X4Fb45uOSH2gDO90+z5c+vQ9+pmsHZtt/wy/xUWlEV
J/hLV10vqmwDdltcc/rhJeihlfyTSy2FnpQ7SaVmtdBzfnCRem4UeuhNd5Nv
pkHP3n/rRteGQ4+IRkTl/Bj00F53KmXOgU/w54WvtBnoCWpiXRWrjXowY9Q3
ix15vGUc/cpGiuDPwuh03k3Mb/3CX2vCTHAecKx23blxK/Ro6t+XFjiCvBfR
RXj5e7FeStVwBsMf/cerz4WmqaC/mISL2VkO5EOFEfpA1R39P09o7qlJQD4K
pctK7kdhfSoX+Z28lgnzf0vXZhtB3e6MXEiwGepby+TnqkahT4qFf0DIEfoK
qRXZLCegL1qZI6UsEu+PlgApr1+E+9nhdlCQ8BL0TUUsS/Z1gf++K/XzLQ/w
y2w/sN2iAfzTHFUhso/A/yBPXdCaB/w5L93XlYzBn0DjuD8WV8DPSHKgsYiA
X8Ft/KrsFvBb5xWlhecD979c8JgrI/jlHXZmvTH0OIh5J8uQcT+dJKXxfJpD
XjqHLe4NCA8xcV0GN6cOO/TE+Yhkz80jD1qkl6KSVvj/macR3+764vyLT6pq
9JPG+TazUWxfNxvO5+Eq1SRecdS5mskS4/tQb14V4VAtj3r3MN8NkSac/68e
5up6chDOz2trH14uxf/zD0gtn3ZCvc7p0+hgEc7/Tn1aXnIU5hHTVW/W7oT9
oMc/eyZSCutf46UxpqeI9e/iszGua4a/JlJ98TKJmHemXqE330b0t2xQ4Rl5
inknaM407A4g3I8ZA0LUfZh3ln34bitFzHd/QdvvkWjggGznTPlFzHvEUP9m
2jhhf5gelhw7hrpkveX4iZ/QGzWunuR0DHrTy670lZwmvMdCpTNiSNgfgZFK
bDwG0DukRlr6bIv3ygOyTWXLDvQfZWs2KOpC3gzzNOPf/o28CPNkmT+bRd4E
7F7ZDYVhXmsLNTq+TuA+NDojKHxcCvpSXj6LZfWAn+1v01L8faDviISKmZEl
/HzvTtP3NIU/6eoVTpGWwGxHaREJxsCiwk0rx22BPzYkXgrSB77otptEdwce
dFf7pqMAbMQdfq+QDDzlvz3b8QfmwfDxkrq9QuDP4HRW3IW62++hC/u2Efbn
Z2qP83fsL+487x1T9fDDadfa7B5+vF8CuQwU2FvhJ4dtP91IEu9nu3K/xFpx
3E//xpdSBMrwPj1e/NhySA5+zlKarH2XMW/p79W9Vx5h3pnpx01kaMjTZOaH
ttZy9DdZX1fKqoP3y6NNj+xVwgj5D0n4snMK99+Ibm+YDCHfvQcmGLmEfL/S
SVdvI+T7zTa9IxcI+X7+8x1dkpDv6LhPv2YJ+b5B7XXT24J8Lyyq9nzVh57t
71hfidljvW1Chx60yqD/zgr5kPoO5Hs5Id3aMgHzIgWvDlz5gXwbKJ9trY7C
PHQdetf5fUW+B3zJxdGboE9AnmvC8THyXbrwjpToD31e+qL3risj3+p76UOe
KvBngvyP0Psw4AMlNd18rMAW7uvuGRG+N7/M91+eIXxvcvyS+Uue8L35O17o
mEMK/NQeNzXNFYBerVOh5w1fQ68uq6ysP+F7k72NtaNrF/QalRcvB8iB33vc
MuTYPcJ7UFF/1JQKPU6FpBvO3NBz+NdZvSv8qHc/lK7IOwT/B9pDL1o/wH7J
Lame8GSD/1cNy5aiqru0/wtXJ+7p
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbHoysJVuIkexbySE19kORRFmyRNYoSdkqUadQigyyZUk4VCaj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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41O0aHoMSkuWUUkSWFCpLNYas5RBGEqLdZMmSUl+WKIyKrKERScrW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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXPYZESGigg6gOZciQzEOmkyGUykymlDljCUWmQshDpboNiKRk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lesaxkMhQwm7EpYMpV0k2UimUyKiJBQrQ4YVMidDCcmUQllbUWSm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4FHoXHiIqblnS/bqXlJ1kz1IiRSK5rmUyGCKELFkTKkvWLCVRMtay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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bHY1IYlAIkSX7WCNr2UqklCylSLY+WfISqShK2ZdBg4rQW1FR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4ltsX9dFniJtHKhEaZMiYqKhMJVOSpBQyfUoRIWS+IlNkTqbMQ+FK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lW0XRehUGozHUMajQoQyldf4Eb05MuRkyFTGDJUhKkSlZMpYmcrY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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlnk4lG0bxg1CWfK+aDFSsivRilSDoUailC3KMoaxlSJrkyaUhIoYRVKS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lNsDHkLXkrJkzRYisiZR1uyNm0jdwiBrCJFCKVFcmYZIhYjCoCxX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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk0lWsbxncSx9App5IolRDJGKLMQ0kcpb6MTUTlJEMpQpHQNkbGRDIP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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0+8vFAAcx/E7Ee2cH5mZFiG2asyPaksRepJmq052M9eW/FirJ/1QlFKe
mLZEmwe1RQoxHSu0do7Gg8Y8YNrakI44hGOt/DrStB502/v7B/ToHn33efTa
+8E3MONycraDQqEIUyoUf6+j1i2spVIdrypecn5VNB33b2fNZajNzTO2rSnY
6f52dNK2w7Z21p0em7Nt92KfGuP4mG2f6XvQ+LhywbZ70mZ1rdoB21a5rsJT
+52Dl7s7GF73hXfwBs3H4CX4lsBLv/MNXn3aMjwP/Xl47Zv+8DRRHfDmukLg
xUyz79P7GXimghV4FYvs+5gTBC/4pAHeUEo0vCIX9g1MsS/UyD7LDvYZAgPg
lVmM8CZDQ+Hd/sG+tVz2NcWy71ZKOryfbwLhGfa2wfNzPAhvVcG+i970kqbY
NzRMr6aWfapU9nl6hcN7tMK+JS09fQD74grpTaSyb7GEfSaP/fAe/qY3v49e
j5V9Vzvo9Y6xL9ubfZkZEfCGrfRKE+lVebHvezm945HsK29jX1pEFLwtG/Se
HaBXpqQX8Zpezjr7dKv0itbYN7lGbyOBXqOa3mwFvUO72Gfpo7fZGwnv1C96
rtH0yp3oBTXQq95Kr2qWXtVRerp1em5x9BxV9CzP6e3xoaccpHeigp5S9FkP
09M40yuso7egotdgpvf0LL0y0dcdS29kGz19tfh3L3rWz/S09+mZhDdyhJ6/
C72kl/R0bvTmv9LLvESvXnjhoi9Z9OXX0HPYTq//Cz3fe/T6hBcfQy9f9HXV
0rvmTq9ljF7pFXqtwjMLTy36JkRfpCc9o4leXj69D8K7Kbwm0Xdd9Ll60HMS
fcs59IzCMwhvWnh+wjMKL2GUXn8evU7hPRFer/AShZclvBfCs9yg1y68ZuGN
Cy9EeHrhaYR3195n77P32fvsffY+e5+97z/1/QF0mMQG
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lH0XxxHerIlJIREzQkhRaJOlDRHelKyRJbJkq4dKqN6xlCVZy1aW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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lHsbHgZZkq3i2EUkSwdZSiHkVExT1rKk+CZ1SChbNdm3OnZD9jVr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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4VWsbxqVQiiZNKEkq45YiURmOJIR2pIPyUZlS25w5ldmpzHNybFF8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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41O0atmXpyxclFM60GFlTKL6U5USrfYn4LMkkYsxE9qXF1sKUJJIl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbZr6EbJFzRMhEpZ0aHcYy0kJi7I20jSkncYwRqi+VIkJFaJMt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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41HsbxnGcjteuDNpOdlliEKI0yAglXoxStixHC0dNKGTJHmNJ1JBU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41esaJWPKNmaIkMpwQqTpyFhkynCKFEkZolLGRLtHGWo729xmyxTX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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lVsbRm06yBQNiuSYUoaUuQxHGRJlKNIgbdpE4mRKlBKZM5eQCMcU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3lYjG0bxpNWlWyR3rYhKrSYSstbjUgr2hHtSlrQvjdUDCqKDKG0ECIt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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41O0aHltElvIRHcc2FOJTirJEEcoyKCJFsjQtosI0LVK0MaioJFJJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41PsXNpaUKJVwtSLLlCVLFFljIpWdtBBD0y1RkhYpjKvEJBrmqkRZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0XRlIokd2rLDV4hawhjeEjS1Moa6koIvs2ImR9KxStKEvyRmSL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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHpFOoSSpESKERIsyUVkrWVJUYmSnRSNEdFqsUZYQIluNpYww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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41Gsbtp82ypKYI8qkI0tfmBidMoNsFaKFKE2ylOWIVEikZAsZyZaM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4le0Wxg2ZSyRKSsZCZjJlVnb6hIgypEwZkqio7M/YYYsMKcP2GVJ7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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lWsXxlG7NMmUyBDpcMwZIkOoQ6aPisySOUOGcHZEZKoOicxjyUnh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHrSXFrJXEiWlq8Mga5w+lDVLKdmXkLIkYqhjKykm5+SLVJYi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lWsbJSFRjqHRFA2GDCekDCFOOkSiiZIx0UdRpk/b1GTYpszaEZJM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVmk4lVsbJnOROUSZpdnUZyxRGTMmJ0MkokTKXDpOpgZzcUwdUbYibYSi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k0ldsbVsqY+UaRMUNpUOYGOTKVmQxJpBTXlIhSMtwyNVEpM8lxTCWl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41esa3SjzPO1cmXKjU3GSFCqEKJUMCaFEpkxJSqeIKDK7xHUzpXRM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lOsbniEqJFkKg6wlcRrJHnNSxxYJKUdFaCwxphOik3DsSdaSUlMi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbHiSdUFqGrxIGx16IVJKlk0ylrJFdm0RFwpe1kxBGaiLapLJn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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41usWNUYyj5kKhyIhnKiQNDiZylBKx5SZMhQ+XRlChkhFhCJDpmQm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbHkuUyocpUkk0RR3KlqXIloiTkmMscchWXXZFKDtNORxk4qCs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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81F0bxsmkhUSrkq2NkaVGjIQQMoRqUCkpkoQkk/IoqURli0eLHi2i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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41esaNZRTZimVtoRNYUcyFJmnDlEklTSYZatMmZNcYx1tc4Y4IkTh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lW0XPZLIkCFTpkSEKFMipSRTpOkoKbNCyJAxIvNUXkOESobqIL2G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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lG0bHtub7Fsk82YJxSQ0UShLKFGK7BRv4TVZQ1MK+VQoI1EoJCqm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41WsX5XCRRIZIGaOuKSkk8ZkpYyjFNWQ4dU1FuMhQVHKRVMYrQ2SI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lHsbHo49jRRTptV2bKlBCoUInUqIksZnKkvU8JkiDXJCC2VfSrZk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lH0bFWksWSJUjAllbEnaUcqSrUFSI2KmtyIqQ2UbZY1S0WrJ0rzy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c41W8fllEyflmvkYPUSdlbsg6VkWxR6JR0UAhFFCIaskpWRTIzykik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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41HsbxkdRQqdBeoVMZUm2SCplS2Qvy2QtSdmylaXEyUgJJ7vRCBVZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81Psexu37mqyJTJHIFiHKfsgxFElKRLKHkiglFNmOU0kR2eLKGlel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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlmk41G0bxidbllSoKI99KwyalCwhHjSJGpJUZC1biUS9yJIsSUNJJVqM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHbPv+9UvGS18FCzCj7ksFZexh/W4mDv6XAUzj/
++lfKTNevYLzLQrvb7378z6cfyRy4e7yl2/tR80bNW/UvFHzRs0bNW/UvFHz
Rs0bNW/UvFHzRs0bNW/UvFHzRs0bNY+W5gEAWDpFAg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGvA3fItb7mdTix1Nn/k+xZexj/luTSiXwcT+H8
xPwHz4W+vYLzO4wMP0UdvA/nzz5aVSL0+i2c/wjNvOdo5gWhmXcVzby5aOaN
um/UfaPuG3XfqPtG3TfqvlH3jbpv1H2j7ht136j7Rt036r5R9426b9R9IPMA
97JuKg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV12s41Hkfx/Fx2LSYRCGs0J1yrcOFYshpJoNMBkvJaUhbkmyJWJQzu6px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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFhfLqb5r7ndVjjVl/54tkZexhfPKvc9OS7J3D+
Zmu+a6bir+H8L6s9Jc5J3YfzrfUcGOe9fAvnJ5h22d83OQvnm0/dEzhH7Cmc
H8vJfqbrxSs4/+Czg59KWB/A+U/WHjWb9R5h3qj7Rt036r5R9426b9R9o+4b
dd+o+0bdN+q+UfeNum/UfaPuG3XfqPtG3QdyHwCblHKz
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN1nk01ekDx3FLP5G1UFmzR/ZoUq5d/NIwkokp5KKSpRDGUlFSCoWupZJo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k01V0bhw/JYyZHhwyFMhxjSuGJDIlHoYhKZnJCSpKkzLOcRCqlUKYK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k41V0Xh0mFkDFKRaYH5ejIlCS8KIpSKfOQWYZIRYTIkKHkSYaoTJll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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k0lQsbPUpFZciNhKvBTKGuqYyZipMxGTJXrjnX2MCpDJk7ZUirPlQ3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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c4120fFUoqEeUnZUYpVLaGmVE2lchjhicikvUjlZFZMopCVnZlPsab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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k0lesbNRyUeR4iQ5HMRDJcQ8mNyDzmqJuxMiYpSaQMCZEMkTIsGSqZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lH0XHmRrRZuoULZEIYUUsmQrIUtfWSrGm6QhEkmSUGn4bC9KmFdi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk41esaxSadCuXKUGSKjDshug4yZDo4SlQ7c+FulCFTpgxlKPPcyViG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k81HsbNZJBlKmRXA2VEokUZrpIRJaiLCHckEgiUUjWsitEFKJb2SVb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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41VsbdciUqUMIqU9XIWOKY6jIFBHJlJlooGtIim4oNKiQEOUkchGX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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41O8eRZmE+CmVRpqfpKFriZFU0qKISpYpZKRSpDJKxNi3dHOzL6Fk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4lAsfnegiMqWFslyRGxJaqQyKSuLKkpKr7IM2ESFp+4qIGtlCyJKy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lO0bVZRIshSyryEqIZ8ogxIKbWiRGEv67BWjZM1SGQwhslRMCknl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81Gsbxi11OkJSUZH1iCxDJSnGMkoqWyk5pWyRrGcqmVKWFhJFWixt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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41WsXdTIc0kdRGVKXK1cqZEjXFEoyh8gs3FAyduRQt3SMR2RKpUji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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4VXsbdUQSyUWmylSmMnUyZCiiQRkyy3BFlDFUXKqbKENIKekaMmQq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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bHZRI9owSbwgjEdlTlhIJIdlCIbKVXaWSZd6kQip7KIOREiEM
GVEppUQkhOxUSko1tPB93x/f7/hrrnPNNfd9zrnPcz/PSB0MsD7ETiKRlNhI
pP99DlgmpPkL8Rk0zdG1BIJf6f8f1w5uSRzqmSDwwf1Fei2vxwmsxhhbJpr2
nsANFrfWuHqNEdhJxMfbLP8jgccTzxr1Ng4SeEom6WABaYrAXPH3A+7JvyCw
Ycj81Mr8UQJPq03M3LswSeDUufHztd19BKYK8l+63fSZwO59tcZUgVYCW5G4
v9LXgH/jdjXSmdIPBA5SX28rxDNCYBFqEe3T708EzpqQS/A+/5rAh4oH/WI0
oU8mVXfuyashAr/sl5waKgEfyZgV9prybQQ+uY79kt9d8FF6K7tG5gX8PFxZ
UbvkN/Sv7av5GCYP/a7McomG0XcEVv4uHqrDDT+Dv5rwVDGeE7jlw7fWrd6o
97nwgLFdM+pd/1vmKhDeS+ARq7BouRPg327wppAzEvkQr2e4fR1FPmbb0s7a
N0APeXrjbC0Dem5b/zFjk0U+vMxFH5/7Cf/mzx1zMnk/QODY8GShA0LQM6nZ
b8+uDz1/4+i9/1Kgp+RG05AfD+YltdQi4hL/WwJLO3A16HJDT2CvjBZJG/M0
5xTbNTOPPEiOdl4ptx1GHjIpTdH++H3FoZHU3Q/hxw25DBWmBPQyflvPxtrC
jyjN78kfnVDftlZEw+Up8mbteuOHtAf4+ydmGFgIdcOvNmZz12Z8/9nB+dd7
zh7kuc60fDgf328j64eGpbwhsJihjHDfcczbbL5n9r5eP4E36RztdumBvnor
0vpqhZcELvPdaMxWhPlVnLMRsjPH/PoeVGhrZSP/oipkKZFG1DvtvTl3Xg/n
8R+uIB1BVfhzYCxUVOIS/El3W/Vsnw384WcrtRN8DH1UlX2a1p2dBA4rc1/j
xA19CqaOt0ixyJOLnh69QQB5ut+zXt/ZBnkaDONy4FRDnhh2dlRpEvpdqxNT
PmCJPA2L57OWrYW+RLetGqvKOwi8lWfnhq050ONy9OIcuwr0DOlni44Mov54
cqR7qRL02GyyjuLKhb/tIjGc1Gbsz4+SuobZC+g/LjlGd9TE/iyilFvrF0GP
9YWZjlEq/JHQKO5S5MD8736/vsKmFfUUnutP7izG/MX/ljxxncT8jcjRrVXf
oe/ZkJR2qR/Oy6cIf3sRN9TjSDez7CW3E/gxx/LoPHecl/IGbdeFFtTXnrY9
rCQB/QPiA5OmfKjvFMOk2Sah/h/pY520buzXXP7EbUttsJ9KbYe7wh8BF7k9
9R/8i/z5s0t1eNiATxk1jXN6kV6djhMXv8xAr0XllDo1AHzSWTQyjyv4cHvl
DXhIQG/0Px+y5rxRfyT0OfX4I9S/rx/XFb4BetexeS9R/YTzlCPksMIoD/U9
eWc8GoKhlz5dVSE3Cz1GekPpT/ejX+wersyYHvRj9vqf8uRFv5RixdZbatDj
YxJumx+Fftvp+Wrxlth3dWNKMrpM+Bm4J25BiAc4PDzvTq4e+ic3PhozJ4Of
jiVNS6kafsbGXO+/Oof+mS7Nj4240D/qbPv0lC72dXrKCwovB/h/S9YQ4jdf
lI+CCfuGEPyed3TVJyXaovtLU3LHBNsifokFd/UugJ9Jm4qn6grwEw5oZrsf
ivO0f32I4546nKfKrJzvXI24PyN5q+/lxy3y78iHDXnc6L/M1LHEORJ+XWD5
nmELA94r628wfQZYMaLUeIM/8NEELRolFZjH6GrcNUtggWYvD77nwKfVOUt4
pqGPSQsM4jwM/Vny+dy+9cjH7tEfNSwV+Nss4pVBHkAe/SjOVPGb0PeOweex
a/eiPEas7mnsRD+/Tsb58ynoJ821bxnVF/0u+5RvsMpBv+zQvYUtL7Hvakkx
tS/n0W+5XYwhywD7bsxQma+9FPOxUg9QbgzHfDgN6VkmMth3sUk/1nF0ot6r
ydutoe7Ydzlb4g6sbgK/PI/9qpfkwO9BZZTGDAt+uISPXBrLRr22Xw8bKSnw
Y0cj/UWgKOahKRKnIqYAPzYOHxEf0oVfFrzG2r0RyN86kzPef07i/rjKNrtn
fQHuj/QfvxJGEnDfq85emy0Mgf5S2asUZ1voL3WSSJzrA98zmo5b3/xuwfkv
zysuSIL+eMFtusqHoT/I1veZjDX0f0hSWMnqR72paaPpqSnUU3S9EqOWgHq+
knkl2SGop0OOlzyhi3p22nR25VHUO5hI8e3IRr199rIDgR6oF+7sLL2kEPVG
a7nuxNUiP0tH+NtN2XH/R2d3VYgLIz8cT4v0y9KRn7+vAprIafAvbZuYz+UU
/N844uQZw7gHfrU3aZvmGXjffNn1wLTrMOY5Vlb3J1wH81xV89vCWRD9hoSr
mR2SmGcm7fhanlS871p+mi+T78f39KV7jhvswHvBmvLzhVUp9OfO3XFgFkD/
zPaW/ttLoT/Cqup9wjjeP5aM1gCpaPARD5RR3VkK/W35B+kveaB/9cI/E+NZ
0O/YuXbyTCbyHu1p+lZVAnn3MkrwiZBE3m+2/Xt0hxX8GbE+mcJ0hz8a599w
yzGQd1HF7ectQqDfSKrwbWNNF4GDi18OVvHj++yoHw1mLPhXJaSypZK06P3P
d3Op+hHcJ8LDLuceSsM/O2e7MA423CfTfZSOWxn4feZlM1m1UuiN1Hic160M
vXn8kW8VFt0vjJpqMi0OegWCvhUKLofexm317oYn4P/Fx9d3J1XDfwb7aJTi
O9wvwasN2wWugA85wNCpZhB8joW5kbWcwOfswBWmMGMRv5AE46CVwKF9lcOi
yuDbZy/rbqYOvnOnXme8iwdf+fYj3rlOmA/Fx/CiQz38rzR/GHOdhXzeZSUq
V0hAz4KPk4KYBN7nA00WZWdXIJ/d1GCxTfHIp8IvVvSCFfwpYl1slRtGPTYT
2d1ZLLzPQ6p0Mtlt4E+DhBdt2BvvMcmVdZIjdOidk2N6+ezCPqk74WX/6Rny
wPnBS1bKE+dpIq/Qns4LvhZTwZzep8HXKu3elPAu8H3yqukK5SP4asjZx/c3
g28UZ0p7gjH4yprEmv1lgm9nj3a8xnvwzalWns9vQP0y/vk4zcOov/nqWY16
Kvb9l6gbHd0jqB/s7x6gnYt9mv7od3WhJ/TnlkQqqNOhv2vaVS/lIfTvjbf5
zMcG/dsf5N11XId96pYaU2lAA782//2FrQngZ/Ht+A+Op9gn5t7JNXGL/i+K
XfC0Im3GPqUleC9XVkYeU2ntGRbJyOO46qn//kEY0f8PYiFwpg==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41esa5ZCMSds8HHYokbIzpJFoMJN5uGVIqUwZmlA7RxxjMlyRkhPp
umRoJz0NplOGnSlKpm1IyLCljFuG89w/7m/tv/aznv1861vr/db7fr+P7OFv
ffo3Dg4OdU4Ojv/9ihYdGwwR3aAfEzb9RKpiXO//eKLnL3OVyAEC//vGa6qD
4BSBNb/63L1x+z2BGWlqHiW2XwnME79l1GxggsCVrbpR9Vw9BNZjFMynOTEJ
3HHLr0zlWBuBJbl5e8PjvxHYV5QhrXx9mMDjMszq2WjobTFmbuXhHyTw6lZW
3NoM+P2W+ZYHWhsJHM0S86OsQO/1us1Ha7dCb5NF/JWI8T4CV/gz+B8JwP9d
e42ZZxnwb2JEr7rnBL6oUqb1sR7wxTr2BNDl4X9ST7OX5g59QZMsOkUU/s/N
zkbLn4L/D9eNCqit8N88PhsbKwP/tEPxS2dJXwg8sz7lCCMZ/FWPbALqelsJ
TDUwzjBzGiXwR7WTJRyvgZXyy7M3CQHTKYWkpf3QQzc8ZcstM0LgU6tBLWq0
MQIXXH2eeJxniMChGT/DjDmhRzvdc07o/EcCK3wNmiQpwk/IlW2hoZzwU2ZH
dbyUifV2J915eh/Bz4e736/LqkBvycTsww5h6J2Tq1i4HAC9aSqmijRN6KWH
qz/wJeP8DpIdXhuSJnGeiitWzK9dBPZXfT5PXsb/M+bhCjEx8LOTS8rNUxd+
er97vaE2I59nMhM4zZ/Cj5SsbuZxEvwsvBIXCfkLeu9oySrNjMHP1bAtlecq
oNebsvYryR95M1lRGHT2ZaBfh1/cp33BfnlXQpo1aE0EVqWpJBVeQL4YD080
GtyFfm5eQx+BfsyDuDAjj0cr4Iumz61Ts0Z/mcn+Xaz/CvpGeborxIOgrz+w
IcrPGfqmuyq6G/vBJ6zQUizQBX1eKV/IzyKg74X3TeO34dC3q046pVEG9c3Y
Ua4Z8R18SrUWik8EwJeadDM0RAZ8qSNpuZ1c0EcJ44ikPepHv43u/lccCf1v
GZ4SaEpB/x9UvJ0ewpYf7+wDSrvZ8mPL3UjXGkZ+Ah43ZOxjy481n8x/J6OR
nwRdjbWl3fA3mRXTGtYCf3E6KoGDpfD37N6thXXiyI976M8Mzlzkx+tqjDvn
CPJzVO2wfEEt9OqzWGt2Z+D/iAa171sWzuc3w3DusTHsJ9uX5stph3qSmv3i
F/VRz8+Bl3M1O6Dfl1E3LWCE/GQNXFyU3IR6Nsyfc/U/jHruPVDf1aoGfWO7
++rIfKjXiMuXDvvfuwksN8Jj57QR+mrVftjUC6GevT2vrpkOod+v7qzfkHgH
8+W71SFvDxOsd1rmJDnnYR6HqQVHaHeifhMvFtz8hqAvn2M0tPAI6ndOKXXn
lBnuj90Sv+7XrII/qzVif4Qh+mVReoIviQa+dzwv72eGgs/SrToxcjvOQ4hR
5endCT4ZPvqK5p5mApcu2nIV0nAehqQl33gDnEdOe87whufI0/4oC12v1+Bb
GU+N9MhtIfAJiVUPYU/kyals8trEMdSzomeMGTGHeW8fZGvJeQDnFfjthqX/
fCeBe+Z/Gm/Ixv8fTqrbldA6cD8pk+47xML/R711Vk29vQTOJm08GkyH3oXp
eauMKfg/5eyQWS4IvSkUTkp6HfSOCG5PT/6M8x/cvL37DzL4/ggif9yc207g
X1cdpPruYD13vfpHncPwm/Ak/mZ0O/yQmyan3lM/4T44WH7s6GfUvzwvxcvq
CPqhklTocpStH9Q/FvNLGKAftFmtk/GqyIc5V7ysKz/2qzZLO2cjgX6gFq+/
MSEEPy+iJtZKZNEPmSbPcl8x4cdbV0f2EBX1WApynx93xHr1UsE2V1P0Q9Fc
r9FoIvqhccpQ4vhl5O1lof29yiT4TfEwS9OdhV9G054X0izwn9nEmu5JQD/s
vJZ/2K+brR8K0vtYlsjD6CfjdH1x9BfvTRutuUXw0fNjiuoTwWeYd/qtXw/4
3iuJ6XyyAB9fu5u5rSz4gotDFh+y6WPJT1D6osBXuKVKmd4Bvmnlg2flbcH3
ID83RoMDfHxxStI+8+D7j0ODMKkUfPGyPtEvJ8HXRprYOLsXfGMk8kBWJPhI
Etn7hLjZ8rKtldq1grzwSv451HsLfJdKCqJjc8An8XDWLdYG/WTbs6FqpQj6
QpRU5e6r4D6pTPRadSxDP/UILSs203H+LPqMkfYa9uNOkFo7q4z9Ik1Vc0fn
oX9ZcinmPNt74tp5hlpkIvTL5zS0bWN7T7CEPT58YntPeD5N3tPIge9ptWat
7udseQ3irC3LM0Ne56wnAqduQ6/7XcNgvYvIa1Tq+gCvVOS1UmSz5gMm8spx
gepwe4ntfrh3Iro4BOfX6me860Ir9DanXMmzcYFeTaead/VdmN/u6p6Lb36A
Lz35scClKfB9KJm7ESwIfcc7hbfVioHP66x77R0jfJ8cUtKqydqIeu4PLq9c
dEA9jcvTHR11oO8RwzC5ZpXtfabTEjzmiPkxHbepmqIEfcOzyaNJKZiHdnpW
dc1xmB/d6xXa7VwxD7n5aTfdKjCfOhJanSdXMQ/Nv0SMdipi/7RXg+sk1pAP
8RAXwW9s+Yg8YfpQIAZ+MuQ8Tj+1gh+fKpstLl/B93yHlCuZCT/1JG+fYWv4
uWe/s1ouAPk49eCiPrkI+eAKm98huhf1P5hs4l3Sx/Y9rH5r95ldyIfcXn9v
K7bvw2szfpYOWtCbr7WsoKAIvXeTU7Pvi6A+BomnzYym8H145TZPeMga2/35
sFtO5iLmt4htC2+aKvTYtolxJn/Hff72UoJwTQ78GkksNr25gH7e0l80OLCA
fp4oD6gZcoV/bdFnS4wO+OczFyG3bWK7v6TePBZXwX3BdBp6khqN/VpyKEnG
v38gsOObyr83puB9llt7tq3MHthZcpJ6pQpY55yL1Q9u4EO+toLeJmzvuao7
l8c4oD+/4qiVVSfyOPB7lui6UugTE2b9TNnL9h7+yRzu4UWe1Sh9Z1yUsN4s
OfVPqgHOK54lTc3/ydbPYWcift1DvkynLlYfZuNfe/3YsJ4f/JrDOvZtyuCX
O9Bf66THNp/ruJjNc2z8VcPGFnHgP3jA4VKOFvgddPvNq9XBP/qWqmihD37H
pJlSSR7wBz6JqwtSR54onw/sL7RE3hY2xoXxvcX/p8erNVd70a8PXmu0vxOG
Pi7r8dR2L8wfkYvH89pEkH/57iY/ESPkX8NBIrpWHXrokpRk7fXYb2gPyVhn
G/wm3RnJlRCF34Yc5q/6efgN3de9JtEOv73p1dFib77o/QOL3x+l
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVmk4lWsbFRVFStuubYwPKYWETA2mzEKlqEhKpiQhdlEOmYcyZkyZZyUZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0XlqgYVNJQeZHsDJOYSFLJ0iJ8aJFs2ZfCS11IliyRpSKvLEWi
QlQIoVTIUhGyVci+TMgSo3f4ru+P73fPX3Pd17nmnPvc5z7P8/y22174jz07
GxsbZRUb2/9+A10qvOOF+Pb3FJxViB8d1Po/lhuLuXFRe4LAd2JDyDUWPQQW
dneatueYJPAp5sERQWYjgSVfOZO1byLfcA6vYPkD5OO60Jzcb/SNwPVFb4N9
nv9E3LVQLECgmcBkm4WjD7OGCezx+O/bLcOjBK4bNb5d/x71hEU0DJucUG+o
wHA57/Z3AvfYOz7Np6NekIhlTrHKRwIvhgqU2uwaIvC2ZUpH7Pg4gWc5Z8tV
yH0EluqgXT4tBD02if4SOznfQGAtq7pNT1eD317jqIobu+gETiz9wC9A7UI/
PQ+6XMoRD7/xLiprUzuBqd/Td+TvQn8LlDKzHU8xH7sDi0LpJPCZ3NPnVJqG
+RxKargbYQk+iT1/MdZ2Ix+f+7i8h9xXAhvIPlusdIJe/MKLFKPxz6hnl5qy
qI15MHSKh703YF5escyI9zVjBPY+HHTFsKefwFUzHOZzYsgvJc1vrpXTSmA3
x92v6+/h/zJ9lld+qQxA34NLXgID0GtQQ9O0XOILgc0dhkOqMzA/3wEV9eRP
mF/r7rXmDBY/T+uZ2AbNQ6+4Mj2ZfTHQ61ufIoX7MfTiD7nko6sOP1/+cFVL
/wn6UbWWHfmkCj/vMmE0FFVDH9dWOWZnMfRTTjv4gUqB/4Qm/nIUngF/Jpcn
tZEd/IVedETeYvGfg61gne0M/CfyY9RAgB38u6YubdmsCr2U7ItpVtLwn0ap
uCi9BPGJkofZcTLwXyRn6sk2LfT/QSRs4yoP+C8w7Cuv6hrwGf+aS9Icgp7l
yqry90LBx38Nn4vGc+SjVWgrNK6BnurPZkrqMqCnftr3w5mB0JM09r4/ed0I
gSPOSXXn6UFPF39vz/1c0NtOU9d6bTP85LXWVPxFLfzo9uexZRoV9eaNpnpP
HIYfed7UMDxP4f93JX6Nktrgx/SQueIAK+jnERX+Q0e5k8Ch4fs47Y4jTrWj
GgfdRvxN7cpQrR/iWeHdkm23OnAeWFj7mrEj/qfTStlUv5vAhkcvzNwVB/94
0nPm3D0W/lUHY4ySwF9xYFC7TQf87aeKYna3I79kgVxDhBf2qXjnuaDSFvjx
wP64Z2Im8KPdnV5+x82Y/+zTbT3nhDH/JM+r/sNCmD/VtlLyhCjqLQRkytRk
wo9lzQc4VEcRD/J813KfE3zseLo4mmPAJ9R17xsDth8Eps/qJzotQQ/r5erZ
5KAPBM4LTLlu0Q4+ioseVaan4Efl8une9p+4P3L0yu4dX0S+by/OK6mnIp/2
wmOR14PI59nlONmrh3xxmdzptjrYlyAe8+TN7NBrfnmfVuI25KvQvHbGKgP5
vN0lvA3jkS9kZMmAWYB9UZPqX81RC36bE2j0kwpNmOenu2fTKNiHPzejtJtT
4IfoQdLmSU344ZDP2PFD36C/ieaa7UsG0D9fzubFYDn0D94qk7kUDT/cmp4c
8FqP/hTGLReUXOGHVwkPBD200V9+9khh+Dz6Uyrwbwi+AX+HtTfX6u1Bf0tB
yzoGvPC3RtN9ATl59ONS9tspmYb8weJ71hmz7E+ilpy+O8v+mDxKsn7Isj/n
OlfGq1j2Z93Ftlw5lv2Rp7eWyupCrzXMtvfzX5D/de5yk4A39NJ2binMb4Ve
KYI6fPlG0Ev5zAVaIsv+nLsUf2l2C/RSaeCYixdEP1vDhflTxVDPTbK1LSSV
ZX8EnYsuDyHurKhps4MMPpoNL0XOJ4GP+O2QyJEh8OE78ueGARv4cP8M+cGz
C/7kazoRWP6EZX8C67PrwjC/fzhlQv9mwJ9duVu0C1uhr+BATP9Lv08Ennsy
YbS2A/cfpT9NX4oMfpZlrfRccZzXK78S6GZxyLevJ8EtcR73w8PvzQn+Xrgf
EqtKPrnHA/9cN/1E8zQwf2Vsu9lr4PebT9pIcgN75eTLiengfumN+nyKxod9
+sedobBUB38c86zdM98Ovh9fzHgPSIJvJXl9wLvr8Fe//DWxhEj8/zSHswPD
Af7yL2liU63APHWfcvFO8OF+Vl7JdJigQn8f5jGXvFc4bzJyj3eX8mCe3q9k
pTTi4C/vRFp77QnMM6H78/jCD+RrqhD4LLGMfSnb7yY0eQb9RAVHnpzd00Lg
SAlXk3/DoBd17DNFNhbz/TnY4Fp9CfN96+W3q56G8/vWnNZJNZb3uu8I2efd
HrzXT4c29vrSkO9ybi9vzTDy1ZStUOii8DNtp83DbSzvpcaj8tVRi3gvHeG6
JnueE/3Lx1mbTOyE3jMcL63C1LFfU7IrStTXiFeL11zkY2K/WiK4v3tKQT/B
xuDg5/OYh5qQmsyFDeAjkRKaJG2JeUjbFhxz3ws+jBQhoWv/stwnpX+yNjhj
HoORZrOBFOhlqBaRnm0Bf2XnrcR9cYC/BOOnnMyK4K/F0fXUeH/0Yz5XLiIZ
i/eHuLnYJDsb4sf1FQI8zFDfLzqsb5U06svwqhp0hqI+N7lbKCQU9ZmBb6lm
Xqh/c7qvcn0hy33janc9VQf+drxytjbSCP0f8bjSdEYQet53seyUZaJ+CCm1
wsoC59Wp3OQrbu+g586R7Lwid+RT46EV2/rjvpeeH//SM4p8pknxmckO8J+i
Cdmm5Rj894CU9VuqEf5TnaDetnCA/57qpme924R5N/OoU8jKLOd7sd5KlgT4
HfNNvDW3CXr4/dteEjEI/03yOQ9NrSC+82t4LtmnDX6VMpXboQg+9he9kkPH
sF85SW0q13LQn/3cNtUAPZyfi6vacwW+4HyrKKnwzEnBPr+RjJQKtEX/ZVXn
ZukFqBdAUqSK5KL/o2fdNm5n+T79dJTNWPcB+n9kcfPCOlv0f7jSlubejvlM
80UPXd2H71PdFetMh/Pgny5369udWnyfGi4zuA9KgS+X4F1642H003Fld2GI
F/xYZaqU55MMP5JoGXUfb0Lf1opNsqok7MNOcgODVMlyPvqmUFQawS9KaNDY
Jx78eOVUsvW/Ql/Xe/QuyTO4X/zts39yVQAHZihZS24AzlYLvkHRQD9Hzj6K
CdmOftiXD101fYJ+RFaTeHaT0U+GSmtVM4PFL9Fpq/2S4ZdV0b93nNLD/Hgq
6ocH8uCXBZtnKlur0Q+n5BRFVAfvyzQHhY5odfARfUJfdooCH/fwyt/b7MHn
GEMr7Hkl+Fz0d3zJ5MS+q87mX38mz7LvAhtTpLqx7+uHdR4+5pvU+i+MiWv6

     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXVcncZCjzkegmoRIiogxlSkkuGTJ0ZJZLCsXFSUKGI9xMJcOR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk41e0WFV9SxjhmkkS6MhQ+HMqUzBo04JIhJIQGImWqqAyZZ5oOGVKG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk8lV0X9WYeooSQ4RpKmePKS4UoKhIN4pplyFyRIlSSTKWBW6JC4c19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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlnc41X8bx+0eZIRf6DiRcWSmVE8a9h4lHClkRFRGZZXEQ9mJhi0iOy2z
smdGViLjJBGyfhn9koae6/nj+b7PX+d6X/f1/dz3+3Xfn/tztjl6mjkzMTAw
KDAyMPzv12IiJ7VJjFv9UZyknfeXD2r/12HH6mOqxP4m9ITtiVq1mHZCr9vk
um7pmSB0ilNPesPZeUKfqnmbtmX1HaEF5agzofsRD07/zLvAPUToqeSluDdl
iCe+qCXLHBggtMejOccfR+dwfp5g+5jgKKH5nJ75OrKiXi1bXclnqx2E3t4f
EPrnzidCs8bMeB8pwHn8G9QGL6nRCD0m5X6nsnwB9UcdqIj/0U3o03mZOWwJ
U4SeLQk3WGSdIXS+AVt5ZzTyvaK1C4sUIx+76PlwIR7km6eNXGh9iHyVOflM
H7R6CP3biRK0/A75jr8OIdXd+0xoP+bjwYJOk4S+3adTJls2S+iT1EZ1n6wx
Qid1U8KzBMDrXvI/H5YVwOt3tcXXCWnUz1ZeGughhP4ocHV+Ir1B/7i/cszJ
MaL+yOCocWGvt4Te+HK6aUYZ9dxQNB6KHPtI6PhrMZFpdLyDXy/5Un6Bd+jF
3y6NdLx5i2zTOljA++4WK+kDN1HvuxmT8yFPwDs1/9qcCxm8zbJv/+B/gny2
0wMteYrgLfo1wF+9CflGWW3EjavBO8WTNJonAd46WX3urKzIJ9orKh1ZhPu0
LT4jZ1UUvF9vS0rxT8R9CujcblvVj/v0T5ZN21Nn8DZn8eopFxgk9Mq1j+vn
9BGfqgnlq65BnIf/k7LFXcTz6gt8I5hwHy9bCBuy1KFekt+q2/GGEUJ3vK8e
P5wMPlLihU7eL8HnXF1Etpj2NKE1Z3xI5FnoRtoJi1v14NdVXlJyqx78eH+a
KdO2gF/mBnu++zyop2h7dKibD/jd6KGkxW4FvyInuVyFQvDLWm2UZhkDP/fv
e9psbOD/DkPuMz4j8AkzFC0544C4tcKEe4EC4qtt8i1r5oiLlK5odl9BPJaa
TDvkh3iOqloNw2Pw3bxl/b2VIOLFztWu+oO4L0MKulfPMINv1OjSCQdn3Bf7
BY2xOFncl8KmRK7lb7gvaeGZPFeK8P2C1qSjgxr6Y7wnw6+tD/wb1/zSL2SD
/2edXTJBluAfWv1KntqCfPPbUkk8ftgX1B3NDupbwN+SHBPjMQH+vBmqlJN/
wL9RoCHPVA3+D1Vfazq6An7skzbmPoWIt+XvrWAPwr6Xr/S643cJ86Dhtxbg
avAe/ejQ7zg6A/8CXx40vnDtJHRNhCRbiTn8PS8sZhpsgz9pThqZ4gF/n+YM
K5VI8KenrDn+bQD+0uzzwm5+hz/LqsrOEh3Un8RV1e/dBX/UuV+lTKl0ccf8
xvlh+OPnppLHC+GvxYJxoH8v9hPLB2aV3lL4s+iWTsljR39Xbgq9zMtEfync
jdShFfS3ukLiLl8x9mHdAYPSgAjkk851mytcRj5tuXDx1GHkC3zHxMAh00Xo
9v7MyKBS8My1cCyRNQZPtuAXv1lzMZ8s39tZP3XhvLXMIweT6nGedHKjQMsf
nMd/7Get/yfs80uXPT2c08YJff2cxOFT5jjPREW1Oc7nDc5/V3KmoRL+5Z4x
B/ZScP7vErZxJUb4f14spe1Uh/1iPMN6y4Tu/84LmfIl5jvo/xcJ5dN6fei/
Xb9i17QL+isnZhTVugH9T6jLDLPXRDxASWhv/kfE477Whwg9QHzZUYdvohDz
8ZTC86ApDvX+MDKQz2lGvwo27w81eAMemdxv18/Ggy/H4sCayCz8m83ZeQ8x
oV99C3xTGlTw7ZnQj34VgPPepi1ZW57vJfQ9kdGR5gnsd5n9kSE2nZg/b4fP
MnWPwX/RVMDqigbyc9dpn4sYQ36Vtnku4924f6ZUpqoQuvfx5xVv3Zh74L8z
cGcO/xD4l19h9X3oCH4rvBfaqRTwHb6eMJ9kiniFYlGBSyziwuGeuu+D6Pb3
k4po6hXs72Hl2gLVdfC/4emdFn96mNCJN2V47+8Grxer+qJFe/oIHX75h2yC
Kd3/k/DUxyWzqJ+PxGkUZ4b8k1+00xmuo75e8djwEX+6+VBaSWpOQn1GE0u3
pjYi7v2vDdnZ/Kjvhn1yU7AQ6kswCbGvmUB96xFX75N7UF/KxmhSRgfmgbI1
SP7YHnz/Oa72qcpOfO+eJdl00ATfL3jpKXEsw5/U4iOxFiPUdzCOPdbqIfxx
8rvWMd5APNlVUqFOGf4aKKfOtAyBf8a/ZaY1lfH/hCQ1FqTmhfpGhc1Nm4sw
r5de/PISF8Q8nnY1udrkhnlVYe81JOug/m/6pcodzNiXP1dND0keQH12d9ui
bDnxfnf7Fo3YliJezvsqf1QL91co3bN1zZLu/9X1Z0wqv/F+ubioLx5hwrxX
f9DyPSD2mtAvX5o9Pl+AejjNaSfXb+G8o/uLyr7XYB9clLUqZu4Fj5MdXhI/
crAP8m/a01SXcR873se6Ba3Cf9muqLPLnuj/2Yno8g53nKeqN/lTqxt8jzNI
KPPvBt8gml6Bzh7wDY/03ZGRiPMptD01D4wxH7F+JV6vB8Hv6KjkaoNrP6H3
1fuPL/VhX7wN0q3wssC+UPO8qHqVDH4+jYdt3Z5jX4iImd/un0Y+8WFX8m4q
8tFOP8977I157O7isPnLG/FNir7TYXV0+2BzU6i9GOJ+bcc9urMxD2UGvUu+
i4jf5hh0FR3C/zlNTsZW7kvwY66vHlC/H++luchfsior4L1t9Iz12ynMg7C/
kTt5E/pnTmOINiRhHrKtWX/F7MN71hp2RH2XCPjoSO8zTGkDnwu1203UlsAn
ULrFL8QY9VvKUjQ254FP+LjClGwU4tJJHRfTVMHnqU6hvuMH1OOTrLFjiR/3
lWz9TcrwLPwJ6eopnpvEPCkNDxhe18U8af99qiV4E+aJQaH+P0YdmCfetoSR
mgHMKyPX9/FvCjj/kOvYErsd9pVcbTd3mCe+X01YX/DIhf8KgfQF61j4I32W
rVsUhb9qLhfny93w93rJgC/TDf4qmdVv811DfqX5WGMrffj7onfM36we76eQ
hddA+0boqmJ1Zis9+E+9YGQ8yQP/qqKB1kmdqD9uM3f9+V74H2yX5wraSbev
E/vMyAbwX2Pbwqlgh++POJI2pLfDf2EYt89DT/iPL2a0cByG/wxP79Ahebp9
p+Hi62eL+RfOTOHY1Y/44dhcy6hA3Gfp1M5g34+Y/42RL0/P7sR93pmc4ZBB
9/5vbS0+wZuGeW1l3yShOYh610gr4mdOIZ/wCH8zs/ig2n8Ba3Qbww==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk0lX0Xvaa3ElFKpotkCJnnpCuSXkVelaEkGZIpuTJ2RbxSFAmfRNeU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4lXsXPbrGZIiQzESR4RoyRShS7kEoDU6GI+pGuCcilCE+wrkRRYpM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k8lWsXPeYMGUPIkIoMEaloQHVFimTMGOckdE2HZCqkY8gQidAtqdAt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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bHWslIYmQeFXSQqKFMEKoiamIElkrIgYtUqnI9FqyhsaWikkN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41PsbHWsM3YyuJSUtJrtKUpYiKVmSJUtZUtYUrhYSCUmWLDfcS+WG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41PsXHrJUlnBTSkShydhShEQJWQsRZS0SEqWUrC1EiSE3I9kil0KF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lH0XHrKHPkkhSzTZCoVEltEoS4sthZTKnkghIvHawpC0SlIvTVok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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0XnohQkixRIqRFEoVsoaSURNYSibJknbGVJZVo8mEqeyUt5s3W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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41AsXJnGnUpZkjbFLEYoyPpGUIqUFRUkmW2mxNCHXUiQhIaJ7s5Sr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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41fkbtQtli0K2KxEqDBVyLRFZRpasWZNBlpsZjWp0FSm7yJZUiEnJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lVsbNmSMbXYOjiQVGTJTKjMZkqGT+MhUJNUxpWxzqD7FScqptNu2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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4lfsWNkedEEVkk4iQoSgZt4QrhXBNTWRM0TZ3kJChq1OUSmYNhhxT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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lG0bnhGiElFESqXsXpUt68jaZBRpka1kCRVJm2yfJQr1tk2yEykS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lXsXPRwiShEnoYwNxkzhyJDLNdxoMBTqIkqIpDIkhfhKphIqZMos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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXPSGuEBEyJpmHyFxmKvNQfQiJShKZSzJclUKGDp8yJV0yZEoa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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41WsXNcRNA0k6KXOEKGXIkJlKyRAZMmUsc7rEzZRCnwxFxkim6oQy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41VsbpRROHNesEBmKkMwSDilKt6Jjdk25CWVI90qSi3RQUoaUKUKG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHnFCiGIU41iKYylEsleynCE0tNgKpYQ61Tj2JLLEZDla0KdS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3lYzGsbbiEt6iBEGhq0DFGpaD2ihZT2ObahFOo0lBqUc5ii5aiG6jvS
lBbtFKmkBRFNex0tKjJEm0w1ja8zGk7lXN8f3++ev+a6r+d63/u5n+X+vUP2
CnA9LiUhIbFJUkLif7+7P/62tGiXkqVtD5UzuYG//f/YqS0jelazmcD37S0e
1hUPEnjAR/eddeE4gWM3yEuYJ/UQeI6imv3bnTEC3+jYx5Dx5hJ4IlSV1jc0
QeDnFQ4DwU1tBDa2Jl9h3BomcGUg3VUimkfgNtOrSjzNjwTW7LqexVyD/NWL
Atevr0H+pNaIspb5QwRWfbTf5sFh5H8h7HlmhtdrAjMf/f3uSTzivo8tealG
vQSefRb8rnwO+kx7MpPmRfURePdekXzOMegzf3rO+ZB6J4GTpnzUM2+MEli2
ZNeY0TXopWQWJatnQi+pd3VMBO8DgT8J+xusN0PvM0WJmw7fmwj84UJMQ1kS
+nXE7B6HWwM9/nPrbD2WoV9Z89NdrD2gpysqJ993+h2Bz4WGKntqg6/q0fEX
znaor4bMpO5/a8E3XXJWhZYCvvRz3zXdZsAXwtty9OoH8MVSVTgH9N4SuL3Y
fcVZNuqXN2J6+Up3O+apsp/F+u0T6sOQObG8APispYgucAeOfUn/IRoDXuxv
JTr/doTAq7Ofy3dVoB9k/+/+O/egH7s2T8o7iNAPVrqubocC+vE+VSE+bRfq
M0i+VT+X00jg5cGdqudfDYBv/+0eHSr07e+kVq69jPm4t4AVVTOMfIobmovj
eZjfBHqyficd9TObydxb8QD9aqM3BpaJ7QNZjjmPWo1+GVc2sLfPw30KTJOJ
jR7ol+p+I3/pg9gH7zcWsn0sxNeX12U+cMA+eK4gT+fLI56nYBRA2ol9oDGc
bpAcofeKhodGRhH0qlozBufJfSZwv7Vb6osM5NfukSI0q4FeBaMfm+aGMC/a
KbUWyxtx/1T3gWTyzpfoj+cmrcGD6Leud1tlQxj49o5TFbSTMb/henmzt55B
j1J1tn27GuZXbUcrL8Mb+YRoKNZ86Uf9S9UvHLmogfq7BE0uEwag/gy2lTrj
Dfgohh69s1Hgs9z6hRYcgPqqKz1l+aghLrNsyOwh9w2Bw7r+3sLcAP2S9Oig
kqtdBG7Uk5qeLoXevh/mpzZogd+x3m8oXxXnDwdYyJIEON+QtI9r/x3nQ19z
PLQvYZ6fRb7NeRqN83uWtP8pMuggsNZ4bJfxX9g/jlwTv2MJsMS3sMJMGuad
vk0q4qIU+tX4q/rcT1LYvwq2Y2yrP/jdh9Ocg6+D3/usrKn+JPxicfv60gsJ
4JvSzbaxugTcPyv/i146sIP+qqggP+Af3kn7z9QD12mb/rGWDJxaqkNLtEb+
E+zB4WZ95F+7KLqioRr1e1NmqOWohPpLXreo+6yD/KvO2eSnMlF/O9Wr7r35
OK+mt+5ltiXO6/CCRAcX4Dw/NlzZ3+cV6hfif5KzF/X7S87pI68S388YuVHT
txM4/4XsKT/liu9xSqmAr3IMfli4Zf6z27247zVdsXa+J/yQl0m+SLfC/PvN
JsXlv4MfqlQXexwQon98riG74Gfw12hG/ZL/E/Qrb+M7HnKH/vFko1i1Gei/
e62A1n8C+2GgMdzxUQf+dS5G87lBCOJPNpuVjtVjv0o3xv7asQvxke6dc4YD
OC99MmKPcyPiRg80rGmj3QTmcrIjs6zhB390rMxUiHqP+mjFiTZtQz1IuZI9
1y/je11+9HbFrBv0vD3jp2AvAl9bU+KmxRz0c28az8WRhfqHvjA4cHc1+pke
7hL7kAy+JbYppdFZ8B8tfuDvwULw6QpX3SadAt/Wcg/frbLQ/0B956iyD+K/
rwph3tuIeIW5hmxuMOKztJkso2bUt8IlK9rPDvHa3jbbsdc4H6bAljvOQZxF
rpy3UAJ+W/xJUe+hK+q7NXl6Q48p6ltPDbgp1IXeq4qVtJuDqO9l+ui2yRjo
jdnorp/TAr4WGXm2ySv0M/FQ/IcEY/Cp9a4JMqsHn6y0zQdHc7H35q3OkVgL
8GmuK96coAO+Or3IJWnLMd8uDj6T2nLoZ6CizR6Vhejnk/yVTKl92I+ZRT+s
hzPF/HlN751qNvytNW8sm20FPypOYYx8loMftdhFCaey4EeRaWlG8kuwT0Hm
gwsDWfje5traF+h3Qz/VuapV6TS+t7spy2JJBchnm7FMyB1v5HPRVSDiifn7
UOsYJ1jM313C/I+3i/m7X0muZook9N/zdg8fDID+sGf8jJ4/wWe3oi/BZAp8
q3KdZZYmgs8rgt/aJfY+vGBcRmXfAS46yxO+ogIrjosiTvKAazwV7nu+R36i
e6UmpAfIny1wyv3qBj+MWzuqrDaO/OOubVnvuRF+KHE0MualLebltku77fv7
8MM6SttASx/0xqgtOzbuDL23eAf9BKl4L40quVkp/YN8JFcs/RJejf75pp9o
ts1A/x5eN/hifBP/v0yE9ZRQAe5Pm7PIW6sHv08mhRcZuULfI0bxDRc+9LlK
pR8r0IC+XVVutjJi79+vUSGvv9+FvpeefQtWv4E+Sm/hPiVX8A9RrQ63JYq9
B0MqdpwQQl+jt8zpiCboE+b5utckQN/nT9zek8PQ16fhOlgzJ/Ye4NeOPGS0
Evj9iifVBgLcNxn/j7blcdxnMZZmsLkX77kWHol0dD30UYwK4juY8NOlyjNe
pR+x79KWXBNGKPzltNbZLLVU+KEv525Z0xbEK1aFfZk5hPfc6Vcb7vV9Q/xp
fL/jhUfwi5EC7uREJPoRrdzeFL8Z/q/hXfX5KAn5Wg0N6NO4yDfsa5qX8zLo
NyjMpnU6gi97LF4QXAV/9hh3FX0rR9xExbyb7wx/NrxlnN10CfVbcFl28X/M
UT+d7oRT/YrIJ4lCTVlU2IJ6b7f0TYxEPiU0a5OrXNz32GJ2ZYct/OfIIU5a
c7rYeyGOUVtzF37Asl/8okFsvx2UG0+Fi+235PLERiOx/dY0HJnwEttvRlKg
ro/Yfq/ZUf62XWy/c5lz31kUzL/bCov+j2L7LUjXzh4pwvyfjzksMBPb7+0D
E3F7XZD/HRsLXVYK5p/pJTpK+YZ8KDdDcqKfoz76cdJbXqSgPl4HT/IVyjD/
IjLT11eI+69v3893msT8r5Ja7VSlB30nN7mXTKmIzf+C1zv8gvoJbH9E3vGw
DfR1HDw9fKIW+hKdSgrXjUBfUlylsaEd+IUhO1gRbdDX9Fjg9jMZ358nRSlW
5XTokx4e5vCmkc8Z123jrLv4P9lSc2zB1GncT+VWcY07O7b/Cxh0Xes=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bpYiKKMqa0kqyJJFdhJQXaSpKodBiqcgnzViSGGRJm1R2cY2l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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbTsgyJlSWRhFJUUI4bfpIKGYIRX10KvuWfUkkOZokKkTIWoQU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXPaRISKRMfSGZpdRVJIdUMg8ZSjmZDjpHEgmVjMmchMtDhhMi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41OsfNZIlEtrUWLq2KHuE7MtVkjAR1VNKClG2yHrlFk0I1SRCWhQl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk0lQsbPaYyhYhjOoRQZMysojlTQvhcQyhTUUlSUVzDKSdDKJkyVFe6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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41WsXlaJckYsQGQuZS4ZMTUqm65AQ0XWRISoVEiqz3BI6ZLhCt9AX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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lG0bxklolayREBFCyJ63GVtpmcaWlklZqikRIqFGYylKNfbQ8r5F
QilSWXvLlmVkrYjGUkSESJvIe3x/fM/5/DXH73iO+7rP67yu+77uWenmbX9w
Dh8fnxY/H9//fkv945fNdRKhJqnZH9dVGaX8nysYGWw/dh3BNpkZ1LmfPxBs
Xbydcij8M8FlZaNmvZw2gls/qtgtMMX3y42VMgIb3hLs1Fl/795vfP+dXPhA
pugVwZ8y1xZzYocI/rFV/+4/Mr0EHze/t5+mC70nm1Ib63m1BA9bco4MxkBv
51qR5RteYT/z0oViDtmvCQ4ozpji0xwmODDhVgNLupvgK5xKTjkd+ym65Vhu
tqghmDb/rw0xae8Jzh3PYJSHjRCs4SUb13+4mWBbnsPrWOFBgv+6y1RVeviR
4IVWphIjgp8IXhB26vGq3D6C1SvG6FtLoFedXWqTt/gdwcfODJj2d2N/Gu9P
fcuyBoItnMRsi1r68f1XPGePHfy+OLDWMroQfud2PS7Rmka8DT0RQY5p9QSv
adpTrCCOeP3U8OEaG+izjPArtQ3pIpiifWvbSyv4ucvz2J7SN/DzCNdI1nYK
fl5+r28puBn77xHYaBTf1kIw6/AWxh99+GU8VfQrYAv8MhKPETm1GvX3uyFg
ap6FfhxgyJ+zUUH8T7tKp70LWgk+4bJvpoCH+GlenS7yL6FPRV7S7ScT65NT
0h/ViUNf4GrNC5+voN5Uv9/F1Ynwy8BrwdjTNPif/OPPm7HhHoLDbAIzKGbw
y61oOmHbFvS7AfWo1Xcz9PuB6hehI9LQU86eU8hagPPlelG3wVkG+x0PPzky
S0E+XvOLcnxKsZ6nLNDRNtgI/bqn1c4+Rr++LLnUEc0Hfx6affS/VQL/Ww/L
aZ28j34QnJHP6nFEv0ZKNW6bHMN+zeOyegrWLwnWT0z8LseEXytsXZ1De6Df
+XToIL8d/OKtOx40ZQ+/9Os15qVKob+Odj8bqzuPfO8l5FfFxmH/a4WhFA8B
nNfr9AynjPsD8HObNT13J1gxYKlbxAT46ZMi7sxb+HPXKzjySxXq7xJiLC9p
hHxkmxV2fJGDPxIaevUiTNw/ZS/eKNIdkM/OzFkfOTHkI2x5Rk05EvnU8lt0
qScgny1aHgZqv5oILtl5ihl5G3r3eSqmmR8Gy27X1ea8BocYsxxURMGmmZHr
b3sin8tH27xERpBPsNBjyTxN1OdLNsMnbin0OY8kaa97BX3XXd3nMh/ifrr4
9lmNhgL825m8KUG1n3S+45dKFJQg3mOlxp1ufoiXEtZpuIqL+q34bvLZlQG9
espCN92WIP5epUNPR38j/kRFgP2ic4jffbe2uonk5/tR6YZvk/BzgfJvWt1N
+FPRzgoW8gaLzlgW3KkF16jy12mrgiNp1ppRm6DP4I/P2whD6OvJ1MyaWwF9
S2tr84wX4ryHTDOjJ82gz2jN2lkPZdxfAobXrvl7Y/2qZ4w821qsv6Bu37ws
Dfej9Jip4XjLG4LPn4hf59eG/jQ938Rz9+kk+F1JxVdKIfaX+6aok7sE/vgn
nVZkNCIfp2cxpmptyHeT1PLNKqT5wXPfbVZOmh99XEGWP2l+GGmyWE2k+dGc
Nq0TS5of8xdkihqR5gd1475RKdL8CL9e+FWZND8MnwxcvUOaH1XvZaj6W3F/
JT7sDStWhT8uZgv3JeVgfnwIm39+UBXx62u2a9Nz4P/t8lfDO94gfgvd+yCj
C/poUUnu7nux3sA+a8bSGfpWqEqVDbbCr0mZGysnZOCX8aTf7GUq/PqQo1VD
zYZf/1a1qLNt4FdS6JH2nHTSfVg6qaHPg54IobjxNc7QczPdu5C2C3o6PA+U
9TdCD/+DA32OStCjHjRfx90QekTUGS+YPdBjPt5e57sNevoEG69RvKHn689N
/L+eQs++Dt19w77Qc3Uo9EjwK5zvList6np36BGosrzTOAs9a7zLLHXEcB/Z
uZhNrLZDfG5sbtnqfMTnDt324Oqgf2l09qGQUfSvideKn37p2C87ck6Rzmns
dz/lbDa9Cvv1+f7jU5mE+aQkuPFMyFbkb8hvIbbyNKl/Wae2RlRBn8NQWeSM
J/StrvI37/qK/D1qb5UGsqBHokYi2ZELPV129bpRDOjRfZ/qfvVvvO+WRIXm
LhGCnuepykxFRbzvTCavNH98ifNwpSNIviUF9V3Hl6fDfYF5/nlle4ihMOKt
DhhgNYkini/tgnh5FeL51jvNLElDPDWN0OD+eNL7YNRZX3cG+eeJcCc/JCKe
ol48RWIR8m2jcqTN7BBvVjAsfLEd+k9B2nTjOSr0pbDD2zmieE/R/X2Dypfj
flwnXj3ar4P97x67e/XLMZzvOYsrundl4nzLPHCpTbbB+oEDh9PGRLBe7Kzh
HWMLvMfyTTzHQ6ioT/ffHrdu9aI+y2v0dqcNYX3bfvYpejTeRy5HhhZKRCN/
XRPtmo48xIs1iJG3qEH/PdwW0u5nifx/5vc4Tw+i/1YqrSj7MBf6A+ctUwg1
J73P8q2iOoSQv4Xz1OSV3cjf23eO/u9fWC/aJ2DiGID702E4kZ/Cw//Fxd8F
3wu54Pv6HzPF51zaCa68Y59vex3flZx+aUR/w3xKSCu8pjCEesv9CNYwF8Z8
qrDZrsBJhf6n4o9SJhtxvu2/NRhnsDGPt05Xrg3IBlvxeDbb94MLEqb0zPrB
lpcL9UYmcD8YbFRmql8nvffYnddkSPWhDSsHtpLq43o2/I4jqT5xrPTDPqT6
OB2f06bxCfUx7y7I+kOqT4JyNc+LVJ/cMyYRDsKoz5ch2sQkqT7W1FJFLVJ9
vlGZDKmT8HfdcLZMZTvqw9wz5cVzxncP18yl+l6oT22wdrEg6f2whVvNcW9F
fUqqTjjnkd4PPaF9o0LeqI+NvHpqbwHp/+XEwWJJMdRHSvm4841m+PtB0uk5
mzQP6ZKej7iy8PeoXMy7SAr2u3SfMVXyAOe/SSDZYpQ0D92Tc/503IC/DXul
uQ1vcf9usKU9DNwPfSId4vwlmzEP+fT/lZCshJ4ZHa7NuCn0/JU6oqe+DHr2
Z83dpc/G+57KmrJSdCTNg47RXgFh6KlxVdKNY0NPel/uG/Fk6KkLKud87YZf
lMyiOAEO+rNnZOe81hhw1rQeM+ESuD+Pdf5APFhhR1T2zygwq+P665tXwQul
B4NUgsH0HzMW/E/AsSGaD6y3gD1f1w9Xz4c/PsIStM85qKfDC81jKYvQn0o6
e1U6bmI+mHGeC0tw4d+oYml27mP0T37v1KejdSOU/wDoGMIO
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k41WsXxrfaOm9lJvMJDaRQGeOkYZt3kXlOkiKRZMpMEg4KDSRk2mjL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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lXsXJVSXXKKTEDJkekIo9yBxj5TQTTJExmRI4dOgQQnp42SoVAdJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk41HsbxkeTlC3bqTip5JTsRBKKHFISWbO1HFLEmAjZko4kqjOyTVJK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41Osbxm05tNiSLWmhMnYmETrKTllC1kKKxp5dRmTJkiJ7mepEIkVI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lG0bxgepLK9kKUT2Fo0llGRSihASEQoxlrIkGZ8IWdJbtiSStU2y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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lVsb3oWQOLtSbPEZTjpiU4ZKTpR5ypxMkSHJEMpYUZkqkaHPUOYo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lOsbJklJ1iiFtNqXLKGyKyOhHELIJESnzhQG2WJyEoUSkm0UCdnK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk0lH0bJkKE0l4kKspSYWSLUqQQZWypSMy89r3BV9lLeAtlyxKVUZIl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk81P0Wxw3DGFuhSbbG0mKPScUkS5KUUBKVyOBJZEkbyZPS9ZAKpRRi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk8lGsbHoOUpRQnR7YkZAuhJGvZOnZqRIukpqPN7hhlKQeJryzZC2kk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbJmSNjI5EZU1IqmHyhY5t7CkcUbpMX2OpM1kqdZJdpRIdS8ZS
soU6YzmHJBUppQYRKmJkG0uWpAXZz/X98f3u+ct1XzPu576f537eeV9lur+T
1wo+Pr6t/Hx8//u7MpJpHuMjaTIRKBZmpTBq/H+8kxwSPWXdT2C9VXO5JY2f
Cawir9l3d+MbAjstC1KbPYcIbNWUIVAfP0LgiwyvjMpYLoEXucn1Wz+PEzhK
tJ5eo/yewL90SE+rj0KPw4kxKTVqL4EfWl8N8GBMEHi3S2Ts3U8vCdwuNdjC
7esj8PhV+4wqPnx/p7sFfSj4NYFjVY5KC0oOEvifmCuKZI8x6C06IXp7ZTeB
O0TrnYf3gu+Jff6r74fZBHZVTqocqEH/HqdXGiRcRP+elT8vojBaCDzk6et/
Tf4TgVlXl/enZKCfWm2LA3766Gd8vInwDucBAreQvmb5kNFPqmSk0c+QDgKz
uY1dglqoL3xHaeKPu28JXKtt9OPnIPgFU8jMklfQf8HIduZoJP5fLSCQdSEM
+l+uGFOX14Z+i/LbpLwQ6NeT153a6wP+RZGYUake5OFF0lq/xFzo59Q8thfm
tMHvvOW3S5OYh0m4HFtwppPA7s7yBx8UQJ/rwrmWnb7NBF4ds3aEoz9MYLrG
6uNHDKHXYVZomEOD3v0DqYzWNOgtLTbz1gyE3lAVuRuuS9D7rKT1kWDFOwJL
56euSshFfrNVl1sZ08iv5wxt0M0B+YmR7NbR24P8ZLt94Zg+QP/bD140VYuF
v9pByZfBu9B/yltHksQk/K06y9+Q+QV+dFe0sLll8Js9shBmykDe6+xu3vCZ
hN5ji+eGO3Sh924jtdruOPSy0vK8/9OFfcuafDhr24l9m9jgNLZeEN8fWJK5
Pb8X+0Z9qGhuNo383ot4JxoUjvnuiZ4dfe3zkcBKvxVcW28AvnVZ9b1L5+oI
nJe5yirdG/MJG7JXL5RAv/y8OsUdDmM+0SO0y9uPwW+9hE7YmWvQT7aVl6Wo
ot730MCMd8X1OO8+709lroF+hdbvKksnkYecHKkXt0U+EHhhuqCGE43P6cPi
taNB7QSuCp78+wQVn6/+9P4pZQ321/jZeASFD35mi5aWgwvhp3tuqKolHX5m
DU2bF0Thh3k8Qu2eHc/8jsy6X4xB3g4XGmQEdyFv9Gdq3LMBqDdiZLC1pR15
u6W7b1o9EHl69Op0stEQ8vRxnWRxuQ30pHdqc37/AD33gxVpkzz5kEnVTJs1
Rz6G+dR1j0+ivwNTh0wOXkI+zK3ObyBbIR96hqzLO/TAN3NQe2yuDvmg2tt1
k5OQj8qOMH/OEPq94p5cfII1fn+E1n70FBNAPYG6P3RsBLAP32zXzUf7oN68
cBT/1gbsQ/P+40rdb+D3SZWLxR0RfN/J7EnaCRL8FlpnGK1qg9+zVF/uXC7q
736aNxCZ0UXgQ7ciA2/+Ar7gv5zmbLwacB7ExRm9CATforUMa4sE/IaMhLn+
fhDnp+T2kvSic5h3ruVfH0j/YN6/slvFo10wbxGWSQhdE+cLhXFD5uwIzsu+
iddRgdXIU+ZE4ljTJfAvzf023ngI/BEBctvEJcHfoWD1Ir0c/F5Rz+do0uDv
FfZkDOXD39PIse+bOtGvj8ksncQzHPw+ed3IrHiD+sFrzAQlBHF/0XFuM2lw
RT3bT66q4bmo59wmV1t9GPlpesf2IpPAV5a8kCOwG/vor/C5w80B+X9Um62x
mY087HOtrfsmjvktSSeWnB7C/IoZCpujnsDfle0WZbXV8DeXEe9zRRR54HM0
PiU/BT3PRc0Ck2QbsW9HFJkTNOynpub7K5NL0Ke+gystIIl8i2SaTQTw5Du8
r8Dj0Gvke3EHUz+lGX5WpuqEufLk+xKtjC9NFvnu6zlAsfgAPwXtyz6+OfCT
EKtzPbsQflqaO0ePy4FP3IQzkGyM/rTFObF2eYJPPKOsskkZ+fYqU/1V6iPO
T3pO3grlvegPg2kjal3bSmCzjUr9tF2Yd3Zdgdi3feDnzlI/sXeCv4SiSC/w
AP8sO//OZiXwR8RV2csP4X51Xq3UvZKEfg8K3WGfcsd+SFzpmKPV8NwPl3Il
hO4hn77Xj+3OLUQ+vytkahkpQ2/4bKZ7ykXo/eqknxS9jP56Gka63MrGvj+l
Uw0cE1Bvh8TISSU57CNXq/pmdivuE2xjt9QKdWB5vS0P8w5gX/v3VzDIm6Cv
JmRcNuUL9PklxQ4JlcDv0QsxHzfFo74CR3qcpYj6Z5a7G+w7UM9aK07VTh74
bVzh2nu+qB9fb2xtMI98/+xl2cloo99nyHdXBCuh/gk5yvRoP+oLKeUV2wg3
EThlM2VQthN8YhmZCUVu4NMJODvWUIz875GaiPeQRV5Pd5SYtbohrz/7WGak
AMwndPzpGQoJeaoo4lY37MR86LXmoaO+0HftALvYdh792fRaZHcHE/5Tb/ZN
i7Ogt0JYRNuP5z4g32AyNSMGvaU/jvCf4bkP7DTN7G/+E/cBxrjdZUY3+qV/
/XKX+inoGQtnNBn2Qk9fPv3ornDoefB5ZuNcO/S4/Gmif8sdehoTa8QS7kDP
IkmlwHQdz++j+H0xbz30r9bPPGc9Df0zSPfp36KB/pX2vOt2rMA+hlC1Ha+b
QO+2dkvhNnnsozPrSM/LYOTTsoBJ3VuJ8/02eaPu0nPwb3hkWkfdgPeIRWh/
vFEU9qu3ixNuY4/7iG2AV642BX4WRIwOPa7EfaTiTSatkOc9zObXjTDkeQ/f
n3JS8+N5DycHXbo2OYL+8WtIUkp43sPGQpYhbjzvYQUbTz/VEZzXPXMm73T6
0W/p9zsk0nnew0EBpfvyQnFeZ/lPfvjC8x4euF7+RJYOv/5TCc+zJPAe3kIW
2XpjH/jMnzKzTrkgT0OS3Dq7KuTp5FfS4q4rmM/J7Y7txU7Ik0ti3KZ1K5En
pUKh8w21OF96hDzSRWfxedDw3/YkDvLBjJ+tIGdCb8al3v8GP8HvC1fIJGpE
AXq7z7+urluNvPVUBaml24IvumE6ercR5vNtF01txhx5KzkfzGTKwE/9m/gt
nnq4DwwIzrQ72mJ++paeHhNtmIdGRGRsshD0SHlreDkZYh6ClfmlrWPQs6cw
bexxDPxFMWzFWZrIX6j9+U6HbeAjfSvUaBLH+4VmY6l14iHyp5DzSTj6Jfyt
LzJ/8H4V8n5qYemyWgjqGU7PHxMIRz1mE3N9lxHq9crxVTY5I+/l9imvbBxR
LyD6q3fpBvTLpaFczX8K+5nNysp+vAH9usofNCxljvy8OXqZ0deM/2da2Ku0
/mgy/hfGpfQW
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHs8020fHiNhIVLkUMkq1SqVUQ61skqRSEkkxxSSp5ASPUhHKUKkiQ6T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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lG0bniZLCVGNrYVQlspbiRohyVD2bKVkmSipkKVQvGgXSr1ERRhM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k8VeseZmtHGY6KZChUpkwhkkwVGepGsiUSRxkyRF3ajnkqm2SKojLu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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk41O0aRsdSpESypFB2uT5GspVthJSvkJCyEyLrSCRKnSKSLVs1MbKM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lWsbJZo4hmQetuFQvjIkQ5IyVLtUJEObkAyJEzlmZeYYMytJUShl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4VXsXNoVUiEgdZUiUqc8pIZTiCoUMKVPFoTJ/hUhCrgoZ0kBmCUXp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lH0XJirUSJJoIUv1WYuUKEzZy5q9LKVQaZFSlpbXUmhQlkgoQ1OW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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WkbtkSi7MtHyISJsmUrdSxZx7ElnIhkkkguoqTQEBJZckiEsoQh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk81HsXxieuXSVKJRRJ1hK6lpumUFkj15KdokYZskQLV27KNlMit8wo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbVomTmVC2sk9kSSuRZYqKJDkhwrGVJOGzJpzIWA5KoYgskS2+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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c81W8bRlYcIyu7yHi1CJ1Ifk5lVCQzoyGEklTmkYySUkYLlXVIw0iS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lWsb3YYMGU+SKVPIWNKpY6OiEo6SRBxE6pjiK4pMJyJkLlMlQ+hQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lP0atjRZEoqx92USfUbqE0nJ2IpGIlEunJT5DC1iqKzVKVmKUqmQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbFhpEiYQySJaOrWUS4SDZIqFMEmMn+1JMm6SEiKQ0lKKS/URC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k8lGsbngyKkiViasoSNdEUokRZjkSIpJOtLMlSEpKlDtkJWSKKUpYo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41O0aln2dkkJhZInQglYp21i+QqdQfIUs2StLElGELEfJ4KQUEhqf
MMg3hZLPjCUSIjtjqaQotJDIuc4f53fPX677ep/fs9zvfT/vUHDxtXLj5uLi
2rKCi+t/f4+f0mX/6zrJYNUHHTp1eVj//5hP1HNo4OxnAou2ezQzmPUEJp2d
pAUNjRA4w6iq46Yi4g9fiSub6Ggi8CzFqqJN7y2Br2gJfyhwnyTwKSkV2xK3
HgLLNL5LaO/AuaazW7ZX5xsCC5+sWzC78InA7jFzs14VgwQOr0w+8Y8b+lFV
/2yz0rCBwOKm9k9kNUYJXBXir5K/NEXgfu5+lSbmSwJv64nJyD74jsARZoeX
enaiftCMR0CKDJvAnqe3yujGoj5Lw4rWFlBH4BkX/9oJEfBXpNpV3OuD+MWs
vJM7p8C38Zz1wek5xCeSFAUnJRGvVS7KI+ffTODuyIhi4/+Ab5eF8j2pIuCz
pH3aViukj8Aq1TWjfLmY3/4AhUUqbSOwQ22sudONcQJfJfWZbKgCnuXtSDrg
A+zo10LK/QU8VioXazH7nsCMjc6R4s0fCMzLENHhsga/58r1g/U0wO/M+dSg
3TbgN2R13Bl2PObnNkvR2HQI/P4KjLmf/g16NpQ84u7jj/jIrfaU4HvgN3+Q
sfV5I/jd1P45n7QZ8bpLe8XnraFn0xXJWa5zYwS+FDeSX1AIfh0mtBsqa7sI
LE01vH1wBc7XTLfR9MvBP2X1aIrUY/B/PbykOGEH+L8s+zO6UwZ8OphxeXtc
BX95v5UHv46Cv6S+KJ88748ElvAXNzBK55jv8N2+Hj0Ov3aMl4kffYF+yaRy
PXfM51b67LHhZvQ3F7BunkrvIDD9uO6olADq1TfoOG+6Dn8VdSwJnq3H9xvq
1RmtWa0EtuDfxW6ugj6+KjsJiClP4D5fLL66lgo9/30rzdJBFHzafvf5XhgI
PnUuCk3G3ke9I/lhoXWV4DNaaUx4/y3w+aRa44f0Q+CLIbSi6jhg0WcJ9qsb
gFcEhV7echRYPXfudZIi7kOa3hd6moZ5MstONNw2xjyysp1zQpaYx1i7kF/N
DvPsDQiWdKrCPuzi6yF3/cQ5z8xbW8rHTgIXKCWEN42C/9bi+tlWT+g/+e79
V5pxHPtc00Yxwo3DL/t16gJ5oI+cYc+vU2cQ76hQkZ/cBr9YNN7wcnyPeJsv
vYmC8ogPE6FrD/NgHzWbiXnZ/Yl5LQMl6gPNMc9U09EaSf5eAjMd+ZpursP9
0aKEMu8rY96uxCKT6BOYN5h0qJ71HP2sjpTo6t6Gfkzn6KGPN8C/qiY1bpF9
0LcF9U5AZgP62TGs5LBAhn9HHeRyRnOwj+JM5s56MwcIvNS9/Zv5ftRbLxFR
reINP50ci8o5FYB6LnP/VNgoYr7J9bL73k3BT26zu9f47cB8p3MNJgrkOfw0
lT0ezcPxvpSu4fc5j/cq8JbykKEC9sGP+JuWh7zQv9rY+y8VfEP4Xml3nJ8v
8jWMGHUzq3Dfep4KLsm94NejxjSzVhnx10q9WekM8Pub/IMevxX3bfSjp03o
AvhtnRxzj+GFvms0h4xyHuBcx1zHY/M4+Fe7svuvvWtxnmGXNJBhCL/3v/dl
HqWCz+be23+eVm8n8L1XxftiFuHXWvb3oIxp+DPf4/VYfwv8a3BPfErJEvzR
/U4uFmqDv/GNnlH/3oz3aPzYQu06Dn95+Bayn7vDXwM3Guf1ecEfY43ck6cc
/lrlbDqypwN8u+WqrVweR3z0vJWlORnxglm/Y7vF4K8F10/Huh3Bd2xH3qOn
JuBr12/aaJYq/NXGOCDpowq+pNqZrj9boL/fWqwcaznoTzPaR5dhC/29ZG9x
znuH7+9/OS0QwPMK/txa41D0BfxdXrtdo9QO+XjYpNDn9ZjvnVKw9AeO9/bv
TkpuyB/QU4afL//UNPyzvGYLmVXGoSexXuumDOhlZolqyprEfaWQmjeGqvVj
Xy/+psX3of8eV3OD9Jvo/w1ZXThfB/rI2rGn5MgU9jd9Q3tLfBP4KK8UUjTP
Qr6w/pexb1rx3hxP6yI7c7wvAsyFtL0c70u9Ort/meN9Gd+0IjzQGviOvt2R
1I3Q55V9gY7UbPSX51iROWqJ/kRYwzXn90APT+q1KiTPgC+yAm1bjj78F1NQ
S3Ktxfklj73r2HrgczGE34XKAJ/Zdbllpiew/9R2l7h+UsX9qT8bLJ5MwP2x
htcmVkuinyzaLCkmEfXKbjmLUIK7Caz0h/BwnDPOt/NWiopFo1/H9BDLsBGc
l7dWBV6LwP8HFHmrb0kU9FsmdU1usR37bkFSwr84Ev2SH914MFIKv2qx7PM6
t0OfqVvuv1V0RrwVT69FVAT+n8h3fhqZdAR6GKT8eL1qAnq4GzA0INrVQmCz
IbXZ2z3wxyrW0LBSCPyhZbnrjXwQ6u+XjfZfaYH6SgwfRcHsRgI/9pW/ELCE
+nFH+Yw0wlD/ETksWPpRO0d9V2Gbc9DTxfoDHkkC0NMW37ac1F3oJ63aSTtg
PfJbMu/qqvKjnzk7aqCaFd4fFacv2rEkzKdpZGwgEYH7uP6dIbgzHv+v3RGX
UJ92RD5pb2FqcSb4LaKefsx0Rf0Nl4wbuoYwX6ixlFyRA/z7PbpXRlMO8wjZ
y/7cL4V5+N4G2ru4c9zXrrIztoPItym8vyjCH/nivXX75FWRT3fccUWZIPIl
aj05ZxWPfPJ1GUa1jciXpn21VOMKfu/6fuVxmC9EPm4zb94GXfiXK7f/1FUn
+EWpefLZLwr0PqnJcn+nhX3OPuTHna6Beq8kmKElj7DP11Q06ZGF0W/bi6cD
E1c5+qUKqbQ34fsiUhhVwh39iicMX2rLQr+fe6hP8g+j37wHjV3m2hz7xt6f
ZXYO/V7eFljEXg//+puzonVKOd6nPaeYCjTsm0t+fZWLM9BL8PVjZU9FsL/b
PlwX7m1HvzHs5nJ3IfRbPa88fykA/V5tfVFin4Z+d9a1TDKT8Z5kRj1M2CmA
fAp8TvlGafi9Gf48vGftQ/CXuSs8RGYev69lK6zdM/yg3xQTnrSkh3jPPXwX
rNJa4Wct25Jxshri6W0vWuih2JdZl3n5CsTA58WjywN2aeCrQU08xYKCfVnI
sKvQN8W5zZi2zj1l6OOOnLShlgrmW1/YWf7wDfRh9fGvx58UMZ9ljZKK1kHo
41cBVy95Ct9PidFIGvewz0wqHmwnPYPfJ4QlKDpZyOd8mM6tL8nx3tsmaOzx
wvyVZz+G+ojD7wmlTbclSajvGGe974Ao4j+r+AosLOP3z/QS/dTN0bf6/wVd
L1tR
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c41f0bPskoGYmQSF4jhFAqEhoyk51wrLKKkqKUzIooykhGRsdMixRO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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41G0Xx4UIoYUWEvNMUZaUlJiSVCJLKUkJydJMCKOEBpEYWQqFxxal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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41V0XvRWJQoakEiVdZKiIzISozIVErqiQIVJkfE25pkqmjF+pt8mQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k8lVsbNaZBKGOhJDQgN2VKyVhckkxxqZMhEkIDko5c8xghFYd8SeH0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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lF0fRh+JN0sYlC1aLdFQxhIp+1tkSbKFVsTknaIyhSRL1pIhCkWi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4ldsbFZWUMXJMiQxFyEkqsxyhjNUV3VMhCZ0UN8MpdR1DhkyZiQyJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4lH0bHSSiLInqFZUskTISSopUkpI1WySVsk0IGVlifEIUGiZbtBEp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lOsfxgddmlTIqST71qIzlqROJkuJspYlS4sWpUSWQcdWESOpyJLB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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN13k4VPsfB/AJWRNqZEkublOhKCWlslTWuoSUSLKFrAmlLBXKGrJMhCkV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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF5Qs0HTi3kc3iZ69bkr3fEHsZ32ecstcf1AZz/
yO/7vZb57+xH1Y+qH1U/qn5U/aj6UfWj6kfVj6ofVT+qflT9qPpR9aPqR9WP
qh9I9QDXjvtG
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANFLCmy5ri/mcyg/GxlqpfbAHsbv2n5fUWPxOzj/
+kbhtM1/DtuPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj6kfVj6of
VT+Q6gE1KInc
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE3z30PfryUz+GiqukCDoEH9jD+lbf/e44sfQfn
11XcXJJ987D9qPpR9aPqR9WPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6
UfUDqR4A4fX0ww==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF8upvmvl/O57Bq/n7J3b/v28P4sl+Yhd4vfwfn
77h/f3/4nsNw/nQ09TJo6o+jqR81f9T8UfNHzR81f9T8UfNHzR81f9T8UfNH
zR81f9T8UfNHzR81f9R8apgPALg1llQ=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANEu3TnPf6/kc5gseF7c6M59exj/S8v/5qsr38H5
DxUW3/6+6DCcvxNN/Tc09UfR1I+aP2r+qPmj5o+aP2r+qPmj5o+aP2r+qPmj
5o+aP2r+qPmj5o+aP2o+NcwHAHSzebg=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGVL9UMOdbwOTQ09F/5uP++PYz/tW2NV+/qd3C+
/Yc+fcWew3D+TjT1P9DUi6KpHzV/1PxR80fNHzV/1PxR80fNHzV/1PxR80fN
HzV/1PxR80fNHzV/1HxqmA8AiryUMA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANHr3B9Wiazjc/g65cF0+WX37WH8KG7VMqW17+D8
WUl3M7TLD9uPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj6kfVj6of
VT+Q6gGeCpen
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGPl84+orCBz+Fk0J95c9a9s4fxHU9GTVqTfBjO
3++39KBh3337UfWj6kfVj6ofVT+qflT9qPpR9aPqR9WPqh9VP6p+VP2o+lH1
o+oHUj0ALb8Iqw==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANESLGF8upv4HNom5PGeLr9vD+Mzev19zbDhHZx/
N078WkzgYftR9aPqR9WPqh9VP6p+VP2o+lH1o+pH1Y+qH1U/qn5U/aj6UfWj
6gdSPQCGEp7w
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANF+SQIRllv4HJR29PMEb3xnD+OHyilc5XA4DOfX
2e85vyLpPpyviqZeC029K5p6ZTT17mjqc9DUq6Cpt0BTH46mftT9o+4fdf+o
+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3j7p/1P0jw/0ANITkoQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJztzs8rgwEcx/FnTkr5A1YOO4jLUpxmitIciBk2Sz01pPyMAwetdlFoJfkx
MykJifbzwSRpjySZw26WHJYDblNycyCHrT6fg7/ge/r2rVef3qaBya6hEkVR
zAZF+btzenrXlixvqlhxpgJavrHwpxdMnf6am+L/9DU4GurIFX9fEH3GjP7d
i35mFf3jNHr1Gf3UBvp4A+0vo29dQ28cQR96QH8XQK+0oB/bRp+h/dt+9Klr
9CrtZ9vQ2/bRV66jL1XRey7RG2l/0Y7eeoTeTfuWPvRb5+g/yV850NeG0c+S
H3ajrz5DnyVf342+Lop+iXx7L/rICfp78j+0b42hD5LXXejzGnqdvK8H/Rvt
75C3076L9i/Iv9D+eBz9AflvJ/rXBPok+TLye7R/SD5HPkX7Gvlm8h+0f0z+
lPw87SfIO8gbyIfJb5L3kI+RnyBfRT5C3k/eTj5K3kveIj3SIz3SIz3SIz3S
Iz3SIz3SIz3/9vwC6Ao21w==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HlQlHUYwPFdtERL0VUQbBQZBgO8EmkVkVtuUEDXAxdC7jNFMU2pgBFB
cCCQTUorD0otUTzBFBZYCAUKEaSodQQV0yiVUDPNoWmmnN/3/eudZ+Yz33mf
54+fReTakBgDmUw2Uy6T/futmpLdH1w1xjXRJ9+i5dQ9l//neLV9h85c92Le
m2bz9TuO11/MmfsSzEWvuO47IPqkjiMdoh+3wBv90P6HXaJfcEBZIfrbc75A
v3yy/J7o8+87tYn+kMl49HVtnd2iD1plfFr0pZ1X0E+Xv9cv+r6LP7WIfoJV
/1TRd2gM9aJ3Wflqpei/a36EvvPOwruiN0pzvyT6Gfmt6K/8oOqa6DPbg8+J
/stdY+GnZRrfEX1ehmeT6PPMzsDXRA27LvptfkbnRX/B1Ar+bu/gbdHP2K1t
FH2Z5UH47JuyHtE7F0dfwL7t9vCmMhP0rXtKGkRvtUbD+5vq0M8dkVgt+mV6
V/hvhiX3iX7MiAqd6HO68uAre1f0ir5WZVcj+nATP/g1l+7eEn30aRn6pros
+AfXLqGf0tyC/h+vB8Nrhm9HPzJqS73olbvS4efNsbgh+quhblrR+xQvh8/R
OKB/Kn08+k1XN8H3TYxGf1LyHvTDq0Lh5SOGboo+4FBDneht7dPgv1q5G/2A
5B70R90Ogz9sewX9me656D9LSoX/aG8N+n/5GNeKPlYVAZ/cehz9oOer0A/z
Wwu/84Qe/T0XndB/ZBcJP3qzBv1f8pTsH06B968e5H3a1Oh37ouCHxeQib42
8jX0p8YnwytjXoJXl6ShP/VcNPytH1LhD5S8jH7L+iT4G/0KeJPm7ejrC2Pg
jeWx8EvLHsN3nU2E1/pMhi+qLoGPsI+FV9xXw7u9/St89zT2DR2s4EtTPoeP
O8m+/98q+O3je+F3VCXAGyyeDl/56SH4QUUc/N4jQfBP73TDG0azX/l4NnzK
zXL439Ts52kC4MOTOuF9LdkvyJ0Lf+bESfhSDftHNvrCZykvwx8biIc/tUgJ
HxhxFn54HfutY7257/NW9lvYHxU2n/vanYP3vMF+qqMnfH52M3zRMfYH/3SA
L1x9Hl77jH19hwd86v6L8F6l7H9s5whvO6wa3sOIPqHWHf6zWU3wb+TQ11ku
hO/wroGfN4Ve/bsb/FbFt/BmW+gz9ewXuGrhy20k+/qzf3p+I7xiHf3IRCf4
iUPsb7Cjb2xzhR8qaoCPiqdP72LfrKgWfrYDfdU69kcq2M+IpC+2cYZ/KKuD
VznTj7Zm375CB/88jN4lgf3y5ez7uNMHPXCBt45hPzeU/pVP2A8vZX+JJ72m
kf2D09nvWUG/Q8v+j83sH/Cmbypjf/NQPd9/Fb2Vnn31APtxvvTf57PffY39
wGX0zwbYrx9DX+9Hf3Qz+6YN9JOX0lcb0IdY0bf608sT6VdV0L8ZQp9rRJ+v
pN8dQH85nN5rP31WMH2cGf1VD8n/BNJPWk5foKF/EkRvYEGvWExfLumnL6Ev
20lfIOn/PI1+QEU/arHk/fSjr8mmd5L0Q6bTP15NHyzpr/ei35JBP7SE/sIs
yT0j6HMk/U0e9BvT6dslfa859E+i6I9L+h5u9O+/S39U0g+aS18ZS98m6We4
0Jtvov9Q0tfb07fG09+R9M2d6RdtpN8q6Q9X0ocm0j+V9C2c6O9toE+S9Psk
/R1J9CMlPnAhfft6+rckvnAefUoy/QSJP+lIL5f0Vf/5fwByPRP7
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1nk81Hkcx3EkZR/kapEj2bSuiTXJ0sGsXIsYKaTFsoki0bXZ3LkmVsZN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1HkwFngcBnDH5F29S44uiqjsLsmtQ0RSrqKIopRIJ5UuXaRjK9vFIitv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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANERlltOlO3jc5gqy9QwZ899exhfLvpkwbu97+D8
lsmuJkZTDsH5bpWlx1pb7sH5J8+tDJi8FqH+gNRjk8jqw3C+nRyq+fJo5peh
mW+CZv5xNPPvopmfima+Ipr5kWjm86KZfxTN/J9o5nePun/U/aPuH3X/qPtH
3T/q/lH3j7p/1P2j7h91/6j7R90/6v5R94+6f1C4HwBGJ/CG
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANG90/OEmg/wOdQ89RePWf3OHsafdOmj1JPZh+F8
G4PMTdqv7sP5Z/Z+OVRyAKG+4vOz3uWFh+D81fILiuLC79mPmj9q/qj5o+aP
mj9q/qj5o+aPmj9q/qj5o+aPmj9q/qj5o+aPmj9qPjXNBwCktg1j
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANGHvmrE9B/icyhp9umQ23bYHsZfeaC4fC77Azh/
9p6UlI5D7+B828M2Ibmhh+D8B/NEvm0zugfnC6Rrtk1fiVA/av6o+aPmj5o/
av6o+aPmj5o/av6o+aPmj5o/av6o+aPmj5o/av6o+dQwHwAMzjDW
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQZWRgANE/gh8vnX2Ez8Hz+Z/2VzaH7GH8SzPSzvMJ34Pz
yzV21outeAfni/Mm1Sw8cxjOv3WkMnqp+AM4f2LPlKKIIwj14WjmP0UzvwrN
/Lc8qObvQzN/Epr5o+4fdf+o+0fdP+r+UfePun/U/aPuH3X/qPtH3T/q/lH3
j7p/1P2j7h8Z7gcAr3M3UA==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1Xs013ccx3FihEyS0K8IMddcYhqFXFInESV+0gUltyi6orVDSTtdtJax
JrqMpjJDdVpqYqRM50QuZS5dJNW6GcfItnO2s/Z59tf3vM75nsd5nvf5nvPV
D4v3XztGRkbGUlZG5p9nae7LwtoPXSttm9e8MK5y+W8nJyd51Q92vNt6I5ZR
1QUv3u0ze9wbcrur3+0vYqyfDxt1v9s5Dom7h2v+f9/BuSVZ9M3dLdeJfo+6
2nrRt+7LyRJ9Ofk310VfyfpquujHXdoaJfqOiR2LRP+Y+iD6pVquVaKvL/vw
kejfenwe/W01BttEP6BMI0z00xbGx4p+rffaPNF/daO2QfTjXmWgX3ZhbKzo
/zLw0k/0bxRsjhb9Sn/Hy6JfIuPULfr9Md3orzhRu1n0jzg1rRT9u9FK6E9q
l/lW9J/mf3pb9Le8jUB/V7lPnOirl2UsFf1TMtfRf0i28oLou7126xD9cxkj
6P8r2nOT6O+OrQwR/YFNdTGi7+vw5WnRP7C/o0n0LZb5od/JNzVe9GcdtF6G
77NrmP0aPWWin7FoZbvo+zSOg7/ppm+i6GcNrl8u+nZKeehv6W4vEn2Tfaub
Rd8pwx1+fMK8DaK/s8k5UPQt+iXwDeU0SkV/2Mv0Hvw2LfjV5mUJou9jnBUs
+r15u+AHKS8+K/q3fQJbRL/rR0f411Or0e9m8gz9tso28FOa+0pEX2XOmrui
f6RLF76mjy/67T4fh/7iukT4NwPnnBP9LQW/o19V1x5+2lyNjaJ/SlkaJPoN
Kc7wLwVaoL8z+3Gb6PcFG8LPyFdDf2Z9uVT0S1Wi4FcU3kG/0XBQq+g/2msD
/9DkeeiPk+Shv0/NC37crrLvRV8+JQv9KR8bw9dT6IV/si0F/Xdtw+DrGtoX
i/7Am2z0X5hrBf9aegT9unr05+zxhh+/PQL9tRHh6B8cawLf26ABfoe5FP1W
zSvgTzudgH6PK9fQ/0mDJXzzmcnwF3g+Qf9E+cXwd0jt0R98xw3962xN6edX
wN8R64b+XeOWww94kIP+8p/aef8uC/gNoRnwpfHD6DeZ4w//qMIk9G9Tm4F+
tVfsT9YphR/ybCb6deZJ4e/tKUW/f8Bz9HvMZ//hG5nwV8krwB9zegn8ItUx
6A+5PQ39o5Fm8L3Cz8D/+YwZ/OXTg+AvbKtC/+ong+gv7zWHn2mUBb8nQhV+
6MGl8KP9BuAXrdJGv84F9pdICuFLaqfDz44JhF8r1wA/p2AU/dOK2J+cmQM/
ZcoE+E8NAuDvtP0NvsvoBPR79LJfO/QUfTl9+PUDy+CX72yCb98vC78jlf1L
rh6FbzZVE/7bz9jfL/8EvvSAGvw8BfpfnTwBPydXF/7ZIvbPPtEKf/wP8vDv
RNFXNMiF76OoBf+PCvYXXnwE//4KVfi5k+nv3XMcvs2kqfBrktjv6HkPfu4G
Bd5fSv9X+WPwO1204c96yP7L3zyAv29IBX7IR/TjG/P5f58yBb5jCPuP9rfD
H9qvCL/El/7GI+zXVtSB//UI+40978OvmMj+FCv6f65k/6EdEvjV89n/8IMO
+C3uY+HPXED/+Gv266Wz30iFvkF0N/z0NGX4RXb0IzTZb6rN/uDZ9KvK2V93
kf3jPelHWuTBn9rK/vGa9EM7u+C3G7N/yIF+wmP6W1snw4+zox8+vRN+vawS
/Fg3+s/96N9Sph8uoe+xm/01z+hPdKS/vY6+aTH9UCv6B2LYP2JN/4or/bYo
+jXm9GP16Ed6s39C7Xv3caIfep7+vcP0TSzoD2WzX8eXfpELfcl2+vWu9Ef1
6TubsF+rmL7XbPqO39GXpNGXmNHvOM/+uWH0R5zpN6bSt/Khn29If4Y6+xuO
0W98rz/tOP2kbfRvmdC3qWN/ZBz9fe/1j2T86/8NWSIVWQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0s9L03Ecx/GvK7AoZM1DhyyoLGJRFlkkg0roMgIhc7V+ENNsSmEbmct+
gNDBgiKxX2YuW0KFzNkgm/lj1myVBwuyDJIkGy6LauhmRbEoOrTxfP8FHb6n
D0948+Jx+MwvsuXv1SiKsixFUf6+RVpzTltf2gZrdWbtYU3v+n/dUPayuvzx
cKI7BhotzqZIog9tshtsGcFEL8pP2XgtbyTRmZ4PY/2Pkvd39Olxtz65ryjT
LRO/kvslvoi2pTl5v2WywPv53sNEl53OXnx7ZnI/1Xt2xNWXvDffp39bN/25
w/RntdvgN40r8O9uo18J6uCvOjgN/s036DeFTfC/WLoa/rmt9NcO0f/zHf3G
EP3b7fRfCdD/vJ3++Dn6vy2nX3+V/gLzVvh3VdKf7aH/xBj9b2P0e0bp9+bR
X+ymv6KDfvcx+gfT6DfW0z+jhv4nTvqDLfR3faH/SJz+V2H6d66jv9FFf24n
/WY7/YbfqfBb6+i/1Uz/8Vb6a4TfM07/GWUQ/sL39PvW0H+hgX6X8Ov20//j
O/2nLtEfuku/y0e/Q/i1UfodGvqbhH/BKvrX1tP/VPjPl9J/cpL+OcIf7qL/
eif9++T/Ef49U+gPCP+BlfTPvkx/SPhLS+j/FKX/40X6b/bQX9FNf7Hwz4rR
PyT8A8JftYL+o3X0R4Tfb6VfEf5nwr/wAf3lfvoLhd8g/OlT6X8t/BnCnyP8
MeF3CL9zgv5e4e8X/lHhtwi/UfiXCP8b4Y9m0T9P+L8K/w7hrxR+v/DrAvTr
elS/6lf9ql/1q37Vr/pVv+r///x/AK+NUDk=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxN2Hk01Qkfx3GyxI2yTYXwWIe6ttsoW2NrsWcLUdayhkgYRpKxRGTEuHaF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlnk01nkbxhGTEhEp5LEkJhlRlhZLliyFbI0eWZMY8kQLylCRl5KlIkTZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmGk01WsfhndCKSENQhkiY4ZIJUeIZDhRbMJx5DhIkikJSeahedimIplT
kmyJXZKhvAiRfTbJkClDKUOJZJ/3/fC6n0+tZ61r3eve1//3DJJ08rJw4aBQ
KEpLKJT//cuhGLO+o4lP99tAk9TmZ+M6/1/X547opjypWlw/aTjuIfqye3E9
+Pd+1rZq8C2HvRVsLMHrN8xkjmqBL1WQkm4rAc/JdDJr5qheXJcYJIRqKvYs
rvfMrmNH14E3Lg4UMJitXFxzWfLY3a3oWlwbygieaM4F/73GSVuKhXyhI1Ur
5qV6F9dpL7L1tJvAJ/Cx46VLkE9lLevwcUJ+d++Cp/xN8Gto7CP2iTWL66YM
CdvEDOQ3Mq0eHa8Cny00L2jjAD/aKjMW3Kbw0zJyQ8+tFLydUICTzyfwx1eM
MMZ44eebPt3pYy147yL7pCMC4McXQlvSetB//ssSQ6588Au5f5UW3YIf6c2f
Iut/EPmhBtEsws+G7fN+lx7Az8PqU3JB1shn0V/82JsEPkRZ1nd1Efz0e49c
5SiGH0kT2cjUCvBP632stkWj/6ZCTpfMMPhZWW4Yfq8cPPfXxzPv08GH9XnT
TuaCtymsDhx8AZ5WYd/MPgl+JKZJkOEG/ml8Z6HdU/Baqqds86rAM6O+98i2
gbdYukXBqAY81c1hqF8ffH+0SsQ9GeL78r49E1kMnh7upXZeCv6F8zKj/Q/D
P/W1bVh4A/hahdY1PF3wHygszIxMgv+19gNc1Azw8mfsdnpKw789/0tP2cPw
7zhBnTMk8g+/85iy6UW+T9HFa5tSkf9mTDHtF5E/0XModoMo8v3DuFQWDiLf
XCwnp5rIH0yfEDvWgXxaetX14BvIz/S7PZCUDj7AruAEQxn5N57u6p34E/lv
35+bK6oH39SfVk4bRn7yk8aAuLvI93kVEJOaBf5hnm6kGify09Nsr3TqIT+e
JibZ/Bo8mzrhHl2P/HH9W+JNIcjPHuNmxtwGL/3U2HfYFvkGtVO8dkHIT8jW
uNhM7N8tCcHNRasxP6cdx5L8PiD/nfplWT1i/56d0+twTsL8aLTGZzhOY36+
nhXjZhL799aeraKPiP17OXwZ6z6xf+NnWJ9NiP1L/Ziekf4I/V/muDHK6Ogv
p+PLzCP27454Va/wKPQPnu0RKg7F/D9k/jNLI/avob/8Zb5M8Dck195bmwd+
ZtRh67JK8NeLzshL+oLPKM4VU3AFX1mhRRcl9i9TSK1M5hX4Y8+2Z31sB/+5
Lloxldi/Ci1n7RR1wLfRL+goSoBPWnpHoZ4O/qpxTDFLCf5nRPIr7F3gf0yP
ksNDzM+jS3zzEUz4j7iix1xzmbi/shJ5m+6AXyKs4dmvCf9ujj83/e4C/90a
yzW5ifkvORdGV51E/tGFlxadj5E/2yWZHZADPmjGvZd7FP39ZprSo1SRX+qe
86K8EbxlYN+YdjnyzZJSf1h6IH/A0uhB8S3wPcOrGnLC0N/FarjUlYb8pM75
6hDCf8BX74xOXfj/bYChG7IZ/l37VDeuIs5PtZg5UWkF9OfalsBwcIR/vwhD
33fE+RPOvukq3Y7+mc6sB2XX0P/ChzM8h4nzp+ydCL+dGvrrN5vvsnJE/5vm
IabBhH9eJZ5TaWPIlzLtUK7MR/5zSrSERjb480XBKh0/0V/klUwf9Tfkf3wS
yStF+F9qcOr2u5fId4mptzUPQP4EY+vMhVTwjrXfPr04SvifKvnqFYF89VwB
fsYr8KsKqgfEJOE/pne+5sV35Js4764bLQCfbmAcWuOL/tsmSsa5q4jzJ2sw
zoU4fyx55pyG6OivNRwrbnEE+Vw/NYzuJ4NnxeQwjG+jP/Osws+Nueh/X2vc
oJQ4HyrraE4H3NA/sST0UaEN5keIX2C6rgz8MKWkq7MdfLlXwmvrSfB7nTmp
Bwg/s5+XJ8nLgpe3Kqlaz0b/EA23LeMPwV/ZYZTi4ww/G8xtWt8UwM9+zdAG
QcKPa+1Qa1gp/MRGUjOfuSBfo0Hl+QPi/Wmm/WP7hqvw80so0aA9FX54fdvK
NhPv8xuNHfPKVPQPubW/bbU2fu/YgbbTU8T7PJnFEbVmCfqnWEa/6pVD/+jj
EXVuxPu8ynVcYnIO/fc7Z/zzsxL9G70yx8Xvgr/8+I4RvRX5pduyjHkk0b/z
ZNNzK8IPZ/21iNpi5E/rNxZecES+sTLjzXtifq6khJ68dot4PxxlnLfORv7B
LKoJm5gfm0sutvbOxPtwotTByBJ+kk33WesQ83Pff3A0thd8kfhnh+p58PeD
/1CfIuYnWi5+bmITeO8r7OcOk+hvQM0vdyT2l9lAdvPfQfAjdazjkvZr+H+g
GxgcS/jhaejRmH4EP8cMo+RS7JFfvtLLWpvws0vmnIBlFvzwSG1VWnUffvjs
3NhChJ9hwWklNR/ifnc2ud7njN8bN7RBeJ4BvpDvx9BQLfhPEqXuxp3gMxT1
TWuJ85+b8smj7TfwYmFWZZMbwe9JrXvvQdy/Ef/JtaSow8/OYIryIQ/4CV29
ftiIuH8PT5nWL7TAz7m6gi8qcfBTvOOAzDri/v21xUGB3wB+Iqfp3b+Ow4+x
lFPqn8T8x263V7r2E/mPd39f0V6FfBnZ0tvaxPybZE/+IdCC/qp51d2T4sT9
aKas60B8X0mujYZmxPwLziu+7SPOz1+TFTJVxPddf6xbf3kq+rNEPVVMc5Bv
ppgn00F83+THyZpBrvCfy3mVpWIN/wLtJynnifkf5Sg46/oevITqSi2ZGfCW
VUsf3iTm33FPuWbXZvBcqvaFcrPonzOVKLiDOD/j96mrpHjCz7ks2jq/Z/i+
IuG9LeaEH5sTsXOij+FH5AyduuQv4v3jvdbxC+GnTM/74sWbxPybj+7Oz4If
+tDOEmHi7/ePHPsmB5zQX1qeobnvEH7vipYVZisJPyeU9vu794PXmCoKz6eg
f6PLxucqxPt/ToCWSRMh7pfzCZfKPqN/1pcIxcYH4PNHtvjHhcPPAXW2jgwL
+QuJdz/kEH6aT+SM7C2En9MDUkG6dsjfYXvQuot4/1uoBesn5cFPiPu+78EF
8CNs1bI+jvj7uoazni0eiP56EUavK7zgh8mu/Z2L+P+lkRbxIxpl4G24WiuN
asFvGfw2aUfcX62Wd4b4D4HXCb1eWLsLvLz/eFTIf++vfwENWTLI
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k0FHobxydCKCTbhCuJCpWLkmyhxURli1Fky3aZCMcVoaO4siVbWW7S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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk01esax0nXkEgyJVNskhLJUAoJZRYVuUoyk5Ao7WPMdFE5xshwlCmK
in0SstltiTITRaZKGsjWQIfUXfeP6/v+Zb1rfdZ3fZ/v73mf99k2OvvZuK1g
Y2NTZmdj+99fn8nF0tke/r0P59X3K0WP6P3/nHM8tHmB8Xn5PMepEMPv8Wj5
zNsfN8XhAH6Tl2mPOB384sy0mUQe+FGXG83uxeDvjYs5v2sCf8BwYixWB/ym
7RHnPmwEb/mjzGPtA/DUhbrJpq/g9cSLMn6Kjy6frQKvTTW3gec5LTV9tJ2B
eurax4tjh5fPWxWCuJ4UgN/11v7bbcGm5bOpTPh0psXY8tmFo7tEogv8Z/NW
Zksu9HdvFTjkZAh99QtajS5Z4K2Oxgd8L4S+8OcrgRXl0M/zMUxjEPkIjvUG
puihXhXvC5m1FORjLBug60zkMxC/cN90Brzl1m+rPgohn7U1vqIBRD6/Z17p
CfbAv5gH02DnZfjXrzy5ubEQvHJ/mtnXlfA/fjE2ItoQ/me6nrk9JPKhJEWY
jKdBv2OnGZWlBf1DZ2T3HboKfrg40WORAX3F+HO+mY3QV2E39wsn+pPnvjB9
8jTqZU80zfFyRT6K5qzDnA3gD9GYZ3mTwXc4bR1PSAMvZcxS92KC77hSlEyz
AR9iub2RXw+8+mrnat068PRp5QFaM8E7qnEyh8HLmTnN8bSC97mhdjNnBXjm
3VOeV7qQD2+4eBKlAry5RVuHRQRz+ezV2W/t+gLfN8q/xf9RD3jFjn+d+HUe
+Q+GmerGrYE+m1tQw/E/wccEDnFUyT1ePq8XPUb98Bv5H+KJoVBo4INyObZ5
b4EfpcW0yn3u8GNuZKuqRPTDBpfqUi7ivqgcXEGzMYAfs/1HHbSI+xIsQqlz
K0E/2OWqPzG6Q/SDqGhtGHFfkoIHz5oYIE95nlaxF5uJ72Vi3f2VuC/mGrTT
2pPgtai3W3/wwP+WuJG83mdE/8hwck8Mwr+56NU5ahb8b49acyChGLz+Ke+B
qk/I58KLZwatO+A/4+NrRkU3+Oxe582OcdAXGlr0WC0PfeHOdZVSaeAnWhWd
OGaQz38W+D4NDEM/04Ht8zOiP7NV6kbG6KhX240iLN6LfG7G6B4wbwE/xZQf
3swHXvcnv6riKPzk2dRN8NwFX5GewRXqhnqzZab2+NKQpzyXCNOI6M82K6c/
voShXrY+q0GD9dC3OTi/sC4F/BnDn03lvOhPy1Wz9u4s1FvC2ifHrAb/9K5W
gvgP+B8r7Fx4JQM/A1Ir3ou0g/8zyLfkbQv8aMTnvwmMgB8dp+jilzeI+bnf
51eDNPKviyoN3WMLP8aOO3QCOsG7e2kqGJdA/z1Fs/q6NfQNZY2bL2WD1+k6
pZUSC/0SnaX9vVnQ19mSnd71BPzu54GreYVQ75WOdK9b76H/dbFfTe8e8d4d
bHd0PYzvVbZHMjUoF/noG+Q4thP9+bw2dltpDPxv4hMTLZWF/kPTPv+/U8Hr
nR5ybP0G/+LKvuXp4/Afpx/htILoTzkBM26+p/DPk+rgdvA1+rNod9T4UWJ+
PtgYdHPnL/gpMBkUpT6FHwEnrXu25eDb1wpn305EvY4MVbvcSdRrwXODOUr0
566lsjKHc9Bnim2o38MHfdql8vbvSeD919lQ3DajP12L3F6mc4wvn03yoyl7
q8BvWrzDzbUTfuSlnsQZnYcficl/pujE/Gw8X6hRT7ynhSp719KJ97SP/XmX
KfGeaq43Fgh4hPyT+WRvThDvqXZdn+8Z4j0Nf93CqPBF/vc4PbOobsg/+GPM
AxniPe1qsMlJSwIfWaWokZAC3mBa0lCHeE8tKbM+8kfAV2SYdXjtAz81+Ekw
i+iH2p/a1yoZ4G3mzsrM9oOn7D7vlkzMq1ZeyyJrHvAKuS63+l8inzqjfZn/
vgN+kDk8t9UP+QdLqlF9Gcjf68vZnj+IfhCWvlj6+Q/k/6vTy4RXGPpNJ3bQ
bJPBe3nYc/GLoB+m7dk6xOeRf7jtSPKu++ADTBuX3vLBj7s10/uELvw091tJ
xHcQ79evqRQjGvxkuXCG0l3gRy+p/rBfHnhmiZDc3HH0Q4Xc7wvq4fAzKBnm
cIR473TnZ4KnxqEv/b6eplMAfas3btGsEvAF8QuOXwfgf0R9puaWAvST+zqv
6RB5StMnWO7h0L/PHB59R8z/3Ef2Z1SJ+Z9vumgitQp5jsvPrnWdgX6TqJTP
EjH/lSJqtMa+oR+EKsLoIRLI0166NnGI2IfnldfMqrXBD9V8iYc/Bn64WB38
CcTvhSGtxFpuEeQZZWdr1G0FP2VCmalfiPn/MCRVcWM+9L9bC8QWH4B+2kUl
22li/4naVh7ingt92Zk+14ab0L8dwMd++TH4E7LmBobqqPfLLcM2BWHcFwlV
qnYu0W894W8KnLjxvU4/3i33XhP5hIXxe6gS/ebj01+jWQP/p1wm1a97E/PH
NPjTxb+IfkgV6G+zhP8CXachnSD4vyqYn00l8le1yHiZ2Q19VZkXkUmXoB9a
Jbm/hPg9wvcPzc6GE/q0kxdf+RhBv7o63KacmJ8qowyfB+nQ56jxE5TcBf3x
7cGXY4j5qWF5LHJnA/H+mmRatNGh37ik6tlDzM+rRdLHzL2Qv8eC/wVRR+T/
jhoZ6Un8Xh4bERZszwJvVJ/nHpUP/kSBVZ83sd++c3UIdTUEf2q6rPH4FvAJ
+rl9UjXgWSc9fF+8Bb8xRrXwISe+7+HJ3y4FxH2P7b7hmTaMfNS/2Bdp5BLv
qZRt7zrivt/iMsiWeov+qeuPn2vchnzO/jh2/iOxPwS+S+7hiYa+5wcqy0UG
+qzoyjXWxP4w7XKt0XQB+Wsqj0YqTEBfUs+JolcLnjsq5sdIH+qt5OY35p5F
PuX89Airp+AXpqUvhbPgpyegduW5avjJn5p3bioDHzLPOLbyLupd3RCSL7wa
fswycoTGiPkWYOekYEfsD0knLb00if1BTF6p4huxP3xPtJ4IJPYH2pYy9nxi
f5jqjynVIfaHohYVRSVifyg8IzIWSOwPdlTfgEai/6n0+vASYn+4nKJf9xex
P2gHfKwzIvrft9IypIbYHyxGjOSEGKh34Hj5L0+i/yMZf99V8EP+GyQCxaXd
kf+HUrarqsT+4CNeu73qCvH/IpMHo0eSwccpcNXIEvtDvmfBSJ4teLUB9+v+
hiN6/wV1ar1F
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k01HsfxydxbdNeRJQlaia6iitZGyE8bhpZklK4nW5FlmQbdaXF0jLS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxV1Xk01HsDx/GJp6GRSGR9wmCUlC0pNbfJcpVlqimVCNGUNUuo3Jps1USy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1HlM02ccx/FSoONyDq0VEakK6wZYkVWlQq3iAU5RMydMoYWBENBMGxke
wJg6EDVYDg/uAU6ZqIxFkXkgKjIqKiISrhZE6kCuySE3iCzLsvL9+Ncvn+T5
45V3nt8zz1e2xZ/JYDD4WgzGv18jps0xjvLjlTK9A7mDAvWK/3e2Fs88KKdL
s/uYTumCtGLNviR1zTVkNmn2tGY2i6OcPH/OIOKLiblFmq032y3wTUqDZt+/
Znh4yeHJ8yNhbU6rDRSaXVw2rjybMOm5Y+ka4hw9eb5d8P6qu6xEs5lm6Qrq
d9j16UzqV7/cqLWY+Hsjo3qoP8exX5f6W35wX0z9dfPbd1E/K+8U+Ne6nXCg
/tNst2rqr7jCDqP+8pDxJOqP8Er4g/pbrZ/Mpn7vHXH3aP+/++P/pP7RNn3o
b24/V0D95/QEO6nfeeYy8PP6dq+g/psPvqujfr+sFuivYCVcon7RWoci6u8I
zjeh/hUWgk7qrx28q6b+kqNj0P80rwv8nAo36N8TFwz+mpiFIuq/vNG7hvoD
SnJDqX+51al06tfxsL5N/Z6pRabUf7RWVE79ySk+5dT/4zRd6M/d7w9+3Wdn
oH8XZyP44/3cxdQ/b/qdWurf4mwF/thadRb1P/NQ3aX+8Tz/WdQvM96vpn4z
Q1E99asK3kP/Atv74PdvZ0P/tPUB4P+G2wb9j56tgv471Uew/8mPzlH/i5eF
BdRvm+4K/SOv5lVRf9u065XU39jDhP5tQxHg//bVPegve+0Gfolj/XLqZ4j2
QP8cYxfwJ5mtvED9W4+XF1J/3PY86N90y+YF9Y9dltZRvzaPAf6h7ivgH/hq
GPwRe33A39e4DPxLV+qBv9B0D/iFz81+oX7pBdkd6g9gz4L+PjdP1lK/b2Rq
Fdx/BvY/EhgP/tCGSvDPKt0OfsuRC+Cf2bsB/K12W8GfwT5+nvq50dugf2ZM
NfRnqVzqqV9uYVpL/bEl2H+Dznnwy251gn/4hRf4Y19JwS/Q5oLfz88f/DeG
EqA/a6AQ+rd7M6H/kuanddQvWRVUTf3JCVrgX7Y1EfzZwnrw14V7gn/MWA7+
X6tF4Lcf3Q7+QS176H8yzhL6789shv5RvwepqD8qLbqG+pWG6LfnZIC/YcFr
8O8skIJfeH83+J0MrMBfKfcBf/nDMujvs68J+ou9h8H/xMdTSf2tDRXQvzcA
/fo9yeBPbm0E/w2xBPxNJ34C/0X+UvDvjZKAP+jL6dD/yqUp0F+4phP8VcVs
6O9b4Qr9n1uj/63Hz+Afvv0X+P0csb+iMBj86/fx8f9t8AZ/RHgz9G/O7ob+
ukN94O+4mQz9o6JHof+Or9Ev5qSCX+dYE/hzT2N/m9fh4J8QC8BfnCUF/wy5
NvTvPqUN/bXsusD/bkcn+IN4dtB/nxD9eYlp4He5+Ar8DG3sb1R5APyHAmzB
v9Qc+5t0d+H74zkI/Y1Zb8F/eGE++LNbjcDvth79ykTsrytWg3/OLezfogoD
v0u/Hfg9LL3AL0p/B36deRP4foZ2g3+blRL8DoOW4D8oRv9FJ+z/kI/9eR3o
38sPAf/U1YvAb/MY/btO9IE/fNMI+PVtesGvWFeE/gk2+Lc5o7+7AvtnxGD/
pEfoj+wPBX+OL/afIUF/Y9wI+KcsGAc/z6gH/C3zn4P/TBIX/HOc0P90NvZ3
H0a/8CX6HRTYP+M89l+chf7fYgfAX5wyCv78x+j3TlWAf0OMCfgT16DfoAP7
s6+hX1WB/qmx2F8+H/tnBKO/UjgM/pDN78Bv4op+acpT8D92nAN+l1XotzDE
/s+a0B+oQv8hffRblGP/rjPor/l+EPyG/DHwu2aif11fKfgDuabgr1iNfusB
7F9ahP5PqtDP90W/LQv7hx1Cf3zmEPjr36DfPxD9BgZl4OcuMgN/2Qf9r2tj
/8016F9Vh/7jn6HfXI39L8vRn6/E/pI96JfI0f/5xCPwR1Ri/4Mf9OeMYv+C
UvSHVaPfcxP6s0fQ7xyJfi8p9i958J//H+ZP++Q=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k41d0axqVeQkqmTZlTphSipCiklCmSvKYkKpQdklPe0KbMOcmYzCFK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk41O0ax4f02uOILEU0yUumbG2ISUKokLzpYGxthEKGl7JlkKgUmi6R
UtpJEtlChKxTGtvIHi0kWfKWzjl/nN/399dc3+v6XPdzL899/+55VNz97A7y
UygUGh+F8r9fZnmmwnreErpEh5CPbNu48f/1JWW1ZzdTKgl9j0nxfGrCI7TF
Xakc85vg6/b5R7kovyQ038GQh1JOfYSeDdEX1e4Efzl46u8qFdh/J+uR0ZTZ
Q2i22Lrf9Bjwfpe8jFJqawhtWOuh8Munn9DrDayEFDLAy3XNjR47Cn9MtqSa
bj4Hf5xfm+Z8fgM+qCOinuoDf6JUGwS/CyPew5NdxrFs8DPccCveXdj/Vwnb
2KcQ9jlvWdyoJvC+seu31NXBvpTjKnOFs7BfrKGgFfwI/Nl9K1f9GVVN6CnL
dWWBw+8JrU6V6JXngX8p6yVYPvaC0DnmDVFhNsjnMtlXroxA8BWGLLPg/FpC
53fvkQ/kHyD0kAG37Kwr+MUuUqY6ta8IXV121ZR7H/wqx7WBUxTwetViLmcG
Ggkt2J4hlZI8DPv7ZAfLlD4RmqWnvthmDPFV64inrSTFZ96j88ubFN/qUu+l
QqT4EqhNETtI8ZlPiPH1P0F8xXqWGfaL4O8ok9KtSIrvYUWKlFwj4uNYy5t5
5YKv3MNKzF74Quj4gObOR3xNhN7olvBV9Cbis3BcXnJKCPEp2iiwZbRwP9JL
ahzlenB++guZ3epziE/lWY7qV0/El85y+8kLBh/cEn6oJgDx7Zoev7OnG/1g
0fwuvt4fvHNamvjFOvBb+tKDtCURX2FW0dXXjuBXB2pK3KPWIT9KB9uNhsBP
rmg1W9mNfEjXRh6q6m0m9NppAf+vaSOE7hC3bfTIHCP0kx9fphyeDBI6zqV5
IXYj7OXNjlrey3pDaK/VjJkG+kfUZzhj2yUt+LNg+euX1k74n+onozYrVE9o
+Rh+tRPHcN7SZompYwE4b+OBpDI1BQ6hM/MZ27gi8Penk5lbBh/qW5f2iZ3F
RX23l8T5XRvrxryYjg3d4USad4zOg258yOczzw9F11rgP8UleNXuMfhzTVHD
450y8mlhPFsvvhn5vPiVuSJSF/lYdGli535b2LvyXFzOfRPOdzWyUiv/hXws
44lZec0jHyElyw6UfP8MfzRH5rvp7YQWHvI7JeGOeBMYArbCYb2EFr24iBn0
Gue1Cgb3CYxg3tV0/bZ8lY95V5HswdldAL5gA0PLez3m3XyaZ4d8EOZBiJLo
t8ku8BFp8muyhWBfXLv2kEUY+kVl7aKzfafAH3rMmGig4f5z5LvaHXPRL9+5
Wi1JpO9N+SaG794qfG+elsWHmnuDL2WIbRPKBG96tWhglxO+B7FaGsFXotHv
wfVBZoLt4A3aMq0dneG/9fJjaTVT8L/8zqm2qBTwk9FjlocHYJ8pri5q0k2a
J3rlmgm14LN/NhZraFYRuj7vsOTMUtTLe1xh4eEL8JYzZ+Luh4Nv66iXG2KB
TzISqTneCJ6jJPtQsgP+f3TpzHXNRH0/W+m7JT8Gv53vTMgGB9R3uO104JF7
qO+nI7ZWdqR5aDIizPn4HfNwC+d7hYMr8pNbxvPlMcEPvpj/URmJ+g7mlitJ
DqFeG64Jmrb7gt9buo4/+zf40JpQJRsd9E9xnWnZDgvw3hMBhtdl0D+yqc1q
7wPQP0ozMuqmPuhfncqB51ImmCciC3f/ltPEPPEOtHdOKxoi9NZeLzszGvqv
lTZRzf7RSWijJIvcZTWwf5lrX76Gv5XQAja+bjNqH5BfhX3fsvNGMS8eqa73
r8L8WmFhscuRh/lxtS4m/J8s3Kfh6tsVb1oRv2DDBa4XG/We6HOlLZij3k1i
VnprssEvRJxbKSeN+0pRdGqf2gv7VVJsVx5pH/yiHLtFSQ72qZIhIbRk1Pu8
yfbLJ6PAN1+fHS/4gv6cvB098I6Fem+zmWcZkfonjbmrR20E/khQR6TzefCH
r8shRZjUP/ufvj7qpot+ENmhKf5ZEf3QumLen1MJ/mKo8PmjfuCFP85vuXwc
fMGsatKhBvBOzbrOmtOIt4h6K4zzCvnUVN76RfMZeO3O6dGSP9A/tdoq0WLG
6J9XvkMzjR3gbQXpD/6tBvsOzlbFT3OQz+g4S/5uFviGgMcvVfOQz+arnQn5
DOSzRLfgyvgN0v77saLKXBX5/OtnQq0tA/l8xLud/4Hkz7vYhM4eVfijS6Or
sW/BH7VPqX0+JH/eZqeVKBXCnzwnC/1ID/hjt+TAj7tZ4BOLz92gbYI/2U2F
Z6je8EefXaD7igv+RWlP0u8NpP83zse8XErhz1pHFdbcWfDDggZFgUHwp7es
83OLPvx5nnD9XBRpf+dGWh9NiUS9KFIF87lDqJf25nsZcqT99hOT/rGFtN8W
VmsPp5D22zCZYIGDpP3WttcuR520v781EFDfTtrf3SP8Am6Q9tt4dsqpsZfY
b+n9R75JkPb3D3ml1QF84GN33tSr6Mb+Lke3TvidhPnRUOy+MZGKfWChbdAk
vAXx7edE6IyS5vkVO00Z1mfE15i3f8bXHvE9Hll32PgkeCvL1AemtxHfY7FT
T7rmke94Rb8TOp7g7VIEC8IuIb4q42U7/khEfMs8+W0OSIPPSfZOqOx+jfnX
rxAQvhjxxW7jUSY5iI+7aDrPVYB0X+OcBercYa9lTt9zVQ7Or2xTDvjnCs7f
1c3VHRcDf+7GPt4JOvKbkqYfLWKI803qmS3h53F+vBlz1Z0IzIcVPvZvlzyE
PUZWqPLqVNw366bmbEUKaT9o3PDfX/AOg23sxFHUQ0/6ll/jbsS3/K6Q9e8A
8Hv4DZ49eYZ6/JQ+nfl0MeLzGJ+7OO0C3mj3jZPUHuRD6bpvr3Ix+PQgCdqe
OXzP9Fyy7sn9hf9TN2mqGn0tyIeLuNTP9AZ8r1LPvDEd4SC+SI1dOYZ1pPvT
v/GNoDTm8fFkoQup35A/ae25xEelpH3Ai2nCKgKvVCZp/uAt5vfhpLtXb3DA
1zz31LgUjvmxUCVb10KF/cdL8ookSe8RY4eD1n0lvUcscV8enkR6j0h9t4/e
T3qPaBbc1FVLeo84lFX9pUME9tOpPjJ5pPeI/TQV84wc2J8XuXB/ugD2X+aO
KFaT3iP2vy+I0amB/TK6VOXyGNhPlnzTWEy6X+uPzrXlnsP9UrBLX7g4hX6n
UWP8NUj3q1Jzq0Mr6X6J2p/+c+0e3K+J7aKu0qR51mHf3Z9YiPtFd25pXhDA
fTHsO5uzmwFemp/vug0X9+vrkbjCDYUDxv8By92tiQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41WsXPVylh1QkZCjqEiJFpntkSIjIHA2XUod8ktBRKVNF5OaQSgnJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lV0bNUTGKCIiTmaVIxVljkqIqDdDg4gMkVTUe5B59oVEUslQGVNm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHktpQacJlTVaFWaS0LFMpayHFqEsZV9StmglJJEWMdokU6Mi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41OsfVXYlt252kgpzkZsU7RKFjMulSZIlFEOSJEs32S651SWKrCl7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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bHVublyJRZAspLUIlyagZRSkNRclWEjL2fV+TaZSlJktpSopQ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk8lG0XnklSskeUEqFkCUmLsldUNKINpXjtFdmGqCwp2be3N5FCUahI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lQsXNdyuKRxcqhsuccucpEHRUXSVMVNE+GigEI2KkCjjkZOZjBlu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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lH0XVpaylmTLiCx5iQgRGSTxolKReK1JarLFhUlUIvLRNvZUshXZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lWsb3YYoSSHKFGqfBkpIgzJGZo6kOoqMZUhpICJOiXzGjlI7SmaK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lXsXPYZESWjOFEVRpFuUIcUxZ6wryXyM3U6kZGhQpBIiQx1DZWog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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lHsbJpWiQcIRI7JNthSphESWspSilJQSxdiSCpVDHVsm2SpL0zJF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lXsXPYZycVSijqmOuonohqhMUcbki1DGlESZmsziEiLiUrof5RqS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3lYzG0bnahE2qSS6iMqQwZRWlQio7R9SIuSCCUqSVpI8SoVxQzJtAgv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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lP0atkQ7pVBRDMnaENIhslQqkiRNFEpaJimNJduXnFTf8ClrdpGl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbHgqHCQ2JyClUGEtJIUsqKUKRLBGhtKIiikihyJYi6ziVykkc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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41G0XHlJCkSVU1kSpV2Vpw5stW5QsxYjeFFG2IksqZZfI0qIYEWqy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk01W0XlQZDQpSxECIl5ZrKlFL68hqKSJrwkgqVihRCSpmFG5fUVaje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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lesXPYgMpXSdBlNC0TWFJKQ6JEMqiszdKIkbEiJDVMJBhAjXGCq6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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4lHsbtqVkiz4ZUcrSOiKFQknU1yiFyS6VIiKcSjgxkeqkhhJjySFK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lese3WxJOSXjRjsl0kCZddyIlByEZDhFRYMp0xGKbTiGipQOmm4q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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lWsbNWZWiAwhUVHGVChDnQaxNRg6ZE5JOVFKZhG2SgqfOUUiQ9ic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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41F0fxu0aa2RJxSvEINEiEkVoYqLlQclWlpIl61O98aQpqawl4UEk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk81Osan9ApS/Y5FaUQSZ1u5xqEDkmyNrYoNfbESdmXkSxdWqgrt0kY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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHqJSdtl17JE9KifLISoRkiQ5yS4iS2gxlrQJQ6Hd8tkdksLY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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHpItW5IkopxiKklkMNYSbShZKjnZioZwyCBJQhI5cpKTVGio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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbtpWRSnZRMWVPIerYSquRxETIMlkaIi2kUxImS3aNpXLIEkIS
opCyS9mSPREtTpbIElnanOv74/vd89dc9/U+v/fZ7ud+nyE7nDNx5GBjY9vC
zsb2v9/3xpFxZwX4di/n51ARSPiq+3/MGTx6Jl67jcDl1kE8ly6MENg2+nnz
X45DBH4t3cfOlPhC4Fwl+a2LOZ8I7HJS988d9QkCR23tE4ijNhJ4OET90AXD
fwksX9YUcKBznMB92gM/Hqt0E/hL2dcvI7I4D5XLnWYz7CWw7pjj1hfC8Ccm
wCbksNBE4H3iqze5aX5G/JXtO6xqxgjspCg8lBf7Dvl89MpzLsF9va8u62lK
1xL4jowqr2zSewLf5KsX1uOfJLDaKgp/GLmMwI9tZPYYUHsIfKt8SJ5BQf07
/nwdPGPeQWBf77r10+qor5HEEPuJM6hvtdNtMZo14mMW7cr3+KuewEcDTgs0
rRkk8DaH8QeuE/BXfVpwdQ5fC763chG7bob+fktM2VGjBv8lMioWR9zgnxK3
bSrVEv49JDtFbhjDv6Da92xzSfiPWse95DsI/4Jh/xRopMN/2BWG3OAd+Ld2
a1HRKR8lsJS7Q6kKE/fRIpa66kNwX8bQr0jPXPB3wO7csR894G87r20uOQb9
T9v+c2iTEfq/auXHOIsN6Ke0Wqa740r086Vz5dXND9HPT2O193nL0M/kkkKG
gyfiuVgoofBDrJ3A6aND5FXbkU9h7v5km3rwv38yaL7gEPh946FlV4H7WwIv
8AYLRz/H/YM+oXJ7ya0E/thdk/LrzDDmZUvtnwO2yH9mlc9bRhTqOxNLF/V6
g3iy+zdXtFNRX41Nm191lMGfnGiXwORR+Ls14xjrlgJ/GeGq9uNc8Hf4teax
3ftxPhnRLvMkG+dkFZJXzBz6oXnSMSK4GnxrTTrnk8f9Ed/3TaVemgbfxrls
afSqSvTnGqW/gr2PwE8ZEp9rqLDPkq0PXdEEfip+LiJruyDfFA07raF7yJf0
+56i51vkq7g1PsZeAvFzZwtbHxJDfmmGneEWczi/NtW8kGWC/HhvaqTzp4Fv
IrdshNgP9RN4LufJDv+3iNei43VWhVY1gf2aTtTmzUKfFg8er3ZvhH24ifnz
IMEaAlOlubwiZQYInDhwUb1qHvYaGzwzP/OgfvNrTW+we0NPQ2oZHutlYU/t
Ohp7Qgx66mCU+tGvHPwtTc+p3nkM/E3bfDEnUxb89ZmlvF2Rifo+PXz/uvM4
6qvAoAdVKaF+ik48BvPfwdcF2ojwiArL/BiTSclt8G8bZ/hoZDf8XzHwklws
gH+D15xJmf3wz5y3kPs1Df35qszYGVMPf3oJKZfSvOEvcIEvZEoG/sSYf4vX
/IS/y5W95/Q1uwj87NnRT1YR6Hf12j0FqnXod1NAOUfrGOrbOu97WXlbFfT+
7o5hgcvgs7GnQYK2B+xvCt09kjL6gsBldaN1f/ZBnzco+5ZMnYc9xX+I/elX
2A8r1yZF6sE+JdvwRbA77Lc9MFvpx/4S+kx6dKPfBPbc35ia907BXm+xTvK1
Pey1vOlcPtdhvy5jFbsFBfbzrkn+XYcbCLwkJXI2qBjz+M2+/NoaJ/SrT4ZH
2zMKenpX72en0j/oT5ln9je5IXzf/yyiebUWvhdNpdoOPcD7OjNP+3H1IvTG
kL99cLgeetMa8Oa3Rz7i/armotB4E++/7XOLzisSHwh8m6I8KiCA9yLxQDe3
1Aq8F37uw6Lhu/BeMAQ5bbfqIr5Q4x/xi+GIT+tf14ZKGuL75T0t58ONeuo0
8lOuxCC+sTUpakdU6wjsvXzTvRebkU+HDqdsxzDsu/0b3SdcwbfKIrW69Gbw
jfw+SoQWCnuXqqR8pULcn9e4jmPRF/fvo89X/dvMwoeDfb/Mp6BfD4Wyj5+f
Bf/LvyRLTbPo+US7mmNyIfSIzrulOH8eejTTzun76DDsFVL3hjO/Q8+Zi60H
PP3Rf+vjp/oLY1HfwzKRpncdsR/QJFonJ+KhN1LFZ9IyRTH/41R6jFQ0y3sU
Qt04E8iSr5tB1WMW/ZVcFhfxnA/66733iwtVCvpbnMATJs+iv+R06zfrJZAv
XzTXwP0Q5Csa7xRqpgj7h66u4vQB7M/vmImrJxOhR797Zs5r+ECPakRuhZRS
wLfzSzbivvtQj2B1yzQtN/At/91y04f6yLegi2GvpwO+naix8ZC/hHiadopU
BBZCT3QstwhdJ8Pere3okyPXYL9+zuqn1hj4kzsdIMJIRz0tO9ZaLVXA3tHl
zvbcEtTTi53eV0jCftZsHNu5lRfzVhH79EJKB+aN2iF3pawb+a/b6J7MH4j8
W9VTc841gw+/YqinXs6ADzezmzK0juH9rneJdu1NgJ6TvCP3F3mAz5NP/jQs
vUf8a2xOTgv2Y74GA0W0tM/h/S6SrWvOZdEXz4iJtugY6IsAr9w+6lroy8MP
J9ukWPTlncwz9lAS8v2smudmvhP57qBYrUraxbKPCrSsv8NEv5OUojP87NBv
5dYzHBFs6N/ZZfTeDzcRH3/p2Qva7OifKttqM6+V6F/YEWb3ninY59irivsN
gt8zlg1baBLQl8SENUbnj8HezTxeU9wO80xJMG+hKGCe6xsG+kf7kE/JglPq
cZ7XBP6+ScFUvxPz2yLiNKzvgvfBuL2o1cQE82LvNnWB3IJ5GdQrZIyZ4//m
7GSLq/dOnNP8XlqavsA+8W0+L+7EZ8QzF2dfkR+KfcKgt9hxOhbx0NX2Df5s
QzzODqTbEzTkt0adu0e1EPeZZaksq7iN/ShobrhU6RP2Tc1avVyTYOAmJ3E1
PVXwt6nnw+Wf4yz7zGwQbeVu+NfR+15Wmo96FLsyQjickS+d8+rVkZcs/2+W
DunE+yC+cbf+9N45zM+2qeTbkmK4v/ZVcUsyCfNzSSdq78YlzM/I1Cl3pe3g
g8urs5IkO/BB7vBQg9kc9okRHS8Z2ij46ZqmlbScF/aKbEErFMObwYcGQWWe
UPgXXvt3qZMV/FNE4gWGe6HP92vVPuqSWOarqG3poEI53qv8076Coui/tS6v
RlgK6tHzLLDxgijqoU22MRszRT/+8N0LCchCPwIuNelHFqJeQtXyxfR74IOd
TjWp6Dzu13/0u1hwF/afIt77PipH8f0LyXI/I3/0k7a88O6jBPSzyW+5ofSN
NwQ2ZAZtCx3DuVKP7Q6DFOyvfmELEl2vUC8mh/RVLhPo12CwfsaebJZ9tJWH
TWgC+vVkxlyi0hz6JW8kvLt/Neq7drAya5kz9EuF30Y76Rr41spRF0+yQ/7z
MnNF90uQ/4YcU7HZklHd/wAmpntL
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnc8lv0X5iEi2aMyUk9PGSUtJFnZFUIlq6woIYqsSER6e6xXpGUm+7Ui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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41GsfxhUtyLETk6yhzNhOibIVESES6s1WtBEhS5iyVPYtW8leEe1K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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lHsbnlA5SoOjGuXKSdakBmmxxVgSvgopKWvyRYut7B1SthpGKvuS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHvElshQqQpYW2VNE2UWy5aASWeKQpL5IlpQ9YkzZS4p20Xec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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lOsbRtmjIVtZQiRr2bJljRPViTBJZC+h1AglJVtOlhSKlCVpI1rp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41VsbNZQphHvkVCi5ZAjXlAxxqAxdkTI0fzmGTpGhFCoRqXiSZLxk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41F8fNZKpkDKMbCGylCXeVJRdZSllTbSgqEjJTrbozd5YQiW0aJNI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0X1iJbyFIpWUJCUqaYyJIUyvoiWVpoIWuyVaiJ0Ytmskb2RGVJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHc41e0fPmjIm1EpIooXWREyXrLqJRLJKnWUBqdsSkZZSfYoW7KVkQqp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lP0aNgqfUpRSlMga5aCyFkYL2UKhZAlZyxK+bGmxDKJGaaQmJ8kc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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4VW0bDRkzRkRKhiMiw6dEgyknit4iY6WUfJQXJSVTScYMTeYpU6cS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4lHsbZggdS40skzQS2SZCJFJ0QlKWyBKpRCgSKZU4UiFRyHasx5KY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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k81HsXRmVrLImplySSJltcFJkRwk1Slha6ZEmpKEu2JLKWkBZu2UpZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbnimyxESUXTtRJFufMqnIOhzkOIgadcqS/aQayq71SFEhISLJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3s41FsbJUl0JCQzdEG5dpmZkiiRhlR0IqXcL6VkkKQopDg5CEVRco/M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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41F0bHpG9bFFKZKkoUmRpkcoSklQIRdJIskypEQYRWUKokC2iCJF3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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lG0bxiflDYXUW6NFRCmJsg6TJaFFTWWXyB4qhSLRJpIiSygZS9L7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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxVV3c81X0btioiFYqsyEpxdDTIHiE0UCRbCU1kq0M99GgQlfkYyQoZiWwJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbNqLNGhVlyhYVWZItexHKMqcoa4nJNqqRUtkirSohS2WLUoq0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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41O0atmTJOsgWo1UGiRa7UF/2pRiV5oukDBKF6BClEE5Z2lAiLp8i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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lVsbVqQk5ZBkJslMh/YWCUWUKEPKFJUhc3xmF5mT5JRzUgipFMkc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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxd1H8w1Hkcx/HdJpIrP8qPfuhKirGDW936/ftHSA1p/bozNfpBzlUiLSHF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4Vmsbxd9QRCdlCgelQmYRMk/JFKJByJwhRIWQxOk9NKiUhCSROZVk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk8lGsbJvuYY9/JlrKEilAYyjgkJaRSIYWSpSklR8tRsqSSKIXhS0IU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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbHk6yVSQRilSUbWwhREUptKiJKSpRErKMwkEcJRRRGC0j2yFk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41WsXPSnDNU/pcypFGUJUKorMY2QKqVylMlxSNyljpJQp00UoogGH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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k8lHsbxgcna6RGROVYWlCcg5xkckZEhEQKScqg3nQsJUdElLKVUhMl
lCJ7tkyyVGRPsmWLLKMpMWpUFOL9vH+8z/X8NZ/rM7/n/t33dX9/m6KLl40b
P4VCUeejUP73G0TXOVhqtsTAiOZ8P5HVTv+/1pemxXNyPhG6d8rw3KIDQ4Su
nr3n+GHJZ0LH6WcrTQWWE7ozVIJ17Hk3oYeEJpqrH3IJrcvnxN3S0kJor73P
e1j6Hwn9etGdey/nOIT+wBhRWmEzSmjPNvmLzOwRQkvlbvnH8s44obNDqLll
KV2EHhsKPv9zLeYPSLG3crXuILTmNNt4m/wYoScOX2qV0Rgk9Kv+4kcsU9Tr
d2KTmCOnmNDhkwpdD5nwL39OttfsOvxTv9w6HpUM/1RKFRLzpicI/bX8wJSQ
0TNCu+0ZnzjyppfQyvl0z0l/jOfzCFROqKwl9Lh7pMBe82FC01kFoyJpGJ/G
FR77YVlNaMbNMymrHqE+4cT3Mfp6qC/xYeYJxbjHhB7NGqB0fYZfHdpf/nK+
BL9iRpLnqDP9hD7MCzVlqSIe41dwsmHoE/jp2Mn9drKT0Cc6vyTUh6B/mS4q
RWpO4MfHvuJ8Sij6dzBdk/XXXCuhxW66Ug6ZgQ9VoeVVR5+Bj/ilbO+ACMTf
GHKxnKqB+Kr+J4JcPRC/9hPrJDOmjdCbKyPbN1Qj/uphiyt+KWxCd2v0HDbL
xfc+aw09lHvB91t/aiXHBHwP/sZl0j+Bb0adSv1tH8RfvqLFcxcD+Ud0iqTt
/oz8nc3V84dz36A/qYProoXxPz2swNJG4y2hFSMZJlQmePiRY1xjbVCD/qls
dlK2BZ831J+6BS9D/2KYtOMP/sD6Xto2I2JzEf7ZWZ3gpjBRP5vPReZIMPpD
zza8V/4W9e///XTopcL3hBbSGg+VtgFPL5yCzdn0AULvapLLszFGPtunw/5I
N2cRuvI0vfQuB+uPUy/5T24L1p9G0Xc38XnwXmmdLv5JjbSe6yZO33YCn/cp
lZqC9uBzXDmI6+oNf39FvO6SrkT9wr+ERJfmof7ZL71ztGb031o5LrCfhvr1
4w3qwygfCB3yhe1Xao7+iw82B0mWov99mUldWTGYv2nNumh5Ycx/T+Zyr5QD
5jeOlI1iCMKP596tHkNr4Mdwd9Q3BRb2i6ZkPmYRA3zs6fBOcubWEbp9cfNc
xCLwbuwsNbNkI8Yn1zJvG001EtrkrqL3mtfIXyFqN7+cH/LX5qvrdkhG/vws
8ZCoO8j/gKdfWL8O+Dm6oT+6OQH+qfl4GSjqY/0MaET0jYWjvh4rZlB/GXh2
vda4I3sM+eab7fkka/2c0L7J/eGSXVgvL5qWPjxYhfHLfg89Z5dRReji0rG1
hWrgs7qtbYPFdvBksEt6j/Ex8KmpLfpr7wL64WTPPD0wjHwXuOKNja/Apzsv
a/85HcTL1pMQm1AqIXTguZ3VXc5Y/+Orn/nc7MT6Uc1wsa617gMfjxS3Vw+g
Hr8+WVv/edT/ZiRVuq8V4y/MNv5MmsH4aM+plTrcp5g/9eyxwRs4n9pmzc4c
dSXxM9+t6MkGP9SShgGfBfDWwqNTov/E+JVN7BLlEvAjLzXwdoB0vouOmhyb
TgY/QyGZ7s33cb7nHfetF14Pfi6q0e2ZO3FeWXSM9bvIwh/xF6937KbB7yUC
LYzFpPO9ydSIT38G53uxmczVxlT0T/T9vqjAO+hfQY74+q/B4G3NFv8xlgDi
Gc6XaB0brsD5MbNi5VxzD9aHATVtcDX88Fbv6fIqfYnz7bmn3sJW7Je8/QZF
2p9RTxg1srmhCvw+zi6MU6tAvPnOzSGHv4JfWn6bjM018Bu7TuT1TlL9wnZx
BV8nUb/tdG0hOxn172NopS26TbofdnLaL0Sh/hiJ71s9FjD/yY74mn8PgR+l
qudMXXXw0+Bw/bu/AcYfeCMe8KC3gdBGFqvHDTeCh56MrNMfVdBvj+h+ufC/
0W+tPdyPTyXhT17cOasSG/Tbf0ad6meCenmPb7hmqGK9mrhf2q36EvVWZ89c
3VGOer2uBWnVaaNea47tx5BViFf/6N1dfeEyQud2J0zVk3hNkzDhEyTxampO
1XlA4lXQqSHNi8TrcbH5BHUSr5O2Px0kSP26cZzG4CfxqpUpLXObxOvOkQsF
diReN3BO0XafRf7cm67vmCReddpMv1pzwGtxZcre0VbwGpnZ8XZWHv1SmKev
V8sGr1v2ZUxe3AReh6x0jQRmUA9zmdzqhPPgtcRK08ImB/Fcg2lq8e9fENqm
a5vFSk/Un6Evmf7FiNS/HrFjPF/0L+7LrSU8Ifhp+15GTn2UdB9g8S+jVCCe
urkVM0cX8a62yqx7UY37rwl3eGZBCvvtssV0Z9s01CMcvTmSeRz339VyKsod
yxFPtI+SvPsVeLAsCfLVpuH8ixxOrEz1AQ8ZN0w9Itxw/xwOPiJicA/3Axcl
qvkID+fxK6u9Fa0u+D6i3E2ishbfl32NXMTj4fuMavMsLW18ryvI3WAnAv8L
A4XDVrxpwnnxLuLK313oZ3HL3hV2pPdS/ojw+T51+Bl/gGb1hMTnskN6euKk
99KP3Jc1XqT30mKRk3OypPdSltjldME74FNDzf52MOm9xK/oqHXPFO+l9Drf
1Oge7CcTcz/8DQIwvkY061+lPLyXcgrFw/PoOI9cH7c7hWaT9h9FmqUFD/yx
Nj3N+HUK9cU9SHwrReLv5rZadmwM+LPSkM+JXwX+rjALGvR+oL61t4bCnjIR
zzJWzUKNjniZEe66rgLg781l6qnAAMQbTDyoyKDB//LZ2jKhCuznDUIfbTXN
EO8Er71BpBv+u9yKO0uNhP+slOkCvyjkZyKnut+6GP5nuFM8jk/AH0vN0q0f
VHB/8CjoZ7snYj2zpaRGxYowfqJSMGfRBfgZH5i69cVG1H/wXXJADYmXbR1D
ISkjyHc+ffyn6XXku5TbrKV3DfnW1FcLmKUg3/22Oo03pzC/npfmjQ8u4CXb
nz+JNw5eLk+Gv7cKwfiRNbUndziAF930RCUTEfAS7rZgRqnH+LOVuXa/2eF8
XVFw4VnKk3eETrK/0ySgj/osPX1fnTFCf52zt9e35aK/3q6LA3Sd0V+HoG9F
otOIZ7gv1s5hG+LVxRqnGVWBPyqnLPxPE8R71X5B/W9pxJvNP7O10wj+l/n2
fA7fgXhZZ360FIogXvdw/PSuAvhfpZ3k8CkD/o9OUnr/4w7/rx4pkndfjHiy
CRzHtWy8H73XmUkWSuA8if0mOFzcgv3rp8MZ4Y3dr9EfBcmVdQy8l3SOZCxX
TsJ7oDbWcWiLLof+XzTn72s=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lH0X5lVCX5bQxFgiiQyjbKVFKUaRtbxJJXtapCiiUH0JDcqoFJII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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXpcxdZE6jzpEhRDKTVBRJrqFkiAZjBxmOpzKUIUKUKBlCOhJR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41F0bthOaFGmz71sUqXdkaFqUZEnKLkSyp0KlKNmiQggV0duH1BAl
S0RCtmSJSui1ZZlhkt6UGN/1/fH97vnLdV/P+T3nfu5zn+c5Q9bV39Kdi4OD
YyMnB8f//krYuW3/Yr5ix/WIdUKDYn2G/8c8mj9maB+mCXy13qLINfgVgfc5
ZFQGRPQTOMGc1XBPmkngL5aCsnpFFQQOHtvPr+z+Aeuj7KuowlMEDpVxVt80
/57A3SYLG+vT6AQumTU5WleO/dzU1d1dlLEf890+H/+WcgJHizz6fLy4h8B3
Gjtbj+YzCHxCe1xhyAV8/KVOcF0VBJ/UHiOGBm83gUda/0lRzQIfgeMzAg3x
4NM8l6VjJQs+9tVVsbWhqN8m36aM3wD70VkTQRfmwEd8VuSYUyj2kylRudLE
xH62P7RjO+s+E5iqJ1Ne8RrnEy2WKOmUVktgVh63bO76LwRucS7ouGUMfs9o
Gc3B7SUEnlDamlUX1UXgot4n1pPXJ6GPjXv8cOEggXnnGyNrfmL/5mfhA5Fu
1QSuXJ6j4DvbC72nQ6fNYrB+VLHecTWjnsAKn1P2MBqQn7mJIsJiYL3bC7rS
nx01BC4tjuDmroceSyNju96w6TG6+flkXir08EjriHu0Dnq8ZnpxXmXT41sW
hbS6E3qYmKiLicVAj+5vcVqTN6BHeRfPsBkNfJs/0R3b57B/6+sWlvce6OHL
QQ8M6IMeHW+SFxQvY/278SMNrQcbCFzwzFtyucAQ7t87slduG5vehU43zOdx
HxPNjHRKKQMErmsyPpy7DfWljeuSusZKCWx55I/4Cl34bZBEzhSsgd90q6Pq
zn9CP+AOdKVrcCHfXC4/NWz1SwKbvVb7cWj+E4HPvBZKndcB35iEnafyrjcT
WLWLEpifOkJg6a38ay+8wH0gR0smJM3h/u4MHa5U6UBcLGfWV+Ik4io/k7bI
RSC+Vty9+JTpRwKHt0yIki7hfguby8mrCHaCj+fc9d12EwTucn2V+usu+D2T
HxkKL0H+1R6mVTUSuM82G75/ix5F/FemXP0cE/oGtFom629DPOvsgQyaFPxg
oLbeTZfK1m/V5JWCupsIbO2iKKW9EXx6fGtFCzaint37lflq5dE/F4tf5lRw
4Typ4TZd9SH/EPjNwNqA6/twnntPDG08z4T/cwJ7ehn34H9jv/vv+bPh/wCv
ikSHUPi/uOf5Wl5B5Otx87zzWbOKwPJpgcqjB+APV+HD4le+gb+JROHOVM02
Aq+IoHNVJn4lcC6XwJ5UAew/x8gSvLeE+1GXmxZpvRX6rXfXSmzzgd9kXI/a
dkVAv4ixWPGQdpzHgWpnPccz8NMZlrJDZhTiLJ8wGtkAfhJ7x3++7yz40319
t90jw09ah083RobDT9rxJMN1O7B/qcRtE+31+H7rZTt5nmycn8+di6El9ji/
aJVjXDki6F9/TX3152frX/2XNaXJgzi/7Gqbo47JOL/ZsumpXWnQ7+2t0jTJ
FJwf3XE2OJAT+ajLeTnj1HC//TKcJUQF4VcvLdncajL01req8DpBgd6DDUJG
0Z6oN+194osD09DTMfKiWGIZ7ofuYYe2BjHET3Ef5Q2jY7/jF9XleyOxnz0z
6MsSCf2Ss7LFwbYf9fzOU/vIMYz1FWJMmYJOzA+pQx8ig9LQ3246O7cq/Iv1
hsZ+7neT0L+DVeKU1MUxbxyCvtuP3MT63mt7LjgdxjxLoTmtM3YHH567DNrg
KuhL8W6ufqlaSeAFW0/L7Cj4i9SYqZNyG/7YEytVs9uug8B8BW+YHjXjmH9P
x6/SZkYJ7P1xhU7CIs77BkMu4fFV3P8Ha/jG2o3Ah9MnQN9D/jmB27TfVy00
wT+2A9LKuTXI5yuhceKhOup7/zBvck4B+T67lj2dWYX3j0tyJVl7Evdrba+k
UHUTzrvDQIQem4n4Od4nu/jvscUn5Bkieei3ZQMUE6Ym9HH9l56UvwH35yTD
VrV3AXwTV2rQU+JQ/16dHtEEtvp/XlnU+a2G+veGcX6SaEf9J3RPCZDrke92
UHl+tjTqD4hIFLdRQT7HhPSk3gK8RyVu6yyR7qK+XAc76u0M1PdqUcNq4Anq
G6qIqPLSQX1UNd+iShb4mO3Vj3o+Bj5OVi28m+tQn9b3BeMQClt/Ny0pkdPD
/F9sZ8i550Ova6r7Q/5yRb8JEqWq+DDwnlhq7F/2lk0vRdqtml42v6TVGpHt
msGP1yThXwabX0ylghtn1KAXZVHYX0MR+dpzUjb2C8MvzTc49gaOQi8r5yof
iTfQS288m5uvEHGPLFOP03mIH/I65dvqCz3Jw/f1W0Wg56ElOWnNfrb6j1uE
SUai/p8sA+1JFdT/+OY3E0dd8PU7sN9+Xr0M92V7kRjZG/2sN+WjSMAw8rnc
ajNvEEa/oR7keFXRjf7h81HvTXES3nNvW1n9BY/x++LVrf8YxbLpxRBwerDE
Cb1GjlzkXuyDHucTM0nHaqHHsr4dszGtiFsarN2iWo64QJT1khAf9CoQqn4h
8wlxjs7ZbDEDfN/mLchIOo64YeYNq3ROzHfB7xI//rRD74W+uPTy3ncELgwb
1czyHCPwzFzMD5dU9DPJel1m8T7Mf+2QTh3PEPipu0DB/NIX+CmjbecvniHo
ybq0lMU1iH6f2NZ5WZoG/StG0qfcfmN91oD4b6k16PcUf0qqRgXmT1jw3Xn9
IKy/HxP6xIuB+XOEkqA44In3yDlVf4Vz6Vhf1MIK95+rI7CblD+pWhn8pacL
V6xWYvs9u/tVyNQM+oef2U/jM+3Qn6a/xcKR7b0sslXE9NAvxKu0mH/fZHsv
p3Srmkb4Ir5gFJidEY64g/WF5KojmD8mtV/3e0fg/Hj1fppYTGH+tHD6icVR
8b7RW983YdCNeb/y5iqR0DPIr9SqepD1GPnr10xQZx4hPye3VdfJr+0EFm18
IClsDT/IaNllTr+FH8y5lEjSOdhffuXbdBpjGPrbCz6644v8q2SHLB5fwfts
s+WmBcMafB95VqWRVoDvn0blLzPJxfeeVikvI3hR/wOHDeeyT4Of3rDiHDkJ
/NYYZG/ezAe/CvQ1x1/mRX5XoQ/bubThj9OG16b4H+L9xONSXmCRCz1T3C6e
bHoIPaN0tJsi2f6fUpnfln6a7f8pQ6XjfTO/0N9oa4zip1PRjxiJUSORL9Ff
6NrJwoJs84t0LOfYaCn8R/JW3iH7N/zDLN1lmZcNPkZlQ8pdqeBT6KPxNEMJ
fMzOfvCmHgQfj5j41BB58JE5u25ymTzm1yrKzpXG5uDjv1u1g6GI963lsZoX
o39wnlfyfGRpspOG/wU/C8+H
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k8lGsbth1CyCkqhaKFIimOkDOGCjnKEh1GZEpI1hI+dSrLOTFkyaSk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41WsXPYYkU+c4RShTUbkhHNwuZR5ucU25Kd1KlJLoHImOpIxl6jNG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lWsXliGVQyibI0QqGxmKQhnLVCgkzilRhtBAyJhCKFPIPJOiQhEy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41PsXRlnj2srSKImkNJaIUIwhKlkjtGftkhDStbdpUblkqYayJYVC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk41O8XNSQjW0g09qyTZCu0iGhFFKlMilQoQloUijbLKNlFiUqjBVmi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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbHiInLUKoZFeRrRkiKansS8KJmphKVITCSUIRxamTtRSh5KSE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c41e0ftkLJOMoInTerekVRSmSFhlGipOGiVxmRU0JCCmXESbbMSMue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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k81OsXRlLWTJEisqaklIsmWYtUXNuNKMq+No2JlGtJFKLu2LJEWSJL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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3lYjOsbLjKdpEUhWiSitBjtG0VHxWTaT6KFNqJFqNChUWnaKVqltJKI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk41ekbxk9aMBFhiuwhIltCxekcZkwdJaLslZDQcBKl0NS0SkQkDMku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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lfsa3caGY+iUDLWRJAodJMrJEMp0uSIhor0zNohwlPGUIXYTSjKT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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4ldsbdZQx6pYKV0IeU2ZSSIgQGUKGTKHIVIdIbiRCgyJDV6Qi4mRI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4lVsfpZShInOmW6bIUIi65BS5MqU4jjHcIuGYGqRJCOXTuSWlyHT6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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lG0bnkTTm7yivFpIpEz5sqWkyJQsUbZQpMhWJNs0ihZbjCJCXmRN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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41GsbnqHIGpWKTvYsJ9miUpipcGjKVirEkRElDTptlqIkDFJSaRkd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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHc81W0fPomMtJBxkKwoq6fSKatOZiijx2giq0EdGZmPESqVSGlQlIqM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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGlYDOwaLk2SPkJ9mY/paz0iffMpp12bpNCiVY4iqUHZpk0ppIUiSdsl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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41V0XNRVSmUoZU4kUIV0alDkkimRIEiVcs2tWLo0IeYpSoUGkfGQK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHc81X0bx63u4lglEbpTaBKRsnKUkTIyKlJGbjSOVUdCNIxIT4rSQFKp
jCKlYx0ju7I72UKyV8l9UOh5PX8834+/vN6v3/W7vtf4XNf3d6xx9LBw5uLg
4FDg5OD4319ha/XMSm8hnb21/HW0L33U/3NN5Q/BvSmDhPcd0au5/ruH8I2D
69qzg0YJew7c26i+pIHwBdkn9qt88D5PTWB++OlvhBPTamtCefG+kFnZNFPu
M2Fhaq/ToeZhwpGilqtPebYTvjOjZkwRGSecahGVN7KHSbhoUf3Vncxm2A/J
33zWhPOWte58mPy8ljCvjccHV7d+woMyYvbc6QOEmfop0mrKqM+lJJmD1QVD
hI1i7YZ69LsJD60/EPhRF/G1TzHXPLnPIFy/1EI7eDeLcCfv4qr7Gsh3WsYl
U2S8k7DB5oD+Qm/4a9Q691vszivC3pdHyyYu1RDWOvZMyK4Z8Rqcd1UPyEQ/
rvhvmt7dg35S/TroarGoT2xWjnkkrZ7wk7Wm/7wZQz0uVdO/WSb1Ej7896dF
r0MRv6aB6N1y6hfCnPoPolPtEH8Of/cPKc83hAdG/aV3J+M8D0bryWA5xEtx
OLfzyhacNxtjnMjeOEJYb2dBeFpEK+Gu4NNry6+PEWZtTk/anFMGpq1X/ouJ
fqlPddZJiyO+ns4hx1UZeYQtt/DlORhCT98GTzmaPUa9jitJVy3VQvyKvrMe
nSWol67YQx7/ReiHdviWJb84Ua+S5tzlRlFdhJW2WhkHuiIe6dvpKyWrMwgr
2M6JqeytI+x61l+C1gX9Rt2b7GE0giPaVJTODoKLdCrs5cvAM7fSJyUpiFf9
Kj17SxCen+DzahYKxXMqr61k3hXk4zO6zva5Bubhra785+sxXwnL0uc2+D1C
P9z3rXvuE19KeJJyPZOLC/1QnpjsaziE/PN0NQyW2GYSbvhQ9n7ODftGsD12
TL0GevF2LDhx7Sn0TQvx1bJnoV9PY5J49FiY/4IJh7jQBfm2+Xik0a4g323u
DfIiYch3S4OM/EU15EtvUMuaeYh8DbRNdecfIF+vrBO7IuuQrw5DI8NCBvnS
7rcV85oiX53RRL8i57eIp58iXb/nE2Gn21dNFS/gfO4xxaIbY/Cnx1M0asMJ
f5I22eJilgWEyxl5+d2GmBe7tVK9TWcR77b56IpgwQrCZQkSIVp3kN/FuSlj
zUTYW5uk/2J5I7+PCgd8r/VDz9x9Lw5QbBGPwheti9RHmP/wW6nXlBswP6U2
U/3/7EU/lV9XBeh04P4I1u5r3B+B+Q/f/yZ+WB7zKc6sTFKJRr/PrIiS/HgL
/vuilDX/swz+ja0yrDkOY7/EeY/JzU9gPoW2cgUEstoIu+z9k8E1hvzlefxj
tAyKCLcYDU5pjMM+q9ztadkk7CsNrXMrywoJS8UL2E0ehX1vS9CDpGrYFx3R
XyO7uphwyPmi1cZ3F+xXN4vfm46jvufz5zb+cX9NOP/ANbmWeuyLVj7hkrWO
0LeLQdxPv0/Q95imzJk3TNRnc0bH7Se1mKcHdbvevX+J+v5UFM9dMg7/5cu7
E3cHwD937zJBzVj47x2l5NxcCf1av96uoTEKfem8e7nP8OSC+pYGLq4tgh5P
Xtnn4L4I8Rxu5np7xwr2nnIKhSO5lYTvSTMGtsXDnpLFvDDSivhrVNySxc5j
H3wononfYYV9YOk7f9GiCfncs5kpcG6DXj5ukiujUaEXU73+n6dZuL9pfaqn
Ihbc333+g33Tsbi/X3s2neG6hvs79b13cXjHgnrR53+WpqIfR70kZv6aRj52
MqOKm0ORj5qo1Oz+H9B7ihH3O0cnvB9iYME2eIh58hN0kI1qxDxZ8qd0dpxs
hD6oCi97n+D5LGtyh+bzJsKMuMKpMgucX7svPVjWCPuquTTsbOUl9PvZxHqT
tn7sq4TgP4HBPKiPWLHsRua/+YQ7PHSyMrmwr1ZISjfFHEW/1ULMEmW80O/N
Qd8Zh+moz1xuz/R6DtgfauUfVA2oJswV+IL50gz1lncUqWLfQLzsF3pG14sQ
72r231JKKxDvsTjawYwhfC/oKg9HZ3hhH9FlrazFs1CfpgPJn46+wrzUSdJc
SnZDX9VtN72SRKC/tHmnQN796F9/j8It6zr0z1mCszX5AfrjtdQlZKwa/Qna
eTf/tAvOp7sLpo68x/35PV1hpGvBPIao8EnSRzCPW30+nmtaMI9hs+orvmZj
Hp9+rDgcyoF674mgVO84AnuXS0b62aHoT4d6A1XrIuyLt/Z/52QjvhWTzkuy
l2AejAOLu4Vi0B8BE04nb0nEu72ifXHwAOItTakwS3bF+TwC/TIDNxHv5ci1
5gX9sC/g64je7gZ75bzkY8uvwv7z6eOrur/CPu2YyPgLT9gPr8lM/mEF+11t
2pW7S2Ef0iZdPxECe6Z+sSjvxnLE92iThSkP7D8kWBytZsNeqvmQulA47ovj
46/6i5RwX1B4hdVZRbCnOBU232zBfcHstWVzxWEfJfu6BUafhX4f1Zvkh+Vg
H/Wto1RG5aP+TcvNE7ymUH876iKJrIvQY/Xw99QGe+jRO3W2OU8K/ZxK5rY0
ScHvnW9iagmKwdiXXSKm4kmWuM/WL+0WKHFAfL+u3NvRpYTvBeUQtqu3F/Zb
oS+HUjIb89Pc6JBZfwf72etwa3rvQ5zn7mn45i9GB+EIsyi9KBOcdzeQ/qyK
ju+v3MfmquaW2GfFXmz/DaHQ3y/frmKHJuwHBo2xR5If/i48OWfiLIp9tqFs
IPePdQthH9VZmXQJ9C/gXx3eF4JVhBv9QkZNw5HP17v8aVwZyCdkZ2b0D0vk
kxo0kxuvveD3VsuIfde2LMKuJfzjTYXoxybjoJi1t+Dv0WKH9up5+GNED1Dl
reAvqCCS97IFvsdnVq3sNHTGPlmsW1c/WQ597E2cqOXLwrwns64ahZdCH33f
VFXDDmIfPhvpUtw/gv233UXs8cNCcJilWU2GKPpts+zgahV3PP9Uprj1/ks8
v115fVpLFfoteCu+UiUX/fNaZO7Ka4H+UXP4rUeoyHeUbuJdLYD6nabTvtgm
oH48HqwxnQDULzMpSLLdD3r+vU64ItYJ/tQYQm0XmPg+iysZWze7DHouPqQg
4RS/IH5DV2rkQcS/+sykqG0Y4p8bkmbvYiH+NvOKx0ECOK9FNZPKHMb/R37N
aVuaq0N/Et9vZsYJQH87cuZtEkqgv42Dmreoo9Bf4ID8vkg55PvKzI51bCu+
97sn1GfjFuyXck5ln6fZ2C+lE1XagkzsF/uUGyJpbOTnd8mPj3IZ+pleJZWV
fRT7JWL9sL2wNPQTbvt2ouE2i/pfLn1CNQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41G0blUgJkSWpsU+JJrtUslS0U7YkLUKRtWQvJmtpI0ZZ2uxZktEQ
URGvQtayZE2EEZPUiHi91/fH9zv+6jrXMz33Oec+z/08PzKn3U0dODk4OCiL
ODj+969R4eTcR98V+sqyG84zzgzp/R8ragYv7y4dJrD8yQxBDrFvBHbZvuXT
ulEmgV8+zhgdbOwjcCTdRrXPjkVgqz8y27610An8W6k9snR9E4Eth6ME/9JR
r0swxVNZCfUW1T/S1KlFPe/8PzdXrftC4BS6GumACeodHnqisM2AQeDqyFIL
OaUWAp/0CTK2c8J+9nFPOCjkfgKf3cD1z/zQOIE9ZMriAx++IXCpPl9toGcX
gfdfyXctE0X9cy9CIz9MvyQw14ms7m9X2gmsE60hK/t6DH5addtsDGiEX6qc
VyeE4McHrsS8jT7ozwq7pvHKB1g/s3eVqrYl/HJl2JOFr0GfXW4+NaYFfonK
Fvi1rQBfA7t9RU8zSwksw9se0s7TQWBNFxfZ7BnwleCUuJZc84HAlbVvxBcH
oP6PwPUhq01Q34ApTpJ3hL8KNdb64RXw1+yHWJdyRQWBg0LYcvcu9xK4PzXM
osYbfDUmH69l0Z4ROG88VfRJcD2BTZ6LmZd+Bp+7xSy/jfQRAhf6fJERYX4l
cAVjrDcxDvoCMqWCr11HPrNmKVKf+fD/h1bbZomcHSTwEUNTS43+UQKn1mV9
p2sjH95p94qCloL/bMJoBVdwGYGPk2ZP8uTC76MdsiQFXfgzfMN6nFu2Bv19
f0n98MUBAm8nk4JOLwX/quhjPl6bPhHYKfSr2e9e8ON7nzrUZAh+r06yaOHL
we8ib3aGvwL4JQw0vCQ7gV+TP01tsxz4/TD4QVucUIv8kC5x9eyDP0Gd2gMH
eL4TuNn/AuveiU4Cq+itzpNpxH63T4lRjGfLCew/lRMm7thD4Gsk6a2d9uAr
VyvRp1mI+aJ5MILRJID+zQqdtFFKwnmp8aIvLTmGfChaZtf5U5FXgZw8jfoR
nJdYqefSD7lRb97Gr0aoDf6YmkV92jMGf6j7HOgpltDDFDZX/P7+HeaB0t9l
EZnIX7IUOTi5Bf27NM8QPd7XQOAnA1edll3H+Rd5ODYj6Q894WL6PPop0FMm
zfWvhgD0SKcKhyfwoh673s+WYQF+cTMsd7428NO3SaS6PcPv0zmTXwfWgV+a
E8UrVxrzanbGxDq5BPxS7VYGl0uD39J/dlzPPYp1Z8/ZssCPWLfX2bub3Y+8
6IWypg21kNemkq3qoVy4X5y45wKafdGPtVqLd5CsMA96pkz6C8QxD6iss6Y9
C/wh1bklqPHDH/eqaZ3V/NBbqZo402oGf44M7rKxm4A/rXGCozve4PfVF7eI
cr2CP8f86CXFwfBHJ8lVUH419La0Kh3scYQf6T/q7MdfYN2nd7jdQxJ8Jab5
ii/1gG+oE3266Sf8aF2fbR9qAz+WLfaSvEgvIPDzycGp3C84Dz4N5w2oVphn
U692bZ9/iXmiZywY41SE85qtsEVQQrmNwL7m258fEoXeK0NWha6dH7HuRznK
zED/Lk/wkAUjuwls4Tz2W2Uv+CqfXPJq6s+C+3qe5GxejvvabFXSJvlu6H89
qxV6jg3972qMJHOOYT9JNbL1TC30H1vSyh5mQ389hSXVew76NfXM5B9GQ7+R
xaacviHo187dyl09h3la2pW5P8se68dqA/b8oeD8Gx7vCGvhRX58nQYnZkfr
CFxHu2UYwIX+epqMC2hzwy/h9L3udyOhbxu9LyPRHfrCak0aNDzyCeyye1vi
DzbmxUoByk3FOOTL4dPZ284OyNfG2ANfVOpR3/xMVOD2avgR0ZufmFqEfL/f
31AzVoV+e71dJa56EPmOKs5KaxlEvRPMfyWrPwCbkt7Iq88Cx55/G7MqGfgI
JXjNGhPw669WuMI1C360kpW/bviBH99RW7MId/Rrz0y30QN+8DPyrjQc4EO/
Hh3Yt5n6Hv5ar2q55fcO919u/U8Zp/Xwt8g4fcjoezGB795a19c90krgO393
BGiz0P/zWhNFUg2o55/V/6hgN9bJPzNKcruRD5FXJo3vDiEfuvLJFi5r3xPY
cakG37LP8N+cf1J4LA36zLPmpdnyyPNNMw3ahWfwz/PU84J4Ffh361kAL+db
nB9WY8rAwDbcb92UXKWRPdDfLjCufmZRIYEvnNpIU3uH81hbKypg3I/9OPW5
zZKGkdffgyLSHSewH+d03/y8M85jR5gP70w6+KvGKvjIk9Hfy/xnf71SwX3w
kdJfzlaAn4rf81zs4j7Dr5Fqb4s78DMi412akV8VgRvnCh5cj4Heq9as8keK
4NfQ+Hin5Q30u+rtBDngAfptmubR6laJ+nbzDa6h3Vh3WXSB23gY62vYTA6h
v8jDSq4I8fnTWBelWq6V00YeTluZRwmvAP/CnQF3DPIxL36lGAwXDcAP21ve
zSXqyLPAQIZf+HL473DG80nlgvtxLrOFWX4U9+M9c5O0sDW4H50ryg5YpiEv
Ha8zqXW86G9xEllniTDySGPsTjhlsuB92pv/basK8jvje82oaxC/9xxNnstM
QH53LdN09PRA/8V3nvWg/0J+I5ghf28kQS+/ayDtQzz0Lvlo01jxGfeJ9ptH
N++bQy+3OeXOn0fP4aewmoZJRjOBU+Xdmk3nF+QtL+TafmXwTardkf9wC/S5
BMlW+dvi/c3rPmksFY/501pRUOjSi/5afXP8aK2OfBjb9pntCcP6pFvWVcUz
+B4kL/c9sYsOf6qPi2yca8J8LVCezP1st+C9d4dng0sT+tWfrshqKYcembsy
2qmV0OO7xCd6qhj7x/ZzaK58gP11m+MOialj//E0hfYvGpjPPIJBElZi2L9k
Qvwo8/CC95ptfZvEv+hPcGeAw3As3vdP7VRO6PTCT/41y5ubpPC+X7xb9aIN
Bf0MZs/slduKftLNKjIKS4twv7iGM/Yt+L5h6z4daF/wfaMYfmHCxwjzfdqU
fD9nwffNfc1YXVF5vN8PZxr+qnfAedSg9qV0yYAvI2T68KccfN/wC2rxn7aA
/rBKkkbUNOrfFmG2ZOdBf2NThbTzN+wXMyV+70kh/p7wenNBjhoNfBUv5z3+
tRZ8SaZUPqoc/p5Qxpr+EtyF91iQl//xXHf012OKEb/lFvIereuxK5uJ/rm5
arl12SIf2xLaOusEwe96q6HNuXjMn3w9hlBlG/TervzD4WwEvRG0kY7KPHyv
C1X5rF+xYP7cLTqvY+GO+fN1tOBxuD7mT19l3P3oF8izoKPTarVR8C1iLk2N
OQW+3k0Koj1C4Pt2+WFyemSd3n/cJCeN
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3s41OkfJYQIWyiaMYnchVy6sFGkJvcQYbGiKWYiowgj41IR1pISsymX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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c8lX0fNiKrbM4hpDIjKqIeRIPI9sjKiKjHrpeMxyga0tBSSkNKGdUx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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0XJkth3owWayhLZY1CfGVLoUZUCq2WbGXpxRejbENaUMqWXlu0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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk4lWsXNpUpyZxdsRuMZc7UMaSEdqiMyViOaleqIzNlSEJl+GTT4ONE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4lG0fVVFItuEzZCkRyZJQWQpRCSlRSUKTImqU9VUSSTFJSvZClj4k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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVmk4lWsblUpKiArh08CRWUQlTpsyhQzHR6WkSHYyh5BikwwVxREhMmSm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41G0XVimUbaYYJEu0IIoskS1CkRTKENkViiHmqyxp7CojL2mxZE8h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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0XRhKidaxpMhWiKeQthUQpUSpby2Qpb1myeyVrlhTeZBcVlRKZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k0lesXPjJLhERE13BuhkSFyHBExc0RCSHKnExxShkyZR6aTkQDEhEL
mRKSXDMRMg/dEFIiqdQtw12/P37fc/761rPed+3h2c/e+/0kHM6aOq8jkUgK
TCTS/77SbGFJevG8OpaWPwxl1g1R/o+zVfOymjnngf2fF7mu7yDwi1mbfFPJ
aQKblb6otJn5SGBa5a1cysQYgcOcY5Xv0z4T+MSTQfEE8WICC7xh/egS3Elg
Df84RT7X9wS+Hx4e+LZlhsAx9Cl3Jk74p38v1DjGM0tgJ7mDOy4Hwr/fmtPS
bDj8r76+HfOXWCGB1x9ofX9u4SWBx92UvOnRUwQeYvY509AE+z8LuyqVP4wS
OHnucDmzDux3+nM5bxR5SuAMa6py6dNeApODy6290mGv7oSNNGf7GwKTtER+
rTjBnuMSTwH38xIC19ZE0q+LdxPYTkxUlbsS/DAJn+Iky4OfD5fGtFeGUZ/x
QAuprWzjBK7XXKe72w3+jH+tzqyKw196N7fs7ttdBOba38uRqQl/+rV5PyUU
Ua97JdttNRQ/ELjoUaznyT/Bp1q1dHjBoU8EHp5RYGH7Cv29CjvJfsUN+jPr
SeCj1DQT+HWWobr6xncEPjfLSqE44v5mz3dDn8ktBO67Pnp5lwnup6d+3bis
hPs6QaFRcx/aCBxE+f3p8ddJAseKrVHqIxHv5Ilc3mCfQdTLMOL2YsscgbNm
6ho1dcFXcuvdfNUP4OcFa/bWbX3AvvyvBbYsA5c+4FWSLAJmMVXJ7NMF39dI
KpkxkjgXbFPkvnAQfNvO9+7tZoi/oONZ2h2G+OkcTD1+NMSvqzNocroV8U+y
tFRIURD/dIDJQZVp+KMP7yH9Ggbm4m/NbV4Adt5b1ni8CZja8nk4QhjxG4sn
tnVfxPmp/moPUj7Oi5cjHUX1od+rfDoCokXQ7+m8VbnFi9Dvg5Arbpr60C9X
slF7jU459JC0ydaLHf23/+Fit5wE+q9Kd5SPZIB5kR4n39UQA3uCJYOdN7/l
E3iJ7fRa+Rz0wipBTx76Dr43H1tg3hYOvhNZbAXbwsB3Wnx8bWgX+H7SxHJz
iAd8i99ZNuR9Cn7EHVRti1TAT87ESrCqFs61tdVtVDaj/ils8jllJ9FvkmZq
I9kryLeyolXrec4Igcu6Ttm6LKEffvfQuXzzXhD4mxypNdQa92996VxgGsf9
rV551H94/ybwxXHjEJftmGdCH9ceOxiCTx7hyPXF9U8IbEj+NGWd0UNgk5VU
vYxe1JtdbscRESHU+0kCM3ejM+yxdpjtpz3EvOo5uLCphAvzMa1atq8lG/yd
lt1H1TadZrB3X607Df4SC8/etXgIf8NB+jzdKvAX9YYSc4BaAfsaz2RzCvoI
7K2z6ZiYHuo/krZApnMME9h/nM4WTQN/haZe5o1UzLeddtQm/9YJAsfZpdtT
buF+gkO71F2jRsSXqx+tEIZ4XS543x3WQ7xrmT1Z9GyGfpiICthjjX4oGqzS
c7SFPs5XTL2S132LeeYdGDsXBXtmLbrRxs4FBLbqTjqkYIL9mSDg4tCsAP11
8J4/RNECH7IOdulr8uDDi1tU2yUE+Vlx5Q9KJjUR+KbuNn1Lc/CRNBd3PeIt
7oul0brKydCfTWWxx/dD0F8ae3JquwniFzkToGjxB/QXWWUafUQU+qvP779p
7AE9LIQ0RVFl4N+jOz7X5yf8Xwj+7CTthX6xkjFPLFVAv3he4Hyz0IP7ocud
wkqdiDfSPE6nV/0fAm9UGLjgw/BeimR5niIqjfeSK92pYioa76VZX8vobg/M
A6b7QYlKtdC7294ujwZR6L0g1tteZxH5/W67ZpfWjPknqRV6T9AP/if1jjsp
+RUR2Gd4X7iv/SsCr7c3lFvqh30JmRqr5GbMoy3vrhhY1mH/LvKn1oV1YP6d
8Fl6pCWF+fdl5kgM50vkY6JGpYfzIp8t3GybXsTi/NC3/fnDcTgPEQwoc7uC
eES9/TK/6iDfb67s6Q23UE+ZGzzm/U9Rn6s/Xe1orvWoX8PpS1wa4KfyuenG
W7HgJ7+y+EZYHfZD2/ydutm/sR/i9hlZt45iP1w6xT1/PgP9cM+r/mhP4wD0
o/tuLMAX/Bwt1yrOoL2G3if1vacnwG857b21fCj4bdoRv6eMA/m03HOuMhTB
+/0VbV2XmRz4iYpIKlEfBT8OgVP2HeswT5ZHV66xuSNfHR8l9TZWzNulJCn/
kXDUT0Ql+rq5DOqRns5sT7ZEvWIFLyZ1TjG854OXcr+1Yl5o1Fj7KrphHrGo
1Qqb/UJ/XDgRfYyN4T2fwz9vJ2OG97yB0+jC9j/aCRwvtKtiLYNhH07LHXd/
APuRdtOPZqowL5IC5kYyHGD/8kzL0WyWUuhf8otMtTX2S9jZDt+mz8inaeVP
Ht4y+Fu5vM1iVyz8KfoJy3w7jHzmJYVu659n2C8lde/kPqHfhGxuKP0lg34P
3jLkWKUJPvsUFar5haAHjn5yX4MN/Mtl+sSpkqA3nx8C8SkpmE/OO2OSjy5C
L/++sVly5KtFv03V6F4pxX3bYVJM/L+4f+36AnuWEeafpntNTrgg7u/1zI57
3I77irIRYxLqdZiHHaa5053gg11Zf0IyFHz4vj93uY7lMYGlix8t21eiviyZ
NMr378j3Gf+evgA58J3enpbjtpNhvoW9Fd0XB/uXzr7M176L/t3JvWXn1XT0
b6M2tYmzFf3rWJk1O18BPkP8eHeR96B/BbJaxuJk0L9s7hJhRu7Yt3Qro8X0
M4gvKojsGbiC/D+OO4+qMerbwpkmaAB9O+87U5MriPz9/9VM3X0P+aeG+lec
z4P9bIn13PUJ0LfbiLL8pxOwf/GwId9aJ/TNk7khtpkF84Z9E9mgKhL6Gi5+
Jr96EnwkclgM3FRCvlz5CkYSe5HvtjLtFP4DiEe1gX/EuhPviyGnsKJfDPXI
ndQ7RfZEPUx4SyZ2XEQ9AkRzyTXF8N80NdAr3Yt6JDkk3X8V3U/gfi6qhVgL
ziVW2T2qenCe0lzWXf4V55sLjgtpvMB7bpG5z2b/EZzPb6/JEW/E/+pXWuZ5
RSvoO68+KtynDP+fgxkuPzfkYD6nZvwW9poGX2M/QvsUFrFP9ytYbz4owfB/
dMewtlAf/C+8fqPxfB75V1M9WNviER+7WLOAHhX/G+4GHZm0p/CnJ3XgyEAF
5nUC34BqvDXm19xqYsnqF+yHMbVCq/zb8G96oH5yVRH+S3aVPJFygP3lnU12
Nxahn6BLvzbUGmK/XMnWGPIIxP41Pjkn/akF/Gk3VNOZvDEf9CwtwreIQS+y
ynFZfJHQi4lERJDwQAHlP2jZhM4=
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c41f0bll1WvCqStzTeMhsKGSmRFdIQp6zKTI5Uyki2jKRE0ZLOS1Zm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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41GsbxjitnHxOkmxZskdCQllStowkkrIvKWsl2yEpY8+aRJI1STKh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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk81OsXHhJpuY2Syprkmm7qJqVNSYqRlCxJKipZGpIhS7YhN6JyK3uR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41esWRoYKJQ0u50i1zaFc85T5dkoIOxkyJcPWsCVUhESSdiVTGbZk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0XnshWylpEphQVKkN56yUUYRRKyV4pjYREtFhKyDRNlhCyC9l3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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVnk4ldsb/VCIcG8lEcWVStEgZEiIZKiDRHJpOEiGooylXMpQSDJkjKuk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k41HsbRqqTLE1EkUFJhZSQNZGUFHptlWzZoiZElmh0OohJKPtWQqEp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHc41m0bfpSd9SCjYWSW+F7Fm7IqI1JmlKw8Vhmp5xWvJBkvGZ+RJypZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41G0bnRj7XklqimTpqxRSSguGiF5ZCtkiRBiNV1F6FZFspZSdCtkr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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41F0bnuyypgVJhFSWSNkilLIl6h1fIdlqaFpEUtpUtGhRyFJvyVK2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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV2k4lAsbtuRYJilKixZESJZjX7JUSFliQrakJBMhQnSISIVIk2xZs3Oo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41V0XvXorczJVRJFZKESXcoVbokuIyjxEJIRSlFBEkkqGCrmJkhIS
MhQyz3OmFE2SIsVrvOV9vj++37p/3Wc9v33O2Wvtvdc5V9zphJnLMhKJpMhC
Iv3vN91bi6M3jWdXe12PZbZjr/b/8ZOMaQPjw+MEVqXXddB0uwgs6Tq4q54+
RuDi3D8+0bkfCJyazfC+aPCTwIPNOj723IUEHm1JUWcbx3632o605276TuAO
QS+FIJNhApsM+OsV3sN+ajKPTXP1Mwh80Svk34K5GgJ/FZk81fwX+Qj0C0YN
SWE9RenbimqtEgKPfU01tTAA/wnNx8bUfeD/4rJEh+xt5BvQ+fly0Efw9/4t
JKW2hHzTr5OoLmFM/LNpw0/WZhP4ppgtrxlLM4Hfcz1c9jL1C4FFf8camRZB
jwaliIiMA+/AR67azeQ49peao2iwc+YRWKurk6wU305g3/gv5Lx9owQ+Xsv+
2GPTV9SzuazikOU3Ake5J0w79Xwm8Ii+auiJ8h8E/j6sTd0rAr0KPYtdqlSg
lwFLuROd3E3geB7PuaNW4KOcaK5veHyIwHdFE0s3p4KPMccDhwObUd+wpaR/
1IdQ394ytibyBOprx5KYMqaI9d5mW03iaMUE5htYrzF0pYfAfjnseebD4PMn
QO3Dj334HrlRzXh1Kb7r/Elfat8OvgVsEzLNOuCb9OxwsXEP+uNfP4+tWbzg
y100S1EJRn8sNxXyYk1GvlbXLI1m3B4R2O2+Q/4aRi2BZwsNKVsefIQ+KfRo
n9oJAt9TrMy5fb+SwLpvJGlugdBX025wsZxJX7K/Y3w4K/SlFnfOs5RDX2v9
SaUd/dC3QN4wuGg71tNDJ1u+SRUReLru1Nsm+hsCXyG9ebDbBPptL7l3+0dz
P4HzNX0qu04i/zIj+7tWtDoCr5vULOvvBV+Vw6pk/nTE21MSpFwTqgncdWu0
dloA+bbW8na0BiHfvf5NdpZeOQQuFVg75Lm5BXyWemW6qSMEbmP57exVj/l+
FKbOy7Ib+785GyLa5439TddJcdKcnhH4WP32XM8VmL9q8xAPSgXmbeYQvfWv
OuZxqCwu9TEN35WSw8gMbsxj8NS+6cYL8IcRPolLhp/RX9TTZ3xIBwYJ7PrW
SG6WjPyS41e+8iWhXiSntxZFF1Cv81qjXcM7Ua9hxzhuuu4A6jnbwKZNh/6L
PWmfdQehv6gjV2imHvTx21mYr+eD8z/oKz49bQF9vDsc0r5Pt8HfOxeEjxaA
f0FyRfgLJr8yPJnS4MjkVx/mZX66M/kVp1LWPXUmv4q3vx2azuRXGwrGNBeE
Mb9HWGZ6OZn8yo2fbYKmBb8yul670GILfT2tGXlKhzFP8ltmBryZ7qNzUful
fQ9jntYOvKDWsGJ+O15zM2LY0M8mon5TLOJYf4c8ddSjDfeRwJ7XNRdKke/a
pRg5hQjk63XQdsUiRyeB59kDxGZToEesGblfWhV6jNd75lT6YX2Yk6SRRDDW
H29l/LzEgn6fiD42zEf9BL2amuk2Zqh/s8dzETfZBtzfjqNj1gzEx7ANXlN+
ivN+nfSINeLsILB0soZRdAnqO+9+Z2qzBuZPqElm2HMA+cTeDSUPM833eKKU
STfTfL/UEYlg88R85698l28gj/nmK7OZUGea70H6woJjA/afUuZ+fkYX+9cE
ywmnMfXvs1/9joKG6F81DqEqvw/o38U9635WPEF/JlF+TXHZgd8aw+kBOgPn
u03TCk2SUC9PiRy3rh2ol0VrlniRB/T7eDOrhVyKeuXs5inVUEX+PY3u5Kk6
9Jd6ntILsRzUy71Jx1F+porAvLJfdAsf4T5aZc4QEkoA35msr9G9PZmo3xFO
LkvdegKH73ykV+CNeoetfDdtq8jkD+WFI6nKTQR20Uw6NqkA/9IecMo3M8d8
7ucX8tbOx/1ASlCspbljP8kakRCzbtwPH8d9AhsVcH6mCpvbF2fEf6OlGhqI
I18R+mV7BxvEL+O5t8qPgvg/VvdvhOg0ws9k5jIz7qMeVNFNF0kM5Huha4CH
Iwn+6Rf5Yj3ZCN/dl0WNBw+BT8BQ9NjIWZzXZ1T1TPYr/EGlTezl6C3UL4Fd
eJa9DfErNLec+iiJ+73oCWMbpek9ge/6fz9tcRv1Oxu0d3GBhvo1BsXMP6yD
fuatN2g/JKFH/KJOKMdxnGf5ymfodQPii2viN+yQRvzG6Gm+lUz1GaS3y+j2
Id7UpqloxxbE818VXJh3QvynE3cS7uxEfVwku+IVPRFvcunqF5utiA/Y/qkg
hRX9VHBdX2hJAP0kJHKC+tQX+p/48/P0oYU+AkfU/XRtFsV+W60Fjx3lxPub
y8Vg08EM7Hc9KHA+JBf+P2Sy7dz7ELy/d9gePRLpC703GpvFJinBH1Zqmtv4
5MEfitJTFa3j4A88gdRG6Svwh3rZ6uv+9+APOt2/I+3UMd+vzzu0Lq9Af0hO
p5RezQef5xpZtkcyMN/OYuMXx30x3wfV0m+cvot8U+IDZt1W471pwZgM6sxC
P5YKsvpX++I81r9BDUojOI/iEXp5vr0C97FU4z+ZH/H+OPR0wmL9IZzHwX+e
M9knH/MaMykReAd+5vqtrMtjLfjK+7K3P+FGP/RTxrkGAnH+8SqOlJ1NyPer
5rM9suHIV/5Xkx51APHlks/UKSGvCfw9iT/BfBj1XFOivEU+BPl6RpakKK7H
fZJQ38Gm9Qn9MpP46UCXKOr1Qedzwabl6BdBOc4EqXTo3x7rMdrN5K8Saevt
72ZiPm8eqHskJox5KFpUkZ49BP69i9+rRHTBJ2/DxudL3PCr0Nm4/ith8Cu7
ljwt3g24P8je+oHa5Xjf6HP/VVIrQb4BcZuXPd8LPQyVBVzPH0O+Im37HzzQ
xf/L4mqRA3bVeN9m60klOvmjnztfrTLqrIE+HlHsRqFzuO/KN9RNmVqB3+M1
HO/kdjHx876jd0YO/GbaqoTpceDX+I4visEJfjU0g5At2+DHrVSR1cPs8AMB
FnGz7FNvCSwe4dgTTAK/EZ/wdaO3ygi8J0OYbH8f71+FrEkV4Qrk1zKTZiy7
BD/OXdYhd/8P3ocPIyff9aRh/4uG55xMwx8if1axyhRD/N/iDydH9V3F+6My
Iy+rlWl+VOdctK1tMD8B7lwrOiMwP9aevM6VbJifzeSsB9Iq0LdgZ8lslgPy
P5I3E2Rqi35rdm4rpVxAfOivLm6FjYgfS4gx1ZiD/55ep26flQy/zAgUbrEs
Rz+dPdG55q08+mmVRUqCvTP4kPr2nzr3Hv1UmahsJbwX78NyB38v2m/0U1R4
GodzOc5TSq99nnQN59nOq+9J13uv/R9jpXeh
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3lYzF0bbtG+CSWVMi0aLUIp3qRVWUqLirahoiJmUkPSRoUWS2/iLUNS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41PsbtUUokWwttNCIJJUlyyVXpCu6spWdULTJLVuyRLQKKWNJN4Rq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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41VsbFSWUJGS6JEMZrhsqDcKRVMaKKJKUSB2cDJmdqHA+p9LBJ0Op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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWGk8lVsfPYUMV+akooGQzhUJkXJU5ihTdTJmToaTEhcRQokiqYx1UiQc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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk81F8bHSl7CC2WSLafSouEyhYtdpIthUgqYw0tkyijlBo1pbKFhPpZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJzt0ltQlGUcx3EOy04UJ0kILRzWQA7jAjouKJKcBgIRHKgQNKFxgVAqGxZG
DgNSEDKAoECMAoIiIhYyYgZhWJxknAVZIhaW06qQuxwHSEFmFGm6CP6/57bb
vXrnd/Gfz3zneXnHTgZGaKipqfHV1dT+/Y5fK2k3u6Xvapn9W3su57HLf3vQ
PnTnlltza1spy3/i/P3VtZ1zODo6qap1beu0P5g0zn20tvuan+7Nq12//3la
VK6/tH5vv9rR+vz1+v3TDYLkceJLj/pLTInfE+I1+zHxe4seRp0n/tHC7vsC
4j//7JDROeKHvnt3ZGhx/f4Kp6yonfhf6Q0ttBA/avjIC+prp0Xu8iX+CufX
9Ezix+656WtN/IIu0T3ar1v1hv088Wem+Poy4gujJakS4l9fPaCkftYHLpsP
Et+21N0oh/iRvA8P2BK/Ka/uMfV9YlcqlMT3cTnt2kN8rqHOBjHxRZLWWeqH
CSWZfvT9Myyqsohvl23ss534Uo/0Xur/UVz89jTxg3Zkhv9J/OqlWdcu4vcL
baapn3vK2Maf+IlpFXuyiT82aWDCJ35IqIOM+kbvS+omiS9XpPJ6iT8hXwnr
JL5ZvGCG+p3W7pO0/7BDyGvary4Zbaf9jm4zUurPmXNdp4gvmgm5Sv2ev6Pu
Uj9yqxj6S58d1KT9C43bjWn/cIGfgvoW3QP91Pe4I+dSv1Fmc5L6DYmGRdTf
57UI/q69A8u0f0JwUYf6Z51HZdR/c2sC+BWfDphSf9nUPJ36doE3K6l/Y24c
/JrLOivU5yTHGFD/3qyHnPo1tuXgv/dXyUbqq/Prk6hfXt1dRv1C5RT4WqVH
XlI/PEWhR/1wgckI9bvG88B37gowoX5g4qbT1K+5YHOF+iWbJ8C/Xan9ivpt
177Tp3597gvwd2sXgX9Dq8+Y+n2KpmTqh8odL1O/zWkS/B9vt0H/L7We4DeL
L4E/eK4A/FdxX75Dfb9V7xTqu39xEfxnHdjvJnkE/oowDPwL8hbw1fMKwZeK
7cDn1BmAr+EYA37KIvob0/rA36T/CfhjoT+BP2qFfniBN/iyAEvwxcvfgC8e
Q3+/7iD484IQ8KN3NoKvDEDfoWwf+MFOW8DXq0wC338KfU+nAfCHsg6Bbzhc
D/4JN/Qjy9zBj3/CA3+3XQr4Pkr0FYvof+0QDP5oZwP4Ot7oR2i4ge973Ax8
L+tk8FMn0D/+A/qfL2D/yxPoh3miX1yN/lvq2L+Qj74m47c8QN9SF/tnz6Mf
68X8fxHo17Zhv0MU+gLGL2tCX1cD/eBv0ddi/I9S0fccQT8oAX0e48e3oJ/M
RT8/E/0djF8Vh35GL/o5MehbM/6Z39Fv4KBvlIG+GeN3JKC/vx99fhz6Foyf
2ox+iRb6QWfQt2J86Sn00/vQnxehb8X495n+OaZfyPTzGD+T6Tdk+rWY/m2M
7870H2P6uUz/NsYPiEd/iel3iUXfkvE1Gd+K8e8w/eaM/5DxI6Xon1X5Kl/l
q3yV/7/8fwBAV8e+
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lWsXxtmESpKEnSFKpDKVEmWscxQKlSgpVEhsVKQodCqzUhkrMmdI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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41VsXx005piJDhpsc1CGKQmVI6CglFKUOMpaEiuqWm3BJ6dYr02Ms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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41V0XveR+0s1rKCWZMhTJa0iINJE5CWUImVLXFBKZSqEiJEPGRJKE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41VsbJSlEyaxBOpSZzIUGFTdFGTJeTeRSIUMiolJuqJshEY2Gg3RE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3c81W0fPsgqcshbVhINs+yUSFpklRWeQ3VOhYw8RkhllZV4E0qUrJSM
IqKs7BEV2VJkZRfZ8TzvH+/vOn/5XB/ne9/f+7qu73Xfv63US4bnGUkkkgwD
ifS/vxNXDyhZveHSCEwyn3WeGT7wf+yqsitFoG6AwFqefeQfEaMEfj74auSm
Rg+B74SVsIkmThI4br+RhgwplcCBIdf5u6srCcxztsT47WgvgZXdugX0j6D+
27rGJbe4PAIzt7MNmTp9JvBnFadKqWj0o6XvN9Mgg35sfKnC5MdYL8KUw/2q
D/o55KciFKBaReA1PpY5i8p9WM9t7d1CYdQbMx37EL/jLYF3/a6pTyK3E3jU
6EfQZNU4gdXrKByHbD5iP3tbplY58Pv4lG9OifUQgc8uVb51n8D/w6bLyZZt
4H8dWZv83hvntZe+INmagfNmBtMYAtPRrw+DKmPPlWQCO85WsZ++Xk7g6ObJ
ahvqNwJnbx3+lZGL+ljprDGdg4kEli3jKLJ0fUfglRC2W179X9BPiam+2D3U
S3R75k8/fUbgLNN9vtmSNdC78UHN/KXvBJaSEhX3OjRB4OGI/NPynHUENpV+
wJAZ0U/gmaBdSz2i4Ns5YsW1LBP+iLWo07MrA18/lgUfFcug39GHRcKqXuiX
aSX23F7ZFwSeChAWNOJpRP9yJleffRgksKTG2tFLiz9w/uPMN07RcJ6s5p1H
JPVxnsZz3i3f3GpRP96TxrIX59l9TyPnwQ2cRzhwv8M6iSYCW/9818xfj/3G
WZ5pmLZhv9nIztT9g6g3k7A+wCn2gcCdt8JvllPgtzNsH8siGLEe29fDc6lp
8NuqlXdReAn4o1Rk2p9XB3/9fXONgtfBn165iHl2VhaB1TQra0ieDfD3MV0H
ynXwd/Sif6u3zwj8abiGup4L8+eqEfO5VwHrq2d1mfal5SN/NLny+vlbobdY
4uzWl2ME/sVnujAe0Ebgcxae3WM+4Odnn3R71kHwu8NRQEviG/h4bOlouZoE
fq1pmS/b/gM9B+Zo12PC3mOeNshknVgFf27JfUkyR8Dfer9Alsz5rwQuklQK
pbzB+fpiJvZc3JwAP3jfUP59oRTzVxG6cPuvbgLvcbz/SvQk6oOOTD94rpRL
4IBL/8qj3Yy8ZJUxtc0H38bis84rXsjfZ2yiipdd6daLanjTtUo3D5ZVLlke
8NOLncOVYkHw0zzjowmfbORXg/7a22csoLesy9P3dQXYn7NlftrQA/ubufYp
NrrR8RGxU+15K/ZPDje80yCH/XM3xDsdPof9Vc3TlDvp7i++OFcnpVrosV3c
rF8uki4PlrJrd+xFfvpn200ZJWD/Grkj+zbK477QifN36p3B/SX0iUISZodf
V0J0LAaUUV9qGHRqxQB+zfrN6rnmUwvug7eW+rX+8GuMbrCcZiLuE4OmTJGF
dfBb8IN3yup8mKfLd0JYDY+DXy2OxbHpJvCrTvVr2qIEfguMlRkFQ9Ff9B2L
GnHDdAIraJNdhgKQt5PpKU9qOpBP6m1z+5s/oF9ZnRijwQrM34GptRPXNmK+
VlLD9+xbRR6zRTYUci+C/8n2M10nB7sInG6dVMiohP7c3nU4dwWBv7Qusc9J
K+DPinRFzugx+gn56cFjO4V5N7AI1p7NQz/R5Symm1twH5MuzzNGxcAvO8N7
nzSEg8+ZQe2ho+fAZ37DsrWYGfR+c7dTlMSBfjt5ttSynioisEPd5tjn7zoI
7J6pXih1E3oOmbzY0ELD+yN1R7oi00ms/6U1rGczGeu7PvUp2t5dSOCHmi4/
A2l062tJLKafxvo3gpq0R6/ivvXJ8cz2TUSeRVs8btu9Cb8v5CilNHkhz+wH
qmxWZjA/ew1u23gYQ796Vz0bpiTk2QjvGj3DAvQ7vq+u7pgV8qz09+uyqUTk
2YDpDfv3OcgzvmBNqtA51IeWcvwZn84msPlY6mTghU/gI/9nWM4W5HWfSRSH
nC36Zdt6+qITP/xhKr/wVFAKfnu7e0pcgYHuvdJlb9lxv5jAFuncjBx5nQRe
ajq0cq0bfDl7++aN2uE9VP/fRGvddtyPurQF88AorK+iNWziyJGGeezSDbfy
hz67dRklXZ9AH17PWt/4DdhPci55S3QG9PmY+3JOlwy/pj/RqamVgj4q0vxS
vzXxvqPqbwyTz0c/e9QmbC2ToQ+596J7xnfoU2LDaR/Kg/MIOsovUS+jvuA6
T1tHBfKZ4lNQIbgB+fxoG2t0kjHy+Zd0u5kVN/Razxla4RsMvYRe2NHujaN/
Rm2rsoOy8IfXX0KVosew/5zvtUeM5/F9cCyHFsVyCHljsjx0ws0N66nqR3On
DyPv7fI8MsdeYL0AEX+3M7ZJyC+p1T0mN8oInDLqYaZqA79XXesLiHyN+rx8
41ftdeCzXe0+qxwr/OEvbF9tcBR8ZnCKLLh4o54y6M7Ea4n300g9Y6K0HPJ+
eJvLnZpT0Fuenxz5tQj5xKOyXc7dAXnPvLvU65Un3fvJa68b12no9cJfn0qj
4X27OVnLj2cR6zucie2afQm9Ni40M3Py4j6wZcjlT0lDvtaPCDnliWM+UzZP
JhgMIV9pGRMNu4agNxMDk12lDfSxmGAKiZYFvwXVnw9L0H2PdD3znYs6i++R
EIlo7k0R4Ld8ladfhwv6jiZfHfGNQ/3DhmWbfMpTArOGMS14MFTjvPHq5r25
yF/N9TFrj37C/Fn2ml9eIsMPMxdm575UYD8RHiFZ80zsV/X3olIyO76/diiO
T/3ZiO+vwcQs7UYBzOfRM+t2MtO9B1uNvjrnysNPp2+H9qVewXzeTxltjfTA
fHDqKLVFnaK7LwziE2L/fkVgRw1n5jdP8N5duqWvsKgI/xgpVGn2f8T58x8K
VVcW4/zXevhfi4ig/zxl0W7xrej/nqrdRAtd/k8IpKQqq6N/n6NR8To30f/n
3sFAtSD0/6fg9fdFC9SvSfhWrLUW/SvFbrfyOoH+KS5U2cIx+LNJk11s203k
p71ax6Z9cuhfuDv6ZO76eswf/3IRWRx+PFg+L1joiPviQ38xu9M23K/K5q00
syNYj7egyrn5F77n5qX08nf6Yz7Eg5O5LBTp3kPSr4rj9yOfRkYNZ+qd4P/E
UL7mrUzw/3QzCykhG3yodvHvOr4K//9aGG9kF4MfLzrQwm/1wI8D7q+V9tHl
m17Gid/vIpFvrJxdRdzpqL8StumZ6GPs33Jx2e0gnZ5Ugb6ps1ToqbSF3+Dt
E+ipzqfjRymAnvdzbzmpn6ebB0rCBrNPuM+3r1C8dbWRF5S7Vwt2MENPd9U4
hYFk6MNLNRFIqgZf17gDvXW5kKcjUcVv6v/9fvgHNYSdDQ==
     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41Nsfx8c2iUKLpWgRTSHdNteSrShlaUGKjESE0ki62aKUsjS2UkpZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk81dkbvpKMJWIINTGEFBnbdSOyNFpQllS3uIlJZZmmUnQREpGbRo0l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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41WsXJZUpYx1kaJQGQ8iNMp6LSKXBUCIJlSkU5cRXhBDlZGo4yFDK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41PsXxyelUrIrESJCZUmWsRRKi60QhaKFSnRJ6ipUQhKRhBRZQpgp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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41F8fVdmTolDI+iJFJFHMIAplSYtJJaJoFCopNZQWPzUqoaIikkha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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNlnk01WsXxw+RotKl6aQ6laGSITQgUyJJdWWqUw6hSW90S5QhUkhkTmbK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk81OsXxydbRFS2W0r4hVSWEFduixZFxeQipvCj/BqJqKQYy50r2XJT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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41ekbxg9tJ0N2DlkLLUiJURhCEsrIWFLWZEkiaTlyHBKTlMJkSbYo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk41GsbxxGlkRgVWijk5JgsUUKYoZJjWhF1jiinErK0yZJ9CadUpmxF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41G0Xx8eSlIzUQ1FU2qhMj8ZSqldKL0OkbIWpbJFSqodClq5CWQqJ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k4lG0bx4myTAuSKJGlerJFhUrxFBlpIUKKUshSiJ5UPGUJZX1lyZ61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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk4FNobJromiRsZe8hSkiLCtUSWylaEqJChUdlSKiJKQkWJMkrIdist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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk8FFobx4du0SBUSpKsbdaUJRkRuVISylKSa7sVErcobXblUm9CiiLG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNWHk41G0btbvKJGo+e5skkZIoSUiypUipJLJEsr+hIlt2vaGQDIlC8tqz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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81VsXxmlSMkQSIaRMiaSiK/FKOkWmzLlFVzJnyjwUzjWEIoRTcrgo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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lG0bxkVCiRaRTElJlmQrlTeRpbIUUW9ERqJUiqJJ2T59tlGkZLJG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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl2k4lWsXx7cp0YA6L5kqU6ZI0SAytsNGR3lDKbMyFIcyS0qUSmUmp2Tq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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNVns41GsXFeWWW3IaxyhJLrmmXNKNOIpKJRRFSiRJJzlTc4R0o4+UptyK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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k4FHobHTSkskQqWSOStEgy1B3ZInEp1E0NUpZU15KypEuMJHuRpURF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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lG8XxyeVIsKPUpFkiUpSUipbKqWyNJZeO2EUJURkkK0kW5ZEizRa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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3s81OkXx5GRW4kSNptE2RRJkU2uobSpXFopK5HLIkMX2TIocgspQ5GS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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3c4lm0fx42iQXiQUqo7yijZq8LTMpNVQhndKg0hKpv0qlSKRLeQ7HGH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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk4lWsXxrVpEFtfOCFJp2PK0a59CA3snEoRDeLkkEKoTNuQuVLJkKTC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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNV3k41fkXJtWEaQwlxpQtikKkwkRaRiiaVkslS66kRAnZkuXaUiOpVIZE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81OsXx8dyS3aKUEm0b4QopeyEEJNwNaqbJVKkSPeirFENEqWSGnuX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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k4lV0XxkkoUkn1ppdGZKzI1KUU6hgOQsYiCfEqCektkVBkyIcixVGR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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81N0Xx5GnpB7KUglJEhLqh1AqSxmaksqoREgySihKQvVYIlvisfZE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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41N0bxifqzZKIQpIlFC22CRXZQotJ2dpTIioySCVkCWlF1lfpLUvy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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk81OsXx0mytNJNKTt1Q4pKITVIi5RsoVFxK8kWP8SgNFIkIiWhK2uZ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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41O0ax8d6NKrRlN6XopSjIqmIpFIRk1LRRshSaqpJ8uKdIkvCSylL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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNmHk41GsbxwenUpmSSCk6RgZ10GJPqGxRZDmcshZKGRWRpcZSKUXKkrLk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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81dkbxxFFKilbQxphrmRLKjOI0OWHImSpSVxKCCFFZCzZZc1Slkii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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k81d0Wxg+OECUJIQkV0WTKEB1kSoNZUjTIkIxliluSJMOrUImuHDJV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     "]]}, 
   {GrayLevel[0], PointSize[0.001], PointBox[CompressedData["
1:eJxNl3k41Gsbx60t3tIYS52UDtkiraQiZCktg0pRkqUhoiwnCXVCpJIxpIVs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     "]]}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{
    FormBox["\"r\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{2.9000000000000004`, 0},
  ImageSize->{683., Automatic},
  LabelStyle->18,
  PlotRange->{{2.9, 4.}, {0., 0.9999876051648642}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 CellChangeTimes->{
  3.563270525256143*^9, 3.563270705116151*^9, 3.563306342332736*^9, {
   3.563306444439713*^9, 3.563306472476172*^9}, 3.563315217174684*^9},
 ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<~/8.09/Logistic_Map.eps\>\"", ",", "tmp"}], "]"}]], "Input",
 CellChangeTimes->{{3.563270311401474*^9, 3.5632703363088627`*^9}, {
   3.563270385198756*^9, 3.563270390212275*^9}, {3.56327043668042*^9, 
   3.56327043749321*^9}, {3.563270467641036*^9, 3.563270469862651*^9}, {
   3.5632706903225327`*^9, 3.563270726914249*^9}, {3.56327089592803*^9, 
   3.563270897781486*^9}, {3.563270940337008*^9, 3.563270954126998*^9}, {
   3.563271087320929*^9, 3.563271091527535*^9}, {3.563271371872592*^9, 
   3.5632713744297543`*^9}, 3.563271430846671*^9, {3.563271470889688*^9, 
   3.563271471477976*^9}}],

Cell[BoxData["\<\"~/8.09/Logistic_Map.eps\"\>"], "Output",
 CellChangeTimes->{
  3.563270325377022*^9, 3.563270400277638*^9, {3.563270452045285*^9, 
   3.563270472339219*^9}, {3.563270722031703*^9, 3.5632707409279127`*^9}, 
   3.563270898815549*^9, 3.563270967963675*^9, 3.5632711062842827`*^9, 
   3.563271389118495*^9, {3.563271445183084*^9, 3.5632714736165648`*^9}, 
   3.5633064808808203`*^9, 3.563315231177437*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<~/8.09/Logistic_Map.pdf\>\"", ",", "tmp"}], "]"}]], "Input",
 CellChangeTimes->{{3.563310302982849*^9, 3.563310303883568*^9}}],

Cell[BoxData["\<\"~/8.09/Logistic_Map.pdf\"\>"], "Output",
 CellChangeTimes->{3.5633152548167543`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{844, 919},
WindowMargins->{{Automatic, 30}, {Automatic, 66}},
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (February 23, \
2011)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3563225260-1052472"->{
  Cell[962, 35, 718, 15, 39, "Print",
   CellTags->"Info3563225260-1052472"]},
 "Info3563295328-3925509"->{
  Cell[16900, 400, 1945, 32, 70, "Print",
   CellTags->"Info3563295328-3925509"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3563225260-1052472", 3816229, 65212},
 {"Info3563295328-3925509", 3816337, 65215}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 238, 5, 46, "Subtitle"],
Cell[CellGroupData[{
Cell[842, 31, 117, 2, 27, "Input"],
Cell[962, 35, 718, 15, 39, "Print",
 CellTags->"Info3563225260-1052472"]
}, Open  ]],
Cell[1695, 53, 553, 10, 43, "Input"],
Cell[2251, 65, 2393, 59, 103, "Input"],
Cell[4647, 126, 1659, 43, 103, "Input"],
Cell[6309, 171, 519, 11, 43, "Input"],
Cell[6831, 184, 525, 14, 58, "Input"],
Cell[CellGroupData[{
Cell[7381, 202, 368, 10, 27, "Input"],
Cell[7752, 214, 6974, 122, 243, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[14763, 341, 822, 17, 58, "Input"],
Cell[15588, 360, 704, 15, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16329, 380, 197, 4, 27, "Input"],
Cell[16529, 386, 214, 5, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16780, 396, 117, 2, 27, "Input"],
Cell[16900, 400, 1945, 32, 70, "Print",
 CellTags->"Info3563295328-3925509"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18882, 437, 1054, 27, 43, "Input"],
Cell[19939, 466, 313745, 5299, 469, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[333721, 5770, 801, 21, 43, "Input"],
Cell[334525, 5793, 1608338, 27141, 442, 1548720, 26161, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1942900, 32939, 1118, 28, 73, "Input"],
Cell[1944021, 32969, 1870431, 32194, 458, 1835608, 31621, "CachedBoxData", \
"BoxData", "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3814489, 65168, 647, 10, 27, "Input"],
Cell[3815139, 65180, 419, 6, 27, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3815595, 65191, 180, 3, 27, "Input"],
Cell[3815778, 65196, 102, 1, 27, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
